(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    461051,      15061]*)
(*NotebookOutlinePosition[    461954,      15090]*)
(*  CellTagsIndexPosition[    461910,      15086]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Symmetry with a High Order Multiplicity :
 A Simple Sextupole\
\>", "Title",
  TextAlignment->Center],

Cell["\<\
Version 2.0 , November 2000
P. Elleaume\
\>", "Text"],

Cell["\<\

This example has two purposes :
1 -Show how to build object with symmetries which are not a combination of \
simple mirrors. The example of a sextupolar field is used .
2 -Show the use of more advance features of the mathematic programming \
language to iterate a computation over different geometries and/or current \
densities.\
\>", "Text"],

Cell[CellGroupData[{

Cell["To Read Before", "Section"],

Cell["\<\
In almost all cases of interest, (undulators, dipoles, quadrupoles) one \
combines symmetries of order 2 which are most often generated by calling \
either RadTrfZerPerp[]; or RadTrfZerPara[];. Radia allows the use of more \
sophisticated symmetries which cannot be reduced to simple mirrors. This is \
made by using the function radTrfMlt[] which , starting from a master object, \
generates a recurrent sequence of clone objects.  Each object is  deduced \
from the previous ones through some transformation.  One of the simplest \
example of that nature is a sextupole magnet. The example of this notebook  \
is a very simple sextupole made of coils and a rudimentary yoke. Note that \
nobody would make a sextupole of such design. The purpose of this notebook is \
purely tutorial. 
Note that the transformation used to generate each new pole is the \
combination of a 2\[Pi]/6 rotation around the main axis together with a field \
inversion . The field inversion  does not change the position or orientation \
of the coils and magnetized volume but it has the effect of inverting the \
magnetization in the yoke  and current densities in the coils . 
More complicated examples could be generated with  higher order multiplicity. \
Octupoles can either be generated by a  similar sequence with a \[Pi]/4 \
rotation applied 8 times, alternatively,  it can also be generated by an \
ensemble of mirror type symmetries. Decapole must be generated by a sequence \
of 10 transformation with  \[Pi]/5 rotation ...
Execute all sections of this notebook in the order of presentation. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< Radia`\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generation of the Model", "Section"],

Cell["\<\

The function f[] build a sextupole, solve it and compute its strength. \
Importantly, it is made Listable.\
\>", "Text"],

Cell[BoxData[{
    \(\(ClearAll[f];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[f, Listable];\)\), "\[IndentingNewLine]", 
    \(\(SetAttributes[seg, 
        Listable];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(f[n_seg, cur_] := 
        Module[{m, res, ma, c, r, dz, 
            hex}, \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Create\ the\ magnet\ *) \[IndentingNewLine]ma = 
            radObjRecMag[{w[\([1]\)]/4, w[\([2]\)]/4, w[\([3]\)]/3 + g/2}, 
              w*{1/2, 1/2, 1}, {0, 0, 0}]; \[IndentingNewLine]radObjDivMag[
            ma, List @@ n]; \[IndentingNewLine]radObjDrwAtr[
            ma, {0, 0.5, 1}]; \[IndentingNewLine]RadTrfZerPerp[
            ma, {0, 0, 0}, {0, 1, 0}]; \[IndentingNewLine]RadTrfZerPerp[
            ma, {0, 0, 0}, {1, 0, 0}]; \[IndentingNewLine]radMatApl[ma, 
            RadMatSteel42[]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Create\ the\ coil\ *) \[IndentingNewLine]c = 
            radObjRaceTrk[{0, 0, w[\([3]\)]/3 + g/2}, {2, 4}, {w[\([1]\)], 
                0}, 5, 4, cur]; \[IndentingNewLine]radObjDrwAtr[
            c, {1, 0, 0}]; \[IndentingNewLine]m = 
            radObjCnt[{ma, c}]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Prepare\ the\ transformation\ *) \[IndentingNewLine]r = 
            radTrfRot[{0, 0, 0}, {1, 0, 0}, 
              2  \[Pi]/6]; \[IndentingNewLine]r = 
            radTrfCmbR[r, 
              radTrfInv[]]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Applies\ the\ transformation\ \ 6\ times\ \
*) \[IndentingNewLine]radTrfMlt[m, r, 
            6]; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            Orient\ the\ sextupole\ *) \[IndentingNewLine]radTrfOrnt[m, 
            radTrfRot[{0, 0, 0}, {1, 0, 0}, 
              2  \[Pi]/12]]; \[IndentingNewLine]\[IndentingNewLine]res = 
            RadSolve[m, 0.0001, 
              200]; \[IndentingNewLine] \
(*\[IndentingNewLine]\(Print["\<radSolve = \>", 
                res];\)\[IndentingNewLine]*) \[IndentingNewLine]dz = 
            1; \[IndentingNewLine]hex = \(-radFldInt[
                  m, "\<inf\>", "\<iby\>", {1, 0, dz}, {\(-1\), 0, dz}]\)/
              dz^2; \[IndentingNewLine]\[IndentingNewLine] (*\ 
            output\ the\ results\ *) \[IndentingNewLine]{Segm \[Rule] \ 
              n, \[IndentingNewLine]Cur -> cur, \[IndentingNewLine]Obj -> 
              m, \[IndentingNewLine]Solv \[Rule] 
              res, \[IndentingNewLine]Sext \[Rule] hex}];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(w = {6, 3, 
          6};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ Magnet\ dimensions\ *) \), "\[IndentingNewLine]", 
    \(\(g = 
        12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Free\ radius\ of\ the\ sextupole\ *) \), "\[IndentingNewLine]", 
    \(\(n = 
        seg[2, 2, 
          2];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Segmentation\ Parameter\ *) \), "\[IndentingNewLine]", 
    \(\(curdens = 
        3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \  (*\ 
      Current\ density\ in\ the\ coil\ *) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(pb = f[n, curdens]\), "\[IndentingNewLine]", 
    \(\(m = \((Obj /. pb)\);\)\)}], "Input"],

Cell[BoxData[
    \({Segm \[Rule] seg[2, 2, 2], Cur \[Rule] 3, Obj \[Rule] 29, 
      Solv \[Rule] {0.00008448086494515847`, 0.07622074193248461`, 
          0.00007616253933452151`, 18}, 
      Sext \[Rule] 0.0036461375064999165`}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Display the geometry", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RadPlot3DOptions[];\)\), "\n", 
    \(\(Show[Graphics3D[radObjDrw[m]]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.69634 .88724 -8.89401 0 ]
[.69634 .88724 9.35599 14 ]
[.77133 .86136 -4.8245 0 ]
[.77133 .86136 5.1755 14 ]
[.85258 .83332 -4.77112 0 ]
[.85258 .83332 5.22888 14 ]
[.77352 .92382 -7.53829 0 ]
[.77352 .92382 8.08671 14 ]
[.35279 .05196 -11.8671 -14 ]
[.35279 .05196 12.3829 0 ]
[.48019 .08723 -9.09901 -14 ]
[.48019 .08723 9.15099 0 ]
[.60156 .12084 -5.07265 -14 ]
[.60156 .12084 4.92735 0 ]
[.71732 .1529 -5.15475 -14 ]
[.71732 .1529 4.84525 0 ]
[.82785 .18351 -8.37191 -14 ]
[.82785 .18351 7.62809 0 ]
[.60065 .05835 -7.92601 -14 ]
[.60065 .05835 7.69899 0 ]
[.87584 .24788 0 -5.12251 ]
[.87584 .24788 24.25 8.87749 ]
[.88218 .37 0 -5.30043 ]
[.88218 .37 18.25 8.69957 ]
[.88873 .49639 0 -5.48507 ]
[.88873 .49639 10 8.51493 ]
[.8955 .62728 0 -5.67683 ]
[.8955 .62728 10 8.32317 ]
[.90251 .76291 0 -5.87613 ]
[.90251 .76291 16 8.12387 ]
[.94981 .50961 0 -5.48507 ]
[.94981 .50961 14.3125 8.51493 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.66279 .88623 m
.89252 .80683 L
s
.25 Mabswid
.69602 .87474 m
.69586 .8685 L
s
gsave
.69634 .88724 -69.894 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.77089 .84887 m
.77067 .84262 L
s
gsave
.77133 .86136 -65.8245 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.85201 .82083 m
.85172 .81459 L
s
gsave
.85258 .83332 -65.7711 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.71053 .86973 m
.71043 .86598 L
s
.72526 .86464 m
.72515 .86089 L
s
.74023 .85946 m
.74011 .85572 L
s
.75544 .85421 m
.75531 .85046 L
s
.78659 .84344 m
.78645 .83969 L
s
.80254 .83793 m
.80239 .83418 L
s
.81876 .83232 m
.8186 .82858 L
s
.83524 .82663 m
.83508 .82288 L
s
.68173 .87968 m
.68165 .87593 L
s
.66766 .88454 m
.66758 .88079 L
s
.86905 .81494 m
.86887 .8112 L
s
.88638 .80895 m
.88619 .80521 L
s
gsave
.77352 .92382 -68.5383 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.31166 .05317 m
.86175 .2052 L
s
.25 Mabswid
.35253 .06446 m
.35239 .07071 L
s
gsave
.35279 .05196 -72.8671 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.48015 .09973 m
.48013 .10598 L
s
gsave
.48019 .08723 -70.099 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.60174 .13334 m
.60183 .13959 L
s
gsave
.60156 .12084 -66.0726 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.71771 .16539 m
.7179 .17164 L
s
gsave
.71732 .1529 -66.1548 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.82844 .196 m
.82873 .20224 L
s
gsave
.82785 .18351 -69.3719 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.37856 .07165 m
.37849 .0754 L
s
.40433 .07878 m
.40428 .08253 L
s
.42985 .08583 m
.42981 .08958 L
s
.45512 .09282 m
.4551 .09657 L
s
.50494 .10659 m
.50494 .11034 L
s
.52949 .11337 m
.5295 .11712 L
s
.5538 .12009 m
.55383 .12384 L
s
.57788 .12675 m
.57793 .1305 L
s
.62537 .13987 m
.62544 .14362 L
s
.64878 .14634 m
.64886 .15009 L
s
.67197 .15275 m
.67206 .1565 L
s
.69494 .1591 m
.69505 .16285 L
s
.74026 .17163 m
.74039 .17537 L
s
.76261 .1778 m
.76275 .18155 L
s
.78475 .18392 m
.7849 .18767 L
s
.80669 .18999 m
.80685 .19373 L
s
.32624 .05719 m
.32614 .06094 L
s
.84998 .20195 m
.85017 .2057 L
s
gsave
.60065 .05835 -68.926 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.86175 .2052 m
.89252 .80683 L
s
.25 Mabswid
.86377 .24465 m
.85773 .24303 L
s
gsave
.87584 .24788 -61 -9.12251 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.87003 .36705 m
.86396 .36558 L
s
gsave
.88218 .37 -61 -9.30043 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.87651 .49375 m
.8704 .49243 L
s
gsave
.88873 .49639 -61 -9.48507 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.88322 .62496 m
.87708 .6238 L
s
gsave
.8955 .62728 -61 -9.67683 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.89017 .76093 m
.884 .75994 L
s
gsave
.90251 .76291 -61 -9.87613 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.865 .2688 m
.86138 .26784 L
s
.86625 .29311 m
.86262 .29217 L
s
.8675 .31759 m
.86386 .31667 L
s
.86876 .34224 m
.86512 .34133 L
s
.87131 .39204 m
.86766 .39118 L
s
.87259 .4172 m
.86894 .41636 L
s
.87389 .44254 m
.87023 .44171 L
s
.87519 .46805 m
.87153 .46724 L
s
.87783 .51962 m
.87416 .51885 L
s
.87916 .54568 m
.87549 .54492 L
s
.88051 .57192 m
.87683 .57118 L
s
.88186 .59834 m
.87818 .59763 L
s
.88459 .65176 m
.8809 .65109 L
s
.88597 .67876 m
.88228 .6781 L
s
.88736 .70595 m
.88366 .70532 L
s
.88876 .73334 m
.88506 .73273 L
s
.86254 .22066 m
.85893 .21967 L
s
.89159 .78872 m
.88789 .78814 L
s
gsave
.94981 .50961 -61 -9.48507 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.14246 .22051 m
.11243 .81583 L
s
.11243 .81583 m
.66279 .88623 L
s
.66279 .88623 m
.65135 .34127 L
s
.65135 .34127 m
.14246 .22051 L
s
.31166 .05317 m
.86175 .2052 L
s
.86175 .2052 m
.89252 .80683 L
s
.89252 .80683 m
.29362 .71644 L
s
.29362 .71644 m
.31166 .05317 L
s
.14246 .22051 m
.11243 .81583 L
s
.11243 .81583 m
.29362 .71644 L
s
.29362 .71644 m
.31166 .05317 L
s
.31166 .05317 m
.14246 .22051 L
s
.65135 .34127 m
.86175 .2052 L
s
.86175 .2052 m
.89252 .80683 L
s
.89252 .80683 m
.66279 .88623 L
s
.66279 .88623 m
.65135 .34127 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.50546 .47447 m .59354 .3989 L .55865 .38601 L .797 0 0 r
F
.56806 .35851 m .55865 .38601 L .59354 .3989 L .669 0 0 r
F
.47266 .45292 m .55865 .38601 L .52669 .36489 L .861 0 0 r
F
.47266 .45292 m .50546 .47447 L .55865 .38601 L F
.55184 .34778 m .55865 .38601 L .56806 .35851 L .669 0 0 r
F
.55184 .34778 m .52669 .36489 L .55865 .38601 L F
.49762 .43672 m .52669 .36489 L .55184 .34778 L .218 0 0 r
F
0 g
[ ] 0 setdash
.53718 .37183 m
.55865 .38601 L
s
.49762 .43672 m .47266 .45292 L .52669 .36489 L .218 0 0 r
F
.49762 .43672 m .52669 .36489 L .47266 .45292 L F
.49762 .43672 m .55184 .34778 L .52669 .36489 L F
.44718 .42634 m .52669 .36489 L .50211 .33848 L .92 0 0 r
F
.44718 .42634 m .47266 .45292 L .52669 .36489 L F
.53948 .33437 m .52669 .36489 L .55184 .34778 L .669 0 0 r
F
.53948 .33437 m .50211 .33848 L .52669 .36489 L F
.541 .48802 m .62646 .40168 L .59354 .3989 L .705 0 0 r
F
.58575 .36499 m .59354 .3989 L .62646 .40168 L .669 0 0 r
F
.50546 .47447 m .541 .48802 L .59354 .3989 L .797 0 0 r
F
.56806 .35851 m .59354 .3989 L .58575 .36499 L .669 0 0 r
F
0 g
.55865 .38601 m
.59354 .3989 L
s
.53665 .53894 m .63969 .59743 L .64306 .55949 L .887 0 0 r
F
.66838 .56441 m .64306 .55949 L .63969 .59743 L .529 0 0 r
F
.54761 .50166 m .64306 .55949 L .65403 .52303 L .874 0 0 r
F
.54761 .50166 m .53665 .53894 L .64306 .55949 L F
.67397 .54591 m .64306 .55949 L .66838 .56441 L .529 0 0 r
F
.67397 .54591 m .65403 .52303 L .64306 .55949 L F
.43273 .39842 m .50211 .33848 L .48852 .31044 L .986 0 0 r
F
.43273 .39842 m .44718 .42634 L .50211 .33848 L F
.5328 .32022 m .50211 .33848 L .53948 .33437 L .669 0 0 r
F
.5328 .32022 m .48852 .31044 L .50211 .33848 L F
0 g
.50211 .33848 m
.52669 .36489 L
s
.69204 .47423 m .77951 .42514 L p .6603 .4412 L .717 0 0 r
F P
0 g
s
.58763 .46864 m .65265 .39371 L .62646 .40168 L .512 0 0 r
F
.59012 .4677 m .65265 .39371 L .58763 .46864 L F
.59389 .46712 m .65265 .39371 L .58391 .47505 L F
.63366 .46184 m .67113 .49315 L .69204 .47423 L .791 0 0 r
F
.54902 .47992 m .56113 .4811 L .62646 .40168 L .705 0 0 r
F
.54311 .48589 m .55114 .48375 L .54902 .47992 L F
.55114 .48375 m .56113 .4811 L .54902 .47992 L F
.57706 .47837 m .5786 .47926 L .58391 .47505 L .85 0 0 r
F
.5786 .47926 m .65403 .52303 L .58391 .47505 L F
.541 .48802 m .55427 .48943 L .56113 .4811 L .705 0 0 r
F
.541 .48802 m .56113 .4811 L .54311 .48589 L F
.56113 .4811 m .58391 .47505 L .62646 .40168 L F
.55427 .48943 m .58391 .47505 L .56113 .4811 L F
.58455 .45141 m .56433 .47099 L .58391 .47505 L .791 0 0 r
F
.73807 .34096 m .65265 .39371 L .61573 .45803 L p .288 0 0 r
F P
0 g
s
.61594 .46654 m .59867 .47113 L .67113 .49315 L .791 0 0 r
F
.59867 .47113 m .59151 .47663 L .67113 .49315 L F
.58391 .47505 m .59012 .4677 L .58763 .46864 L .512 0 0 r
F
.60746 .46245 m .58391 .47505 L .61594 .46654 L .791 0 0 r
F
.59028 .47164 m .59389 .46712 L .58391 .47505 L .512 0 0 r
F
.59867 .47113 m .58391 .47505 L .59151 .47663 L .791 0 0 r
F
.5323 .45448 m .54352 .46439 L .541 .48802 L .656 0 0 r
F
.56433 .47099 m .55427 .48943 L .55497 .49107 L .85 0 0 r
F
.5786 .47926 m .54983 .5021 L .65403 .52303 L F
.56433 .47099 m .54983 .5021 L .5786 .47926 L F
.56565 .48391 m .57432 .49157 L .58391 .47505 L .705 0 0 r
F
.56479 .48315 m .57432 .49157 L .55427 .48943 L .656 0 0 r
F
.57487 .50927 m .56346 .50609 L .56402 .48361 L .502 0 0 r
F
.56727 .48167 m .56402 .48361 L .56433 .47099 L F
.56402 .48361 m .55427 .48943 L .56433 .47099 L F
.5323 .45448 m .54909 .45614 L .56727 .48167 L .656 0 0 r
F
.56479 .48315 m .56727 .48167 L .57432 .49157 L F
.5323 .45448 m .56727 .48167 L .56479 .48315 L F
.56346 .50609 m .55427 .48943 L .56402 .48361 L .502 0 0 r
F
.57487 .50927 m .56402 .48361 L .56727 .48167 L F
.54352 .46439 m .56479 .48315 L .55427 .48943 L .656 0 0 r
F
.54352 .46439 m .55427 .48943 L .541 .48802 L F
.55497 .49107 m .54761 .50166 L .54983 .5021 L .85 0 0 r
F
.55427 .48943 m .54761 .50166 L .55497 .49107 L F
.61573 .45803 m .61594 .46654 L .63366 .46184 L .791 0 0 r
F
.60041 .46622 m .61573 .45803 L .62442 .44289 L .512 0 0 r
F
.59389 .46712 m .62442 .44289 L .65265 .39371 L F
.58391 .47505 m .65403 .52303 L .67113 .49315 L .85 0 0 r
F
.57432 .49157 m .62442 .44289 L .59389 .46712 L .512 0 0 r
F
.58455 .45141 m .60746 .46245 L .61573 .45803 L .791 0 0 r
F
.60746 .46245 m .61594 .46654 L .61573 .45803 L F
.57432 .49157 m .60059 .48439 L .61573 .45803 L .512 0 0 r
F
.57432 .49157 m .61573 .45803 L .60041 .46622 L F
.58455 .45141 m .58391 .47505 L .60746 .46245 L .791 0 0 r
F
.57432 .49157 m .59028 .47164 L .58391 .47505 L .512 0 0 r
F
.61594 .46654 m .67113 .49315 L .63366 .46184 L .791 0 0 r
F
.63928 .44404 m .61573 .45803 L .6603 .4412 L .717 0 0 r
F
.63928 .44404 m .65412 .42855 L .61573 .45803 L .288 0 0 r
F
.65412 .42855 m .73807 .34096 L .61573 .45803 L F
.60234 .36626 m .62646 .40168 L .65265 .39371 L .669 0 0 r
F
.58575 .36499 m .62646 .40168 L .60234 .36626 L F
.60234 .36626 m .65265 .39371 L .61536 .36206 L F
.60059 .48439 m .65265 .39371 L .61536 .36206 L p .894 0 0 r
F P
0 g
s
.56433 .47099 m .57706 .47837 L .58391 .47505 L .85 0 0 r
F
.58478 .47121 m .56433 .47099 L .58455 .45141 L .502 0 0 r
F
.56727 .48167 m .60059 .48439 L .57432 .49157 L .656 0 0 r
F
.58085 .47356 m .60059 .48439 L .56727 .48167 L F
.57063 .47967 m .56433 .47099 L .58478 .47121 L .502 0 0 r
F
.54909 .45614 m .56214 .45234 L .58478 .47121 L .656 0 0 r
F
.58085 .47356 m .58478 .47121 L .60059 .48439 L F
.54909 .45614 m .58478 .47121 L .58085 .47356 L F
.58478 .47121 m .65265 .39371 L .60059 .48439 L .894 0 0 r
F
.56214 .45234 m .5844 .43793 L .58478 .47121 L F
.5844 .43793 m .65265 .39371 L .58478 .47121 L F
.61536 .36206 m .56214 .45234 L .60059 .48439 L p F P
0 g
s
.66886 .4001 m .58455 .45141 L p .63928 .44404 L .717 0 0 r
F P
0 g
s
.70098 .40737 m .71015 .39286 L .70972 .39173 L .1 0 0 r
F
.70512 .40313 m .75524 .32157 L .70098 .40737 L F
.70098 .40737 m .73807 .34096 L p .66037 .42203 L .288 0 0 r
F P
0 g
s
.63928 .44404 m .70098 .40737 L .66037 .42203 L .288 0 0 r
F
.72032 .40039 m .77951 .42514 L .80347 .41939 L .55 0 0 r
F
.63928 .44404 m .66917 .44001 L .70098 .40737 L .717 0 0 r
F
.66917 .44001 m .72302 .43275 L .70098 .40737 L F
.77951 .42514 m .71944 .41155 L p .72302 .43275 L F P
0 g
s
.71944 .41155 m .70098 .40737 L p .72302 .43275 L .717 0 0 r
F P
0 g
s
.73805 .34098 m .73801 .34108 L .73807 .34096 L .899 0 0 r
F
.64583 .4008 m .73801 .34108 L .73805 .34098 L F
.70098 .40737 m .66886 .4001 L p .63928 .44404 L .717 0 0 r
F P
0 g
s
.61573 .45803 m .69204 .47423 L p .6603 .4412 L .717 0 0 r
F P
0 g
s
.69204 .47423 m .58455 .45141 L .58511 .49963 L p .894 0 0 r
F P
0 g
s
.58511 .49963 m .58455 .45141 L .69204 .47423 L .894 0 0 r
F
.60059 .48439 m .68576 .43462 L .70098 .40737 L p .288 0 0 r
F P
0 g
s
.60059 .48439 m .70098 .40737 L .63928 .44404 L .288 0 0 r
F
.58455 .45141 m .66886 .4001 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.58455 .45141 m .61573 .45803 L p .63928 .44404 L .717 0 0 r
F P
0 g
s
.61573 .45803 m .60059 .48439 L p .63928 .44404 L .288 0 0 r
F P
0 g
s
.68576 .43462 m .60059 .48439 L p .61868 .45096 L .656 0 0 r
F P
0 g
s
.66934 .42071 m .68576 .43462 L p .61868 .45096 L .656 0 0 r
F P
0 g
s
.58478 .47121 m .58455 .45141 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.60059 .48439 m .56214 .45234 L .64583 .4008 L p .656 0 0 r
F P
0 g
s
.67003 .45029 m .58511 .49963 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.66886 .4001 m .66934 .42071 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.66934 .42071 m .67003 .45029 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.64583 .4008 m .66934 .42071 L p .61868 .45096 L .656 0 0 r
F P
0 g
s
.64583 .4008 m .68576 .43462 L .73801 .34108 L .899 0 0 r
F
.70972 .39173 m .75524 .32157 L .73807 .34096 L .1 0 0 r
F
.71015 .39286 m .75524 .32157 L .70972 .39173 L F
.65265 .39371 m .73807 .34096 L .6994 .3076 L p .669 0 0 r
F P
0 g
s
.6994 .3076 m .73807 .34096 L .75524 .32157 L .669 0 0 r
F
.61536 .36206 m .65265 .39371 L p .67544 .35173 L F P
0 g
s
.6994 .3076 m .65642 .33546 L p .67544 .35173 L .669 0 0 r
F P
0 g
s
.65642 .33546 m .61536 .36206 L p .67544 .35173 L .669 0 0 r
F P
0 g
s
.5323 .45448 m .58575 .36499 L .60234 .36626 L .702 0 0 r
F
.51426 .44767 m .58575 .36499 L .5323 .45448 L .797 0 0 r
F
.54909 .45614 m .60234 .36626 L .61536 .36206 L .497 0 0 r
F
.5323 .45448 m .60234 .36626 L .54909 .45614 L .702 0 0 r
F
.56214 .45234 m .61536 .36206 L .65265 .39371 L .894 0 0 r
F
.51426 .44767 m .56806 .35851 L .58575 .36499 L .797 0 0 r
F
.49762 .43672 m .56806 .35851 L .51426 .44767 L .862 0 0 r
F
.51776 .42925 m .54698 .45355 L .6112 .34534 L p 0 .35 .74 r
F P
0 g
s
.56214 .45234 m .61536 .36206 L .6994 .3076 L p .255 0 0 r
F P
0 g
s
.54909 .45614 m .61536 .36206 L .56214 .45234 L .497 0 0 r
F
.6994 .3076 m .64583 .4008 L .56214 .45234 L p .255 0 0 r
F P
0 g
s
.6112 .34534 m .54698 .45355 L .58763 .42832 L p 0 .05 .312 r
F P
0 g
s
.58763 .42832 m .6521 .31838 L .6112 .34534 L p 0 .05 .312 r
F P
0 g
s
.55786 .40336 m .58763 .42832 L .64687 .32729 L p 0 .351 .737 r
F P
0 g
s
.64687 .32729 m .6521 .31838 L p .64449 .32525 L 0 .351 .737 r
F P
0 g
s
.55786 .40336 m .64687 .32729 L .64449 .32525 L 0 .351 .737 r
F
.64583 .4008 m .73807 .34096 L .6994 .3076 L .899 0 0 r
F
.6994 .3076 m .73807 .34096 L .68576 .43462 L p F P
0 g
s
.6994 .3076 m .75524 .32157 L .70772 .29771 L .669 0 0 r
F
.70772 .29771 m .75524 .32157 L .75816 .29433 L F
.71005 .40037 m .71414 .40183 L .71237 .39857 L .55 0 0 r
F
.71414 .40183 m .71524 .40222 L .71237 .39857 L F
.70389 .40512 m .71237 .39857 L .75524 .32157 L .1 0 0 r
F
.71237 .39857 m .71546 .38795 L .71612 .39184 L 1 0 0 r
F
.67003 .45029 m .77951 .42514 L .66886 .4001 L .899 0 0 r
F
.68576 .43462 m .64583 .4008 L .6994 .3076 L p F P
0 g
s
.69189 .39389 m .66886 .4001 L .70098 .40737 L .55 0 0 r
F
.71005 .40037 m .70098 .40737 L .71944 .41155 L F
.70389 .40512 m .70512 .40313 L .70098 .40737 L .1 0 0 r
F
.69189 .39389 m .70098 .40737 L .71005 .40037 L .55 0 0 r
F
.67003 .45029 m .66886 .4001 L .77951 .42514 L p .899 0 0 r
F P
0 g
s
.68576 .43462 m .70389 .40512 L .70098 .40737 L .1 0 0 r
F
.68576 .43462 m .7027 .41594 L .70312 .4111 L F
.71005 .40037 m .71944 .41155 L .71414 .40183 L .55 0 0 r
F
.70331 .41084 m .7027 .41594 L .71237 .39857 L .1 0 0 r
F
.68576 .43462 m .71237 .39857 L .70389 .40512 L F
.69189 .39389 m .71005 .40037 L .71237 .39857 L .55 0 0 r
F
.7027 .41594 m .70409 .39996 L .70463 .39987 L 1 0 0 r
F
.69204 .47423 m .69327 .52155 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.77951 .42514 m .73477 .45024 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.73477 .45024 m .69204 .47423 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.68269 .53088 m .67113 .49315 L .65403 .52303 L .529 0 0 r
F
.69327 .52155 m .67113 .49315 L .68269 .53088 L F
.69327 .52155 m .69204 .47423 L .67113 .49315 L F
.68269 .53088 m .65403 .52303 L .67397 .54591 L F
.57487 .50927 m .68269 .53088 L .67397 .54591 L .85 0 0 r
F
.58511 .49963 m .69327 .52155 L .69204 .47423 L p .894 0 0 r
F P
0 g
s
.58511 .49963 m .69204 .47423 L .69327 .52155 L .894 0 0 r
F
.58511 .49963 m .68269 .53088 L .57487 .50927 L .789 0 0 r
F
.58511 .49963 m .69327 .52155 L .68269 .53088 L F
.66838 .56441 m .63969 .59743 L .6667 .58367 L .529 0 0 r
F
.56076 .54363 m .66838 .56441 L .6667 .58367 L .888 0 0 r
F
.56635 .52471 m .66838 .56441 L .56076 .54363 L .875 0 0 r
F
.56635 .52471 m .67397 .54591 L .66838 .56441 L F
.57487 .50927 m .67397 .54591 L .56635 .52471 L .85 0 0 r
F
.57487 .50927 m .56803 .52166 L .54761 .50166 L .502 0 0 r
F
.56803 .52166 m .56635 .52471 L .56519 .52329 L F
.56803 .52166 m .56519 .52329 L .54761 .50166 L F
.78139 .47437 m .77951 .42514 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.69327 .52155 m .73632 .4985 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.73632 .4985 m .78139 .47437 L p .73554 .4743 L .529 0 0 r
F P
0 g
s
.72004 .50722 m .69327 .52155 L .67138 .51712 L p .709 0 0 r
F P
0 g
s
.67138 .51712 m .58511 .49963 L p .72004 .50722 L .709 0 0 r
F P
0 g
s
.78139 .47437 m .72004 .50722 L p .58511 .49963 L .709 0 0 r
F P
0 g
s
.58511 .49963 m .67003 .45029 L .78139 .47437 L p .709 0 0 r
F P
0 g
s
.70416 .5356 m .74743 .51289 L .61551 .48561 L p 0 .446 1 r
F P
0 g
s
.74866 .54955 m .74743 .51289 L .70416 .5356 L p 0 .207 .719 r
F P
0 g
s
.74866 .54955 m .74743 .51289 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.58525 .51178 m .70416 .5356 L p .62324 .48997 L 0 .446 1 r
F P
0 g
s
.70416 .5356 m .6347 .52169 L p .68613 .53709 L 0 .35 .74 r
F P
0 g
s
.6347 .52169 m .57415 .50956 L p .68613 .53709 L 0 .35 .74 r
F P
0 g
s
.57415 .50956 m .57452 .54633 L p .68613 .53709 L 0 .35 .74 r
F P
0 g
s
.57452 .54633 m .70515 .57155 L .70416 .5356 L p 0 .35 .74 r
F P
0 g
s
.70416 .5356 m .70515 .57155 L .74866 .54955 L p 0 .207 .719 r
F P
0 g
s
.6161 .52314 m .73788 .54741 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.73788 .54741 m .74866 .54955 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.58511 .49963 m .57487 .50927 L .56433 .47099 L .502 0 0 r
F
.61551 .48561 m .57415 .50956 L .58525 .51178 L p 0 .446 1 r
F P
0 g
s
.61551 .48561 m .58525 .51178 L .62324 .48997 L 0 .446 1 r
F
.61551 .48561 m .6161 .52314 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.74743 .51289 m .73671 .51067 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.73671 .51067 m .61551 .48561 L p .7368 .51372 L 0 .351 .737 r
F P
0 g
s
.67003 .45029 m .78139 .47437 L .77951 .42514 L .899 0 0 r
F
.77951 .42514 m .78139 .47437 L .67003 .45029 L p F P
0 g
s
.68155 .44752 m .78139 .47437 L .67003 .45029 L .525 0 0 r
F
.79339 .47182 m .77951 .42514 L .78139 .47437 L .529 0 0 r
F
.68155 .44752 m .79339 .47182 L .78139 .47437 L .525 0 0 r
F
.69165 .45294 m .79339 .47182 L .68155 .44752 L .613 0 0 r
F
.69165 .45294 m .69171 .43715 L .71235 .40406 L .502 0 0 r
F
.66934 .42071 m .7027 .41594 L .68576 .43462 L .656 0 0 r
F
.68515 .41127 m .7027 .41594 L .66934 .42071 L F
.68898 .40898 m .66886 .4001 L .69189 .39389 L .502 0 0 r
F
.68515 .41127 m .68898 .40898 L .7027 .41594 L .656 0 0 r
F
.68155 .44752 m .67368 .41812 L .68898 .40898 L .502 0 0 r
F
.67368 .41812 m .66886 .4001 L .68898 .40898 L F
.68155 .44752 m .67003 .45029 L .66886 .4001 L F
.64583 .4008 m .65402 .39125 L .68898 .40898 L .656 0 0 r
F
.64583 .4008 m .68898 .40898 L .68515 .41127 L F
.64583 .4008 m .68515 .41127 L .66934 .42071 L F
.69183 .40728 m .69189 .39389 L .70409 .39996 L .502 0 0 r
F
.70409 .39996 m .69189 .39389 L .71237 .39857 L .577 0 0 r
F
.68898 .40898 m .70409 .39996 L .7027 .41594 L .656 0 0 r
F
.69165 .45294 m .68155 .44752 L .69189 .39389 L .502 0 0 r
F
.65402 .39125 m .70504 .38915 L .70409 .39996 L .656 0 0 r
F
.65402 .39125 m .70409 .39996 L .68898 .40898 L F
.7027 .41594 m .70615 .38717 L .71142 .39682 L 1 0 0 r
F
.7027 .41594 m .71142 .39682 L .71237 .39857 L F
.69171 .43715 m .70409 .39996 L .71235 .40406 L .502 0 0 r
F
.69171 .43715 m .69183 .40728 L .70409 .39996 L F
.71235 .40406 m .70409 .39996 L .71237 .39857 L .577 0 0 r
F
.70463 .39987 m .70504 .38915 L .70615 .38717 L 1 0 0 r
F
.70409 .39996 m .70504 .38915 L .70463 .39987 L F
.71142 .39682 m .70615 .38717 L .75816 .29433 L F
.71414 .40183 m .71944 .41155 L .77951 .42514 L .55 0 0 r
F
.71142 .39682 m .71546 .38795 L .71237 .39857 L 1 0 0 r
F
.71237 .39857 m .71524 .40222 L .72032 .40039 L .55 0 0 r
F
.71612 .39184 m .75816 .29433 L .75524 .32157 L 1 0 0 r
F
.71546 .38795 m .75816 .29433 L .71612 .39184 L F
.71524 .40222 m .77951 .42514 L .72032 .40039 L .55 0 0 r
F
.71465 .40444 m .71237 .39857 L .80347 .41939 L .577 0 0 r
F
.71235 .40406 m .71237 .39857 L .71465 .40444 L F
.58511 .49963 m .58478 .47121 L p .63351 .44211 L .502 0 0 r
F P
0 g
s
.58511 .49963 m .57063 .47967 L .58478 .47121 L .502 0 0 r
F
.54909 .45614 m .58085 .47356 L .56727 .48167 L .656 0 0 r
F
.56346 .50609 m .54761 .50166 L .55427 .48943 L .502 0 0 r
F
.53293 .57765 m .64445 .63159 L .63969 .59743 L .892 0 0 r
F
.6667 .58367 m .63969 .59743 L .64445 .63159 L .529 0 0 r
F
.53665 .53894 m .53293 .57765 L .63969 .59743 L .887 0 0 r
F
.5589 .56329 m .63969 .59743 L .6667 .58367 L .7 0 0 r
F
0 g
.64134 .57888 m
.64175 .57424 L
s
.5589 .56329 m .53293 .57765 L .63969 .59743 L .7 0 0 r
F
.5589 .56329 m .63969 .59743 L .53293 .57765 L F
.5589 .56329 m .6667 .58367 L .63969 .59743 L F
.53701 .6124 m .65682 .65701 L .64445 .63159 L .879 0 0 r
F
.6692 .60089 m .64445 .63159 L .65682 .65701 L .529 0 0 r
F
.53293 .57765 m .53701 .6124 L .64445 .63159 L .892 0 0 r
F
.6667 .58367 m .64445 .63159 L .6692 .60089 L .529 0 0 r
F
0 g
.63969 .59743 m
.64445 .63159 L
s
.52669 .36489 m
.54727 .35089 L
s
.49762 .43672 m .55184 .34778 L .56806 .35851 L .862 0 0 r
F
0 g
.56806 .35851 m
.58575 .36499 L
s
.41918 .39549 m .43233 .38839 L .39655 .26274 L .747 0 0 r
F
.43984 .36421 m .44082 .36313 L .44211 .35693 L 1 0 0 r
F
.44082 .36313 m .48852 .31044 L .44211 .35693 L F
.44211 .35693 m .42115 .24579 L .39655 .26274 L .658 0 0 r
F
.44211 .35693 m .48852 .31044 L .48818 .2848 L 1 0 0 r
F
.42899 .37667 m .44211 .35693 L .39655 .26274 L .747 0 0 r
F
.43233 .38839 m .44211 .35693 L .42899 .37667 L F
.41918 .39549 m .39655 .26274 L .36397 .28107 L F
.38309 .41279 m .41918 .39549 L .36397 .28107 L .806 0 0 r
F
.40822 .39412 m .42002 .38971 L .41918 .39549 L .705 0 0 r
F
.43173 .37318 m .43233 .38839 L .44259 .38287 L 1 0 0 r
F
.44082 .36313 m .44457 .37974 L .48852 .31044 L F
.43173 .37318 m .43807 .37642 L .44082 .36313 L F
.43807 .37642 m .44457 .37974 L .44082 .36313 L F
.46056 .32915 m .44211 .35693 L .48818 .2848 L .1 0 0 r
F
.4563 .33599 m .44211 .35693 L .46056 .32915 L F
.45215 .37769 m .46129 .32863 L .45205 .34226 L .658 0 0 r
F
.44594 .35127 m .45195 .30936 L .44452 .34525 L F
.45215 .37769 m .45205 .34226 L .44594 .35127 L F
.45205 .34226 m .45195 .30936 L .44594 .35127 L F
.53289 .30743 m .48818 .2848 L .48852 .31044 L .669 0 0 r
F
.53983 .29797 m .48818 .2848 L .53289 .30743 L F
.53983 .29797 m .50159 .26551 L .48818 .2848 L F
.46129 .32863 m .48818 .2848 L .50159 .26551 L .1 0 0 r
F
.45215 .37769 m .44452 .34525 L .44211 .35693 L .658 0 0 r
F
.44477 .35451 m .4563 .33599 L .46129 .32863 L .1 0 0 r
F
.45707 .33475 m .48818 .2848 L .46129 .32863 L F
.49831 .18406 m .42115 .24579 L .46129 .32863 L p .584 0 0 r
F P
0 g
s
.58133 .20572 m .50159 .26551 L .53983 .29797 L p .669 0 0 r
F P
0 g
s
.53289 .30743 m .48852 .31044 L .5328 .32022 L .669 0 0 r
F
.47745 .39655 m .5328 .32022 L .47769 .40913 L 1 0 0 r
F
.47745 .39655 m .53289 .30743 L .5328 .32022 L F
.48423 .3874 m .48692 .38298 L .47745 .39655 L .1 0 0 r
F
.50552 .35242 m .53289 .30743 L .50329 .35501 L F
.48423 .3874 m .53983 .29797 L .53289 .30743 L F
.53983 .29797 m .50159 .26551 L p .48549 .37856 L .894 0 0 r
F P
0 g
s
.48692 .38298 m .50552 .35242 L .47956 .39316 L .1 0 0 r
F
.50552 .35242 m .50329 .35501 L .47956 .39316 L F
.48692 .38298 m .47956 .39316 L .47745 .39655 L F
.48423 .3874 m .48734 .38239 L p .48549 .37856 L .894 0 0 r
F P
0 g
s
.48734 .38239 m .53983 .29797 L p .48549 .37856 L .894 0 0 r
F P
0 g
s
.48423 .3874 m .50159 .26551 L .53983 .29797 L .894 0 0 r
F
.45215 .37769 m .47739 .36186 L .46129 .32863 L .658 0 0 r
F
.43233 .38839 m .45215 .37769 L .43414 .38258 L .747 0 0 r
F
.4347 .38075 m .45029 .37385 L .44211 .35693 L F
.44458 .37975 m .44151 .38191 L .43173 .37318 L .656 0 0 r
F
.44151 .38191 m .43233 .38839 L .43173 .37318 L F
.44224 .3814 m .45215 .37769 L .43233 .38839 L .705 0 0 r
F
.43233 .38839 m .43273 .39842 L .43958 .38761 L 1 0 0 r
F
.43233 .38839 m .43958 .38761 L .44259 .38287 L F
.45879 .39733 m .43233 .38839 L .44151 .38191 L .656 0 0 r
F
.44458 .37975 m .47739 .36186 L .45215 .37769 L .705 0 0 r
F
.45737 .37072 m .47739 .36186 L .44458 .37975 L F
.43173 .37318 m .43984 .36421 L .44211 .35693 L 1 0 0 r
F
.46108 .36811 m .43173 .37318 L .44477 .35451 L .656 0 0 r
F
.44224 .3814 m .44458 .37975 L .45215 .37769 L .705 0 0 r
F
.44774 .37752 m .43173 .37318 L .46108 .36811 L .656 0 0 r
F
.44774 .37752 m .44458 .37975 L .43173 .37318 L F
.42494 .38508 m .43756 .37711 L .46108 .36811 L .705 0 0 r
F
.42494 .38508 m .46108 .36811 L .45737 .37072 L F
.40822 .39412 m .42494 .38508 L .44458 .37975 L F
.40822 .39412 m .44458 .37975 L .44224 .3814 L F
.42494 .38508 m .45737 .37072 L .44458 .37975 L F
.42002 .38971 m .44224 .3814 L .43233 .38839 L F
.42002 .38971 m .43233 .38839 L .41918 .39549 L F
.45879 .39733 m .43273 .39842 L .43233 .38839 L .656 0 0 r
F
.38983 .40293 m .41918 .39549 L .38309 .41279 L .705 0 0 r
F
.38983 .40293 m .40822 .39412 L .41918 .39549 L F
.35202 .27757 m .36397 .28107 L .39655 .26274 L .771 0 0 r
F
.36854 .26825 m .39655 .26274 L .42115 .24579 L F
.35202 .27757 m .39655 .26274 L .36854 .26825 L F
.36854 .26825 m .42115 .24579 L .38083 .25971 L F
.42494 .38508 m .36854 .26825 L .38083 .25971 L .654 0 0 r
F
.40822 .39412 m .36854 .26825 L .42494 .38508 L .745 0 0 r
F
.44477 .35451 m .43173 .37318 L .44211 .35693 L .1 0 0 r
F
.42494 .38508 m .38083 .25971 L .43756 .37711 L .654 0 0 r
F
.40258 .40462 m .43317 .39279 L .42747 .38097 L p 0 .35 .74 r
F P
0 g
s
.38309 .41279 m .36397 .28107 L .32798 .29827 L .806 0 0 r
F
.33369 .28633 m .36397 .28107 L .35202 .27757 L .771 0 0 r
F
.33369 .28633 m .32798 .29827 L .36397 .28107 L F
.40822 .39412 m .35202 .27757 L .36854 .26825 L .745 0 0 r
F
.38983 .40293 m .35202 .27757 L .40822 .39412 L .806 0 0 r
F
.42747 .38097 m .36494 .25151 L p .39941 .39172 L 0 .35 .74 r
F P
0 g
s
.40258 .40462 m .42747 .38097 L .39941 .39172 L 0 .35 .74 r
F
.45737 .37072 m .46108 .36811 L .47739 .36186 L .705 0 0 r
F
.48423 .3874 m .47745 .39655 L .44458 .37975 L .656 0 0 r
F
.48423 .3874 m .44458 .37975 L .44774 .37752 L F
.48423 .3874 m .44774 .37752 L .46108 .36811 L F
.50159 .26551 m .44477 .35451 L .48423 .3874 L p .894 0 0 r
F P
0 g
s
.48423 .3874 m .44477 .35451 L .50159 .26551 L .894 0 0 r
F
.50159 .26551 m .58133 .20572 L p .48318 .31265 L .133 0 0 r
F P
0 g
s
.46129 .32863 m .50159 .26551 L p .48318 .31265 L .133 0 0 r
F P
0 g
s
.47769 .40913 m .5328 .32022 L .53948 .33437 L .99 0 0 r
F
.48479 .42322 m .55184 .34778 L .49762 .43672 L .922 0 0 r
F
.48479 .42322 m .53948 .33437 L .55184 .34778 L F
.51776 .42925 m .58305 .32141 L .55473 .29733 L p 0 .35 .74 r
F P
0 g
s
.55473 .29733 m .58305 .32141 L .62343 .29382 L p 0 .355 .953 r
F P
0 g
s
.47769 .40913 m .53948 .33437 L .48479 .42322 L .99 0 0 r
F
.55473 .29733 m .48836 .40479 L .51776 .42925 L p 0 .35 .74 r
F P
0 g
s
.62343 .29382 m .59459 .26909 L .55473 .29733 L p 0 .355 .953 r
F P
0 g
s
.55473 .29733 m .59459 .26909 L .52789 .37823 L p 0 .05 .258 r
F P
0 g
s
.52789 .37823 m .48836 .40479 L .55473 .29733 L p 0 .05 .258 r
F P
0 g
s
.62104 .23998 m .53983 .29797 L .48423 .3874 L p .177 0 0 r
F P
0 g
s
.47739 .36186 m .52777 .32647 L p .51944 .2862 L .584 0 0 r
F P
0 g
s
.47739 .36186 m .51944 .2862 L .48318 .31265 L .584 0 0 r
F
.48318 .31265 m .50414 .28982 L .54059 .27076 L .133 0 0 r
F
.58133 .20572 m .54059 .27076 L p .50414 .28982 L F P
0 g
s
.54059 .27076 m .51292 .16943 L .49831 .18406 L .466 0 0 r
F
.53983 .29797 m .62104 .23998 L .58133 .20572 L p .669 0 0 r
F P
0 g
s
.55165 .29344 m .54059 .27076 L p .52777 .32647 L .584 0 0 r
F P
0 g
s
.52777 .32647 m .54059 .27076 L .51754 .27705 L .584 0 0 r
F
.52777 .32647 m .55755 .30555 L .55165 .29344 L p F P
0 g
s
.55755 .30555 m .52777 .32647 L p .53956 .31273 L .705 0 0 r
F P
0 g
s
.52386 .29747 m .54082 .31184 L p .50702 .33569 L .656 0 0 r
F P
0 g
s
.54009 .31211 m .54082 .31184 L p .53956 .31273 L .705 0 0 r
F P
0 g
s
.54082 .31184 m .55755 .30555 L p .53956 .31273 L .705 0 0 r
F P
0 g
s
.5167 .3209 m .54009 .31211 L p .53732 .31431 L .705 0 0 r
F P
0 g
s
.47739 .36186 m .49304 .34555 L .53732 .31431 L .705 0 0 r
F
.46129 .32863 m .47739 .36186 L p .48318 .31265 L .584 0 0 r
F P
0 g
s
.4563 .33599 m .45707 .33475 L .46129 .32863 L .1 0 0 r
F
.44477 .35451 m .44211 .35693 L .4563 .33599 L F
.45205 .34226 m .46129 .32863 L .45195 .30936 L .658 0 0 r
F
.44452 .34525 m .45195 .30936 L .42115 .24579 L F
.44452 .34525 m .42115 .24579 L .44211 .35693 L F
.43756 .37711 m .42115 .24579 L .47739 .36186 L .894 0 0 r
F
.47739 .36186 m .42115 .24579 L .38083 .25971 L p F P
0 g
s
.38083 .25971 m .43756 .37711 L .47739 .36186 L p .894 0 0 r
F P
0 g
s
.50702 .33569 m .49752 .33856 L .52386 .29747 L .656 0 0 r
F
.44477 .35451 m .48337 .32667 L p .49752 .33856 L F P
0 g
s
.48337 .32667 m .52386 .29747 L p .49752 .33856 L .656 0 0 r
F P
0 g
s
.52777 .32647 m .47739 .36186 L p .54009 .31211 L .705 0 0 r
F P
0 g
s
.46108 .36811 m .44477 .35451 L p .50702 .33569 L .656 0 0 r
F P
0 g
s
.47739 .36186 m .43756 .37711 L .47618 .34968 L p .705 0 0 r
F P
0 g
s
.47618 .34968 m .5167 .3209 L p .49646 .34198 L .705 0 0 r
F P
0 g
s
.47739 .36186 m .47618 .34968 L .49646 .34198 L .705 0 0 r
F
.48423 .3874 m .46108 .36811 L p .5 .34064 L .656 0 0 r
F P
0 g
s
.50353 .34361 m .5 .34064 L .50702 .33569 L .656 0 0 r
F
.48423 .3874 m .5 .34064 L .50353 .34361 L F
.44477 .35451 m .48318 .31265 L .49504 .30823 L .133 0 0 r
F
.52386 .29747 m .48337 .32667 L p .49504 .30823 L F P
0 g
s
.48337 .32667 m .44477 .35451 L p .49504 .30823 L .133 0 0 r
F P
0 g
s
.44477 .35451 m .46129 .32863 L p .48318 .31265 L .133 0 0 r
F P
0 g
s
.47745 .39655 m .45879 .39733 L .44151 .38191 L .656 0 0 r
F
.47745 .39655 m .44151 .38191 L .44458 .37975 L F
.43756 .37711 m .38083 .25971 L .42115 .24579 L .894 0 0 r
F
.38083 .25971 m .42115 .24579 L p .4385 .22257 L .771 0 0 r
F P
0 g
s
.45691 .19794 m .41796 .22956 L p .4385 .22257 L .771 0 0 r
F P
0 g
s
.41796 .22956 m .38083 .25971 L p .4385 .22257 L .771 0 0 r
F P
0 g
s
.43756 .37711 m .38083 .25971 L .41796 .22956 L p .577 0 0 r
F P
0 g
s
.42115 .24579 m .49831 .18406 L .45691 .19794 L p .771 0 0 r
F P
0 g
s
.41796 .22956 m .45691 .19794 L p .44702 .28952 L .577 0 0 r
F P
0 g
s
.43756 .37711 m .41796 .22956 L .44702 .28952 L .577 0 0 r
F
.54059 .27076 m .52386 .29747 L p .48318 .31265 L .133 0 0 r
F P
0 g
s
.48318 .31265 m .51944 .2862 L .49831 .18406 L .584 0 0 r
F
.48318 .31265 m .48542 .29361 L .46129 .32863 L F
.48542 .29361 m .49831 .18406 L .46129 .32863 L F
.45691 .19794 m .5167 .3209 L .43756 .37711 L p .577 0 0 r
F P
0 g
s
.36494 .25151 m .43317 .39279 L .47181 .36565 L p 0 .278 .858 r
F P
0 g
s
.47181 .36565 m .40178 .22109 L .36494 .25151 L p 0 .278 .858 r
F P
0 g
s
.44081 .37753 m .47181 .36565 L .46595 .35356 L p 0 .351 .737 r
F P
0 g
s
.46595 .35356 m .43203 .28354 L p .4395 .36359 L 0 .351 .737 r
F P
0 g
s
.44081 .37753 m .46595 .35356 L .4395 .36359 L 0 .351 .737 r
F
.43203 .28354 m .40178 .22109 L p .41347 .26794 L F P
0 g
s
.44081 .37753 m .43203 .28354 L .41347 .26794 L 0 .351 .737 r
F
.42551 .3162 m .405 .23398 L .4633 .35656 L F
.405 .23398 m .40178 .22109 L .40728 .2332 L F
.405 .23398 m .40728 .2332 L .4633 .35656 L F
.36494 .25151 m .40178 .22109 L .37031 .23168 L p 0 .532 1 r
F P
0 g
s
.40178 .22109 m .37031 .23168 L .43491 .36533 L p 0 .351 .737 r
F P
0 g
s
.43491 .36533 m .44081 .37753 L p .43752 .36434 L 0 .351 .737 r
F P
0 g
s
.43752 .36434 m .40178 .22109 L .43491 .36533 L 0 .351 .737 r
F
.37031 .23168 m .44081 .37753 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.44081 .37753 m .42551 .3162 L .4633 .35656 L 0 .351 .737 r
F
.40178 .22109 m .46613 .35392 L p .4633 .35656 L F P
0 g
s
.44044 .18918 m .40178 .22109 L .47181 .36565 L p 0 .278 .858 r
F P
0 g
s
.37031 .23168 m .40178 .22109 L .44044 .18918 L p 0 .532 1 r
F P
0 g
s
.44081 .37753 m .37031 .23168 L .40178 .22109 L p 0 .351 .737 r
F P
0 g
s
.44044 .18918 m .40852 .19975 L .37031 .23168 L p 0 .532 1 r
F P
0 g
s
.40852 .19975 m .37031 .23168 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.37031 .23168 m .37031 .23168 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.38983 .40293 m .33369 .28633 L .35202 .27757 L .806 0 0 r
F
.36494 .25151 m .33391 .26211 L .40258 .40462 L p 0 .35 .74 r
F P
0 g
s
.33391 .26211 m .40258 .40462 L .44081 .37753 L p 0 .276 .858 r
F P
0 g
s
.37031 .23168 m .33391 .26211 L .36494 .25151 L p 0 .532 1 r
F P
0 g
s
.44081 .37753 m .37031 .23168 L .33391 .26211 L p 0 .276 .858 r
F P
0 g
s
.37031 .23168 m .44081 .37753 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.33391 .26211 m .37031 .23168 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.37031 .23168 m .37031 .23168 L p .44081 .37753 L 0 .276 .858 r
F P
0 g
s
.44081 .37753 m .37031 .23168 L .37031 .23168 L p 0 .351 .737 r
F P
0 g
s
.30234 .27288 m .33391 .26211 L .37031 .23168 L p 0 .532 1 r
F P
0 g
s
.37031 .23168 m .33829 .24246 L .30234 .27288 L p 0 .532 1 r
F P
0 g
s
.37031 .23168 m .33829 .24246 L p .34687 .25376 L 0 .351 .737 r
F P
0 g
s
.3488 .42723 m .32798 .29827 L .29347 .31199 L .861 0 0 r
F
.3488 .42723 m .38309 .41279 L .32798 .29827 L F
.31618 .29326 m .32798 .29827 L .33369 .28633 L .771 0 0 r
F
.31618 .29326 m .29347 .31199 L .32798 .29827 L F
.37244 .41024 m .33369 .28633 L .38983 .40293 L .862 0 0 r
F
.37244 .41024 m .31618 .29326 L .33369 .28633 L F
.40258 .40462 m .33391 .26211 L .30234 .27288 L p 0 .35 .74 r
F P
0 g
s
.44081 .37753 m .40258 .40462 L .33391 .26211 L p 0 .276 .858 r
F P
0 g
s
.44081 .37753 m .36937 .2834 L .40351 .37768 L 0 .351 .737 r
F
.33829 .24246 m .36895 .30603 L p .36937 .2834 L F P
0 g
s
.36895 .30603 m .40351 .37768 L p .36937 .2834 L 0 .351 .737 r
F P
0 g
s
.40351 .37768 m .40927 .38962 L .42699 .38283 L p 0 .351 .737 r
F P
0 g
s
.42699 .38283 m .44081 .37753 L p .40351 .37768 L 0 .351 .737 r
F P
0 g
s
.30234 .27288 m .33829 .24246 L .36895 .30603 L p 0 .274 .858 r
F P
0 g
s
.36895 .30603 m .40927 .38962 L p .3479 .32262 L 0 .274 .858 r
F P
0 g
s
.3479 .32262 m .30234 .27288 L .36895 .30603 L 0 .274 .858 r
F
.44081 .37753 m .37616 .24379 L .34687 .25376 L 0 .351 .737 r
F
.44081 .37753 m .37031 .23168 L .44081 .37753 L F
.37244 .41024 m .38309 .41279 L .3488 .42723 L .705 0 0 r
F
.37244 .41024 m .38983 .40293 L .38309 .41279 L F
.37244 .41024 m .29347 .31199 L .31618 .29326 L .568 0 0 r
F
.37244 .41024 m .3488 .42723 L .29347 .31199 L F
.37244 .41024 m .29347 .31199 L .3488 .42723 L F
.37244 .41024 m .31618 .29326 L .29347 .31199 L F
.30206 .29733 m .29347 .31199 L .31618 .29326 L .771 0 0 r
F
.35858 .41496 m .37244 .41024 L .3488 .42723 L .705 0 0 r
F
.35858 .41496 m .31618 .29326 L .37244 .41024 L .927 0 0 r
F
.35858 .41496 m .30206 .29733 L .31618 .29326 L F
.30234 .27288 m .37147 .41665 L .40258 .40462 L p 0 .35 .74 r
F P
0 g
s
.40927 .38962 m .37147 .41665 L .30234 .27288 L p 0 .274 .858 r
F P
0 g
s
.37616 .24379 m .37031 .23168 L .34687 .25376 L 0 .351 .737 r
F
.35035 .41637 m .30206 .29733 L .35858 .41496 L 1 0 0 r
F
.37604 .21052 m .33829 .24246 L .37031 .23168 L p 0 .532 1 r
F P
0 g
s
.37031 .23168 m .40852 .19975 L .37604 .21052 L p 0 .532 1 r
F P
0 g
s
.44081 .37753 m .37031 .23168 L .40852 .19975 L p 0 .276 .858 r
F P
0 g
s
.33829 .24246 m .37031 .23168 L .44081 .37753 L p 0 .351 .737 r
F P
0 g
s
.44081 .37753 m .40927 .38962 L .34419 .25468 L p 0 .351 .737 r
F P
0 g
s
.34419 .25468 m .33829 .24246 L p .34687 .25376 L 0 .351 .737 r
F P
0 g
s
.44081 .37753 m .34419 .25468 L .34687 .25376 L 0 .351 .737 r
F
.40927 .38962 m .33829 .24246 L .37604 .21052 L p 0 .274 .858 r
F P
0 g
s
.3334 .25835 m .37116 .2267 L p .31165 .26575 L .771 0 0 r
F P
0 g
s
.46613 .35392 m .47181 .36565 L .45452 .37228 L p 0 .351 .737 r
F P
0 g
s
.45452 .37228 m .44081 .37753 L p .46613 .35392 L 0 .351 .737 r
F P
0 g
s
.49304 .34555 m .5167 .3209 L .53732 .31431 L .705 0 0 r
F
.63633 .23952 m .59459 .26909 L .62343 .29382 L p 0 .355 .953 r
F P
0 g
s
.6112 .34534 m .58305 .32141 L .51776 .42925 L p 0 .35 .74 r
F P
0 g
s
.62343 .29382 m .58305 .32141 L .6112 .34534 L p 0 .355 .953 r
F P
0 g
s
.58305 .32141 m .51776 .42925 L .55786 .40336 L p 0 .05 .286 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .58305 .32141 L p 0 .05 .286 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .62343 .29382 L p 0 .351 .737 r
F P
0 g
s
.58305 .32141 m .62343 .29382 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.55786 .40336 m .51776 .42925 L .58305 .32141 L p 0 .05 .286 r
F P
0 g
s
.59459 .26909 m .5336 .36887 L p .56099 .39189 L 0 .351 .737 r
F P
0 g
s
.62343 .29382 m .59459 .26909 L p .55786 .40336 L 0 .351 .737 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .55786 .40336 L 0 .351 .737 r
F
.6112 .34534 m .6521 .31838 L .62343 .29382 L p 0 .355 .953 r
F P
0 g
s
.6521 .31838 m .62343 .29382 L .55786 .40336 L p 0 .351 .737 r
F P
0 g
s
.62343 .29382 m .55786 .40336 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.62343 .29382 m .62343 .29382 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.59459 .26909 m .62343 .29382 L .55786 .40336 L p 0 .351 .737 r
F P
0 g
s
.52789 .37823 m .55786 .40336 L p .56099 .39189 L 0 .351 .737 r
F P
0 g
s
.5336 .36887 m .52789 .37823 L p .56099 .39189 L 0 .351 .737 r
F P
0 g
s
.55786 .40336 m .52789 .37823 L .5336 .36887 L p 0 .351 .737 r
F P
0 g
s
.5336 .36887 m .59459 .26909 L p .56099 .39189 L 0 .351 .737 r
F P
0 g
s
.55786 .40336 m .5336 .36887 L .56099 .39189 L 0 .351 .737 r
F
.59459 .26909 m .63633 .23952 L p .53698 .36659 L 0 .05 .258 r
F P
0 g
s
.5336 .36887 m .59459 .26909 L p .53698 .36659 L 0 .05 .258 r
F P
0 g
s
.63633 .23952 m .56934 .35037 L .52789 .37823 L p 0 .05 .258 r
F P
0 g
s
.48423 .3874 m .56489 .33222 L .62104 .23998 L p .177 0 0 r
F P
0 g
s
.56489 .33222 m .5236 .36047 L p .50702 .33569 L .656 0 0 r
F P
0 g
s
.52789 .37823 m .5336 .36887 L p .53698 .36659 L 0 .05 .258 r
F P
0 g
s
.5236 .36047 m .48423 .3874 L p .50353 .34361 L .656 0 0 r
F P
0 g
s
.50353 .34361 m .50702 .33569 L .5236 .36047 L .656 0 0 r
F
.54082 .31184 m .56489 .33222 L p .50702 .33569 L F P
0 g
s
.47181 .36565 m .51235 .33717 L .44044 .18918 L p 0 .278 .858 r
F P
0 g
s
.44081 .37753 m .48093 .3491 L .40852 .19975 L p 0 .276 .858 r
F P
0 g
s
.40852 .19975 m .48093 .3491 L .44081 .37753 L p 0 .276 .858 r
F P
0 g
s
.37604 .21052 m .44896 .36124 L .40927 .38962 L p 0 .274 .858 r
F P
0 g
s
.35519 .40864 m .43206 .35268 L .37116 .2267 L p .559 0 0 r
F P
0 g
s
.43206 .35268 m .39268 .38135 L p .3901 .37429 L .705 0 0 r
F P
0 g
s
.4067 .34079 m .36779 .36986 L p .38325 .37931 L .421 0 0 r
F P
0 g
s
.40642 .36231 m .4067 .34079 L p .38325 .37931 L .421 0 0 r
F P
0 g
s
.38821 .36915 m .40642 .36231 L p .3901 .37429 L .705 0 0 r
F P
0 g
s
.40642 .36231 m .43206 .35268 L p .3901 .37429 L .705 0 0 r
F P
0 g
s
.39268 .38135 m .35519 .40864 L p .3712 .3895 L .705 0 0 r
F P
0 g
s
.3712 .3895 m .37411 .38602 L .39268 .38135 L .705 0 0 r
F
.3674 .39094 m .38325 .37931 L .36779 .36986 L .421 0 0 r
F
.37411 .38602 m .38821 .36915 L .3901 .37429 L .705 0 0 r
F
.37411 .38602 m .3901 .37429 L .39268 .38135 L F
.37147 .41665 m .40927 .38962 L .44081 .37753 L p 0 .525 .99 r
F P
0 g
s
.36732 .39544 m .40602 .39322 L .38325 .37931 L .421 0 0 r
F
.32109 .43677 m .3488 .42723 L .29347 .31199 L .925 0 0 r
F
.30206 .29733 m .26526 .32026 L .29347 .31199 L .771 0 0 r
F
.29346 .29791 m .26526 .32026 L .30206 .29733 L F
.35035 .41637 m .29346 .29791 L .30206 .29733 L 1 0 0 r
F
.3491 .41417 m .29346 .29791 L .35035 .41637 L .763 0 0 r
F
.29346 .29791 m .2476 .32173 L .26526 .32026 L .771 0 0 r
F
.29179 .29483 m .2476 .32173 L .29346 .29791 L F
.3491 .41417 m .29179 .29483 L .29346 .29791 L .763 0 0 r
F
.35519 .40864 m .29179 .29483 L .3491 .41417 L .404 0 0 r
F
.35519 .40864 m .29746 .28849 L .29179 .29483 L F
.32109 .43677 m .29347 .31199 L .26526 .32026 L .925 0 0 r
F
.29179 .29483 m .24355 .3159 L .2476 .32173 L .771 0 0 r
F
.29746 .28849 m .24355 .3159 L .29179 .29483 L F
.29746 .28849 m .25434 .30337 L .24355 .3159 L F
.35519 .40864 m .29746 .28849 L .25434 .30337 L p .894 0 0 r
F P
0 g
s
.37116 .2267 m .29746 .28849 L .35519 .40864 L p .559 0 0 r
F P
0 g
s
.35519 .40864 m .25434 .30337 L .29746 .28849 L .894 0 0 r
F
.30416 .43988 m .26526 .32026 L .2476 .32173 L 1 0 0 r
F
.30416 .43988 m .32109 .43677 L .26526 .32026 L F
.29663 .45125 m .30289 .43828 L .1893 .39315 L .85 0 0 r
F
.29344 .41977 m .29254 .41783 L .29058 .41417 L .817 0 0 r
F
.29254 .41783 m .2476 .32173 L .29058 .41417 L F
.29058 .41417 m .20673 .37121 L .1893 .39315 L .791 0 0 r
F
.29058 .41417 m .2476 .32173 L .24355 .3159 L .817 0 0 r
F
.30289 .43828 m .29058 .41417 L .29255 .43417 L .85 0 0 r
F
.31225 .47465 m .31228 .45967 L .29663 .45125 L .421 0 0 r
F
.30156 .43526 m .30416 .43988 L .30183 .43502 L .817 0 0 r
F
.30289 .43828 m .30416 .43988 L .30156 .43526 L F
.3491 .41417 m .33038 .42488 L .31163 .43186 L .705 0 0 r
F
.31232 .43136 m .31234 .41868 L .30289 .43828 L .421 0 0 r
F
.30095 .43584 m .30289 .43828 L .30156 .43526 L .817 0 0 r
F
.29089 .41432 m .29224 .41498 L .2476 .32173 L F
.30289 .43828 m .31234 .41868 L .29058 .41417 L .85 0 0 r
F
.3491 .41417 m .31163 .43186 L .31455 .42972 L .705 0 0 r
F
.33038 .42488 m .30416 .43988 L .30289 .43828 L F
.33038 .42488 m .30289 .43828 L .31163 .43186 L F
.35035 .41637 m .32109 .43677 L .30416 .43988 L F
.3491 .41417 m .35035 .41637 L .30416 .43988 L F
.31225 .47465 m .32026 .45825 L .31455 .42972 L .421 0 0 r
F
.31232 .43136 m .31455 .42972 L .31234 .41868 L F
.31225 .47465 m .31455 .42972 L .31232 .43136 L F
.31163 .43186 m .30289 .43828 L .30095 .43584 L .705 0 0 r
F
.31455 .42972 m .31163 .43186 L .30095 .43584 L F
.31228 .45967 m .31232 .43136 L .30289 .43828 L .421 0 0 r
F
.31228 .45967 m .30289 .43828 L .29663 .45125 L F
.30095 .43584 m .29344 .41977 L .29058 .41417 L .817 0 0 r
F
.31259 .42495 m .30095 .43584 L .29058 .41417 L .383 0 0 r
F
.28779 .38579 m .2893 .40113 L .24355 .3159 L F
.2893 .40113 m .28654 .40572 L .24355 .3159 L F
.29452 .39641 m .29058 .41417 L .28779 .38579 L F
.31234 .41868 m .29164 .40938 L .29058 .41417 L .791 0 0 r
F
.2893 .40113 m .29058 .41417 L .28654 .40572 L .383 0 0 r
F
.31234 .41868 m .33075 .39754 L .29591 .39014 L .791 0 0 r
F
.29452 .39641 m .24355 .3159 L .29591 .39014 L .383 0 0 r
F
.29164 .40938 m .29591 .39014 L .20673 .37121 L .791 0 0 r
F
.31234 .41868 m .29591 .39014 L .29164 .40938 L F
.29591 .39014 m .24355 .3159 L .25434 .30337 L .383 0 0 r
F
.31259 .42495 m .29452 .39641 L .29591 .39014 L F
.31259 .42495 m .29058 .41417 L .29452 .39641 L F
.29164 .40938 m .28689 .40724 L .29058 .41417 L .791 0 0 r
F
.35858 .41496 m .3488 .42723 L .32109 .43677 L .705 0 0 r
F
.35035 .41637 m .35858 .41496 L .32109 .43677 L F
.31455 .42972 m .33075 .39754 L .31234 .41868 L .421 0 0 r
F
.35519 .40864 m .3491 .41417 L .31455 .42972 L .705 0 0 r
F
.35519 .40864 m .31455 .42972 L .31756 .42751 L F
.32674 .42078 m .33075 .39754 L .31455 .42972 L .421 0 0 r
F
.35519 .40864 m .31756 .42751 L .33027 .41818 L .705 0 0 r
F
.32026 .45825 m .32958 .44782 L .33075 .39754 L .421 0 0 r
F
.33027 .41818 m .30095 .43584 L .31259 .42495 L .705 0 0 r
F
.31756 .42751 m .30095 .43584 L .33027 .41818 L F
.31259 .42495 m .35519 .40864 L p .34807 .40121 L .894 0 0 r
F P
0 g
s
.35519 .40864 m .31259 .42495 L .25434 .30337 L .894 0 0 r
F
.35519 .40864 m .33027 .41818 L p .37411 .38602 L .705 0 0 r
F P
0 g
s
.44081 .37753 m .40258 .40462 L .37147 .41665 L p 0 .525 .99 r
F P
0 g
s
.32958 .44782 m .36685 .4212 L p .36076 .39582 L .421 0 0 r
F P
0 g
s
.33027 .41818 m .32958 .44782 L p .36076 .39582 L .421 0 0 r
F P
0 g
s
.32026 .45825 m .32674 .42078 L .31455 .42972 L .421 0 0 r
F
.31756 .42751 m .31455 .42972 L .30095 .43584 L .705 0 0 r
F
.28574 .4905 m .29663 .45125 L .17415 .42666 L .874 0 0 r
F
.3067 .49459 m .29663 .45125 L .28574 .4905 L .421 0 0 r
F
.29663 .45125 m .1893 .39315 L .17415 .42666 L .85 0 0 r
F
.3067 .49459 m .31225 .47465 L .29663 .45125 L .421 0 0 r
F
.31225 .47465 m .19584 .43331 L .32026 .45825 L .85 0 0 r
F
.28574 .4905 m .17415 .42666 L .16331 .46687 L .874 0 0 r
F
.31225 .47465 m .18811 .45019 L .19584 .43331 L .85 0 0 r
F
.29255 .43417 m .29058 .41417 L .1893 .39315 L F
.28689 .40724 m .20673 .37121 L .29058 .41417 L .791 0 0 r
F
.20465 .4225 m .32958 .44782 L .33075 .39754 L p .894 0 0 r
F P
0 g
s
.32958 .44782 m .20673 .37121 L .33075 .39754 L .894 0 0 r
F
.32026 .45825 m .20465 .4225 L .32958 .44782 L .789 0 0 r
F
.32026 .45825 m .19584 .43331 L .20465 .4225 L F
.32958 .44782 m .20465 .4225 L .20673 .37121 L .894 0 0 r
F
.36685 .4212 m .40602 .39322 L p .36732 .39544 L .421 0 0 r
F P
0 g
s
.36076 .39582 m .36685 .4212 L .36732 .39544 L .421 0 0 r
F
.25434 .30337 m .29591 .39014 L p .34807 .40121 L .894 0 0 r
F P
0 g
s
.29591 .39014 m .31259 .42495 L p .34807 .40121 L .894 0 0 r
F P
0 g
s
.33075 .39754 m .33027 .41818 L p .36076 .39582 L .421 0 0 r
F P
0 g
s
.37116 .2267 m .32674 .24159 L p .31165 .26575 L .771 0 0 r
F P
0 g
s
.29746 .28849 m .3334 .25835 L p .31165 .26575 L .771 0 0 r
F P
0 g
s
.32674 .24159 m .25434 .30337 L .29746 .28849 L p .771 0 0 r
F P
0 g
s
.25434 .30337 m .32674 .24159 L p .31865 .34635 L .55 0 0 r
F P
0 g
s
.29591 .39014 m .33075 .39754 L p .3165 .37429 L .717 0 0 r
F P
0 g
s
.35135 .39636 m .36076 .39582 L .36293 .38781 L .421 0 0 r
F
.35135 .39636 m .36293 .38781 L .36779 .36986 L F
.36779 .36986 m .33075 .39754 L p .35135 .39636 L F P
0 g
s
.36076 .39582 m .3674 .39094 L .36779 .36986 L .421 0 0 r
F
.3165 .37429 m .31865 .34635 L .37061 .33262 L .55 0 0 r
F
.32674 .24159 m .37061 .33262 L p .31865 .34635 L F P
0 g
s
.32674 .24159 m .37116 .2267 L .43206 .35268 L p .899 0 0 r
F P
0 g
s
.43206 .35268 m .37116 .2267 L .32674 .24159 L .899 0 0 r
F
.48093 .3491 m .44896 .36124 L .37604 .21052 L p 0 .351 .734 r
F P
0 g
s
.44573 .3439 m .37116 .2267 L .43206 .35268 L .642 0 0 r
F
.4067 .34079 m .37061 .33262 L p .34851 .34964 L .717 0 0 r
F P
0 g
s
.3165 .37429 m .29703 .35207 L .31865 .34635 L .55 0 0 r
F
.36779 .36986 m .4067 .34079 L p .30541 .3562 L .717 0 0 r
F P
0 g
s
.43206 .35268 m .38821 .36915 L .32674 .24159 L p .899 0 0 r
F P
0 g
s
.43206 .35268 m .32674 .24159 L .38821 .36915 L .899 0 0 r
F
.37604 .21052 m .40852 .19975 L .48093 .3491 L p 0 .351 .734 r
F P
0 g
s
.38444 .21725 m .32674 .24159 L .37116 .2267 L .771 0 0 r
F
.38444 .21725 m .35328 .22253 L .32674 .24159 L F
.4043 .32815 m .32674 .24159 L .35328 .22253 L .637 0 0 r
F
.4067 .34079 m .42724 .3334 L .4043 .32815 L .55 0 0 r
F
.4067 .34079 m .4043 .32815 L .39758 .32904 L F
.39745 .32906 m .39334 .32398 L .4043 .32815 L .637 0 0 r
F
.39334 .32398 m .32674 .24159 L .4043 .32815 L F
.40642 .36231 m .42724 .3334 L .4067 .34079 L .421 0 0 r
F
.44573 .3439 m .43206 .35268 L .40642 .36231 L .705 0 0 r
F
.44573 .3439 m .40642 .36231 L .41034 .35944 L F
.4207 .35184 m .42724 .3334 L .40642 .36231 L .421 0 0 r
F
.29703 .35207 m .25434 .30337 L .31865 .34635 L .55 0 0 r
F
.30541 .3562 m .34851 .34964 L .27813 .3117 L .717 0 0 r
F
.37061 .33262 m .27813 .3117 L p .34851 .34964 L F P
0 g
s
.33075 .39754 m .36779 .36986 L p .30541 .3562 L .717 0 0 r
F P
0 g
s
.33075 .39754 m .20673 .37121 L .20465 .4225 L p .894 0 0 r
F P
0 g
s
.31259 .42495 m .3165 .37429 L .33747 .37278 L .55 0 0 r
F
.38821 .36915 m .34946 .39774 L p .33747 .37278 L F P
0 g
s
.34946 .39774 m .31259 .42495 L p .33747 .37278 L .55 0 0 r
F P
0 g
s
.31259 .42495 m .29591 .39014 L p .3165 .37429 L .55 0 0 r
F P
0 g
s
.37061 .33262 m .38821 .36915 L p .3165 .37429 L .55 0 0 r
F P
0 g
s
.29591 .39014 m .25434 .30337 L p .3165 .37429 L .55 0 0 r
F P
0 g
s
.3165 .37429 m .31092 .36518 L .29591 .39014 L .717 0 0 r
F
.27813 .3117 m .20673 .37121 L .29591 .39014 L p F P
0 g
s
.27647 .36522 m .29097 .36835 L p .29251 .37515 L .709 0 0 r
F P
0 g
s
.31092 .36518 m .27813 .3117 L .29591 .39014 L .717 0 0 r
F
.37411 .38602 m .36474 .39195 L .38821 .36915 L .705 0 0 r
F
.31259 .42495 m .34946 .39774 L p .36474 .39195 L F P
0 g
s
.34946 .39774 m .38821 .36915 L p .36474 .39195 L .705 0 0 r
F P
0 g
s
.33027 .41818 m .31259 .42495 L p .37411 .38602 L .705 0 0 r
F P
0 g
s
.36685 .4212 m .32958 .44782 L p .30401 .40805 L .709 0 0 r
F P
0 g
s
.3695 .44337 m .37903 .43672 L p .36761 .43648 L 0 .446 1 r
F P
0 g
s
.32958 .44782 m .20465 .4225 L .27647 .36522 L p .709 0 0 r
F P
0 g
s
.19584 .43331 m .1893 .39315 L .20673 .37121 L .37 0 0 r
F
.18963 .44686 m .1893 .39315 L .19584 .43331 L F
.18811 .45019 m .18816 .44803 L .18963 .44686 L F
.18816 .44803 m .1893 .39315 L .18963 .44686 L F
.34148 .46295 m .3695 .44337 L p .20627 .43375 L 0 .446 1 r
F P
0 g
s
.19584 .43331 m .20673 .37121 L .20465 .4225 L .37 0 0 r
F
.19129 .43286 m .20413 .43544 L p .20627 .43375 L 0 .446 1 r
F P
0 g
s
.20413 .43544 m .34148 .46295 L p .20627 .43375 L 0 .446 1 r
F P
0 g
s
.36761 .43648 m .19129 .43286 L .3695 .44337 L 0 .446 1 r
F
.37838 .47576 m .37903 .43672 L .34148 .46295 L p 0 .158 .672 r
F P
0 g
s
.20465 .4225 m .20673 .37121 L p .24059 .3683 L .37 0 0 r
F P
0 g
s
.27647 .36522 m .23965 .39459 L p .24059 .3683 L .37 0 0 r
F P
0 g
s
.23965 .39459 m .20465 .4225 L p .24059 .3683 L .37 0 0 r
F P
0 g
s
.37903 .43672 m .22609 .4051 L .22609 .4051 L p 0 .446 1 r
F P
0 g
s
.22609 .4051 m .19129 .43286 L p .37903 .43672 L 0 .446 1 r
F P
0 g
s
.37903 .43672 m .22609 .4051 L .37903 .43672 L 0 .446 1 r
F
.36661 .43415 m .23918 .4078 L p .36596 .47 L 0 .351 .737 r
F P
0 g
s
.23918 .4078 m .22609 .4051 L p .23906 .41111 L 0 .351 .737 r
F P
0 g
s
.36596 .47 m .23918 .4078 L .23906 .41111 L 0 .351 .737 r
F
.27286 .4268 m .23906 .41111 L .2934 .41901 L F
.22609 .4051 m .23918 .4078 L p .23906 .41111 L F P
0 g
s
.23918 .4078 m .2934 .41901 L p .23906 .41111 L 0 .351 .737 r
F P
0 g
s
.37838 .47576 m .37903 .43672 L .36661 .43415 L p 0 .351 .737 r
F P
0 g
s
.37838 .47576 m .36661 .43415 L .36596 .47 L 0 .351 .737 r
F
.3067 .49459 m .18811 .45019 L .31225 .47465 L .875 0 0 r
F
.34066 .50118 m .34148 .46295 L .19129 .43286 L p 0 .35 .74 r
F P
0 g
s
.34148 .46295 m .34066 .50118 L .37838 .47576 L p 0 .158 .672 r
F P
0 g
s
.22609 .4051 m .22458 .44511 L .37838 .47576 L p 0 .351 .737 r
F P
0 g
s
.22458 .44511 m .37838 .47576 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.37838 .47576 m .27286 .4268 L .36699 .43423 L 0 .351 .737 r
F
.2934 .41901 m .36699 .43423 L p .27286 .4268 L F P
0 g
s
.37838 .47576 m .22458 .44511 L .22609 .4051 L p 0 .351 .737 r
F P
0 g
s
.26138 .41678 m .22458 .44511 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.22458 .44511 m .22458 .44511 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.36732 .39544 m .38325 .37931 L .3674 .39094 L .421 0 0 r
F
.29097 .36835 m .40602 .39322 L p .29251 .37515 L .709 0 0 r
F P
0 g
s
.36076 .39582 m .36732 .39544 L .3674 .39094 L .421 0 0 r
F
.40602 .39322 m .36685 .4212 L p .29251 .37515 L .709 0 0 r
F P
0 g
s
.30401 .40805 m .27647 .36522 L .36685 .4212 L .709 0 0 r
F
.36699 .43423 m .37903 .43672 L .37867 .45852 L p 0 .351 .737 r
F P
0 g
s
.37867 .45852 m .37838 .47576 L p .36699 .43423 L 0 .351 .737 r
F P
0 g
s
.41848 .40915 m .37903 .43672 L .37838 .47576 L p 0 .158 .672 r
F P
0 g
s
.37838 .47576 m .41803 .44904 L .41848 .40915 L p 0 .158 .672 r
F P
0 g
s
.37838 .47576 m .41803 .44904 L .26138 .41678 L p 0 .448 1 r
F P
0 g
s
.40602 .39322 m .40642 .36231 L p .38325 .37931 L .421 0 0 r
F P
0 g
s
.40602 .39322 m .4067 .34079 L .27813 .3117 L .899 0 0 r
F
.4067 .34079 m .40602 .39322 L .27647 .36522 L p F P
0 g
s
.4207 .35184 m .42415 .3493 L .42724 .3334 L .421 0 0 r
F
.42415 .3493 m .38821 .36915 L .41555 .35145 L .705 0 0 r
F
.44573 .3439 m .41034 .35944 L .42415 .3493 L F
.41034 .35944 m .38821 .36915 L .42415 .3493 L F
.44081 .37753 m .40927 .38962 L .44896 .36124 L p 0 .525 .99 r
F P
0 g
s
.40602 .39322 m .41629 .3899 L .42415 .3493 L .421 0 0 r
F
.40602 .39322 m .42415 .3493 L .4207 .35184 L F
.40602 .39322 m .4207 .35184 L .40642 .36231 L F
.41034 .35944 m .40642 .36231 L .38821 .36915 L .705 0 0 r
F
.27647 .36522 m .27813 .3117 L .4067 .34079 L p .899 0 0 r
F P
0 g
s
.41555 .35145 m .38821 .36915 L .37061 .33262 L .637 0 0 r
F
.44573 .3439 m .38444 .21725 L .37116 .2267 L .642 0 0 r
F
.46405 .3339 m .38444 .21725 L .44573 .3439 L .74 0 0 r
F
.45129 .33852 m .44573 .3439 L .42415 .3493 L .705 0 0 r
F
.45129 .33852 m .42415 .3493 L .42673 .34741 L F
.42415 .3493 m .43782 .33927 L .42724 .3334 L .421 0 0 r
F
.46405 .3339 m .45129 .33852 L .45277 .33109 L .705 0 0 r
F
.45129 .33852 m .41555 .35145 L .43782 .33927 L F
.45129 .33852 m .43782 .33927 L .45277 .33109 L F
.39745 .32906 m .37061 .33262 L .3604 .31144 L .637 0 0 r
F
.39745 .32906 m .3604 .31144 L .39334 .32398 L F
.4067 .34079 m .39758 .32904 L .37924 .33148 L .55 0 0 r
F
.4067 .34079 m .37735 .33084 L .37061 .33262 L F
.41555 .35145 m .37061 .33262 L .39745 .32906 L .637 0 0 r
F
.37924 .33148 m .39529 .3261 L .37735 .33084 L .55 0 0 r
F
.39758 .32904 m .39529 .3261 L .37924 .33148 L F
.41555 .35145 m .39745 .32906 L .4043 .32815 L .637 0 0 r
F
.39758 .32904 m .4043 .32815 L .39529 .3261 L .55 0 0 r
F
.37735 .33084 m .39529 .3261 L .29731 .3037 L F
.37061 .33262 m .29731 .3037 L .27813 .3117 L F
.37735 .33084 m .29731 .3037 L .37061 .33262 L F
.45277 .33109 m .43782 .33927 L .35328 .22253 L .739 0 0 r
F
.43782 .33927 m .41555 .35145 L .4043 .32815 L F
.42724 .3334 m .43782 .33927 L .43568 .33856 L .577 0 0 r
F
.41629 .3899 m .44499 .34325 L .43782 .33927 L .421 0 0 r
F
.41629 .3899 m .43782 .33927 L .42415 .3493 L F
.42724 .3334 m .44237 .34265 L .41016 .33039 L .577 0 0 r
F
.42724 .3334 m .41016 .33039 L .4043 .32815 L F
.43782 .33927 m .4043 .32815 L .35328 .22253 L .739 0 0 r
F
.43568 .33856 m .43782 .33927 L .43692 .33932 L .577 0 0 r
F
.41016 .33039 m .43405 .33948 L .31358 .31336 L F
.43405 .33948 m .44237 .34265 L .42954 .33973 L F
.43405 .33948 m .42954 .33973 L .31358 .31336 L F
.42673 .34741 m .42415 .3493 L .41555 .35145 L .705 0 0 r
F
.46405 .3339 m .45607 .33826 L .45129 .33852 L F
.45607 .33826 m .44573 .3439 L .45129 .33852 L F
.43692 .33932 m .44499 .34325 L .44237 .34265 L .577 0 0 r
F
.43782 .33927 m .44499 .34325 L .43692 .33932 L F
.39334 .32398 m .3604 .31144 L .32674 .24159 L .637 0 0 r
F
.4043 .32815 m .31358 .31336 L .29731 .3037 L .577 0 0 r
F
.41016 .33039 m .31358 .31336 L .4043 .32815 L F
.56489 .33222 m .52386 .29747 L .54059 .27076 L p .899 0 0 r
F P
0 g
s
.54059 .27076 m .58133 .20572 L p .56608 .32304 L .899 0 0 r
F P
0 g
s
.56489 .33222 m .54059 .27076 L .56608 .32304 L .899 0 0 r
F
.56489 .33222 m .58133 .20572 L .52386 .29747 L F
.55956 .26559 m .54059 .27076 L .58133 .20572 L .433 0 0 r
F
.55755 .30555 m .54611 .27066 L .54059 .27076 L .466 0 0 r
F
.5578 .27044 m .54059 .27076 L .55956 .26559 L .433 0 0 r
F
.54611 .27066 m .54533 .26828 L .54059 .27076 L .466 0 0 r
F
.58133 .20572 m .62104 .23998 L .56489 .33222 L p .899 0 0 r
F P
0 g
s
.56489 .33222 m .62104 .23998 L .58133 .20572 L .899 0 0 r
F
.55755 .30555 m .57307 .29261 L .5622 .27036 L .466 0 0 r
F
.5578 .27044 m .55919 .26662 L .5622 .27036 L .433 0 0 r
F
.55919 .26662 m .58133 .20572 L .5622 .27036 L F
.5622 .27036 m .5129 .1609 L .51292 .16943 L .1 0 0 r
F
.63498 .2348 m .58133 .20572 L .62104 .23998 L .669 0 0 r
F
.63498 .2348 m .60903 .19485 L .58133 .20572 L F
.58843 .28955 m .57363 .28869 L .60903 .19485 L .683 0 0 r
F
.57307 .29261 m .56482 .27456 L .5622 .27036 L .1 0 0 r
F
.55755 .30555 m .5622 .27036 L .54611 .27066 L .466 0 0 r
F
.57363 .28869 m .5622 .27036 L .60903 .19485 L .683 0 0 r
F
.5622 .27036 m .58133 .20572 L .60903 .19485 L .433 0 0 r
F
.57307 .29261 m .57363 .28869 L .5129 .1609 L .1 0 0 r
F
.57363 .28869 m .57401 .28602 L .56664 .27094 L F
.57363 .28869 m .56664 .27094 L .5129 .1609 L F
.6521 .31838 m .58763 .42832 L .55786 .40336 L p 0 .351 .737 r
F P
0 g
s
.62343 .29382 m .6521 .31838 L .69492 .29017 L p 0 .355 .953 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .62343 .29382 L p 0 .351 .737 r
F P
0 g
s
.62343 .29382 m .6521 .31838 L p .55786 .40336 L 0 .351 .737 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .55786 .40336 L 0 .351 .737 r
F
.62343 .29382 m .55786 .40336 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.69492 .29017 m .66572 .26493 L .62343 .29382 L p 0 .355 .953 r
F P
0 g
s
.66572 .26493 m .62343 .29382 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.62343 .29382 m .62343 .29382 L p .55786 .40336 L 0 .05 .286 r
F P
0 g
s
.55786 .40336 m .5999 .37621 L .66572 .26493 L p 0 .05 .286 r
F P
0 g
s
.55786 .40336 m .62343 .29382 L .66572 .26493 L p 0 .05 .286 r
F P
0 g
s
.66572 .26493 m .5999 .37621 L .55786 .40336 L p 0 .05 .286 r
F P
0 g
s
.5999 .37621 m .56934 .35037 L .63633 .23952 L p 0 .351 .734 r
F P
0 g
s
.57887 .32745 m .62104 .23998 L .56489 .33222 L .453 0 0 r
F
.57887 .32745 m .63498 .2348 L .62104 .23998 L F
.59712 .32868 m .63498 .2348 L .57887 .32745 L .687 0 0 r
F
.59712 .32868 m .58507 .31775 L .58843 .28955 L .656 0 0 r
F
.54059 .27076 m .49831 .18406 L p .51754 .27705 L .584 0 0 r
F P
0 g
s
.5167 .3209 m .55755 .30555 L .49831 .18406 L .899 0 0 r
F
.45691 .19794 m .49831 .18406 L .55755 .30555 L p F P
0 g
s
.55755 .30555 m .5167 .3209 L .45691 .19794 L p .899 0 0 r
F P
0 g
s
.54082 .31184 m .57307 .29261 L .55755 .30555 L .705 0 0 r
F
.55574 .30131 m .57307 .29261 L .54082 .31184 L F
.57887 .32745 m .56489 .33222 L .52386 .29747 L .656 0 0 r
F
.55936 .29876 m .52386 .29747 L .55163 .2874 L F
.55574 .30131 m .55936 .29876 L .57307 .29261 L .705 0 0 r
F
.57887 .32745 m .54492 .30894 L .55936 .29876 L .656 0 0 r
F
.54492 .30894 m .52386 .29747 L .55936 .29876 L F
.5167 .3209 m .52419 .31451 L .55936 .29876 L .705 0 0 r
F
.5167 .3209 m .55936 .29876 L .55574 .30131 L F
.5167 .3209 m .55574 .30131 L .54082 .31184 L F
.56205 .29686 m .55163 .2874 L .57363 .28869 L .656 0 0 r
F
.57363 .28869 m .55163 .2874 L .5622 .27036 L .683 0 0 r
F
.56205 .29686 m .55936 .29876 L .55163 .2874 L .656 0 0 r
F
.52419 .31451 m .57401 .28602 L .57363 .28869 L .705 0 0 r
F
.55936 .29876 m .57363 .28869 L .57307 .29261 L F
.52419 .31451 m .57363 .28869 L .55936 .29876 L F
.59712 .32868 m .57887 .32745 L .55936 .29876 L .656 0 0 r
F
.59712 .32868 m .55936 .29876 L .56205 .29686 L F
.58507 .31775 m .56205 .29686 L .57363 .28869 L F
.58507 .31775 m .57363 .28869 L .58843 .28955 L F
.56482 .27456 m .56382 .27236 L .5622 .27036 L .1 0 0 r
F
.56382 .27236 m .5129 .1609 L .5622 .27036 L F
.54611 .27066 m .5622 .27036 L .51292 .16943 L .466 0 0 r
F
.55163 .2874 m .5578 .27044 L .5622 .27036 L .433 0 0 r
F
.55163 .2874 m .54059 .27076 L .5578 .27044 L F
.55163 .2874 m .52386 .29747 L .54059 .27076 L F
.54533 .26828 m .51292 .16943 L .54059 .27076 L .466 0 0 r
F
.5589 .56329 m .6667 .58367 L .6692 .60089 L .893 0 0 r
F
0 g
.63969 .59743 m
.64745 .59348 L
s
.56076 .54363 m .6667 .58367 L .5589 .56329 L .888 0 0 r
F
0 g
.6667 .58367 m
.66837 .56445 L
s
.51426 .44767 m .541 .48802 L .50546 .47447 L .656 0 0 r
F
.49762 .43672 m .50546 .47447 L .47266 .45292 L F
.49762 .43672 m .51426 .44767 L .50546 .47447 L F
.54849 .63817 m .67523 .66971 L .65682 .65701 L .73 0 0 r
F
.67556 .61352 m .65682 .65701 L .67523 .66971 L .529 0 0 r
F
.53701 .6124 m .54849 .63817 L .65682 .65701 L .879 0 0 r
F
.6692 .60089 m .65682 .65701 L .67556 .61352 L .529 0 0 r
F
0 g
.64445 .63159 m
.65682 .65701 L
s
.48479 .42322 m .47266 .45292 L .44718 .42634 L .656 0 0 r
F
.48479 .42322 m .49762 .43672 L .47266 .45292 L F
0 g
.47266 .45292 m
.50546 .47447 L
s
.47266 .45292 m
.49762 .43672 L
s
.49762 .43672 m
.50742 .42065 L
s
.56106 .58081 m .6692 .60089 L .67556 .61352 L .88 0 0 r
F
.5589 .56329 m .6692 .60089 L .56106 .58081 L .893 0 0 r
F
0 g
.6667 .58367 m
.6692 .60089 L
s
.56076 .54363 m .53293 .57765 L .53665 .53894 L .502 0 0 r
F
.56635 .52471 m .53665 .53894 L .54761 .50166 L F
.56635 .52471 m .56076 .54363 L .53665 .53894 L F
0 g
.53665 .53894 m
.54761 .50166 L
s
.56214 .45234 m
.56512 .44729 L
s
.56512 .44729 m
.56976 .43941 L
s
.55427 .48943 m
.55427 .48943 L
s
.51426 .44767 m .5323 .45448 L .541 .48802 L .656 0 0 r
F
0 g
.541 .48802 m
.55427 .48943 L
s
.50546 .47447 m
.541 .48802 L
s
.54761 .50166 m
.55427 .48943 L
s
.5589 .56329 m .53701 .6124 L .53293 .57765 L .502 0 0 r
F
0 g
.55101 .581 m
.58149 .58665 L
s
.56076 .54363 m .5589 .56329 L .53293 .57765 L .502 0 0 r
F
0 g
.53293 .57765 m
.53665 .53894 L
s
.47769 .40913 m .44718 .42634 L .43273 .39842 L .656 0 0 r
F
.47769 .40913 m .48479 .42322 L .44718 .42634 L F
0 g
.44718 .42634 m
.47266 .45292 L
s
.43532 .40341 m
.44718 .42634 L
s
.58511 .49963 m
.5897 .50056 L
s
.67556 .61352 m .67523 .66971 L .68488 .61959 L .529 0 0 r
F
.56697 .5936 m .67556 .61352 L .68488 .61959 L .712 0 0 r
F
.56106 .58081 m .67556 .61352 L .56697 .5936 L .88 0 0 r
F
0 g
.6692 .60089 m
.67556 .61352 L
s
.70616 .60784 m .70515 .57155 L .57452 .54633 L p 0 .35 .74 r
F P
0 g
s
.74866 .54955 m .70515 .57155 L .70616 .60784 L p 0 .207 .719 r
F P
0 g
s
.70515 .57155 m .74866 .54955 L .6161 .52314 L p 0 .448 1 r
F P
0 g
s
.6161 .52314 m .57452 .54633 L .70515 .57155 L p 0 .448 1 r
F P
0 g
s
.70515 .57155 m .57452 .54633 L .6161 .52314 L p 0 .448 1 r
F P
0 g
s
.6161 .52314 m .74866 .54955 L .74866 .54955 L p 0 .448 1 r
F P
0 g
s
.74866 .54955 m .70515 .57155 L p .6161 .52314 L 0 .448 1 r
F P
0 g
s
.74866 .54955 m .6161 .52314 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.6161 .52314 m .74866 .54955 L .6161 .52314 L 0 .448 1 r
F
.70616 .60784 m .7499 .58659 L .74866 .54955 L p 0 .207 .719 r
F P
0 g
s
.7499 .58659 m .74866 .54955 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.74866 .54955 m .74866 .54955 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.56697 .5936 m .68488 .61959 L .57579 .59968 L .712 0 0 r
F
.57579 .59968 m .68488 .61959 L .6958 .61806 L .445 0 0 r
F
.54849 .63817 m .55541 .64323 L .5603 .64111 L .73 0 0 r
F
.56697 .5936 m .56615 .63777 L .54849 .63817 L .502 0 0 r
F
.56869 .63648 m .56536 .63817 L .57576 .63326 L .452 0 0 r
F
.56615 .63777 m .55541 .64323 L .54849 .63817 L .502 0 0 r
F
.56536 .63817 m .55541 .64323 L .57576 .63326 L .452 0 0 r
F
.54681 .64694 m .55541 .64323 L .56536 .63817 L F
.56697 .5936 m .57579 .59968 L .56869 .63648 L .502 0 0 r
F
.5603 .64111 m .55541 .64323 L .67523 .66971 L .73 0 0 r
F
.57888 .65177 m .5419 .64984 L .54305 .65222 L .747 0 0 r
F
.57926 .65402 m .54305 .65222 L .59827 .76667 L F
.57888 .65177 m .54305 .65222 L .57926 .65402 L F
.56673 .64573 m .58596 .65435 L .67523 .66971 L .73 0 0 r
F
.55541 .64323 m .58596 .65435 L .56673 .64573 L F
.60245 .61992 m .57576 .63326 L .58596 .65435 L .658 0 0 r
F
.61318 .66656 m .58596 .65435 L .63253 .75065 L F
.68488 .61959 m .67523 .66971 L .69708 .66727 L .529 0 0 r
F
.58596 .65435 m .69708 .66727 L .67523 .66971 L .406 0 0 r
F
.60245 .61992 m .58596 .65435 L .61026 .65387 L .658 0 0 r
F
.55541 .64323 m .5419 .64984 L .57888 .65177 L .747 0 0 r
F
.58596 .65435 m .59827 .76667 L .63253 .75065 L F
.57576 .63326 m .57926 .65402 L .58596 .65435 L F
.57926 .65402 m .59827 .76667 L .58596 .65435 L F
.55541 .64323 m .56591 .6509 L .582 .65291 L .73 0 0 r
F
.57576 .63326 m .55541 .64323 L .57888 .65177 L .747 0 0 r
F
.60876 .6545 m .61882 .6537 L .63722 .65689 L .406 0 0 r
F
.60298 .65402 m .61882 .6537 L .60876 .6545 L F
.59857 .65497 m .63722 .65689 L .69708 .66727 L F
.59857 .65497 m .69708 .66727 L .58596 .65435 L F
.60245 .61992 m .61026 .65387 L .61882 .6537 L .658 0 0 r
F
.68488 .61959 m .69708 .66727 L .6958 .61806 L .529 0 0 r
F
.58682 .64816 m .69708 .66727 L .6958 .61806 L p .894 0 0 r
F P
0 g
s
.78524 .57485 m .6958 .61806 L .69708 .66727 L p .529 0 0 r
F P
0 g
s
.57579 .59968 m .58039 .60039 L .58625 .59799 L .445 0 0 r
F
.58039 .60039 m .6958 .61806 L .59236 .59911 L F
.58039 .60039 m .59236 .59911 L .58625 .59799 L F
.59424 .60299 m .6958 .61806 L .69708 .66727 L .894 0 0 r
F
.58625 .59799 m .59236 .59911 L .59424 .60299 L F
.59236 .59911 m .6958 .61806 L .59424 .60299 L F
.69708 .66727 m .78721 .62613 L .78524 .57485 L p .529 0 0 r
F P
0 g
s
.56697 .5936 m .56869 .63648 L .56615 .63777 L .502 0 0 r
F
.58658 .62739 m .57576 .63326 L .60245 .61992 L .452 0 0 r
F
.57212 .63474 m .57576 .63326 L .58658 .62739 L F
.56869 .63648 m .58682 .64816 L .56591 .6509 L .502 0 0 r
F
.57579 .59968 m .58256 .62944 L .56869 .63648 L F
.57212 .63474 m .56869 .63648 L .57576 .63326 L .452 0 0 r
F
.58256 .62944 m .58682 .64816 L .56869 .63648 L .502 0 0 r
F
.56372 .63816 m .55035 .64485 L .56869 .63648 L .452 0 0 r
F
.56372 .63816 m .56869 .63648 L .57212 .63474 L F
.57579 .59968 m .58625 .59799 L .58658 .62739 L .502 0 0 r
F
.58256 .62944 m .58658 .62739 L .58682 .64816 L F
.57579 .59968 m .58658 .62739 L .58256 .62944 L F
.58658 .62739 m .69708 .66727 L .58682 .64816 L .894 0 0 r
F
.58625 .59799 m .61322 .61485 L .58658 .62739 L F
.61322 .61485 m .69708 .66727 L .58658 .62739 L F
.57452 .54633 m .5749 .58347 L .70616 .60784 L p 0 .35 .74 r
F P
0 g
s
.70616 .60784 m .5749 .58347 L .6167 .56105 L p 0 .45 1 r
F P
0 g
s
.6167 .56105 m .7499 .58659 L .70616 .60784 L p 0 .45 1 r
F P
0 g
s
.62808 .56323 m .7499 .58659 L p .62748 .52853 L 0 .351 .737 r
F P
0 g
s
.74866 .54955 m .7499 .58659 L .79574 .56432 L p 0 .207 .719 r
F P
0 g
s
.6161 .52314 m .74866 .54955 L .7499 .58659 L p 0 .351 .737 r
F P
0 g
s
.6161 .52314 m .6167 .56105 L .62808 .56323 L p 0 .351 .737 r
F P
0 g
s
.6161 .52314 m .62808 .56323 L .62748 .52853 L 0 .351 .737 r
F
.6167 .56105 m .6161 .52314 L p .62748 .52853 L F P
0 g
s
.7499 .58659 m .62808 .56323 L p .62748 .52853 L 0 .351 .737 r
F P
0 g
s
.62808 .56323 m .6167 .56105 L p .62748 .52853 L 0 .351 .737 r
F P
0 g
s
.79574 .56432 m .7499 .58659 L .62808 .56323 L p 0 .45 1 r
F P
0 g
s
.62808 .56323 m .6167 .56105 L p .63167 .56132 L 0 .45 1 r
F P
0 g
s
.63167 .56132 m .79574 .56432 L .62808 .56323 L 0 .45 1 r
F
.58625 .59799 m .6958 .61806 L .78524 .57485 L p .689 0 0 r
F P
0 g
s
.62874 .60145 m .62859 .59306 L .63716 .59207 L .502 0 0 r
F
.6167 .56105 m .66055 .53753 L .79574 .56432 L p 0 .45 1 r
F P
0 g
s
.78524 .57485 m .67241 .55278 L .58625 .59799 L p .689 0 0 r
F P
0 g
s
.62859 .59306 m .6283 .57593 L .63716 .59207 L .502 0 0 r
F
.6283 .57593 m .67241 .55278 L p .63716 .59207 L F P
0 g
s
.6958 .61806 m .58625 .59799 L .58682 .64816 L p .894 0 0 r
F P
0 g
s
.60245 .61992 m .68935 .57582 L p .63643 .60208 L .452 0 0 r
F P
0 g
s
.58625 .59799 m .6283 .57593 L p .60375 .61868 L .502 0 0 r
F P
0 g
s
.58658 .62739 m .58625 .59799 L p .60375 .61868 L .502 0 0 r
F P
0 g
s
.58658 .62739 m .60245 .61992 L p .63643 .60208 L .452 0 0 r
F P
0 g
s
.78721 .62613 m .69708 .66727 L .61882 .6537 L p .678 0 0 r
F P
0 g
s
.60245 .61992 m .64305 .64198 L .69535 .58813 L .584 0 0 r
F
.64305 .64198 m .78721 .62613 L .61882 .6537 L .678 0 0 r
F
.70661 .61122 m .69535 .58813 L p .64305 .64198 L .584 0 0 r
F P
0 g
s
.60245 .61992 m .61882 .6537 L p .64305 .64198 L .584 0 0 r
F P
0 g
s
.56372 .63816 m .57212 .63474 L .58658 .62739 L .452 0 0 r
F
.56591 .6509 m .63722 .65689 L .59857 .65497 L .406 0 0 r
F
.61882 .6537 m .63253 .75065 L .6599 .73847 L .658 0 0 r
F
.61026 .65387 m .63253 .75065 L .61882 .6537 L F
.56591 .6509 m .58682 .64816 L .61882 .6537 L .406 0 0 r
F
.56591 .6509 m .61882 .6537 L .60298 .65402 L F
.56591 .6509 m .59252 .65422 L .58596 .65435 L F
.59252 .65422 m .59857 .65497 L .58596 .65435 L F
.61026 .65387 m .58596 .65435 L .61318 .66656 L .658 0 0 r
F
.56615 .63777 m .56869 .63648 L .56591 .6509 L .502 0 0 r
F
.56615 .63777 m .56591 .6509 L .55541 .64323 L F
.55035 .64485 m .54681 .64694 L .56536 .63817 L .452 0 0 r
F
.55035 .64485 m .56536 .63817 L .56869 .63648 L F
.6599 .73847 m .60245 .61992 L .56372 .63816 L p .894 0 0 r
F P
0 g
s
.56372 .63816 m .60245 .61992 L .6599 .73847 L .894 0 0 r
F
.78524 .57485 m .78721 .62613 L .67362 .60511 L p .899 0 0 r
F P
0 g
s
.69535 .58813 m .68935 .57582 L .65705 .59221 L p .584 0 0 r
F P
0 g
s
.65705 .59221 m .60245 .61992 L p .69535 .58813 L .584 0 0 r
F P
0 g
s
.62126 .60979 m .6283 .57593 L .62874 .60145 L .502 0 0 r
F
.58682 .64816 m .60375 .61868 L .62126 .60979 L F
.60375 .61868 m .6283 .57593 L .62126 .60979 L F
.68935 .57582 m .67312 .58345 L p .65459 .59286 L .452 0 0 r
F P
0 g
s
.58682 .64816 m .62126 .60979 L .62887 .60911 L .502 0 0 r
F
.62918 .62716 m .58682 .64816 L p .62887 .60911 L F P
0 g
s
.67241 .55278 m .67312 .58345 L p .62126 .60979 L .502 0 0 r
F P
0 g
s
.60568 .61684 m .56372 .63816 L p .62538 .60756 L .452 0 0 r
F P
0 g
s
.58682 .64816 m .62918 .62716 L p .68577 .63728 L .678 0 0 r
F P
0 g
s
.56372 .63816 m .58658 .62739 L p .63643 .60208 L .452 0 0 r
F P
0 g
s
.58682 .64816 m .58658 .62739 L p .60375 .61868 L .502 0 0 r
F P
0 g
s
.61882 .6537 m .58682 .64816 L p .64305 .64198 L .678 0 0 r
F P
0 g
s
.60797 .76419 m .63253 .75065 L .59827 .76667 L .1 0 0 r
F
.62168 .75811 m .63253 .75065 L .60797 .76419 L F
.54681 .64694 m .5419 .64984 L .55541 .64323 L .452 0 0 r
F
.56106 .58081 m .54849 .63817 L .53701 .6124 L .502 0 0 r
F
.56106 .58081 m .56697 .5936 L .54849 .63817 L F
.5419 .64984 m .56187 .78431 L .59827 .76667 L .806 0 0 r
F
.5419 .64984 m .5056 .66737 L .56187 .78431 L F
.53317 .65326 m .5056 .66737 L .5419 .64984 L .452 0 0 r
F
.55035 .64485 m .53317 .65326 L .5419 .64984 L F
.53317 .65326 m .51468 .66219 L .5056 .66737 L F
.59058 .77232 m .59827 .76667 L .56187 .78431 L .1 0 0 r
F
.59058 .77232 m .56187 .78431 L .57204 .7813 L F
.53317 .65326 m .57204 .7813 L .51468 .66219 L .806 0 0 r
F
.53317 .65326 m .59058 .77232 L .57204 .7813 L F
.55035 .64485 m .59058 .77232 L .53317 .65326 L .745 0 0 r
F
.60797 .76419 m .59827 .76667 L .59058 .77232 L .1 0 0 r
F
.55035 .64485 m .60797 .76419 L .59058 .77232 L .745 0 0 r
F
.56372 .63816 m .60797 .76419 L .55035 .64485 L .654 0 0 r
F
.56372 .63816 m .62168 .75811 L .60797 .76419 L F
.54811 .6308 m .51829 .64473 L p .60956 .76433 L 0 .35 .74 r
F P
0 g
s
.61782 .77516 m .61199 .76308 L p .60956 .76433 L 0 .35 .74 r
F P
0 g
s
.61199 .76308 m .54811 .6308 L p .60956 .76433 L 0 .35 .74 r
F P
0 g
s
.62168 .75811 m .6599 .73847 L .63253 .75065 L .1 0 0 r
F
.56372 .63816 m .62168 .75811 L .6599 .73847 L p .894 0 0 r
F P
0 g
s
.56372 .63816 m .6599 .73847 L .62168 .75811 L .894 0 0 r
F
.6599 .73847 m .74993 .70005 L p .65881 .65054 L .584 0 0 r
F P
0 g
s
.61882 .6537 m .6599 .73847 L p .65881 .65054 L .584 0 0 r
F P
0 g
s
.6599 .73847 m .62168 .75811 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.74993 .70005 m .70383 .71972 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.70383 .71972 m .6599 .73847 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.62168 .75811 m .56372 .63816 L p .63538 .67812 L .577 0 0 r
F P
0 g
s
.71087 .7202 m .74993 .70005 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.62168 .75811 m .66519 .73961 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.66519 .73961 m .71087 .7202 L p .68462 .72961 L .1 0 0 r
F P
0 g
s
.66519 .73961 m .62168 .75811 L p .63538 .67812 L .577 0 0 r
F P
0 g
s
.67362 .60511 m .62918 .62716 L p .62887 .60911 L .502 0 0 r
F P
0 g
s
.63643 .60208 m .68935 .57582 L .65459 .59286 L .452 0 0 r
F
.67312 .58345 m .67362 .60511 L p .62126 .60979 L .502 0 0 r
F P
0 g
s
.62538 .60756 m .63643 .60208 L .60568 .61684 L .452 0 0 r
F
.63643 .60208 m .65459 .59286 L .60568 .61684 L F
.64972 .59445 m .60568 .61684 L p .65459 .59286 L F P
0 g
s
.62918 .62716 m .67362 .60511 L p .68577 .63728 L .678 0 0 r
F P
0 g
s
.68577 .63728 m .68327 .63067 L .78721 .62613 L .678 0 0 r
F
.67362 .60511 m .70661 .61122 L p .68327 .63067 L F P
0 g
s
.70661 .61122 m .78721 .62613 L p .68327 .63067 L .678 0 0 r
F P
0 g
s
.74993 .70005 m .70661 .61122 L p .64305 .64198 L .584 0 0 r
F P
0 g
s
.64305 .64198 m .61882 .6537 L .65881 .65054 L .584 0 0 r
F
.56372 .63816 m .64972 .59445 L .71087 .7202 L p .577 0 0 r
F P
0 g
s
.61782 .77516 m .66138 .75702 L .5898 .60924 L p 0 .278 .858 r
F P
0 g
s
.63072 .71675 m .65293 .74592 L .63031 .69288 L 0 .351 .737 r
F
.65539 .74466 m .63031 .69288 L p .65293 .74592 L F P
0 g
s
.5898 .60924 m .54811 .6308 L .61782 .77516 L p 0 .278 .858 r
F P
0 g
s
.56812 .63451 m .63072 .71675 L .59574 .62151 L 0 .351 .737 r
F
.63031 .69288 m .59574 .62151 L p .63072 .71675 L F P
0 g
s
.54811 .6308 m .5898 .60924 L .55961 .62332 L p 0 .458 .794 r
F P
0 g
s
.55961 .62332 m .56812 .63451 L .59556 .62114 L 0 .351 .737 r
F
.59574 .62151 m .59556 .62114 L p .56812 .63451 L F P
0 g
s
.59556 .62114 m .5898 .60924 L .57296 .61709 L p 0 .351 .737 r
F P
0 g
s
.57296 .61709 m .55961 .62332 L p .59556 .62114 L 0 .351 .737 r
F P
0 g
s
.51829 .64473 m .58847 .79036 L .61782 .77516 L p 0 .35 .74 r
F P
0 g
s
.5056 .66737 m .5283 .80115 L .56187 .78431 L .861 0 0 r
F
.57204 .7813 m .56187 .78431 L .5283 .80115 L .1 0 0 r
F
.55502 .78985 m .5283 .80115 L .50225 .81486 L F
.5056 .66737 m .4718 .68346 L .5283 .80115 L .861 0 0 r
F
.51468 .66219 m .4718 .68346 L .5056 .66737 L .452 0 0 r
F
.51468 .66219 m .49754 .67035 L .4718 .68346 L F
.57204 .7813 m .5283 .80115 L .55502 .78985 L .1 0 0 r
F
.49754 .67035 m .5283 .80115 L .55502 .78985 L .568 0 0 r
F
.49754 .67035 m .55502 .78985 L .5283 .80115 L F
.51468 .66219 m .55502 .78985 L .49754 .67035 L .862 0 0 r
F
.51468 .66219 m .57204 .7813 L .55502 .78985 L F
.55502 .78985 m .50225 .81486 L .54201 .79671 L .1 0 0 r
F
.49754 .67035 m .55502 .78985 L .54201 .79671 L .927 0 0 r
F
.55861 .80583 m .58847 .79036 L .51829 .64473 L p 0 .35 .74 r
F P
0 g
s
.49754 .67035 m .44522 .69584 L .4718 .68346 L .452 0 0 r
F
.49754 .67035 m .4718 .68346 L .5283 .80115 L .568 0 0 r
F
.49754 .67035 m .5283 .80115 L .4718 .68346 L F
.49754 .67035 m .48426 .67653 L .44522 .69584 L .452 0 0 r
F
.49754 .67035 m .54201 .79671 L .48426 .67653 L .927 0 0 r
F
.51829 .64473 m .48795 .65889 L .55861 .80583 L p 0 .35 .74 r
F P
0 g
s
.55961 .62332 m .51829 .64473 L .54811 .6308 L p 0 .458 .794 r
F P
0 g
s
.55961 .62332 m .51829 .64473 L .58847 .79036 L p 0 .276 .858 r
F P
0 g
s
.58847 .79036 m .51829 .64473 L .55961 .62332 L p 0 .276 .858 r
F P
0 g
s
.61782 .77516 m .58847 .79036 L .63168 .77244 L p 0 .05 .1 r
F P
0 g
s
.48795 .65889 m .51829 .64473 L .55961 .62332 L p 0 .458 .794 r
F P
0 g
s
.63168 .77244 m .58847 .79036 L .55861 .80583 L p 0 .05 .1 r
F P
0 g
s
.63168 .77244 m .66138 .75702 L .61782 .77516 L p 0 .05 .1 r
F P
0 g
s
.58847 .79036 m .63168 .77244 L .55961 .62332 L p 0 .276 .858 r
F P
0 g
s
.63168 .77244 m .66138 .75702 L p .65293 .74592 L 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .56559 .6357 L p .56812 .63451 L 0 .351 .737 r
F P
0 g
s
.56559 .6357 m .62565 .75997 L p .56812 .63451 L 0 .351 .737 r
F P
0 g
s
.56812 .63451 m .62565 .75997 L .65293 .74592 L 0 .351 .737 r
F
.62565 .75997 m .63168 .77244 L p .65293 .74592 L F P
0 g
s
.59574 .62151 m .65539 .74466 L p .56835 .6344 L 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .63168 .77244 L .63168 .77244 L p 0 .276 .858 r
F P
0 g
s
.55961 .62332 m .59574 .62151 L .56835 .6344 L 0 .351 .737 r
F
.66138 .75702 m .65539 .74466 L p .65293 .74592 L F P
0 g
s
.65539 .74466 m .66138 .75702 L p .65293 .74592 L 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .65539 .74466 L .65293 .74592 L 0 .351 .737 r
F
.71087 .7202 m .66519 .73961 L p .63538 .67812 L .577 0 0 r
F P
0 g
s
.5898 .60924 m .66138 .75702 L .70711 .73798 L p 0 .278 .858 r
F P
0 g
s
.70711 .73798 m .66138 .75702 L .63168 .77244 L p 0 .05 .1 r
F P
0 g
s
.66138 .75702 m .63168 .77244 L .62565 .75997 L p 0 .351 .737 r
F P
0 g
s
.62565 .75997 m .55961 .62332 L p .65293 .74592 L 0 .351 .737 r
F P
0 g
s
.65293 .74592 m .66138 .75702 L .62565 .75997 L 0 .351 .737 r
F
.63168 .77244 m .67707 .75362 L .70711 .73798 L p 0 .05 .1 r
F P
0 g
s
.63168 .77244 m .67707 .75362 L p .55961 .62332 L 0 .276 .858 r
F P
0 g
s
.55961 .62332 m .63168 .77244 L .55961 .62332 L 0 .276 .858 r
F
.55961 .62332 m .62565 .75997 L .62565 .75997 L p F P
0 g
s
.63168 .77244 m .58847 .79036 L p .55961 .62332 L 0 .276 .858 r
F P
0 g
s
.63168 .77244 m .55961 .62332 L p .55961 .62332 L 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .63168 .77244 L .55961 .62332 L 0 .276 .858 r
F
.55861 .80583 m .60146 .78814 L .63168 .77244 L p 0 .05 .1 r
F P
0 g
s
.60146 .78814 m .63168 .77244 L p .55961 .62332 L 0 .351 .737 r
F P
0 g
s
.63168 .77244 m .63168 .77244 L p .55961 .62332 L 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .52888 .63764 L .48795 .65889 L p 0 .458 .794 r
F P
0 g
s
.43506 .66792 m .45936 .68732 L p .483 .67524 L .617 0 0 r
F P
0 g
s
.55861 .80583 m .48795 .65889 L .52888 .63764 L p 0 .274 .858 r
F P
0 g
s
.49273 .67028 m .50369 .66483 L .5 .66656 L .452 0 0 r
F
.43506 .66792 m .483 .67524 L .49631 .66359 L .617 0 0 r
F
.4836 .6759 m .52456 .65501 L p .47587 .67888 L .452 0 0 r
F P
0 g
s
.43506 .66792 m .44545 .69442 L .45936 .68732 L .617 0 0 r
F
.4718 .68346 m .44522 .69584 L .50225 .81486 L .925 0 0 r
F
.47767 .76355 m .4877 .82336 L .50225 .81486 L 1 0 0 r
F
.44522 .69584 m .46174 .74543 L .47767 .76355 L F
.46174 .74543 m .4877 .82336 L .47767 .76355 L F
.44522 .69584 m .42992 .70263 L .4877 .82336 L F
.48426 .67653 m .42992 .70263 L .44522 .69584 L .452 0 0 r
F
.48426 .67653 m .47686 .6798 L .42992 .70263 L F
.47686 .6798 m .43972 .69735 L .42992 .70263 L F
.42198 .67068 m .41701 .69454 L .43382 .70036 L .617 0 0 r
F
.42198 .67068 m .43382 .70036 L .44216 .6961 L F
.43972 .69735 m .4294 .70262 L .42992 .70263 L .452 0 0 r
F
.47686 .6798 m .47657 .6796 L .44216 .6961 L F
.41701 .69454 m .42323 .70161 L .4294 .70262 L .617 0 0 r
F
.42992 .70263 m .43513 .71377 L .43684 .7171 L .817 0 0 r
F
.43129 .70556 m .43474 .71392 L .48729 .82518 L F
.4294 .70262 m .43916 .72461 L .48729 .82518 L F
.43684 .7171 m .48729 .82518 L .4877 .82336 L F
.43513 .71377 m .48729 .82518 L .43684 .7171 L F
.4718 .68346 m .50225 .81486 L .5283 .80115 L .925 0 0 r
F
.47633 .70086 m .44998 .70596 L .43916 .72461 L .512 0 0 r
F
.44547 .73989 m .43916 .72461 L .38859 .81181 L F
.54201 .79671 m .50225 .81486 L .4877 .82336 L .1 0 0 r
F
.54201 .79671 m .4877 .82336 L .53499 .80084 L F
.53499 .80084 m .4877 .82336 L .48729 .82518 L F
.53499 .80084 m .48729 .82518 L .53515 .80158 L F
.53515 .80158 m .48729 .82518 L .50171 .81973 L F
.44328 .73322 m .50171 .81973 L .48729 .82518 L .383 0 0 r
F
.44468 .73301 m .50171 .81973 L .44328 .73322 L F
.44314 .72585 m .50171 .81973 L .43916 .72461 L F
.47633 .70086 m .43916 .72461 L .45391 .72921 L .512 0 0 r
F
.42992 .70263 m .4294 .70262 L .43474 .71392 L .817 0 0 r
F
.42992 .70263 m .43474 .71392 L .43129 .70556 L F
.43689 .71949 m .41579 .70041 L .354 .8052 L .705 0 0 r
F
.4294 .70262 m .41579 .70041 L .43689 .71949 L F
.44998 .70596 m .4353 .72114 L .43916 .72461 L F
.4294 .70262 m .42862 .70259 L .43028 .7046 L .817 0 0 r
F
.43028 .7046 m .42862 .70259 L .43916 .72461 L F
.44998 .70596 m .4294 .70262 L .43689 .71949 L .705 0 0 r
F
.42922 .70227 m .4294 .70262 L .44697 .70547 L .617 0 0 r
F
.42922 .70227 m .42986 .70238 L .42986 .70238 L F
.42704 .69801 m .42922 .70227 L .44998 .70596 L F
.41701 .69454 m .4294 .70262 L .42704 .69801 L F
.43506 .66792 m .42198 .67068 L .44216 .6961 L F
.47657 .6796 m .45549 .68929 L .44216 .6961 L .452 0 0 r
F
.47686 .6798 m .44216 .6961 L .43972 .69735 L F
.44545 .69442 m .44216 .6961 L .44998 .70596 L .617 0 0 r
F
.43506 .66792 m .44216 .6961 L .44545 .69442 L F
.44216 .6961 m .44216 .69542 L .42862 .70259 L .452 0 0 r
F
.45549 .68929 m .44216 .69542 L .44216 .6961 L F
.42986 .70238 m .44697 .70547 L .44998 .70596 L .617 0 0 r
F
.42986 .70238 m .44697 .70547 L .42986 .70238 L F
.43972 .69735 m .44216 .6961 L .42862 .70259 L .452 0 0 r
F
.43972 .69735 m .42862 .70259 L .4294 .70262 L F
.44216 .6961 m .43382 .70036 L .44998 .70596 L .617 0 0 r
F
.44948 .72783 m .45913 .73084 L .469 .75144 L .383 0 0 r
F
.44645 .73117 m .469 .75144 L .50171 .81973 L F
.42862 .70259 m .469 .75144 L .44645 .73117 L F
.45913 .73084 m .38859 .81181 L .41492 .80785 L .512 0 0 r
F
.47633 .70086 m .45391 .72921 L .45913 .73084 L F
.45391 .72921 m .38859 .81181 L .45913 .73084 L F
.42862 .70259 m .44216 .69542 L .45913 .73084 L .383 0 0 r
F
.42862 .70259 m .45913 .73084 L .44948 .72783 L F
.43916 .72461 m .354 .8052 L .38859 .81181 L .705 0 0 r
F
.4353 .72114 m .354 .8052 L .43916 .72461 L F
.47657 .6796 m .4836 .6759 L .44216 .69542 L .452 0 0 r
F
.45936 .68732 m .44998 .70596 L .47633 .70086 L .617 0 0 r
F
.44545 .69442 m .44998 .70596 L .45936 .68732 L F
.48426 .67653 m .53499 .80084 L .47686 .6798 L 1 0 0 r
F
.47686 .6798 m .53515 .80158 L .47657 .6796 L .763 0 0 r
F
.47686 .6798 m .53499 .80084 L .53515 .80158 L F
.48426 .67653 m .54201 .79671 L .53499 .80084 L 1 0 0 r
F
.47657 .6796 m .54262 .79872 L .4836 .6759 L .404 0 0 r
F
.47657 .6796 m .53515 .80158 L .54262 .79872 L F
.4836 .6759 m .50171 .81973 L .44216 .69542 L .894 0 0 r
F
.53515 .80158 m .50171 .81973 L .54262 .79872 L .1 0 0 r
F
.4836 .6759 m .54262 .79872 L .50171 .81973 L .894 0 0 r
F
.54262 .79872 m .4836 .6759 L .44216 .69542 L p F P
0 g
s
.44216 .69542 m .50171 .81973 L .54262 .79872 L p .894 0 0 r
F P
0 g
s
.5887 .73788 m .58207 .73255 L .60146 .78814 L 0 .351 .737 r
F
.53473 .64976 m .56996 .72282 L p .54615 .62959 L F P
0 g
s
.56996 .72282 m .60146 .78814 L p .58207 .73255 L 0 .351 .737 r
F P
0 g
s
.54615 .62959 m .56996 .72282 L .58207 .73255 L 0 .351 .737 r
F
.55961 .62332 m .54615 .62959 L p .58207 .73255 L F P
0 g
s
.55961 .62332 m .58207 .73255 L .5887 .73788 L 0 .351 .737 r
F
.54615 .62959 m .52888 .63764 L .53473 .64976 L p F P
0 g
s
.52888 .63764 m .60146 .78814 L .55861 .80583 L p 0 .274 .858 r
F P
0 g
s
.67707 .75362 m .63168 .77244 L .55961 .62332 L p 0 .276 .858 r
F P
0 g
s
.60146 .78814 m .52888 .63764 L .55961 .62332 L p 0 .351 .737 r
F P
0 g
s
.55961 .62332 m .63168 .77244 L .60146 .78814 L p 0 .351 .737 r
F P
0 g
s
.6465 .76954 m .67707 .75362 L .63168 .77244 L p 0 .05 .1 r
F P
0 g
s
.63168 .77244 m .60146 .78814 L .6465 .76954 L p 0 .05 .1 r
F P
0 g
s
.6465 .76954 m .60146 .78814 L .52888 .63764 L p 0 .274 .858 r
F P
0 g
s
.55961 .62332 m .5898 .60924 L .59574 .62151 L p 0 .351 .737 r
F P
0 g
s
.70711 .73798 m .63356 .58661 L .5898 .60924 L p 0 .278 .858 r
F P
0 g
s
.55961 .62332 m .5898 .60924 L .63356 .58661 L p 0 .458 .794 r
F P
0 g
s
.63356 .58661 m .603 .60084 L .55961 .62332 L p 0 .458 .794 r
F P
0 g
s
.67707 .75362 m .603 .60084 L .55961 .62332 L p 0 .276 .858 r
F P
0 g
s
.57189 .61533 m .52888 .63764 L .55961 .62332 L p 0 .458 .794 r
F P
0 g
s
.55961 .62332 m .603 .60084 L .57189 .61533 L p 0 .458 .794 r
F P
0 g
s
.55961 .62332 m .603 .60084 L .67707 .75362 L p 0 .276 .858 r
F P
0 g
s
.52888 .63764 m .57189 .61533 L .6465 .76954 L p 0 .274 .858 r
F P
0 g
s
.50369 .66483 m .5676 .63305 L .51735 .6577 L .452 0 0 r
F
.5174 .62424 m .4752 .64662 L p .52484 .65388 L .617 0 0 r
F P
0 g
s
.54272 .64475 m .5174 .62424 L p .52484 .65388 L .617 0 0 r
F P
0 g
s
.5676 .63305 m .54272 .64475 L p .51735 .6577 L .452 0 0 r
F P
0 g
s
.50369 .66483 m .51735 .6577 L .5 .66656 L .452 0 0 r
F
.52456 .65501 m .5676 .63305 L p .50369 .66483 L F P
0 g
s
.483 .67524 m .5 .66656 L .49631 .66359 L .617 0 0 r
F
.49273 .67028 m .52456 .65501 L .50369 .66483 L .452 0 0 r
F
.43916 .72461 m .44468 .73301 L .44328 .73322 L .383 0 0 r
F
.42862 .70259 m .44314 .72585 L .43916 .72461 L F
.45391 .72921 m .43916 .72461 L .44547 .73989 L .512 0 0 r
F
.41492 .80785 m .47633 .70086 L .43506 .66792 L p .894 0 0 r
F P
0 g
s
.43506 .66792 m .47633 .70086 L .41492 .80785 L .894 0 0 r
F
.44216 .69542 m .47587 .67888 L .49273 .67028 L .452 0 0 r
F
.47587 .67888 m .52456 .65501 L .49273 .67028 L F
.62992 .76197 m .5676 .63305 L .4836 .6759 L p .559 0 0 r
F P
0 g
s
.51732 .68049 m .56039 .65907 L p .50734 .66282 L .617 0 0 r
F P
0 g
s
.49631 .66359 m .5 .66656 L .50734 .66282 L .617 0 0 r
F
.5 .66656 m .51732 .68049 L .50734 .66282 L F
.49631 .66359 m .56039 .65907 L .4752 .64662 L F
.52505 .65306 m .48257 .67477 L p .51735 .6577 L .452 0 0 r
F P
0 g
s
.54272 .64475 m .52505 .65306 L p .51735 .6577 L .452 0 0 r
F P
0 g
s
.56039 .65907 m .54272 .64475 L p .52484 .65388 L .617 0 0 r
F P
0 g
s
.4752 .64662 m .43506 .66792 L p .49631 .66359 L .617 0 0 r
F P
0 g
s
.58797 .78362 m .62992 .76197 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.50171 .81973 m .54376 .80213 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.54376 .80213 m .58797 .78362 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.54262 .79872 m .50171 .81973 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.62992 .76197 m .58519 .7808 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.58519 .7808 m .54262 .79872 L p .5646 .7914 L .1 0 0 r
F P
0 g
s
.4836 .6759 m .54262 .79872 L .62992 .76197 L p .559 0 0 r
F P
0 g
s
.6465 .76954 m .57189 .61533 L .603 .60084 L p 0 .351 .734 r
F P
0 g
s
.603 .60084 m .67707 .75362 L .6465 .76954 L p 0 .351 .734 r
F P
0 g
s
.5676 .63305 m .64487 .75538 L .58214 .62576 L .642 0 0 r
F
.5676 .63305 m .62992 .76197 L .64487 .75538 L F
.5676 .63305 m .58797 .78362 L .62992 .76197 L .899 0 0 r
F
.58797 .78362 m .50171 .81973 L .47553 .76508 L p .55 0 0 r
F P
0 g
s
.49365 .74498 m .58797 .78362 L .47553 .76508 L .55 0 0 r
F
.48223 .71966 m .58797 .78362 L .45913 .73084 L F
.56039 .65907 m .51732 .68049 L p .51205 .70522 L .288 0 0 r
F P
0 g
s
.54297 .69025 m .58797 .78362 L p .48223 .71966 L .55 0 0 r
F P
0 g
s
.49817 .77047 m .54297 .69025 L p .51205 .70522 L .288 0 0 r
F P
0 g
s
.54297 .69025 m .56039 .65907 L p .51205 .70522 L .288 0 0 r
F P
0 g
s
.44216 .69542 m .45936 .68732 L p .47587 .67888 L .452 0 0 r
F P
0 g
s
.45936 .68732 m .4836 .6759 L p .47587 .67888 L .452 0 0 r
F P
0 g
s
.483 .67524 m .51732 .68049 L .5 .66656 L .617 0 0 r
F
.5 .66656 m .51735 .6577 L .48257 .67477 L .452 0 0 r
F
.48257 .67477 m .44216 .69542 L p .49273 .67028 L F P
0 g
s
.49273 .67028 m .5 .66656 L .48257 .67477 L .452 0 0 r
F
.47633 .70086 m .51732 .68049 L p .483 .67524 L .617 0 0 r
F P
0 g
s
.45936 .68732 m .47633 .70086 L p .483 .67524 L .617 0 0 r
F P
0 g
s
.51732 .68049 m .47633 .70086 L p .48683 .73431 L .288 0 0 r
F P
0 g
s
.47553 .76508 m .45913 .73084 L p .49365 .74498 L .55 0 0 r
F P
0 g
s
.48683 .73431 m .49817 .77047 L .51732 .68049 L .288 0 0 r
F
.57244 .66884 m .52505 .65306 L .58797 .78362 L .899 0 0 r
F
.5676 .63305 m .54272 .64475 L .57244 .66884 L F
.54272 .64475 m .52505 .65306 L .57244 .66884 L F
.52521 .61565 m .5174 .62424 L .54272 .64475 L .617 0 0 r
F
.52521 .61565 m .54272 .64475 L .54701 .64256 L F
.52505 .65306 m .54297 .69025 L p .45927 .69454 L .55 0 0 r
F P
0 g
s
.4711 .68063 m .52505 .65306 L p .45927 .69454 L .55 0 0 r
F P
0 g
s
.47633 .70086 m .45913 .73084 L p .48223 .71966 L .288 0 0 r
F P
0 g
s
.44216 .69542 m .54297 .69025 L .48223 .71966 L .55 0 0 r
F
.5174 .62424 m .56039 .65907 L .49817 .77047 L p .899 0 0 r
F P
0 g
s
.5174 .62424 m .49817 .77047 L .56039 .65907 L .899 0 0 r
F
.5676 .63305 m .55835 .63676 L .54272 .64475 L .452 0 0 r
F
.5676 .63305 m .56214 .63483 L .55835 .63676 L F
.52505 .65306 m .5676 .63305 L .62992 .76197 L p .899 0 0 r
F P
0 g
s
.56214 .63483 m .56039 .65907 L .57664 .64236 L .617 0 0 r
F
.52521 .61565 m .54701 .64256 L .56214 .63483 L F
.54701 .64256 m .56039 .65907 L .56214 .63483 L F
.5676 .63305 m .58214 .62576 L .56214 .63483 L .452 0 0 r
F
.55835 .63676 m .56214 .63483 L .55416 .63845 L F
.54272 .64475 m .55416 .63845 L .52505 .65306 L F
.55835 .63676 m .55416 .63845 L .54272 .64475 L F
.54701 .64256 m .54272 .64475 L .56039 .65907 L .617 0 0 r
F
.52521 .61565 m .52256 .62008 L .5174 .62424 L .1 0 0 r
F
.45913 .73084 m .44216 .69542 L p .48223 .71966 L .55 0 0 r
F P
0 g
s
.48223 .71966 m .45913 .73084 L .48454 .72703 L .288 0 0 r
F
.41492 .80785 m .49817 .77047 L p .48454 .72703 L F P
0 g
s
.45913 .73084 m .41492 .80785 L p .48454 .72703 L .288 0 0 r
F P
0 g
s
.49817 .77047 m .45363 .73518 L .5174 .62424 L p .899 0 0 r
F P
0 g
s
.5174 .62424 m .45363 .73518 L .49817 .77047 L .899 0 0 r
F
.52256 .62008 m .45363 .73518 L .514 .63014 L .1 0 0 r
F
.52256 .62008 m .514 .63014 L .5174 .62424 L F
.44216 .69542 m .4711 .68063 L p .45927 .69454 L .55 0 0 r
F P
0 g
s
.62992 .76197 m .58797 .78362 L .52505 .65306 L p .899 0 0 r
F P
0 g
s
.57664 .64236 m .56039 .65907 L .54297 .69025 L .1 0 0 r
F
.62992 .76197 m .58797 .78362 L .61792 .77045 L F
.57664 .64236 m .54297 .69025 L .56102 .66786 L F
.53631 .61245 m .52521 .61565 L .56214 .63483 L .617 0 0 r
F
.58214 .62576 m .56584 .63294 L .56214 .63483 L .452 0 0 r
F
.56497 .63339 m .56214 .63483 L .57664 .64236 L .617 0 0 r
F
.5589 .56329 m .56106 .58081 L .53701 .6124 L .502 0 0 r
F
.52526 .60287 m .56214 .63483 L .56497 .63339 L .617 0 0 r
F
.58214 .62576 m .58637 .62326 L .56584 .63294 L .452 0 0 r
F
.52526 .60287 m .56497 .63339 L .57743 .61693 L .617 0 0 r
F
.58637 .62326 m .57711 .62719 L .56584 .63294 L .452 0 0 r
F
.56497 .63339 m .57664 .64236 L .57711 .62719 L .617 0 0 r
F
.56497 .63339 m .57711 .62719 L .57743 .61693 L F
.56584 .63294 m .57711 .62719 L .55416 .63845 L .452 0 0 r
F
.56214 .63483 m .56584 .63294 L .55416 .63845 L F
.55416 .63845 m .57711 .62719 L .56827 .6541 L .739 0 0 r
F
.54297 .69025 m .55544 .70359 L .5534 .71189 L .637 0 0 r
F
.54878 .68305 m .61792 .77045 L .54297 .69025 L F
.57664 .64236 m .56102 .66786 L .56562 .66216 L .1 0 0 r
F
.52505 .65306 m .55416 .63845 L .56562 .66216 L .637 0 0 r
F
.54878 .68305 m .56562 .66216 L .61792 .77045 L F
.52505 .65306 m .56562 .66216 L .54878 .68305 L F
.56102 .66786 m .55745 .67369 L .56562 .66216 L .1 0 0 r
F
.56562 .66216 m .49817 .77047 L .514 .75487 L F
.55745 .67369 m .49817 .77047 L .56562 .66216 L F
.57519 .63303 m .57664 .64236 L .56562 .66216 L 1 0 0 r
F
.57711 .62719 m .57664 .64236 L .57446 .62831 L F
.56827 .6541 m .57711 .62719 L .58339 .63705 L .739 0 0 r
F
.58214 .62576 m .64487 .75538 L .66398 .74647 L .74 0 0 r
F
.64487 .75538 m .65679 .75235 L .66398 .74647 L .1 0 0 r
F
.56998 .656 m .58339 .63705 L .65679 .75235 L .739 0 0 r
F
.56827 .6541 m .58339 .63705 L .56998 .656 L F
.62992 .76197 m .61792 .77045 L .64487 .75538 L .1 0 0 r
F
.64487 .75538 m .61792 .77045 L .65679 .75235 L F
.55416 .63845 m .65679 .75235 L .61792 .77045 L .739 0 0 r
F
.57446 .62831 m .57519 .63303 L .56562 .66216 L 1 0 0 r
F
.58637 .62326 m .59251 .61963 L .57711 .62719 L .452 0 0 r
F
.58214 .62576 m .66398 .74647 L .601 .61651 L .74 0 0 r
F
.58214 .62576 m .601 .61651 L .59251 .61963 L .452 0 0 r
F
.57711 .62719 m .59251 .61963 L .60021 .63553 L .739 0 0 r
F
.57711 .62719 m .60021 .63553 L .65679 .75235 L F
.52526 .60287 m .52524 .60845 L .53631 .61245 L .617 0 0 r
F
.52524 .60845 m .52521 .61565 L .53631 .61245 L F
.57743 .61693 m .57711 .62719 L .57446 .62831 L 1 0 0 r
F
.52505 .65306 m .54878 .68305 L .54297 .69025 L .637 0 0 r
F
.56102 .66786 m .54297 .69025 L .55648 .67526 L .1 0 0 r
F
.55648 .67526 m .54297 .69025 L .49817 .77047 L F
.57591 .62023 m .56562 .66216 L .514 .75487 L 1 0 0 r
F
.57743 .61693 m .56562 .66216 L .57591 .62023 L F
.5534 .71189 m .61792 .77045 L .58797 .78362 L .637 0 0 r
F
.55544 .70359 m .61792 .77045 L .5534 .71189 L F
.41701 .69454 m .41579 .70041 L .42323 .70161 L .617 0 0 r
F
.67312 .58345 m .64972 .59445 L p .65459 .59286 L .452 0 0 r
F P
0 g
s
.67362 .60511 m .67241 .55278 L .78524 .57485 L p .899 0 0 r
F P
0 g
s
.67241 .55278 m .78721 .62613 L .78524 .57485 L .899 0 0 r
F
.67241 .55278 m .67362 .60511 L .78721 .62613 L F
.70689 .56669 m .68935 .57582 L .70661 .61122 L .466 0 0 r
F
.78524 .57485 m .78721 .62613 L .81128 .60705 L .529 0 0 r
F
.70661 .61122 m .81128 .60705 L .78721 .62613 L .779 0 0 r
F
.70689 .56669 m .70661 .61122 L .71564 .59379 L .466 0 0 r
F
.64972 .59445 m .74993 .70005 L .68935 .57582 L .899 0 0 r
F
.64972 .59445 m .68935 .57582 L .74993 .70005 L p F P
0 g
s
.67362 .60511 m .70951 .60562 L .70661 .61122 L .779 0 0 r
F
.70951 .60562 m .81128 .60705 L .70661 .61122 L F
.70689 .56669 m .71564 .59379 L .71794 .58933 L .466 0 0 r
F
.67362 .60511 m .69694 .58534 L .71794 .58933 L .779 0 0 r
F
.78524 .57485 m .81128 .60705 L .79712 .56514 L .529 0 0 r
F
.79712 .56514 m .81128 .60705 L .83141 .57459 L F
.71794 .58933 m .83141 .57459 L .81128 .60705 L .854 0 0 r
F
.70874 .56536 m .70689 .56669 L .71794 .58933 L .1 0 0 r
F
.69694 .58534 m .71583 .58383 L .71794 .58933 L .854 0 0 r
F
.71583 .58383 m .83141 .57459 L .71794 .58933 L F
.67241 .55278 m .78524 .57485 L .79712 .56514 L .782 0 0 r
F
.67241 .55278 m .79712 .56514 L .68391 .54272 L F
.69694 .58534 m .70874 .56536 L .83141 .57459 L .854 0 0 r
F
.70874 .56536 m .71667 .55193 L .73075 .55471 L F
.70874 .56536 m .73075 .55471 L .83141 .57459 L F
.67312 .58345 m .69694 .58534 L .67362 .60511 L .502 0 0 r
F
.67241 .55278 m .68932 .57522 L .67312 .58345 L F
.69324 .57323 m .68935 .57582 L .70689 .56669 L .452 0 0 r
F
.67241 .55278 m .69324 .57323 L .68932 .57522 L .502 0 0 r
F
.65824 .59 m .67757 .58119 L .69324 .57323 L .452 0 0 r
F
.67757 .58119 m .68935 .57582 L .69324 .57323 L F
.67241 .55278 m .68391 .54272 L .69324 .57323 L .502 0 0 r
F
.68932 .57522 m .69324 .57323 L .69694 .58534 L F
.65824 .59 m .64972 .59445 L .68935 .57582 L .452 0 0 r
F
.68932 .57522 m .69694 .58534 L .67312 .58345 L .502 0 0 r
F
.69617 .57175 m .70689 .56669 L .70874 .56536 L .452 0 0 r
F
.68391 .54272 m .71667 .55193 L .70874 .56536 L .502 0 0 r
F
.68391 .54272 m .70874 .56536 L .69324 .57323 L F
.65939 .58908 m .65824 .59 L .70689 .56669 L .452 0 0 r
F
.69324 .57323 m .70874 .56536 L .69694 .58534 L .502 0 0 r
F
.67214 .58307 m .70874 .56536 L .70999 .56446 L .452 0 0 r
F
.67214 .58307 m .69617 .57175 L .70874 .56536 L F
.65939 .58908 m .67214 .58307 L .70999 .56446 L F
.70999 .56446 m .70874 .56536 L .71794 .58933 L .1 0 0 r
F
.72289 .60581 m .71794 .58933 L .81128 .60705 L .779 0 0 r
F
.71143 .56762 m .71794 .58933 L .76841 .69269 L .1 0 0 r
F
.70999 .56446 m .71794 .58933 L .71143 .56762 L F
.70951 .60562 m .71794 .58933 L .72289 .60581 L .779 0 0 r
F
.67362 .60511 m .71794 .58933 L .70951 .60562 L F
.71794 .58933 m .74993 .70005 L .76841 .69269 L .466 0 0 r
F
.71564 .59379 m .74993 .70005 L .71794 .58933 L F
.71564 .59379 m .70661 .61122 L .71815 .60159 L F
.71815 .60159 m .70661 .61122 L .74993 .70005 L F
0 g
.5589 .56329 m
.57472 .56628 L
s
.53293 .57765 m
.53624 .60583 L
s
.53293 .57765 m
.5589 .56329 L
s
.51426 .44767 m
.5323 .45448 L
s
.49762 .43672 m
.51426 .44767 L
s
.47745 .39655 m .47769 .40913 L .43273 .39842 L .656 0 0 r
F
0 g
.43252 .39304 m
.43273 .39842 L
s
.43273 .39842 m
.43532 .40341 L
s
.48479 .42322 m
.49762 .43672 L
s
.5323 .45448 m
.54909 .45614 L
s
.5589 .56329 m
.56076 .54363 L
s
.56076 .54363 m
.56635 .52471 L
s
0 0 0 r
.52511 .36363 m
.52956 .35639 L
s
0 g
.38309 .41279 m
.38989 .40953 L
s
.37222 .41737 m
.38309 .41279 L
s
.47769 .40913 m
.48479 .42322 L
s
.56635 .52471 m
.56803 .52166 L
s
.56803 .52166 m
.57416 .51056 L
s
.5589 .56329 m
.56106 .58081 L
s
.56214 .45234 m
.56214 .45234 L
s
.54909 .45614 m
.56214 .45234 L
s
.58478 .47121 m
.58511 .49963 L
s
.56214 .45234 m
.58478 .47121 L
s
.57524 .50893 m
.58511 .49963 L
s
.56106 .58081 m
.56697 .5936 L
s
.69492 .29017 m .6521 .31838 L .58763 .42832 L p 0 .05 .312 r
F P
0 g
s
.47745 .39655 m
.47769 .40913 L
s
.62343 .29382 m .66572 .26493 L .63633 .23952 L p 0 .355 .953 r
F P
0 g
s
0 0 0 r
.55129 .37694 m
.566 .35262 L
s
0 g
.5687 .5948 m
.57579 .59968 L
s
.56697 .5936 m
.5687 .5948 L
s
.61551 .48561 m .74743 .51289 L .79275 .4891 L p 0 .446 1 r
F P
0 g
s
.79275 .4891 m .74743 .51289 L .74866 .54955 L p 0 .207 .719 r
F P
0 g
s
.6161 .52314 m .74866 .54955 L .74866 .54955 L p 0 .448 1 r
F P
0 g
s
.74743 .51289 m .74866 .54955 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.74866 .54955 m .79424 .52652 L .79275 .4891 L p 0 .207 .719 r
F P
0 g
s
.74866 .54955 m .79424 .52652 L p .6161 .52314 L 0 .448 1 r
F P
0 g
s
.6161 .52314 m .74866 .54955 L .6161 .52314 L 0 .448 1 r
F
.74866 .54955 m .6161 .52314 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.74866 .54955 m .74866 .54955 L p .6161 .52314 L 0 .351 .737 r
F P
0 g
s
.6161 .52314 m .61551 .48561 L .74743 .51289 L p 0 .351 .737 r
F P
0 g
s
.79424 .52652 m .65971 .49881 L .6161 .52314 L p 0 .448 1 r
F P
0 g
s
.47745 .39655 m
.48423 .3874 L
s
.54698 .45355 m .51776 .42925 L .55786 .40336 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.53239 .44142 m
.53239 .44142 L
s
.53239 .44142 m
.53239 .44142 L
s
.55786 .40336 m .58763 .42832 L .54698 .45355 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.56706 .44109 m
.56706 .44109 L
s
.56706 .44109 m
.56706 .44109 L
s
.57415 .50956 m .61551 .48561 L .6161 .52314 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.59459 .49772 m
.59459 .49772 L
s
.59459 .49772 m
.59459 .49772 L
s
.6161 .52314 m .57452 .54633 L .57415 .50956 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.57434 .5279 m
.57434 .5279 L
s
.57434 .5279 m
.57434 .5279 L
s
.53239 .44142 m
.53239 .44142 L
s
.79574 .56432 m .79424 .52652 L .74866 .54955 L p 0 .207 .719 r
F P
0 g
s
.79424 .52652 m .74866 .54955 L .6161 .52314 L p 0 .448 1 r
F P
0 g
s
0 0 0 r
.71798 .52507 m
.71798 .52507 L
s
.68327 .53652 m
.68327 .53652 L
s
.68327 .53652 m
.68327 .53652 L
s
.55786 .40336 m .51776 .42925 L .48836 .40479 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.53757 .41646 m
.53757 .41646 L
s
.53757 .41646 m
.53757 .41646 L
s
.50308 .41704 m
.50308 .41704 L
s
.50308 .41704 m
.50308 .41704 L
s
.57434 .5279 m
.57434 .5279 L
s
0 g
.57579 .59968 m
.58625 .59799 L
s
0 0 0 r
.50308 .41704 m
.50308 .41704 L
s
0 g
.46439 .37086 m
.48423 .3874 L
s
.48836 .40479 m .52789 .37823 L .55786 .40336 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.54856 .38144 m
.55129 .37694 L
s
.51359 .38238 m
.52511 .36363 L
s
.51342 .38266 m
.51359 .38238 L
s
.50789 .39166 m
.50789 .39166 L
s
.50789 .39166 m
.51342 .38266 L
s
.5749 .58347 m .57452 .54633 L .6161 .52314 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.57471 .56485 m
.57471 .56485 L
s
.57471 .56485 m
.57471 .56485 L
s
.63901 .28848 m
.64433 .27954 L
s
.60819 .3622 m
.62036 .37251 L
s
.57471 .56485 m
.57471 .56485 L
s
.55786 .34885 m
.56877 .3309 L
s
0 g
.58625 .59799 m
.58637 .60858 L
s
0 0 0 r
.68327 .53652 m
.68327 .53652 L
s
.68327 .53652 m
.68327 .53652 L
s
.68327 .53652 m
.68327 .53652 L
s
.68236 .49943 m
.68297 .52441 L
s
.6161 .52314 m .6167 .56105 L .5749 .58347 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.59555 .57239 m
.60684 .57452 L
s
.59555 .57239 m
.59555 .57239 L
s
.60684 .57452 m
.62459 .57787 L
s
.59507 .53487 m
.59507 .53487 L
s
.59507 .53487 m
.59507 .53487 L
s
.53757 .41646 m
.53757 .41646 L
s
.53757 .41646 m
.53757 .41646 L
s
.53757 .41646 m
.56706 .44109 L
s
.56706 .44109 m
.56706 .44109 L
s
.59507 .53487 m
.59507 .53487 L
s
.59507 .53487 m
.59507 .53487 L
s
.59459 .49772 m
.59507 .53487 L
s
.59459 .49772 m
.59459 .49772 L
s
.50789 .39166 m
.50789 .39166 L
s
.50789 .39166 m
.53757 .41646 L
s
.53757 .41646 m
.53757 .41646 L
s
.79339 .47182 m .80347 .41939 L .77951 .42514 L .529 0 0 r
F
0 g
.78105 .46548 m
.78119 .46917 L
s
.77951 .42514 m
.78105 .46548 L
s
.71944 .41155 m
.77951 .42514 L
s
.58763 .42832 m .63025 .40187 L .69492 .29017 L p 0 .05 .312 r
F P
0 g
s
.69492 .29017 m .63025 .40187 L .5999 .37621 L p 0 .351 .734 r
F P
0 g
s
.5999 .37621 m .66572 .26493 L .69492 .29017 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.68034 .27757 m
.68034 .27757 L
s
.68034 .27757 m
.68034 .27757 L
s
.57834 .40646 m
.59401 .38001 L
s
.68327 .53652 m
.68341 .54206 L
s
.43317 .39279 m .40258 .40462 L .44081 .37753 L p 0 .525 .99 r
F P
0 g
s
.44081 .37753 m .47181 .36565 L .43317 .39279 L p 0 .525 .99 r
F P
0 g
s
0 0 0 r
.41794 .39868 m
.41794 .39868 L
s
.41794 .39868 m
.41794 .39868 L
s
.64583 .4008 m .6994 .3076 L .70772 .29771 L .1 0 0 r
F
0 g
.70097 .30895 m
.734 .33745 L
s
0 0 0 r
.67506 .2866 m
.68034 .27757 L
s
.68034 .27757 m
.68034 .27757 L
s
.59555 .57239 m
.59555 .57239 L
s
.59507 .53487 m
.59555 .57239 L
s
.59507 .53487 m
.59507 .53487 L
s
.63633 .23952 m .66572 .26493 L .5999 .37621 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.65105 .25225 m
.65105 .25225 L
s
.65105 .25225 m
.65105 .25225 L
s
.28114 .53099 m .28574 .4905 L .16331 .46687 L .887 0 0 r
F
.30439 .51516 m .28574 .4905 L .28114 .53099 L .421 0 0 r
F
.30439 .51516 m .3067 .49459 L .28574 .4905 L F
0 g
.28574 .4905 m
.28669 .4871 L
s
0 0 0 r
.64568 .26124 m
.65105 .25225 L
s
.65105 .25225 m
.65105 .25225 L
s
.41794 .39868 m
.41794 .39868 L
s
.79275 .4891 m .79424 .52652 L .65971 .49881 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.79349 .50776 m
.79349 .50776 L
s
.79349 .50776 m
.79349 .50776 L
s
.79275 .4891 m .65888 .46051 L .61551 .48561 L p 0 .446 1 r
F P
0 g
s
.65971 .49881 m .65888 .46051 L .79275 .4891 L p 0 .351 .734 r
F P
0 g
s
.28114 .53099 m .16331 .46687 L .15826 .50822 L .887 0 0 r
F
.30439 .51516 m .28114 .53099 L .15826 .50822 L .7 0 0 r
F
0 g
.28305 .51415 m
.28574 .4905 L
s
.30439 .51516 m .15826 .50822 L .28114 .53099 L .7 0 0 r
F
.28351 .56712 m .28114 .53099 L .15826 .50822 L .892 0 0 r
F
.30568 .53338 m .28114 .53099 L .28351 .56712 L .421 0 0 r
F
.30568 .53338 m .30439 .51516 L .28114 .53099 L F
0 g
.67003 .45029 m
.67625 .45164 L
s
.63025 .40187 m .58763 .42832 L .55786 .40336 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.60868 .41526 m
.60868 .41526 L
s
.60868 .41526 m
.60868 .41526 L
s
.53239 .44142 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.64583 .4008 m .70772 .29771 L .65402 .39125 L .1 0 0 r
F
.65402 .39125 m .70772 .29771 L .70888 .28405 L 1 0 0 r
F
.70772 .29771 m .75816 .29433 L .70888 .28405 L .669 0 0 r
F
0 g
.64583 .4008 m
.64884 .39557 L
s
0 0 0 r
.66049 .47986 m
.67077 .48202 L
s
.79349 .50776 m
.79349 .50776 L
s
.37871 .68524 m .28041 .76614 L .31619 .78921 L .861 0 0 r
F
.37871 .68524 m .34392 .66267 L .28041 .76614 L F
.38593 .66037 m .34392 .66267 L .37871 .68524 L .617 0 0 r
F
.41579 .70041 m .37871 .68524 L .31619 .78921 L .797 0 0 r
F
.40476 .66802 m .37871 .68524 L .41579 .70041 L .617 0 0 r
F
.40476 .66802 m .38593 .66037 L .37871 .68524 L F
0 0 0 r
.45226 .37938 m
.45226 .37938 L
s
.45226 .37938 m
.45226 .37938 L
s
.6161 .52314 m .61551 .48561 L .65888 .46051 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.57434 .5279 m
.61581 .50433 L
s
.61581 .50433 m
.61581 .50433 L
s
.61581 .50433 m
.61581 .50433 L
s
.61581 .50433 m
.61581 .50433 L
s
.62735 .50667 m
.64075 .50939 L
s
.61581 .50433 m
.61581 .50433 L
s
.57277 .41586 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.57277 .41586 m
.57277 .41586 L
s
.38709 .41061 m
.38709 .41061 L
s
.38709 .41061 m
.38709 .41061 L
s
.38593 .66037 m .36826 .64889 L .34392 .66267 L .617 0 0 r
F
.36826 .64889 m .28041 .76614 L .34392 .66267 L .218 0 0 r
F
0 g
.35335 .66879 m
.37871 .68524 L
s
.34392 .66267 m .25159 .73916 L .28041 .76614 L .92 0 0 r
F
.34392 .66267 m .31622 .63579 L .25159 .73916 L F
.36826 .64889 m .31622 .63579 L .34392 .66267 L .617 0 0 r
F
.36826 .64889 m .34392 .66267 L .28041 .76614 L .218 0 0 r
F
0 g
.60267 .22413 m
.61393 .23385 L
s
.61393 .23385 m
.62104 .23998 L
s
.6161 .52314 m .65971 .49881 L .79424 .52652 L p 0 .448 1 r
F P
0 g
s
.65971 .49881 m .79424 .52652 L .79574 .56432 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.76506 .5018 m
.79349 .50776 L
s
.68327 .53652 m
.70933 .52271 L
s
.79499 .54537 m
.79499 .54537 L
s
.79499 .54537 m
.79499 .54537 L
s
.56934 .35037 m .5999 .37621 L .55786 .40336 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.58465 .36331 m
.58465 .36331 L
s
.58465 .36331 m
.59034 .35379 L
s
.55786 .40336 m .52789 .37823 L .56934 .35037 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.5541 .35504 m
.55786 .34885 L
s
.54836 .36447 m
.54836 .36447 L
s
.54836 .36447 m
.5541 .35504 L
s
.5429 .39081 m
.5429 .39081 L
s
.5429 .39081 m
.5429 .39081 L
s
.5429 .39081 m
.5429 .39081 L
s
.5429 .39081 m
.5429 .39081 L
s
.50308 .41704 m
.5429 .39081 L
s
.55786 .40336 m .5999 .37621 L .63025 .40187 L p 0 .355 .964 r
F P
0 g
s
0 0 0 r
.57863 .38995 m
.57863 .38995 L
s
.57863 .38995 m
.57863 .38995 L
s
.57277 .41586 m
.6151 .38906 L
s
.6151 .38906 m
.6151 .38906 L
s
.6151 .38906 m
.6151 .38906 L
s
.61581 .50433 m
.61581 .50433 L
s
.58465 .36331 m
.58465 .36331 L
s
.5429 .39081 m
.58465 .36331 L
s
.5429 .39081 m
.5429 .39081 L
s
.804 .47727 m .80347 .41939 L .79339 .47182 L .529 0 0 r
F
.804 .47727 m .82496 .42967 L .80347 .41939 L F
.71235 .40406 m .80347 .41939 L .82496 .42967 L .577 0 0 r
F
0 g
.77951 .42514 m
.79193 .42216 L
s
.71008 .40943 m
.71944 .41155 L
s
.69165 .45294 m .804 .47727 L .79339 .47182 L .613 0 0 r
F
0 g
.78139 .47437 m
.78603 .47338 L
s
0 0 0 r
.72673 .475 m
.72673 .475 L
s
.72673 .475 m
.72673 .475 L
s
0 g
.42323 .70161 m
.42877 .70251 L
s
.41579 .70041 m .31619 .78921 L .354 .8052 L .797 0 0 r
F
.42198 .67068 m .40476 .66802 L .41579 .70041 L .617 0 0 r
F
0 g
.37871 .68524 m
.41579 .70041 L
s
.41579 .70041 m
.42323 .70161 L
s
0 0 0 r
.42146 .39124 m
.42146 .39124 L
s
.42146 .39124 m
.42146 .39124 L
s
.42146 .39124 m
.45226 .37938 L
s
.45226 .37938 m
.45226 .37938 L
s
.79499 .54537 m
.79499 .54537 L
s
.28351 .56712 m .15826 .50822 L .15973 .54501 L .892 0 0 r
F
.29267 .59367 m .28351 .56712 L .15973 .54501 L .879 0 0 r
F
.31041 .54655 m .28351 .56712 L .29267 .59367 L .421 0 0 r
F
.31041 .54655 m .30568 .53338 L .28351 .56712 L F
0 g
.28114 .53099 m
.28351 .56712 L
s
0 0 0 r
.4251 .38355 m
.4251 .38355 L
s
.4251 .38355 m
.4251 .38355 L
s
.38709 .41061 m
.4161 .38996 L
s
.41636 .38977 m
.4251 .38355 L
s
.38709 .41061 m
.38709 .41061 L
s
.65488 .37782 m .70888 .28405 L .70258 .26868 L 1 0 0 r
F
.70888 .28405 m .74588 .26328 L .70258 .26868 L .669 0 0 r
F
.70888 .28405 m .75816 .29433 L .74588 .26328 L F
.65402 .39125 m .70888 .28405 L .65488 .37782 L 1 0 0 r
F
0 g
.70772 .29771 m
.70888 .28405 L
s
.64884 .39557 m
.65436 .38596 L
s
0 0 0 r
.66309 .34514 m
.66309 .34514 L
s
.66309 .34514 m
.66309 .34514 L
s
.66055 .53753 m .6167 .56105 L .6161 .52314 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.63836 .54943 m
.63836 .54943 L
s
.63836 .54943 m
.64983 .55166 L
s
.6164 .54204 m
.6164 .54204 L
s
.6164 .54204 m
.6164 .54204 L
s
.6164 .54204 m
.6164 .54204 L
s
.6164 .54204 m
.6164 .54204 L
s
.6164 .54204 m
.6164 .54204 L
s
.6164 .54204 m
.6164 .54204 L
s
.57471 .56485 m
.6164 .54204 L
s
.6161 .52314 m .65971 .49881 L .66055 .53753 L p 0 .192 .705 r
F P
0 g
s
.65888 .46051 m .65971 .49881 L .6161 .52314 L p 0 .192 .705 r
F P
0 g
s
0 0 0 r
.63765 .51112 m
.63765 .51112 L
s
.63765 .51112 m
.63765 .51112 L
s
.61581 .50433 m
.6593 .47961 L
s
.6593 .47961 m
.6593 .47961 L
s
.63694 .47321 m
.63694 .47321 L
s
.63694 .47321 m
.63694 .47321 L
s
.6593 .47961 m
.6593 .47961 L
s
.6593 .47961 m
.66049 .47986 L
s
0 g
.24355 .3159 m
.25434 .30337 L
s
.52386 .29747 m
.54059 .27076 L
s
.55518 .24747 m
.58133 .20572 L
s
0 0 0 r
.66309 .34514 m
.66309 .34514 L
s
.31622 .63579 m .23391 .71199 L .25159 .73916 L .986 0 0 r
F
.31622 .63579 m .29964 .60832 L .23391 .71199 L F
.3543 .63524 m .29964 .60832 L .31622 .63579 L .617 0 0 r
F
.36826 .64889 m .3543 .63524 L .31622 .63579 L F
0 g
.31622 .63579 m
.34392 .66267 L
s
.79574 .56432 m .66055 .53753 L .65971 .49881 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.66013 .51812 m
.67166 .52045 L
s
.66013 .51812 m
.66013 .51812 L
s
.64983 .55166 m
.66785 .55518 L
s
.7279 .51286 m
.7279 .51286 L
s
.7279 .51286 m
.7279 .51286 L
s
.59712 .32868 m .65298 .23561 L .63498 .2348 L .687 0 0 r
F
0 0 0 r
.63333 .31969 m
.63333 .31969 L
s
.63333 .31969 m
.63333 .31969 L
s
.63333 .31969 m
.63333 .31969 L
s
.63333 .31969 m
.63333 .31969 L
s
.65298 .23561 m .60903 .19485 L .63498 .2348 L .669 0 0 r
F
0 g
.62104 .23998 m
.63498 .2348 L
s
0 0 0 r
.66013 .51812 m
.66013 .51812 L
s
.6164 .54204 m
.66013 .51812 L
s
.6164 .54204 m
.6164 .54204 L
s
.42146 .39124 m
.42146 .39124 L
s
.42146 .39124 m
.42146 .39124 L
s
.64813 .36251 m .70258 .26868 L .6897 .254 L .935 0 0 r
F
0 0 0 r
.65983 .34235 m
.66309 .34514 L
s
.70258 .26868 m .71996 .23342 L .6897 .254 L .669 0 0 r
F
.70258 .26868 m .74588 .26328 L .71996 .23342 L F
.65488 .37782 m .70258 .26868 L .64813 .36251 L 1 0 0 r
F
0 g
.70258 .26868 m
.70888 .28405 L
s
0 0 0 r
.63333 .31969 m
.65683 .33979 L
s
.63333 .31969 m
.63333 .31969 L
s
.7279 .51286 m
.7279 .51286 L
s
.7279 .51286 m
.7279 .51286 L
s
.72673 .475 m
.72673 .475 L
s
.59188 .40111 m
.60868 .41526 L
s
.60868 .41526 m
.60868 .41526 L
s
.57863 .38995 m
.57863 .38995 L
s
.57863 .38995 m
.57863 .38995 L
s
.57863 .38995 m
.59188 .40111 L
s
.69872 .46586 m .804 .47727 L .69165 .45294 L .882 0 0 r
F
0 g
.67625 .45164 m
.6929 .45524 L
s
.69872 .46586 m .81155 .49004 L .804 .47727 L .882 0 0 r
F
0 0 0 r
.72673 .475 m
.7279 .51286 L
s
.81155 .49004 m .82496 .42967 L .804 .47727 L .529 0 0 r
F
0 g
.79339 .47182 m
.804 .47727 L
s
.65298 .23561 m .64535 .19616 L .60903 .19485 L .669 0 0 r
F
.61678 .3358 m .65298 .23561 L .59712 .32868 L .795 0 0 r
F
0 0 0 r
.62513 .31269 m
.63333 .31969 L
s
.59034 .35379 m
.60389 .33113 L
s
.64074 .2695 m
.64568 .26124 L
s
.61678 .3358 m .67224 .24236 L .65298 .23561 L .795 0 0 r
F
.67224 .24236 m .64535 .19616 L .65298 .23561 L .669 0 0 r
F
0 g
.63498 .2348 m
.65298 .23561 L
s
.3067 .49459 m .18258 .47063 L .18811 .45019 L .875 0 0 r
F
.30439 .51516 m .18258 .47063 L .3067 .49459 L .888 0 0 r
F
0 g
.3067 .49459 m
.30891 .48666 L
s
0 0 0 r
.63694 .47321 m
.63733 .49439 L
s
.63694 .47321 m
.63694 .47321 L
s
.63765 .51112 m
.63765 .51112 L
s
.63765 .51112 m
.63765 .51112 L
s
.63733 .49439 m
.63765 .51112 L
s
.39398 .40182 m
.42146 .39124 L
s
.42146 .39124 m
.42146 .39124 L
s
.64813 .36251 m .6897 .254 L .63474 .34771 L .935 0 0 r
F
.63474 .34771 m .6897 .254 L .71996 .23342 L .218 0 0 r
F
0 0 0 r
.6151 .38906 m
.63751 .35077 L
s
0 g
.69776 .26319 m
.70258 .26868 L
s
.63474 .34771 m .6897 .254 L .67224 .24236 L .868 0 0 r
F
.6897 .254 m .68449 .20972 L .67224 .24236 L .669 0 0 r
F
.6897 .254 m .71996 .23342 L .68449 .20972 L F
.63474 .34771 m .71996 .23342 L .6897 .254 L .218 0 0 r
F
.70504 .38915 m .74588 .26328 L .75816 .29433 L 1 0 0 r
F
0 g
.75524 .32157 m
.75816 .29433 L
s
.30439 .51516 m .18004 .49165 L .15826 .50822 L .7 0 0 r
F
.30439 .51516 m .15826 .50822 L .18004 .49165 L F
.30568 .53338 m .18004 .49165 L .30439 .51516 L .893 0 0 r
F
0 g
.28114 .53099 m
.28682 .52712 L
s
.30439 .51516 m .18004 .49165 L .18258 .47063 L .888 0 0 r
F
0 g
.30439 .51516 m
.3067 .49459 L
s
.66934 .42071 m
.67003 .45029 L
s
.67224 .24236 m .68449 .20972 L .64535 .19616 L .669 0 0 r
F
.63474 .34771 m .67224 .24236 L .61678 .3358 L .868 0 0 r
F
0 g
.67224 .24236 m
.6897 .254 L
s
.65298 .23561 m
.67224 .24236 L
s
.58908 .29248 m
.62104 .23998 L
s
0 0 0 r
.54836 .36447 m
.54836 .36447 L
s
.54836 .36447 m
.57863 .38995 L
s
.57863 .38995 m
.57863 .38995 L
s
0 g
.64583 .4008 m
.66934 .42071 L
s
0 0 0 r
.7279 .51286 m
.7279 .51286 L
s
.51235 .33717 m .47181 .36565 L .44081 .37753 L p 0 .525 .99 r
F P
0 g
s
0 0 0 r
.41794 .39868 m
.45637 .37157 L
s
.45637 .37157 m
.45637 .37157 L
s
.45637 .37157 m
.45637 .37157 L
s
.81155 .49004 m .84049 .45496 L .82496 .42967 L .529 0 0 r
F
.7016 .48438 m .81155 .49004 L .69872 .46586 L .903 0 0 r
F
.7016 .48438 m .8148 .50822 L .81155 .49004 L F
.8148 .50822 m .84049 .45496 L .81155 .49004 L .529 0 0 r
F
0 g
.804 .47727 m
.81155 .49004 L
s
.29267 .59367 m .29041 .59285 L .29017 .59324 L .879 0 0 r
F
.29964 .60832 m .29856 .59874 L .29238 .60687 L 1 0 0 r
F
.29238 .60687 m .28517 .60261 L .23025 .68857 L F
.29856 .59874 m .28517 .60261 L .29238 .60687 L F
.28829 .60171 m .29267 .59367 L .29017 .59324 L .73 0 0 r
F
.28595 .60113 m .29017 .59324 L .16766 .57193 L F
.28829 .60171 m .29017 .59324 L .28595 .60113 L F
.28517 .60261 m .24266 .671 L .26879 .62824 L .1 0 0 r
F
.34614 .62138 m .30817 .59272 L .29964 .60832 L .617 0 0 r
F
.29856 .59874 m .29267 .59367 L .29856 .59874 L .421 0 0 r
F
.31795 .55262 m .3074 .56975 L .29856 .59874 L F
.3074 .56975 m .29267 .59367 L .29856 .59874 L F
.29856 .59874 m .29267 .59367 L .28829 .60171 L .73 0 0 r
F
.31795 .55262 m .31041 .54655 L .29267 .59367 L .421 0 0 r
F
.30817 .59272 m .29856 .59874 L .29964 .60832 L .617 0 0 r
F
.28517 .60261 m .16766 .57193 L .1811 .58471 L .73 0 0 r
F
.3075 .60645 m .28595 .60113 L .28517 .60261 L F
.28595 .60113 m .16766 .57193 L .28517 .60261 L F
.29856 .59874 m .29691 .58422 L .28517 .60261 L 1 0 0 r
F
.31795 .55262 m .29856 .59874 L .31044 .5913 L .421 0 0 r
F
.30817 .59272 m .29691 .58422 L .29856 .59874 L .617 0 0 r
F
.34614 .62138 m .34506 .60939 L .31044 .5913 L F
.30817 .59272 m .31044 .5913 L .29691 .58422 L F
.34614 .62138 m .31044 .5913 L .30817 .59272 L F
.32719 .55052 m .31795 .55262 L .31044 .5913 L .421 0 0 r
F
.32719 .55052 m .31044 .5913 L .31351 .58937 L F
.31044 .5913 m .30893 .56725 L .29691 .58422 L .617 0 0 r
F
.34506 .60939 m .32287 .58351 L .31044 .5913 L F
.32719 .55052 m .31351 .58937 L .32647 .58125 L .421 0 0 r
F
.32287 .58351 m .30893 .56725 L .31044 .5913 L .617 0 0 r
F
.34506 .60939 m .35136 .60111 L .32647 .58125 L F
.32287 .58351 m .32647 .58125 L .30893 .56725 L F
.34506 .60939 m .32647 .58125 L .32287 .58351 L F
.32647 .58125 m .3075 .60645 L .32597 .60296 L .421 0 0 r
F
.31351 .58937 m .3075 .60645 L .32647 .58125 L F
.31351 .58937 m .31044 .5913 L .3075 .60645 L F
.31044 .5913 m .29856 .59874 L .3075 .60645 L F
.3075 .60645 m .29856 .59874 L .28829 .60171 L .73 0 0 r
F
.32597 .60296 m .3075 .60645 L .28517 .60261 L .406 0 0 r
F
.29691 .58422 m .2901 .59674 L .28771 .59958 L .1 0 0 r
F
.29691 .58422 m .28771 .59958 L .28615 .60144 L F
.29691 .58422 m .28615 .60144 L .28517 .60261 L F
.32597 .60296 m .28517 .60261 L .28881 .59828 L .406 0 0 r
F
.28615 .60144 m .28367 .6054 L .28517 .60261 L .1 0 0 r
F
.28881 .59828 m .28517 .60261 L .27485 .59652 L .406 0 0 r
F
.2901 .59674 m .27485 .59652 L .26905 .59309 L F
.32597 .60296 m .28881 .59828 L .2901 .59674 L F
.28881 .59828 m .27485 .59652 L .2901 .59674 L F
.28615 .60144 m .27903 .61408 L .28367 .6054 L .1 0 0 r
F
.28771 .59958 m .27903 .61408 L .28615 .60144 L F
.3543 .63524 m .34614 .62138 L .29964 .60832 L .617 0 0 r
F
.34614 .62138 m .27959 .71465 L .34506 .60939 L 1 0 0 r
F
.34614 .62138 m .28111 .72629 L .27959 .71465 L F
.34506 .60939 m .28562 .70686 L .35136 .60111 L .1 0 0 r
F
.34506 .60939 m .27959 .71465 L .28562 .70686 L F
.28562 .70686 m .32502 .64348 L p .30893 .56725 L .894 0 0 r
F P
0 g
s
.32502 .64348 m .35136 .60111 L .32647 .58125 L p .894 0 0 r
F P
0 g
s
.32647 .58125 m .30893 .56725 L p .32502 .64348 L .894 0 0 r
F P
0 g
s
.32719 .55052 m .32647 .58125 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.29691 .58422 m .30893 .56725 L .2901 .59674 L .1 0 0 r
F
.29017 .59324 m .15973 .54501 L .16766 .57193 L .879 0 0 r
F
.29041 .59285 m .15973 .54501 L .29017 .59324 L F
.19824 .58083 m .32597 .60296 L .32719 .55052 L p .894 0 0 r
F P
0 g
s
.32719 .55052 m .32597 .60296 L .19824 .58083 L .894 0 0 r
F
.30893 .56725 m .35136 .60111 L .43017 .55355 L p .617 0 0 r
F P
0 g
s
.29802 .61019 m .29238 .60687 L .23025 .68857 L 1 0 0 r
F
.29964 .60832 m .29238 .60687 L .29802 .61019 L F
.29964 .60832 m .23025 .68857 L .23391 .71199 L F
.35136 .60111 m .2417 .67255 L .30893 .56725 L .894 0 0 r
F
.40463 .50042 m .32719 .55052 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.38592 .5177 m .30893 .56725 L p .35758 .56175 L .617 0 0 r
F P
0 g
s
.43017 .55355 m .40422 .53252 L p .35758 .56175 L .617 0 0 r
F P
0 g
s
.40422 .53252 m .40463 .50042 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.40422 .53252 m .38592 .5177 L p .35758 .56175 L .617 0 0 r
F P
0 g
s
.40392 .55521 m .40422 .53252 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.32597 .60296 m .40392 .55521 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.32647 .58125 m .32597 .60296 L p .37121 .55321 L .421 0 0 r
F P
0 g
s
.28771 .59958 m .2901 .59674 L .27903 .61408 L .1 0 0 r
F
.28367 .6054 m .27903 .61408 L .2417 .67255 L F
.28367 .6054 m .24266 .671 L .28517 .60261 L F
.26905 .59309 m .1811 .58471 L .19824 .58083 L .406 0 0 r
F
.27485 .59652 m .1811 .58471 L .26905 .59309 L F
.27485 .59652 m .28517 .60261 L .1811 .58471 L F
.26879 .62824 m .2417 .67255 L .23025 .68857 L .1 0 0 r
F
.24266 .671 m .2417 .67255 L .26879 .62824 L F
0 0 0 r
.45637 .37157 m
.45637 .37157 L
s
.45637 .37157 m
.45637 .37157 L
s
.45455 .36779 m
.4553 .36935 L
s
.38593 .66037 m .30436 .7537 L .36826 .64889 L .862 0 0 r
F
0 g
.34392 .66267 m
.34956 .65947 L
s
.38593 .66037 m .32255 .76544 L .30436 .7537 L .862 0 0 r
F
.40476 .66802 m .32255 .76544 L .38593 .66037 L .797 0 0 r
F
.68391 .54272 m .79712 .56514 L .80697 .54902 L .853 0 0 r
F
0 0 0 r
.7279 .51286 m
.72889 .54502 L
s
.79712 .56514 m .83141 .57459 L .80697 .54902 L .529 0 0 r
F
0 g
.79448 .5673 m
.79712 .56514 L
s
.42862 .70259 m
.43019 .70176 L
s
.36826 .64889 m .30436 .7537 L .28041 .76614 L .218 0 0 r
F
.36826 .64889 m .28983 .73999 L .3543 .63524 L .922 0 0 r
F
.36826 .64889 m .28041 .76614 L .30436 .7537 L .218 0 0 r
F
.36826 .64889 m .30436 .7537 L .28983 .73999 L .922 0 0 r
F
0 g
.36826 .64889 m
.38593 .66037 L
s
.72692 .42965 m .82496 .42967 L .84049 .45496 L .882 0 0 r
F
.72692 .42965 m .71235 .40406 L .82496 .42967 L F
0 g
.80347 .41939 m
.82496 .42967 L
s
.30568 .53338 m .18087 .5102 L .18004 .49165 L .893 0 0 r
F
.31041 .54655 m .18087 .5102 L .30568 .53338 L .88 0 0 r
F
0 g
.30439 .51516 m
.30568 .53338 L
s
0 0 0 r
.63836 .54943 m
.63836 .54943 L
s
.63765 .51112 m
.63836 .54943 L
s
.63765 .51112 m
.63765 .51112 L
s
.18258 .47063 m .16331 .46687 L .17415 .42666 L .37 0 0 r
F
.18004 .49165 m .16331 .46687 L .18258 .47063 L F
.18004 .49165 m .15826 .50822 L .16331 .46687 L F
.58843 .28955 m .60903 .19485 L .64535 .19616 L .683 0 0 r
F
0 g
.58133 .20572 m
.60903 .19485 L
s
.78721 .62613 m
.81128 .60705 L
s
.73356 .6162 m
.78721 .62613 L
s
.40476 .66802 m .34175 .7735 L .32255 .76544 L .797 0 0 r
F
.42198 .67068 m .34175 .7735 L .40476 .66802 L .702 0 0 r
F
0 g
.38593 .66037 m
.40476 .66802 L
s
.25434 .30337 m
.26398 .32349 L
s
.18811 .45019 m .17415 .42666 L .1893 .39315 L .37 0 0 r
F
.18258 .47063 m .17415 .42666 L .18811 .45019 L F
0 g
.16331 .46687 m
.17415 .42666 L
s
.17415 .42666 m
.1893 .39315 L
s
.3543 .63524 m .28111 .72629 L .34614 .62138 L .99 0 0 r
F
.3543 .63524 m .28983 .73999 L .28111 .72629 L F
0 g
.3543 .63524 m
.36826 .64889 L
s
.34614 .62138 m
.3543 .63524 L
s
.48729 .82518 m
.50171 .81973 L
s
.18087 .5102 m .15826 .50822 L .18004 .49165 L .37 0 0 r
F
.18087 .5102 m .15973 .54501 L .15826 .50822 L F
0 g
.15826 .50822 m
.16331 .46687 L
s
.17967 .51219 m
.204 .5167 L
s
.15826 .50822 m
.18004 .49165 L
s
.67003 .45029 m
.68155 .44752 L
s
.8148 .50822 m .84734 .49165 L .84049 .45496 L .529 0 0 r
F
.7016 .48438 m .84734 .49165 L .8148 .50822 L .7 0 0 r
F
.7016 .48438 m .8148 .50822 L .84734 .49165 L F
.69979 .5056 m .8148 .50822 L .7016 .48438 L .897 0 0 r
F
0 0 0 r
.67077 .48202 m
.70126 .48841 L
s
.69979 .5056 m .8132 .52898 L .8148 .50822 L .897 0 0 r
F
.8132 .52898 m .84734 .49165 L .8148 .50822 L .529 0 0 r
F
.69356 .52613 m .80697 .54902 L .8132 .52898 L .882 0 0 r
F
.80697 .54902 m .84416 .53387 L .8132 .52898 L .529 0 0 r
F
.80697 .54902 m .83141 .57459 L .84416 .53387 L F
.68391 .54272 m .80697 .54902 L .69356 .52613 L .853 0 0 r
F
0 g
.79712 .56514 m
.80697 .54902 L
s
0 0 0 r
.45637 .37157 m
.45637 .37157 L
s
.8132 .52898 m .84416 .53387 L .84734 .49165 L .529 0 0 r
F
.69356 .52613 m .8132 .52898 L .69979 .5056 L .882 0 0 r
F
0 g
.8132 .52898 m
.8148 .50822 L
s
.80697 .54902 m
.8132 .52898 L
s
0 0 0 r
.67166 .52045 m
.69392 .52495 L
s
.45691 .19794 m .49831 .18406 L .51292 .16943 L .771 0 0 r
F
.5167 .3209 m .49831 .18406 L .45691 .19794 L .899 0 0 r
F
0 g
.49831 .18406 m
.54059 .27076 L
s
.42198 .67068 m .35917 .7767 L .34175 .7735 L .702 0 0 r
F
.43506 .66792 m .35917 .7767 L .42198 .67068 L .497 0 0 r
F
0 g
.40476 .66802 m
.42198 .67068 L
s
.31041 .54655 m .18498 .52355 L .18087 .5102 L .88 0 0 r
F
.31795 .55262 m .18498 .52355 L .31041 .54655 L .712 0 0 r
F
0 g
.30568 .53338 m
.31041 .54655 L
s
.69188 .35823 m .71996 .23342 L .74588 .26328 L .938 0 0 r
F
.70504 .38915 m .69188 .35823 L .74588 .26328 L 1 0 0 r
F
0 g
.74588 .26328 m
.75816 .29433 L
s
0 0 0 r
.57977 .79709 m
.57977 .79709 L
s
.57977 .79709 m
.57978 .79709 L
s
.44896 .36124 m .48093 .3491 L .44081 .37753 L p 0 .525 .99 r
F P
0 g
s
.44081 .37753 m .48093 .3491 L .51235 .33717 L p 0 .525 .99 r
F P
0 g
s
0 0 0 r
.49183 .35158 m
.49183 .35158 L
s
.49183 .35158 m
.49183 .35158 L
s
.4251 .38355 m
.4251 .38355 L
s
.39235 .20511 m
.39235 .20511 L
s
.39235 .20511 m
.39235 .20511 L
s
.4251 .38355 m
.4251 .38355 L
s
0 g
.3452 .61102 m
.34614 .62138 L
s
.65402 .39125 m .65488 .37782 L .70504 .38915 L .656 0 0 r
F
0 g
.64583 .4008 m
.65402 .39125 L
s
.62841 .30388 m .64535 .19616 L .68449 .20972 L .794 0 0 r
F
.62841 .30388 m .58843 .28955 L .64535 .19616 L F
0 g
.60903 .19485 m
.64535 .19616 L
s
.32255 .76544 m .31619 .78921 L .28041 .76614 L .592 0 0 r
F
.34175 .7735 m .31619 .78921 L .32255 .76544 L F
.34175 .7735 m .354 .8052 L .31619 .78921 L F
.18796 .51162 m .33982 .53982 L .34066 .50118 L p 0 .35 .74 r
F P
0 g
s
.34066 .50118 m .18963 .47203 L .18796 .51162 L p 0 .35 .74 r
F P
0 g
s
.18004 .49165 m
.18873 .49329 L
s
.19129 .43286 m .18963 .47203 L .34066 .50118 L p 0 .35 .74 r
F P
0 g
s
.18963 .47203 m .34066 .50118 L .37838 .47576 L p 0 .448 1 r
F P
0 g
s
.37838 .47576 m .34066 .50118 L .33982 .53982 L p 0 .158 .672 r
F P
0 g
s
.37838 .47576 m .34066 .50118 L .18963 .47203 L p 0 .448 1 r
F P
0 g
s
.33982 .53982 m .37773 .51523 L .37838 .47576 L p 0 .158 .672 r
F P
0 g
s
.37773 .51523 m .37838 .47576 L p .23642 .48473 L 0 .351 .737 r
F P
0 g
s
.2363 .48811 m .37773 .51523 L p .23642 .48473 L 0 .351 .737 r
F P
0 g
s
.37773 .51523 m .33982 .53982 L .18796 .51162 L p 0 .45 1 r
F P
0 g
s
.31795 .55262 m .19183 .5296 L .18498 .52355 L .712 0 0 r
F
.37838 .47576 m .22458 .44511 L .18963 .47203 L p 0 .448 1 r
F P
0 g
s
.37838 .47576 m .22458 .44511 L .22458 .44511 L p 0 .351 .737 r
F P
0 g
s
.18963 .47203 m .22458 .44511 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.22458 .44511 m .22306 .48558 L p .37838 .47576 L 0 .351 .737 r
F P
0 g
s
.37838 .47576 m .22458 .44511 L .37838 .47576 L 0 .351 .737 r
F
.22458 .44511 m .37838 .47576 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.22458 .44511 m .22458 .44511 L p .37838 .47576 L 0 .448 1 r
F P
0 g
s
.22306 .48558 m .22458 .44511 L .23774 .44774 L p 0 .351 .737 r
F P
0 g
s
.23774 .44774 m .37838 .47576 L p .23642 .48473 L 0 .351 .737 r
F P
0 g
s
.23642 .48473 m .22306 .48558 L .23774 .44774 L 0 .351 .737 r
F
.22306 .48558 m .2363 .48811 L p .23642 .48473 L F P
0 g
s
.37838 .47576 m .37773 .51523 L .22306 .48558 L p 0 .351 .737 r
F P
0 g
s
.37773 .51523 m .22306 .48558 L .26003 .45816 L p 0 .45 1 r
F P
0 g
s
.18796 .51162 m .22306 .48558 L .37773 .51523 L p 0 .45 1 r
F P
0 g
s
.27309 .47469 m .20041 .52729 L .32719 .55052 L p .689 0 0 r
F P
0 g
s
.23581 .50167 m .27309 .47469 L .23483 .52894 L .37 0 0 r
F
.27309 .47469 m .27136 .53068 L p .23483 .52894 L F P
0 g
s
.20041 .52729 m .23581 .50167 L p .23483 .52894 L .37 0 0 r
F P
0 g
s
.35917 .7767 m .354 .8052 L .3425 .77545 L .592 0 0 r
F
.34518 .77413 m .3425 .77545 L .34175 .7735 L F
.35917 .7767 m .3425 .77545 L .34518 .77413 L F
.43506 .66792 m .37222 .7745 L .41492 .80785 L p .894 0 0 r
F P
0 g
s
.43506 .66792 m .41492 .80785 L .37222 .7745 L .894 0 0 r
F
.45363 .73518 m .37222 .7745 L .43506 .66792 L p .255 0 0 r
F P
0 g
s
.43506 .66792 m .5174 .62424 L .45363 .73518 L p .255 0 0 r
F P
0 g
s
.43506 .66792 m .37222 .7745 L .35917 .7767 L .497 0 0 r
F
.47079 .62757 m .43081 .6493 L .36149 .76612 L p 0 .05 .312 r
F P
0 g
s
.36149 .76612 m .35497 .77709 L p .3647 .76454 L 0 .05 .312 r
F P
0 g
s
.47079 .62757 m .36149 .76612 L .3647 .76454 L 0 .05 .312 r
F
.35497 .77709 m .43081 .6493 L .39964 .62436 L p 0 .35 .74 r
F P
0 g
s
.43081 .6493 m .47079 .62757 L .43897 .60194 L p 0 .355 .983 r
F P
0 g
s
.43897 .60194 m .39964 .62436 L .43081 .6493 L p 0 .355 .983 r
F P
0 g
s
.32255 .76544 m .28041 .76614 L .30436 .7537 L .592 0 0 r
F
.30436 .7537 m .28041 .76614 L .25159 .73916 L F
0 g
.2904 .74985 m
.29403 .74395 L
s
.28041 .76614 m
.31619 .78921 L
s
.54082 .31184 m
.56489 .33222 L
s
.52386 .29747 m
.53601 .30775 L
s
.56489 .33222 m
.57887 .32745 L
s
.18498 .52355 m .15973 .54501 L .18087 .5102 L .37 0 0 r
F
.18498 .52355 m .16766 .57193 L .15973 .54501 L F
0 g
.15826 .50822 m
.15973 .54501 L
s
0 0 0 r
.57575 .78874 m
.57977 .79709 L
s
.57977 .79709 m
.57977 .79709 L
s
.46062 .36349 m
.46062 .36349 L
s
.46062 .36349 m
.46062 .36349 L
s
.46062 .36349 m
.49183 .35158 L
s
.49183 .35158 m
.49183 .35158 L
s
.73302 .46701 m .84049 .45496 L .84734 .49165 L .905 0 0 r
F
.73302 .46701 m .72692 .42965 L .84049 .45496 L F
0 g
.82496 .42967 m
.84049 .45496 L
s
.63474 .34771 m .71996 .23342 L .66491 .32813 L .218 0 0 r
F
.69188 .35823 m .66491 .32813 L .71996 .23342 L .938 0 0 r
F
.63474 .34771 m .66491 .32813 L .71996 .23342 L .218 0 0 r
F
.66491 .32813 m .68449 .20972 L .71996 .23342 L .869 0 0 r
F
0 g
.71996 .23342 m
.74588 .26328 L
s
0 0 0 r
.46502 .35514 m
.46502 .35514 L
s
.4251 .38355 m
.46502 .35514 L
s
.4251 .38355 m
.4251 .38355 L
s
.32719 .55052 m .19183 .5296 L .31795 .55262 L .445 0 0 r
F
0 g
.31185 .54771 m
.31253 .54826 L
s
.66491 .32813 m .62841 .30388 L .68449 .20972 L .869 0 0 r
F
0 g
.64535 .19616 m
.68449 .20972 L
s
.68449 .20972 m
.71996 .23342 L
s
.35917 .7767 m .38859 .81181 L .354 .8052 L .592 0 0 r
F
0 g
.31619 .78921 m
.354 .8052 L
s
.28979 .72629 m .3225 .75178 L .39964 .62436 L p 0 .35 .74 r
F P
0 g
s
.36182 .65946 m
.36826 .64889 L
s
.39964 .62436 m .36825 .59926 L .28979 .72629 L p 0 .35 .74 r
F P
0 g
s
.39964 .62436 m .3225 .75178 L .35497 .77709 L p 0 .35 .74 r
F P
0 g
s
.43897 .60194 m .39964 .62436 L .3225 .75178 L p 0 .05 .286 r
F P
0 g
s
.36825 .59926 m .39964 .62436 L .43897 .60194 L p 0 .355 .983 r
F P
0 g
s
.3225 .75178 m .36118 .73189 L .43897 .60194 L p 0 .05 .286 r
F P
0 g
s
.36118 .73189 m .43897 .60194 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.3225 .75178 m .39964 .62436 L .43897 .60194 L p 0 .05 .286 r
F P
0 g
s
.36118 .73189 m .36118 .73189 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .36118 .73189 L .3225 .75178 L p 0 .05 .286 r
F P
0 g
s
.32776 .70567 m .36118 .73189 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.40988 .71062 m
.42079 .69212 L
s
.48166 .77788 m
.50171 .81973 L
s
.65488 .37782 m .69188 .35823 L .70504 .38915 L .656 0 0 r
F
0 g
.70409 .39996 m
.70504 .38915 L
s
.65488 .37782 m .64813 .36251 L .69188 .35823 L .656 0 0 r
F
0 g
.65402 .39125 m
.65488 .37782 L
s
0 0 0 r
.46062 .36349 m
.46062 .36349 L
s
.46062 .36349 m
.46062 .36349 L
s
.28983 .73999 m .25159 .73916 L .23391 .71199 L .592 0 0 r
F
.30436 .7537 m .25159 .73916 L .28983 .73999 L F
0 g
.25159 .73916 m
.28041 .76614 L
s
.30436 .7537 m
.311 .74281 L
s
.28041 .76614 m
.30436 .7537 L
s
.69872 .46586 m .69165 .45294 L .71235 .40406 L .502 0 0 r
F
0 g
.68155 .44752 m
.69165 .45294 L
s
.45691 .19794 m .51292 .16943 L .46395 .19069 L .771 0 0 r
F
.5167 .3209 m .45691 .19794 L .46395 .19069 L .45 0 0 r
F
0 g
.46569 .195 m
.49831 .18406 L
s
.43897 .60194 m .40694 .57612 L .36825 .59926 L p 0 .355 .983 r
F P
0 g
s
.28979 .72629 m .36825 .59926 L .40694 .57612 L p 0 .05 .258 r
F P
0 g
s
.67241 .55278 m
.6731 .58241 L
s
.18258 .47063 m
.18811 .45019 L
s
.18004 .49165 m
.18258 .47063 L
s
0 0 0 r
.58751 .60805 m
.58751 .60805 L
s
.58751 .60805 m
.58751 .60805 L
s
0 g
.18811 .45019 m
.18963 .44686 L
s
.18963 .44686 m
.1908 .44431 L
s
.44044 .18918 m .51235 .33717 L .48093 .3491 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.49671 .34311 m
.49671 .34311 L
s
.48093 .3491 m .40852 .19975 L .44044 .18918 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.44465 .27427 m
.44465 .27427 L
s
.44465 .27427 m
.44465 .27427 L
s
.45637 .37157 m
.49671 .34311 L
s
.42455 .19444 m
.42455 .19444 L
s
.42455 .19444 m
.42455 .19444 L
s
0 g
.18004 .49165 m
.18087 .5102 L
s
.32719 .55052 m .20041 .52729 L .19183 .5296 L .445 0 0 r
F
.32719 .55052 m .20041 .52729 L .19824 .58083 L p .894 0 0 r
F P
0 g
s
.37838 .47576 m .37773 .51523 L .41758 .48938 L p 0 .158 .672 r
F P
0 g
s
.41758 .48938 m .37773 .51523 L p .3684 .51071 L 0 .45 1 r
F P
0 g
s
.26003 .45816 m .40481 .48685 L p .3684 .51071 L 0 .45 1 r
F P
0 g
s
.40481 .48685 m .41758 .48938 L p .3684 .51071 L 0 .45 1 r
F P
0 g
s
.41758 .48938 m .41803 .44904 L .37838 .47576 L p 0 .158 .672 r
F P
0 g
s
.26138 .41678 m .41803 .44904 L .37838 .47576 L p 0 .448 1 r
F P
0 g
s
.37838 .47576 m .22458 .44511 L .26138 .41678 L p 0 .448 1 r
F P
0 g
s
.41803 .44904 m .41758 .48938 L .26003 .45816 L p 0 .351 .734 r
F P
0 g
s
.43017 .55355 m .44418 .54987 L .42235 .52116 L .617 0 0 r
F
.43017 .55355 m .42235 .52116 L .41881 .52337 L F
.43897 .60194 m .40694 .57612 L .33457 .69453 L p 0 .351 .737 r
F P
0 g
s
.33457 .69453 m .32776 .70567 L p .33735 .69672 L 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .33457 .69453 L .33735 .69672 L 0 .351 .737 r
F
.35136 .60111 m .28562 .70686 L .2417 .67255 L .894 0 0 r
F
.30893 .56725 m .2417 .67255 L .28562 .70686 L p F P
0 g
s
.28562 .70686 m .2417 .67255 L p .30103 .66815 L .592 0 0 r
F P
0 g
s
.40694 .57612 m .43897 .60194 L p .33735 .69672 L 0 .351 .737 r
F P
0 g
s
.32776 .70567 m .33457 .69453 L p .33735 .69672 L 0 .351 .737 r
F P
0 g
s
.33457 .69453 m .40694 .57612 L p .33735 .69672 L 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .36118 .73189 L .32776 .70567 L p 0 .351 .737 r
F P
0 g
s
.36775 .68394 m .32776 .70567 L .40694 .57612 L p 0 .05 .258 r
F P
0 g
s
.40694 .57612 m .32776 .70567 L .28979 .72629 L p 0 .05 .258 r
F P
0 g
s
.3101 .66748 m .36322 .66354 L p .35136 .60111 L .177 0 0 r
F P
0 g
s
.30684 .67272 m .28562 .70686 L p .32341 .68576 L .177 0 0 r
F P
0 g
s
.36322 .66354 m .32341 .68576 L p .30103 .66815 L .592 0 0 r
F P
0 g
s
.32341 .68576 m .28562 .70686 L p .30103 .66815 L .592 0 0 r
F P
0 g
s
.44761 .55179 m .40694 .57612 L .43897 .60194 L p 0 .355 .983 r
F P
0 g
s
.40694 .57612 m .44761 .55179 L .36775 .68394 L p 0 .05 .258 r
F P
0 g
s
.36322 .66354 m .43017 .55355 L .35136 .60111 L p .177 0 0 r
F P
0 g
s
.32719 .55052 m .40463 .50042 L .27309 .47469 L p .689 0 0 r
F P
0 g
s
.32719 .55052 m .19824 .58083 L .20041 .52729 L .894 0 0 r
F
.40392 .55521 m .32597 .60296 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.2901 .59674 m .30893 .56725 L p .3112 .58341 L .133 0 0 r
F P
0 g
s
.36673 .54833 m .40392 .55521 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.30893 .56725 m .38592 .5177 L .36673 .54833 L p .133 0 0 r
F P
0 g
s
.32597 .60296 m .2901 .59674 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.36673 .54833 m .31734 .62719 L p .3112 .58341 L .133 0 0 r
F P
0 g
s
.30893 .56725 m .36673 .54833 L .3112 .58341 L .133 0 0 r
F
.19824 .58083 m .27136 .53068 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.2901 .59674 m .19824 .58083 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.27136 .53068 m .36673 .54833 L p .3112 .58341 L .678 0 0 r
F P
0 g
s
.31734 .62719 m .2417 .67255 L .2901 .59674 L p .133 0 0 r
F P
0 g
s
.3112 .58341 m .31734 .62719 L .2901 .59674 L .133 0 0 r
F
.38592 .5177 m .43017 .55355 L .36322 .66354 L p .899 0 0 r
F P
0 g
s
.43017 .55355 m .41881 .52337 L .40422 .53252 L .617 0 0 r
F
.43017 .55355 m .38592 .5177 L .31734 .62719 L .899 0 0 r
F
.42235 .52116 m .40392 .55521 L .42521 .53373 L .421 0 0 r
F
.41514 .48949 m .40822 .53001 L .42235 .52116 L F
.40822 .53001 m .40392 .55521 L .42235 .52116 L F
.40463 .50042 m .40392 .55521 L .27136 .53068 L p .899 0 0 r
F P
0 g
s
.40463 .50042 m .27136 .53068 L .40392 .55521 L .899 0 0 r
F
.41514 .48949 m .40463 .50042 L .40392 .55521 L .421 0 0 r
F
.40422 .53252 m .4137 .50978 L .38592 .5177 L .617 0 0 r
F
.41881 .52337 m .4137 .50978 L .40422 .53252 L F
.41881 .52337 m .42235 .52116 L .4137 .50978 L F
.42427 .47409 m .41514 .48949 L .42235 .52116 L .421 0 0 r
F
.42427 .47409 m .42235 .52116 L .42499 .5195 L F
.44418 .54987 m .45157 .51415 L .43633 .5124 L .617 0 0 r
F
.42423 .47178 m .42449 .48814 L .44381 .49804 L .421 0 0 r
F
.42449 .48814 m .42499 .5195 L .4345 .50865 L F
.42449 .48814 m .4345 .50865 L .44381 .49804 L F
.42499 .5195 m .43633 .5124 L .44381 .49804 L F
.42235 .52116 m .43633 .5124 L .4137 .50978 L .617 0 0 r
F
.44418 .54987 m .43633 .5124 L .42235 .52116 L F
.42499 .5195 m .42521 .53373 L .43633 .5124 L .421 0 0 r
F
.42499 .5195 m .42235 .52116 L .42521 .53373 L F
.43017 .55355 m .31734 .62719 L .36322 .66354 L .899 0 0 r
F
.36322 .66354 m .31734 .62719 L .38592 .5177 L p F P
0 g
s
.36673 .54833 m .34505 .62047 L .31734 .62719 L .433 0 0 r
F
.38592 .5177 m .37568 .54344 L .36673 .54833 L F
.42521 .53373 m .40392 .55521 L .36673 .54833 L .779 0 0 r
F
.42521 .53373 m .36673 .54833 L .38337 .53923 L F
.37568 .54344 m .34505 .62047 L .36673 .54833 L .433 0 0 r
F
.38592 .5177 m .4137 .50978 L .40162 .52925 L F
.42521 .53373 m .38337 .53923 L .39454 .53312 L .779 0 0 r
F
.38592 .5177 m .40162 .52925 L .37568 .54344 L .433 0 0 r
F
.27136 .53068 m .27309 .47469 L .40463 .50042 L p .899 0 0 r
F P
0 g
s
.40463 .50042 m .27309 .47469 L .27136 .53068 L .899 0 0 r
F
.40162 .52925 m .27136 .53068 L .29153 .50834 L .779 0 0 r
F
.42521 .53373 m .38754 .53299 L .40162 .52925 L F
.38754 .53299 m .27136 .53068 L .40162 .52925 L F
.40162 .52925 m .38339 .62603 L .34505 .62047 L .683 0 0 r
F
.4137 .50978 m .40964 .52536 L .40162 .52925 L F
.43633 .5124 m .42521 .53373 L .40162 .52925 L .854 0 0 r
F
.4137 .50978 m .43633 .5124 L .43226 .52113 L .683 0 0 r
F
.4137 .50978 m .43226 .52113 L .40914 .52726 L F
.44381 .49804 m .43633 .5124 L .29153 .50834 L .854 0 0 r
F
.43633 .5124 m .40162 .52925 L .29153 .50834 L F
.40964 .52536 m .40914 .52726 L .40162 .52925 L .683 0 0 r
F
.40914 .52726 m .38339 .62603 L .40162 .52925 L F
.37568 .54344 m .40162 .52925 L .34505 .62047 L .433 0 0 r
F
.39454 .53312 m .34489 .54429 L .38754 .53299 L .779 0 0 r
F
.38337 .53923 m .34489 .54429 L .39454 .53312 L F
.38337 .53923 m .36673 .54833 L .34489 .54429 L F
.38754 .53299 m .34489 .54429 L .27136 .53068 L F
.40914 .52726 m .43226 .52113 L .38339 .62603 L .683 0 0 r
F
.43633 .5124 m .45157 .51415 L .44358 .52726 L F
.43633 .5124 m .44358 .52726 L .38339 .62603 L F
.42423 .47178 m .42243 .4753 L .42427 .47409 L .421 0 0 r
F
.42243 .4753 m .41514 .48949 L .42427 .47409 L F
.7016 .48438 m .73302 .46701 L .84734 .49165 L .7 0 0 r
F
.7016 .48438 m .84734 .49165 L .73302 .46701 L F
.72942 .51017 m .84734 .49165 L .84416 .53387 L .899 0 0 r
F
.72942 .51017 m .73302 .46701 L .84734 .49165 L F
0 g
.84049 .45496 m
.84734 .49165 L
s
.46395 .19069 m .51292 .16943 L .5129 .1609 L .771 0 0 r
F
0 g
.49831 .18406 m
.51292 .16943 L
s
.64813 .36251 m .66491 .32813 L .69188 .35823 L .656 0 0 r
F
.64813 .36251 m .63474 .34771 L .66491 .32813 L F
0 g
.64813 .36251 m
.65488 .37782 L
s
.71667 .55193 m .84416 .53387 L .83141 .57459 L .883 0 0 r
F
0 g
.81128 .60705 m
.83141 .57459 L
s
.64972 .59445 m .71087 .7202 L .74993 .70005 L .899 0 0 r
F
.71987 .71665 m .74993 .70005 L .71087 .7202 L .1 0 0 r
F
.71987 .71665 m .76841 .69269 L .74993 .70005 L F
.74993 .70005 m .71087 .7202 L .64972 .59445 L p .899 0 0 r
F P
0 g
s
.70661 .61122 m
.74993 .70005 L
s
.67362 .60511 m
.70661 .61122 L
s
.67312 .58345 m
.67362 .60511 L
s
0 0 0 r
.42887 .3756 m
.42887 .3756 L
s
.42887 .3756 m
.46062 .36349 L
s
.46062 .36349 m
.46062 .36349 L
s
.5167 .3209 m .46395 .19069 L .52419 .31451 L .45 0 0 r
F
0 0 0 r
.47632 .26302 m
.47632 .26302 L
s
.47632 .26302 m
.47632 .26302 L
s
0 g
.45691 .19794 m
.5167 .3209 L
s
.5167 .3209 m
.54082 .31184 L
s
.3101 .66748 m
.32927 .63664 L
s
.61678 .3358 m .59712 .32868 L .58843 .28955 L .656 0 0 r
F
0 g
.57887 .32745 m
.59712 .32868 L
s
0 0 0 r
.44465 .27427 m
.44465 .27427 L
s
.44465 .27427 m
.44465 .27427 L
s
.47632 .26302 m
.47632 .26302 L
s
.20673 .37121 m .27813 .3117 L .27647 .36522 L p .37 0 0 r
F P
0 g
s
.20467 .42219 m
.20673 .37121 L
s
.1893 .39315 m
.20673 .37121 L
s
.37222 .7745 m .38859 .81181 L .35917 .7767 L .592 0 0 r
F
.37222 .7745 m .41492 .80785 L .38859 .81181 L F
0 g
.354 .8052 m
.38859 .81181 L
s
.71667 .55193 m .72942 .51017 L .84416 .53387 L .883 0 0 r
F
0 g
.84416 .53387 m
.84734 .49165 L
s
.83141 .57459 m
.84416 .53387 L
s
.69872 .46586 m .71235 .40406 L .72692 .42965 L .502 0 0 r
F
0 g
.70409 .39996 m
.71235 .40406 L
s
.7016 .48438 m .69872 .46586 L .72692 .42965 L .502 0 0 r
F
0 g
.69165 .45294 m
.69872 .46586 L
s
.19183 .5296 m .16766 .57193 L .18498 .52355 L .37 0 0 r
F
.19183 .5296 m .1811 .58471 L .16766 .57193 L F
0 g
.15973 .54501 m
.16766 .57193 L
s
.63474 .34771 m .62841 .30388 L .66491 .32813 L .656 0 0 r
F
0 g
.64009 .34424 m
.66491 .32813 L
s
.66491 .32813 m
.71996 .23342 L
s
.63474 .34771 m .61678 .3358 L .62841 .30388 L .656 0 0 r
F
0 g
.63474 .34771 m
.64813 .36251 L
s
.63474 .34771 m
.64009 .34424 L
s
.68391 .54272 m .69356 .52613 L .71667 .55193 L .502 0 0 r
F
0 g
.67241 .55278 m
.68391 .54272 L
s
.69188 .35823 m
.70504 .38915 L
s
.61678 .3358 m .58843 .28955 L .62841 .30388 L .656 0 0 r
F
0 g
.59712 .32868 m
.61678 .3358 L
s
.61678 .3358 m
.63474 .34771 L
s
0 0 0 r
.66185 .76155 m
.66185 .76155 L
s
.66185 .76155 m
.66185 .76155 L
s
0 g
.18087 .5102 m
.18498 .52355 L
s
0 0 0 r
.49067 .33067 m
.49653 .34273 L
s
.42455 .19444 m
.43054 .20678 L
s
.49671 .34311 m
.49671 .34311 L
s
.49653 .34273 m
.49671 .34311 L
s
.42455 .19444 m
.42455 .19444 L
s
.46395 .19069 m .5129 .1609 L .46355 .18661 L .771 0 0 r
F
.52419 .31451 m .46395 .19069 L .46355 .18661 L .1 0 0 r
F
0 g
.52386 .29747 m
.55163 .2874 L
s
.45691 .19794 m
.46395 .19069 L
s
0 0 0 r
.42887 .3756 m
.42887 .3756 L
s
.4272 .37216 m
.42887 .3756 L
s
0 g
.27903 .61408 m
.2901 .59674 L
s
.30436 .7537 m
.32255 .76544 L
s

.32255 .76544 m
.34175 .7735 L
s
.26905 .59309 m
.2901 .59674 L
s
.7016 .48438 m .72692 .42965 L .73302 .46701 L .502 0 0 r
F
0 g
.71235 .40406 m
.72692 .42965 L
s
.69979 .5056 m .7016 .48438 L .73302 .46701 L .502 0 0 r
F
0 g
.69872 .46586 m
.7016 .48438 L
s
.71554 .48731 m
.73105 .49058 L
s
.28111 .72629 m .23391 .71199 L .23025 .68857 L .592 0 0 r
F
.28983 .73999 m .23391 .71199 L .28111 .72629 L F
0 g
.23391 .71199 m
.25159 .73916 L
s
.69356 .52613 m .72942 .51017 L .71667 .55193 L .502 0 0 r
F
.69356 .52613 m .69979 .5056 L .72942 .51017 L F
0 g
.68391 .54272 m
.69356 .52613 L
s
.28983 .73999 m
.30436 .7537 L
s
.52419 .31451 m .46355 .18661 L .52427 .3114 L .1 0 0 r
F
0 0 0 r
.44465 .27427 m
.47632 .26302 L
s
.43054 .20678 m
.49067 .33067 L
s
.52419 .31451 m .52427 .3114 L .57401 .28602 L .705 0 0 r
F
0 g
.5167 .3209 m
.52419 .31451 L
s
.55163 .2874 m
.56929 .28843 L
s
.57363 .28869 m
.57363 .28869 L
s
.69979 .5056 m .73302 .46701 L .72942 .51017 L .502 0 0 r
F
0 g
.69979 .5056 m
.7016 .48438 L
s
.69356 .52613 m
.69979 .5056 L
s
.7016 .48438 m
.73302 .46701 L
s
.73302 .46701 m
.84734 .49165 L
s
.65824 .59 m .71087 .7202 L .64972 .59445 L .45 0 0 r
F
0 g
.64972 .59445 m
.65305 .60131 L
s
.65305 .60131 m
.67456 .64555 L
s
.65839 .59037 m
.67312 .58345 L
s
.34175 .7735 m
.34518 .77413 L
s
.34518 .77413 m
.35304 .77558 L
s
.35576 .77608 m
.35917 .7767 L
s
.18498 .52355 m
.18633 .52474 L
s
0 0 0 r
.3153 .70509 m
.32915 .68256 L
s
.26272 .37588 m .22609 .4051 L .37903 .43672 L p 0 .446 1 r
F P
0 g
s
.37903 .43672 m .41848 .40915 L .26272 .37588 L p 0 .446 1 r
F P
0 g
s
0 0 0 r
.42751 .28036 m
.44465 .27427 L
s
.44465 .27427 m
.44465 .27427 L
s
.603 .60084 m .63356 .58661 L .70711 .73798 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.61835 .5937 m
.61835 .5937 L
s
.61834 .5937 m
.61835 .5937 L
s
.6237 .77896 m
.6237 .77896 L
s
.6237 .77896 m
.6237 .77896 L
s
.65824 .59 m .71987 .71665 L .71087 .7202 L .45 0 0 r
F
0 g
.67456 .64555 m
.71087 .7202 L
s
0 0 0 r
.67026 .66214 m
.67026 .66214 L
s
.67026 .66214 m
.67026 .66213 L
s
0 g
.71944 .71578 m
.74993 .70005 L
s
.52427 .3114 m .46355 .18661 L .4556 .1864 L 1 0 0 r
F
.46355 .18661 m .49757 .16008 L .4556 .1864 L .771 0 0 r
F
.46355 .18661 m .5129 .1609 L .49757 .16008 L F
0 0 0 r
.46502 .35514 m
.46502 .35514 L
s
.45894 .34259 m
.46502 .35514 L
s
.39235 .20511 m
.40803 .23749 L
s
.40803 .23749 m
.43195 .28687 L
s
.45668 .33792 m
.45894 .34259 L
s
.39235 .20511 m
.39235 .20511 L
s
.67026 .66214 m
.67026 .66213 L
s
.19129 .43286 m .22609 .4051 L .22458 .44511 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.20847 .41915 m
.20847 .41915 L
s
.20847 .41915 m
.20847 .41915 L
s
.22458 .44511 m .18963 .47203 L .19129 .43286 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.19046 .45239 m
.19046 .45239 L
s
.19046 .45239 m
.19046 .45239 L
s
0 g
.66491 .32813 m
.69188 .35823 L
s
.49817 .77047 m .41492 .80785 L .37222 .7745 L p .592 0 0 r
F P
0 g
s
.43522 .77249 m
.4557 .73682 L
s
.38859 .81181 m
.41492 .80785 L
s
.70999 .56446 m .76841 .69269 L .77251 .69249 L .1 0 0 r
F
.72152 .71675 m .76841 .69269 L .71987 .71665 L F
.72152 .71675 m .77251 .69249 L .76841 .69269 L F
0 g
.74993 .70005 m
.76841 .69269 L
s
.43581 .73774 m .51281 .60473 L .47079 .62757 L p 0 .05 .312 r
F P
0 g
s
.47079 .62757 m .39435 .75792 L .43581 .73774 L p 0 .05 .312 r
F P
0 g
s
.35497 .77709 m .39435 .75792 L .47079 .62757 L p 0 .05 .312 r
F P
0 g
s
.39435 .75792 m .47079 .62757 L .43897 .60194 L p 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .47079 .62757 L .51281 .60473 L p 0 .355 .983 r
F P
0 g
s
.35917 .7767 m
.37222 .7745 L
s
.43897 .60194 m .47079 .62757 L .39435 .75792 L p 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .36118 .73189 L .39435 .75792 L p 0 .351 .737 r
F P
0 g
s
.51281 .60473 m .48033 .57836 L .43897 .60194 L p 0 .355 .983 r
F P
0 g
s
.36118 .73189 m .43897 .60194 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.39435 .75792 m .36118 .73189 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.36118 .73189 m .36118 .73189 L p .43897 .60194 L 0 .351 .737 r
F P
0 g
s
.43897 .60194 m .36118 .73189 L .36118 .73189 L p 0 .05 .286 r
F P
0 g
s
.36118 .73189 m .40191 .71094 L p .43897 .60194 L 0 .05 .286 r
F P
0 g
s
.43897 .60194 m .36118 .73189 L .43897 .60194 L 0 .05 .286 r
F
.40191 .71094 m .48033 .57836 L .43897 .60194 L p F P
0 g
s
.70711 .73798 m .67707 .75362 L .603 .60084 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.63996 .67707 m
.63996 .67707 L
s
.63996 .67707 m
.63996 .67707 L
s
.63996 .67707 m
.63996 .67707 L
s
.63996 .67707 m
.63996 .67707 L
s
.69216 .74577 m
.69216 .74577 L
s
.69216 .74577 m
.69216 .74577 L
s
.28111 .72629 m .23025 .68857 L .27959 .71465 L .592 0 0 r
F
0 g
.28111 .72629 m
.28983 .73999 L
s
0 0 0 r
.61835 .5937 m
.61898 .595 L
s
.61835 .5937 m
.61835 .5937 L
s
.69216 .74577 m
.69216 .74577 L
s
0 g
.72692 .42965 m
.73302 .46701 L
s
.65939 .58908 m .71987 .71665 L .65824 .59 L .1 0 0 r
F
0 0 0 r
.61898 .595 m
.67612 .71273 L
s
0 g
.67362 .60511 m
.69694 .58534 L
s
.64972 .59445 m
.65824 .59 L
s
.57401 .28602 m .49757 .16008 L .5129 .1609 L 1 0 0 r
F
.52427 .3114 m .4556 .1864 L .51675 .31212 L F
.52427 .3114 m .55955 .2871 L .57401 .28602 L .705 0 0 r
F
0 g
.57363 .28869 m
.58843 .28955 L
s
.52427 .3114 m .51675 .31212 L .55955 .2871 L .705 0 0 r
F
0 g
.52419 .31451 m
.52427 .3114 L
s
0 0 0 r
.19046 .45239 m
.19046 .45239 L
s
0 g
.69694 .58534 m
.70874 .56536 L
s
0 0 0 r
.61928 .76981 m
.6237 .77896 L
s
.6237 .77896 m
.6237 .77896 L
s
0 g
.58843 .28955 m
.62841 .30388 L
s
.20041 .52729 m .1811 .58471 L .19183 .5296 L .37 0 0 r
F
0 g
.18633 .52474 m
.19183 .5296 L
s
.20041 .52729 m .19824 .58083 L .1811 .58471 L .37 0 0 r
F
0 g
.16766 .57193 m
.1811 .58471 L
s
0 0 0 r
.41781 .46916 m
.41781 .46916 L
s
.41781 .46916 m
.41781 .46916 L
s
.43897 .60194 m .48033 .57836 L .44761 .55179 L p 0 .355 .983 r
F P
0 g
s
.40191 .71094 m .36118 .73189 L .43897 .60194 L p 0 .05 .286 r
F P
0 g
s
0 0 0 r
.39493 .716 m
.39619 .71388 L
s
.40072 .66583 m
.40072 .66583 L
s
.40072 .66583 m
.40072 .66583 L
s
.43897 .60194 m .48033 .57836 L .40191 .71094 L p 0 .05 .286 r
F P
0 g
s
.18796 .51162 m .18963 .47203 L .22458 .44511 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.1888 .49177 m
.1888 .49177 L
s
.1888 .49177 m
.1888 .49177 L
s
.37222 .7745 m .45363 .73518 L .49817 .77047 L p .592 0 0 r
F P
0 g
s
.37222 .7745 m
.37222 .7745 L
s
.37222 .7745 m
.41492 .80785 L
s
.37222 .7745 m
.37703 .76635 L
s
.65939 .58908 m .72152 .71675 L .71987 .71665 L .1 0 0 r
F
0 g
.71087 .7202 m
.71987 .71665 L
s
0 0 0 r
.63996 .67707 m
.67026 .66214 L
s
.67612 .71273 m
.69216 .74577 L
s
.57401 .28602 m .55955 .2871 L .49757 .16008 L 1 0 0 r
F
0 g
.57363 .28869 m
.57401 .28602 L
s
.62841 .30388 m
.66491 .32813 L
s
.27959 .71465 m .23025 .68857 L .2417 .67255 L .592 0 0 r
F
0 g
.23025 .68857 m
.23391 .71199 L
s
.51675 .31212 m .4556 .1864 L .44119 .19017 L .941 0 0 r
F
.4556 .1864 m .46875 .16744 L .44119 .19017 L .771 0 0 r
F
.4556 .1864 m .49757 .16008 L .46875 .16744 L F
0 g
.4556 .1864 m
.46355 .18661 L
s
0 0 0 r
.36194 .68996 m
.36452 .68569 L
s
0 g
.36041 .2303 m
.37116 .2267 L
s
.37116 .2267 m
.38684 .25915 L
s
0 0 0 r
.1888 .49177 m
.1888 .49177 L
s
.27959 .71465 m .2417 .67255 L .28562 .70686 L .592 0 0 r
F
0 g
.27959 .71465 m
.28562 .70686 L
s
.27959 .71465 m
.28111 .72629 L
s
0 0 0 r
.6322 .68089 m
.63996 .67707 L
s
.63996 .67707 m
.63996 .67707 L
s
.35497 .77709 m .3225 .75178 L .36118 .73189 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.33877 .76446 m
.33877 .76445 L
s
.33877 .76445 m
.33877 .76445 L
s
.36118 .73189 m .39435 .75792 L .35497 .77709 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.37441 .76763 m
.37441 .76763 L
s
.37441 .76763 m
.37441 .76762 L
s
.38442 .73374 m
.39493 .716 L
s
.51675 .31212 m .44119 .19017 L .50264 .31664 L .941 0 0 r
F
.51675 .31212 m .53136 .296 L .55955 .2871 L .705 0 0 r
F
.51675 .31212 m .50264 .31664 L .53136 .296 L F
0 g
.51675 .31212 m
.52427 .3114 L
s
.27136 .53068 m .19824 .58083 L .20041 .52729 L p .37 0 0 r
F P
0 g
s
.19183 .5296 m
.20041 .52729 L
s
.19824 .58083 m
.26905 .59309 L
s
.1811 .58471 m
.19824 .58083 L
s
.19824 .58083 m
.20041 .52729 L
s
.72942 .51017 m
.73302 .46701 L
s
.65283 .5919 m .72152 .71675 L .65939 .58908 L 1 0 0 r
F
.65283 .5919 m .65939 .58908 L .70999 .56446 L .452 0 0 r
F
0 g
.70899 .56494 m
.71667 .55193 L
s
.71667 .55193 m
.72942 .51017 L
s
0 0 0 r
.30354 .42547 m
.30366 .42113 L
s
.30366 .42113 m
.30366 .42113 L
s
.22458 .44511 m .22306 .48558 L .18796 .51162 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.20529 .49876 m
.2184 .50124 L
s
.20529 .49876 m
.20529 .49876 L
s
.2184 .50124 m
.23269 .50393 L
s
.20689 .45874 m
.20689 .45874 L
s
.20689 .45874 m
.20689 .45874 L
s
0 g
.44384 .34512 m
.44573 .3439 L
s
0 0 0 r
.58751 .60805 m
.59303 .61944 L
s
.65723 .75199 m
.66185 .76155 L
s
.58751 .60805 m
.58751 .60805 L
s
.66185 .76155 m
.66185 .76155 L
s
.33877 .76446 m
.33877 .76446 L
s
.50264 .31664 m .44119 .19017 L .46875 .16744 L .568 0 0 r
F
.50264 .31664 m .44119 .19017 L .4225 .19739 L .867 0 0 r
F
.44119 .19017 m .4308 .18202 L .4225 .19739 L .771 0 0 r
F
.44119 .19017 m .46875 .16744 L .4308 .18202 L F
.50264 .31664 m .46875 .16744 L .44119 .19017 L .568 0 0 r
F
0 0 0 r
.20689 .45874 m
.20689 .45874 L
s
.20689 .45874 m
.20689 .45874 L
s
.20689 .45874 m
.20847 .41915 L
s
.20847 .41915 m
.20847 .41915 L
s
.46405 .3339 m .40252 .20693 L .38444 .21725 L .74 0 0 r
F
.40252 .20693 m .35328 .22253 L .38444 .21725 L .771 0 0 r
F
0 g
.37116 .2267 m
.38444 .21725 L
s
.36118 .73189 m .3225 .75178 L .28979 .72629 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.34159 .74196 m
.34159 .74196 L
s
.34159 .74196 m
.34159 .74196 L
s
.30618 .73906 m
.30618 .73906 L
s
.30618 .73906 m
.30618 .73906 L
s
.65283 .5919 m .70999 .56446 L .69749 .5698 L .452 0 0 r
F
.69749 .5698 m .70999 .56446 L .77251 .69249 L 1 0 0 r
F
.65283 .5919 m .7154 .72055 L .72152 .71675 L F
.7154 .72055 m .77251 .69249 L .72152 .71675 L .1 0 0 r
F
0 0 0 r
.30618 .73906 m
.30618 .73906 L
s
.48409 .3243 m .4225 .19739 L .40252 .20693 L .806 0 0 r
F
.4225 .19739 m .39 .20149 L .40252 .20693 L .771 0 0 r
F
.4225 .19739 m .4308 .18202 L .39 .20149 L F
.50264 .31664 m .4225 .19739 L .48409 .3243 L .867 0 0 r
F
0 g
.4225 .19739 m
.44119 .19017 L
s
.40252 .20693 m .39 .20149 L .35328 .22253 L .771 0 0 r
F
.48409 .3243 m .40252 .20693 L .46405 .3339 L .806 0 0 r
F
0 g
.38444 .21725 m
.40252 .20693 L
s
.40252 .20693 m
.4225 .19739 L
s
.50264 .31664 m .46875 .16744 L .53136 .296 L .568 0 0 r
F
.50264 .31664 m .53136 .296 L .46875 .16744 L F
.50264 .31664 m .49369 .3115 L .53136 .296 L .705 0 0 r
F
0 g
.44119 .19017 m
.49907 .30929 L
s
.50264 .31664 m .48409 .3243 L .49369 .3115 L .705 0 0 r
F
0 g
.50264 .31664 m
.51675 .31212 L
s
.28979 .72629 m .32776 .70567 L .36118 .73189 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.30853 .71611 m
.30853 .71611 L
s
.30853 .71611 m
.3153 .70509 L
s
.55955 .2871 m .46875 .16744 L .49757 .16008 L .945 0 0 r
F
0 g
.49757 .16008 m
.5129 .1609 L
s
.7154 .72055 m .76093 .6998 L .77251 .69249 L .1 0 0 r
F
.69749 .5698 m .77251 .69249 L .76093 .6998 L 1 0 0 r
F
.63942 .59811 m .7154 .72055 L .65283 .5919 L .941 0 0 r
F
.63942 .59811 m .65283 .5919 L .69749 .5698 L .452 0 0 r
F
0 g
.65283 .5919 m
.65939 .58908 L
s
0 0 0 r
.42702 .56411 m
.42702 .56411 L
s
.42702 .56411 m
.42702 .56411 L
s
.45308 .6009 m
.45939 .5903 L
s
.20529 .49876 m
.20529 .49876 L
s
.20529 .49876 m
.20689 .45874 L
s
.20689 .45874 m
.20689 .45874 L
s
.40072 .66583 m
.40072 .66583 L
s
.41968 .6809 m
.4332 .69166 L
s
.48409 .3243 m .45277 .33109 L .49369 .3115 L .705 0 0 r
F
.48409 .3243 m .46405 .3339 L .45277 .33109 L F
0 g
.48409 .3243 m
.50264 .31664 L
s
.46405 .3339 m
.48409 .3243 L
s
.44573 .3439 m
.46405 .3339 L
s
.32674 .24159 m
.3604 .31144 L
s
.3604 .31144 m
.36402 .31895 L
s
.2417 .67255 m .31734 .62719 L .36322 .66354 L p .592 0 0 r
F P
0 g
s
.2417 .67255 m
.28562 .70686 L
s
.23025 .68857 m
.2417 .67255 L
s
.2417 .67255 m
.27903 .61408 L
s
.55955 .2871 m .53136 .296 L .46875 .16744 L .945 0 0 r
F
0 g
.55955 .2871 m
.57401 .28602 L
s
.63942 .59811 m .70231 .72754 L .7154 .72055 L .941 0 0 r
F
.70231 .72754 m .76093 .6998 L .7154 .72055 L .1 0 0 r
F
0 g
.7154 .72055 m
.72152 .71675 L
s
0 0 0 r
.42059 .57468 m
.42702 .56411 L
s
.42702 .56411 m
.42702 .56411 L
s
.26272 .37588 m .41848 .40915 L .41803 .44904 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.41826 .42904 m
.41826 .42904 L
s
.41826 .42904 m
.41826 .42904 L
s
.38585 .654 m
.40072 .66583 L
s
.40602 .39322 m .27813 .3117 L .27647 .36522 L .899 0 0 r
F
.40602 .39322 m .28605 .36161 L .41629 .3899 L .525 0 0 r
F
0 g
.40609 .38768 m
.40642 .36231 L
s
.40602 .39322 m .27647 .36522 L .28605 .36161 L .525 0 0 r
F
0 g
.38821 .36915 m
.40642 .36231 L
s
.37061 .33262 m
.38821 .36915 L
s
.39909 .39173 m
.40602 .39322 L
s
.34942 .32783 m
.37061 .33262 L
s
0 0 0 r
.34159 .74196 m
.34159 .74196 L
s
.34159 .74196 m
.34159 .74196 L
s
.34159 .74196 m
.37441 .76763 L
s
.37441 .76763 m
.37441 .76763 L
s
.63942 .59811 m .69749 .5698 L .67074 .58216 L .452 0 0 r
F
.70231 .72754 m .73484 .71378 L .76093 .6998 L .1 0 0 r
F
.63942 .59811 m .73484 .71378 L .70231 .72754 L .568 0 0 r
F
.63942 .59811 m .67074 .58216 L .73484 .71378 L F
.63942 .59811 m .73484 .71378 L .67074 .58216 L F
.63942 .59811 m .70231 .72754 L .73484 .71378 L F
.62118 .60677 m .70231 .72754 L .63942 .59811 L .867 0 0 r
F
.62118 .60677 m .63942 .59811 L .67074 .58216 L .452 0 0 r
F
0 g
.5192 .62569 m
.54229 .6444 L
s
0 0 0 r
.41826 .42904 m
.41826 .42904 L
s
.22458 .44511 m .22609 .4051 L .26272 .37588 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.19046 .45239 m
.22534 .42505 L
s
.22534 .42505 m
.22534 .42505 L
s
.22534 .42505 m
.22534 .42505 L
s
.22534 .42505 m
.22534 .42505 L
s
.2346 .42693 m
.24536 .42912 L
s
.22534 .42505 m
.22534 .42505 L
s
.30853 .71611 m
.30853 .71611 L
s
.30853 .71611 m
.34159 .74196 L
s
.34159 .74196 m
.34159 .74196 L
s
.26003 .45816 m .26138 .41678 L .41803 .44904 L p 0 .351 .734 r
F P
0 g
s
.41803 .44904 m .26138 .41678 L .26272 .37588 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.34087 .43315 m
.34087 .43315 L
s
.34087 .43315 m
.34087 .43315 L
s
.62118 .60677 m .68421 .73667 L .70231 .72754 L .867 0 0 r
F
.62118 .60677 m .67074 .58216 L .63371 .59974 L .452 0 0 r
F
.601 .61651 m .68421 .73667 L .62118 .60677 L .806 0 0 r
F
.601 .61651 m .62118 .60677 L .63371 .59974 L .452 0 0 r
F
0 g
.62118 .60677 m
.63942 .59811 L
s
.48033 .57836 m .51281 .60473 L .43581 .73774 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.4966 .59157 m
.4966 .59157 L
s
.4966 .59157 m
.4966 .59157 L
s
.601 .61651 m .66398 .74647 L .68421 .73667 L .806 0 0 r
F
.601 .61651 m .63371 .59974 L .59251 .61963 L .452 0 0 r
F
0 g
.59292 .62048 m
.601 .61651 L
s
.601 .61651 m
.62118 .60677 L
s
.68421 .73667 m .73484 .71378 L .70231 .72754 L .1 0 0 r
F
0 g
.63942 .59811 m
.70231 .72754 L
s
0 0 0 r
.22534 .42505 m
.22534 .42505 L
s
0 g
.514 .63014 m
.5174 .62424 L
s
0 0 0 r
.49595 .59268 m
.4966 .59157 L
s
.4966 .59157 m
.4966 .59157 L
s
.67074 .58216 m .69749 .5698 L .76093 .6998 L .945 0 0 r
F
0 g
.69749 .5698 m
.70999 .56446 L
s
.53136 .296 m .4308 .18202 L .46875 .16744 L .868 0 0 r
F
0 g
.46875 .16744 m
.49757 .16008 L
s
.41629 .3899 m .29405 .36683 L .42502 .3952 L .613 0 0 r
F
0 0 0 r
.34175 .39276 m
.34175 .39276 L
s
.34175 .39276 m
.34175 .39276 L
s
0 g
.40602 .39322 m
.40998 .39194 L
s
.41629 .3899 m .28605 .36161 L .29405 .36683 L .613 0 0 r
F
0 g
.38821 .36915 m
.41555 .35145 L
s
.35404 .38199 m
.39909 .39173 L
s
.41629 .3899 m .42502 .3952 L .44499 .34325 L .421 0 0 r
F
0 g
.41629 .3899 m
.42328 .39414 L
s
0 0 0 r
.41781 .46916 m
.41781 .46916 L
s
.45277 .33109 m .35328 .22253 L .39 .20149 L .739 0 0 r
F
0 g
.32674 .24159 m
.35328 .22253 L
s
.36775 .68394 m .44761 .55179 L .48033 .57836 L p 0 .351 .734 r
F P
0 g
s
0 0 0 r
.464 .5651 m
.464 .5651 L
s
.464 .5651 m
.464 .5651 L
s
.48033 .57836 m .40191 .71094 L .36775 .68394 L p 0 .351 .734 r
F P
0 g
s
.43581 .73774 m .40191 .71094 L .48033 .57836 L p 0 .351 .734 r
F P
0 g
s
.26003 .45816 m .22306 .48558 L .22458 .44511 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.25467 .47465 m
.26923 .47749 L
s
.2413 .47205 m
.2413 .47205 L
s
.2413 .47205 m
.25467 .47465 L
s
.22382 .46529 m
.22382 .46529 L
s
.22382 .46529 m
.22382 .46529 L
s
.22382 .46529 m
.22382 .46529 L
s
.22382 .46529 m
.22382 .46529 L
s
.1888 .49177 m
.22382 .46529 L
s
.22458 .44511 m .26138 .41678 L .26003 .45816 L p 0 .13 .643 r
F P
0 g
s
.26272 .37588 m .26138 .41678 L .22458 .44511 L p 0 .13 .643 r
F P
0 g
s
0 0 0 r
.24274 .43113 m
.24274 .43113 L
s
.24274 .43113 m
.24274 .43113 L
s
.22534 .42505 m
.26205 .39627 L
s
.2607 .43741 m
.2607 .43741 L
s
.26205 .39627 m
.26205 .39627 L
s
.26205 .39627 m
.26205 .39627 L
s
.24417 .39067 m
.24417 .39067 L
s
.24417 .39067 m
.24417 .39067 L
s
.68421 .73667 m .69811 .73232 L .73484 .71378 L .1 0 0 r
F
.66398 .74647 m .69811 .73232 L .68421 .73667 L F
0 g
.68421 .73667 m
.70231 .72754 L
s
.52505 .65306 m
.54297 .69025 L
s
.5534 .71189 m
.58797 .78362 L
s
.54622 .69699 m
.5534 .71189 L
s
.66398 .74647 m .65679 .75235 L .69811 .73232 L .1 0 0 r
F
0 g
.65579 .75029 m
.66398 .74647 L
s
.66398 .74647 m
.68421 .73667 L
s
0 0 0 r
.45761 .57579 m
.464 .5651 L
s
.464 .5651 m
.464 .5651 L
s
.67074 .58216 m .76093 .6998 L .73484 .71378 L .945 0 0 r
F
0 g
.76093 .6998 m
.77251 .69249 L
s
.53136 .296 m .49369 .3115 L .4308 .18202 L .868 0 0 r
F
0 g
.53136 .296 m
.55955 .2871 L
s
.50264 .31664 m
.53136 .296 L
s
.46875 .16744 m
.53136 .296 L
s
0 0 0 r
.2607 .43741 m
.2607 .43741 L
s
.22382 .46529 m
.2607 .43741 L
s
.22382 .46529 m
.22382 .46529 L
s
0 g
.43782 .33927 m
.43782 .33927 L
s
.58797 .78362 m
.61792 .77045 L
s
.43581 .73774 m .39435 .75792 L .36118 .73189 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.41481 .74796 m
.41481 .74796 L
s
.41481 .74796 m
.41481 .74796 L
s
.33877 .76446 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
.52521 .61565 m .46121 .72714 L .45363 .73518 L .1 0 0 r
F
.52526 .60287 m .46121 .72714 L .52521 .61565 L 1 0 0 r
F
0 g
.52505 .65306 m
.55416 .63845 L
s
.49369 .3115 m .39 .20149 L .4308 .18202 L .806 0 0 r
F
0 g
.4308 .18202 m
.46875 .16744 L
s
0 0 0 r
.34087 .43315 m
.34087 .43315 L
s
.34087 .43315 m
.34087 .43315 L
s
.34175 .39276 m
.34175 .39276 L
s
.49369 .3115 m .45277 .33109 L .39 .20149 L .806 0 0 r
F
0 g
.35328 .22253 m
.39 .20149 L
s
.49369 .3115 m
.53136 .296 L
s
.39 .20149 m
.4308 .18202 L
s
.43782 .33927 m
.45277 .33109 L
s
.42502 .3952 m .29919 .38026 L .43084 .40846 L .882 0 0 r
F
.42502 .3952 m .29405 .36683 L .29919 .38026 L F
0 0 0 r
.34087 .43315 m
.34175 .39276 L
s
.42502 .3952 m .45702 .36949 L .44499 .34325 L .421 0 0 r
F
0 g
.41555 .35145 m
.43479 .34093 L
s
.42502 .3952 m .43084 .40846 L .45702 .36949 L .421 0 0 r
F
0 g
.42328 .39414 m
.42502 .3952 L
s
.41514 .48949 m .27309 .47469 L .40463 .50042 L .782 0 0 r
F
0 g
.40463 .50069 m
.40463 .50042 L
s
0 0 0 r
.37779 .74493 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
.37779 .74493 m
.37779 .74493 L
s
0 g
.57711 .62719 m
.57711 .62719 L
s
0 0 0 r
.24274 .43113 m
.24274 .43113 L
s
.24274 .43113 m
.24274 .43113 L
s
.24274 .43113 m
.24417 .39067 L
s
.24417 .39067 m
.24417 .39067 L
s
.43017 .55355 m .37721 .66046 L .44418 .54987 L .453 0 0 r
F
.43017 .55355 m .36322 .66354 L .37721 .66046 L F
0 0 0 r
.35433 .6837 m
.3671 .66269 L
s
0 g
.42842 .55214 m
.43017 .55355 L
s
.42661 .55941 m
.43017 .55355 L
s
.36775 .68394 m .40191 .71094 L .36118 .73189 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.38486 .69746 m
.38486 .69746 L
s
.36118 .73189 m .32776 .70567 L .36775 .68394 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.34749 .69495 m
.34749 .69495 L
s
.34749 .69495 m
.35433 .6837 L
s
.3445 .7188 m
.3445 .7188 L
s
.3445 .7188 m
.3445 .7188 L
s
.3445 .7188 m
.3445 .7188 L
s
.3445 .7188 m
.3445 .7188 L
s
.30618 .73906 m
.3445 .7188 L
s
.36118 .73189 m .40191 .71094 L .43581 .73774 L p 0 .354 .996 r
F P
0 g
s
0 0 0 r
.38127 .72155 m
.38127 .72155 L
s
.38127 .72155 m
.38127 .72155 L
s
.38127 .72155 m
.38127 .72155 L
s
.37779 .74493 m
.41889 .72436 L
s
.41889 .72436 m
.41889 .72436 L
s
.41889 .72436 m
.41889 .72436 L
s
.41889 .72436 m
.43617 .69483 L
s
.27647 .36522 m .27813 .3117 L .29731 .3037 L .37 0 0 r
F
0 g
.29343 .31516 m
.34942 .32783 L
s
.45277 .33109 m
.49369 .3115 L
s
0 0 0 r
.38486 .69747 m
.38486 .69746 L
s
.3445 .7188 m
.38486 .69747 L
s
.3445 .7188 m
.3445 .7188 L
s
.63371 .59974 m .67074 .58216 L .73484 .71378 L .868 0 0 r
F
0 g
.67074 .58216 m
.69749 .5698 L
s
0 0 0 r
.34087 .43315 m
.34087 .43315 L
s
0 g
.55416 .63845 m
.57143 .62997 L
s
.52526 .60287 m .46082 .71475 L .46121 .72714 L 1 0 0 r
F
.51739 .5878 m .46082 .71475 L .52526 .60287 L F
0 0 0 r
.47496 .6701 m
.47496 .6701 L
s
.47496 .6701 m
.47496 .6701 L
s
.51739 .5878 m .52526 .60287 L .57743 .61693 L .617 0 0 r
F
0 g
.52521 .61565 m
.52526 .60287 L
s
.43084 .40846 m .30059 .39991 L .43276 .42775 L .903 0 0 r
F
.43084 .40846 m .29919 .38026 L .30059 .39991 L F
.43084 .40846 m .46116 .40841 L .45702 .36949 L .421 0 0 r
F
.43084 .40846 m .43276 .42775 L .46116 .40841 L F
0 g
.42502 .3952 m
.43084 .40846 L
s
.41514 .48949 m .28304 .46333 L .27309 .47469 L .782 0 0 r
F
.42423 .47178 m .28304 .46333 L .41514 .48949 L .853 0 0 r
F
0 g
.40463 .50042 m
.41514 .48949 L
s
0 0 0 r
.34014 .46675 m
.34087 .43315 L
s
0 g
.41514 .48949 m
.42243 .4753 L
s
.44499 .34325 m .32424 .33989 L .31358 .31336 L .882 0 0 r
F
.44499 .34325 m .45702 .36949 L .32424 .33989 L F
0 g
.43782 .33927 m
.44499 .34325 L
s
0 0 0 r
.2413 .47205 m
.2413 .47204 L
s
.2413 .47204 m
.24274 .43113 L
s
.24274 .43113 m
.24274 .43113 L
s
.47496 .6701 m
.47496 .6701 L
s
0 g
.34489 .54429 m
.36673 .54833 L
s
.44418 .54987 m .39623 .66338 L .46296 .5522 L .687 0 0 r
F
.44418 .54987 m .37721 .66046 L .39623 .66338 L F
0 0 0 r
.44179 .64351 m
.44179 .64351 L
s
.44179 .64351 m
.44179 .64351 L
s
.44179 .64351 m
.44179 .64351 L
s
.44179 .64351 m
.44179 .64351 L
s
.44418 .54987 m .46296 .5522 L .45157 .51415 L .617 0 0 r
F
0 g
.44418 .54987 m
.45923 .55174 L
s
.43017 .55355 m
.44418 .54987 L
s
.63371 .59974 m .73484 .71378 L .69811 .73232 L .868 0 0 r
F
0 g
.73484 .71378 m
.76093 .6998 L
s
.67074 .58216 m
.73484 .71378 L
s
.27647 .36522 m .29731 .3037 L .28605 .36161 L .37 0 0 r
F
0 g
.27647 .36522 m
.29496 .36922 L
s
.27647 .36522 m
.27813 .3117 L
s
.43276 .42775 m .32733 .37957 L .46116 .40841 L .7 0 0 r
F
.43276 .42775 m .30059 .39991 L .32733 .37957 L F
.43276 .42775 m .29801 .42273 L .43044 .45004 L .897 0 0 r
F
.43276 .42775 m .30059 .39991 L .29801 .42273 L F
0 0 0 r
.26205 .39627 m
.3001 .40425 L
s
.43276 .42775 m .45652 .4538 L .46116 .40841 L .421 0 0 r
F
.43276 .42775 m .43044 .45004 L .45652 .4538 L F
.43276 .42775 m .32733 .37957 L .30059 .39991 L .7 0 0 r
F
.43276 .42775 m .46116 .40841 L .32733 .37957 L F
.42423 .47178 m .29182 .44506 L .28304 .46333 L .853 0 0 r
F
.43044 .45004 m .29182 .44506 L .42423 .47178 L .882 0 0 r
F
.43044 .45004 m .42423 .47178 L .44381 .49804 L .421 0 0 r
F
0 g
.42243 .4753 m
.42423 .47178 L
s
.51739 .5878 m .45237 .69986 L .46082 .71475 L 1 0 0 r
F
.51739 .5878 m .57743 .61693 L .56204 .58651 L .617 0 0 r
F
.50274 .5728 m .45237 .69986 L .51739 .5878 L .935 0 0 r
F
0 0 0 r
.44179 .64351 m
.46677 .66353 L
s
.50274 .5728 m .51739 .5878 L .56204 .58651 L .617 0 0 r
F
0 g
.51739 .5878 m
.52526 .60287 L
s
.59251 .61963 m .63371 .59974 L .69811 .73232 L .806 0 0 r
F
0 g
.63371 .59974 m
.67074 .58216 L
s
0 0 0 r
.44179 .64351 m
.44179 .64351 L
s
.59251 .61963 m .69811 .73232 L .65679 .75235 L .806 0 0 r
F
0 g
.57711 .62719 m
.59251 .61963 L
s
.69811 .73232 m
.73484 .71378 L
s
.59251 .61963 m
.63371 .59974 L
s
.61792 .77045 m
.65679 .75235 L
s
0 0 0 r
.38127 .72155 m
.38127 .72155 L
s
.38127 .72155 m
.38127 .72155 L
s
.38127 .72155 m
.41481 .74796 L
s
.41481 .74796 m
.41481 .74796 L
s
.43044 .45004 m .29801 .42273 L .29182 .44506 L .882 0 0 r
F
0 0 0 r
.2607 .43741 m
.29218 .44377 L
s
.43044 .45004 m .44381 .49804 L .45652 .4538 L .421 0 0 r
F
0 g
.43044 .45004 m
.43276 .42775 L
s
.42423 .47178 m
.43044 .45004 L
s
.46296 .5522 m .4173 .67194 L .48357 .56026 L .795 0 0 r
F
0 0 0 r
.43662 .63937 m
.44179 .64351 L
s
.46296 .5522 m .39623 .66338 L .4173 .67194 L .795 0 0 r
F
0 g
.40337 .59758 m
.42661 .55941 L
s
0 0 0 r
.40246 .66803 m
.40348 .66633 L
s
.38486 .69746 m
.40246 .66803 L
s
.46296 .5522 m .4935 .53041 L .45157 .51415 L .617 0 0 r
F
.46296 .5522 m .48357 .56026 L .4935 .53041 L F
0 g
.45923 .55174 m
.46296 .5522 L
s
.50274 .5728 m .43707 .68478 L .45237 .69986 L .935 0 0 r
F
0 0 0 r
.43617 .69483 m
.44023 .6879 L
s
.50274 .5728 m .56204 .58651 L .5325 .55596 L .617 0 0 r
F
.50274 .5728 m .46652 .66948 L .43707 .68478 L .218 0 0 r
F
.50274 .5728 m .5325 .55596 L .46652 .66948 L F
0 g
.51526 .58562 m
.51739 .5878 L
s
.50274 .5728 m .46652 .66948 L .5325 .55596 L .218 0 0 r
F
.50274 .5728 m .43707 .68478 L .46652 .66948 L F
.48357 .56026 m .43707 .68478 L .50274 .5728 L .868 0 0 r
F
.48357 .56026 m .50274 .5728 L .5325 .55596 L .617 0 0 r
F
.57743 .61693 m .514 .75487 L .51394 .73024 L 1 0 0 r
F
.56204 .58651 m .57743 .61693 L .51394 .73024 L F
0 g
.57711 .62719 m
.57743 .61693 L
s
.48357 .56026 m .4173 .67194 L .43707 .68478 L .868 0 0 r
F
.48357 .56026 m .5325 .55596 L .4935 .53041 L .617 0 0 r
F
0 g
.46296 .5522 m
.48357 .56026 L
s
.48357 .56026 m
.50274 .5728 L
s
.65679 .75235 m
.69811 .73232 L
s
0 0 0 r
.34749 .69495 m
.34749 .69495 L
s
.34749 .69495 m
.38127 .72155 L
s
.38127 .72155 m
.38127 .72155 L
s
.46121 .72714 m .49817 .77047 L .45363 .73518 L .592 0 0 r
F
0 g
.45363 .73518 m
.46106 .72226 L
s
.46121 .72714 m .514 .75487 L .49817 .77047 L .592 0 0 r
F
0 g
.5085 .75198 m
.51397 .74218 L
s
.45363 .73518 m
.49817 .77047 L
s
.28605 .36161 m .29731 .3037 L .31358 .31336 L .37 0 0 r
F
0 g
.27813 .3117 m
.29731 .3037 L
s
.28605 .36161 m .31358 .31336 L .29405 .36683 L .37 0 0 r
F
0 g
.27647 .36522 m
.28605 .36161 L
s
.45702 .36949 m .32733 .37957 L .32424 .33989 L .905 0 0 r
F
.45702 .36949 m .46116 .40841 L .32733 .37957 L F
0 g
.44499 .34325 m
.45702 .36949 L
s
.43633 .5124 m
.43633 .5124 L
s
.29405 .36683 m .32424 .33989 L .29919 .38026 L .37 0 0 r
F
.29405 .36683 m .31358 .31336 L .32424 .33989 L F
0 g
.28605 .36161 m
.29405 .36683 L
s
.29731 .3037 m
.31358 .31336 L
s
.28304 .46333 m .27136 .53068 L .27309 .47469 L .37 0 0 r
F
0 g
.28081 .4762 m
.40463 .50042 L
s
.56204 .58651 m .51394 .73024 L .49738 .70019 L 1 0 0 r
F
.5325 .55596 m .56204 .58651 L .49738 .70019 L .938 0 0 r
F
0 g
.56204 .58651 m
.57743 .61693 L
s
.46116 .40841 m .32214 .42604 L .32733 .37957 L .899 0 0 r
F
0 g
.38613 .41793 m
.43276 .42775 L
s
.46116 .40841 m .45652 .4538 L .32214 .42604 L .899 0 0 r
F
0 g
.45702 .36949 m
.46116 .40841 L
s
.46082 .71475 m .514 .75487 L .46121 .72714 L .592 0 0 r
F
0 g
.45363 .73518 m
.46121 .72714 L
s
.44381 .49804 m .29153 .50834 L .30948 .47151 L .854 0 0 r
F
.45652 .4538 m .44381 .49804 L .30948 .47151 L .883 0 0 r
F
0 g
.43633 .5124 m
.44381 .49804 L
s
.45157 .51415 m .42627 .64329 L .38339 .62603 L .794 0 0 r
F
.45157 .51415 m .4935 .53041 L .42627 .64329 L F
0 g
.43633 .5124 m
.45157 .51415 L
s
.46082 .71475 m .51394 .73024 L .514 .75487 L .592 0 0 r
F
0 g
.49817 .77047 m
.514 .75487 L
s
.36322 .66354 m .34505 .62047 L .37721 .66046 L .592 0 0 r
F
0 g
.37032 .65188 m
.38553 .62689 L
s
.36322 .66354 m .31734 .62719 L .34505 .62047 L .592 0 0 r
F
0 g
.31734 .62719 m
.36673 .54833 L
s
.31734 .62719 m
.36322 .66354 L
s
.45652 .4538 m .30948 .47151 L .32214 .42604 L .883 0 0 r
F
0 g
.45652 .4538 m
.46116 .40841 L
s
.44381 .49804 m
.45652 .4538 L
s
.29919 .38026 m .32733 .37957 L .30059 .39991 L .37 0 0 r
F
.29919 .38026 m .32424 .33989 L .32733 .37957 L F
0 g
.29405 .36683 m
.29919 .38026 L
s
.28304 .46333 m .29153 .50834 L .27136 .53068 L .37 0 0 r
F
0 g
.27136 .53068 m
.34489 .54429 L
s
.27136 .53068 m
.27309 .47469 L
s
.29182 .44506 m .29153 .50834 L .28304 .46333 L .37 0 0 r
F
0 g
.27309 .47469 m
.28304 .46333 L
s
.5325 .55596 m .49738 .70019 L .46652 .66948 L .938 0 0 r
F
.4935 .53041 m .5325 .55596 L .46652 .66948 L .869 0 0 r
F
0 g
.5325 .55596 m
.56204 .58651 L
s
.31358 .31336 m
.32424 .33989 L
s
.4935 .53041 m .46652 .66948 L .42627 .64329 L .869 0 0 r
F
0 g
.45157 .51415 m
.4935 .53041 L
s
.4935 .53041 m
.5325 .55596 L
s
.45237 .69986 m .51394 .73024 L .46082 .71475 L .592 0 0 r
F
0 g
.46082 .71475 m
.46121 .72714 L
s
.30059 .39991 m .32214 .42604 L .29801 .42273 L .37 0 0 r
F
.30059 .39991 m .32733 .37957 L .32214 .42604 L F
0 g
.29919 .38026 m
.30059 .39991 L
s
.30059 .39991 m
.32733 .37957 L
s
.32733 .37957 m
.46116 .40841 L
s
.29182 .44506 m .30948 .47151 L .29153 .50834 L .37 0 0 r
F
0 g
.27136 .53068 m
.29153 .50834 L
s
.29801 .42273 m .30948 .47151 L .29182 .44506 L .37 0 0 r
F
0 g
.28304 .46333 m
.29182 .44506 L
s
.29801 .42273 m .32214 .42604 L .30948 .47151 L .37 0 0 r
F
0 g
.29801 .42273 m
.30059 .39991 L
s
.29182 .44506 m
.29801 .42273 L
s
.37721 .66046 m .38339 .62603 L .39623 .66338 L .592 0 0 r
F
.37721 .66046 m .34505 .62047 L .38339 .62603 L F
0 g
.36322 .66354 m
.37721 .66046 L
s
.31734 .62719 m
.34505 .62047 L
s
.45237 .69986 m .49738 .70019 L .51394 .73024 L .592 0 0 r
F
0 g
.51394 .73024 m
.514 .75487 L
s
.43707 .68478 m .49738 .70019 L .45237 .69986 L .592 0 0 r
F
0 g
.45237 .69986 m
.46082 .71475 L
s
.39623 .66338 m .42627 .64329 L .4173 .67194 L .592 0 0 r
F
.39623 .66338 m .38339 .62603 L .42627 .64329 L F
0 g
.37721 .66046 m
.39623 .66338 L
s
.43707 .68478 m .46652 .66948 L .49738 .70019 L .592 0 0 r
F
.4173 .67194 m .46652 .66948 L .43707 .68478 L F
0 g
.43707 .68478 m
.45237 .69986 L
s
.44542 .67054 m
.4517 .65984 L
s
.43707 .68478 m
.44228 .68208 L
s
.49738 .70019 m
.51394 .73024 L
s
.4173 .67194 m .42627 .64329 L .46652 .66948 L .592 0 0 r
F
0 g
.39623 .66338 m
.4173 .67194 L
s
.44228 .68208 m
.46652 .66948 L
s
.46652 .66948 m
.5325 .55596 L
s
.4173 .67194 m
.43707 .68478 L
s
.32424 .33989 m
.32733 .37957 L
s
.29153 .50834 m
.30948 .47151 L
s
.34505 .62047 m
.38339 .62603 L
s
.32214 .42604 m
.32733 .37957 L
s
.30948 .47151 m
.32214 .42604 L
s
.46652 .66948 m
.49738 .70019 L
s
.38339 .62603 m
.42627 .64329 L
s
.42627 .64329 m
.46652 .66948 L
s
[ .01 .01 ] 0 setdash
.31166 .05317 m
.86175 .2052 L
s
.86175 .2052 m
.89252 .80683 L
s
.89252 .80683 m
.29362 .71644 L
s
.29362 .71644 m
.31166 .05317 L
s
.14246 .22051 m
.11243 .81583 L
s
.11243 .81583 m
.29362 .71644 L
s
.29362 .71644 m
.31166 .05317 L
s
.31166 .05317 m
.14246 .22051 L
s
.003 w
[ ] 0 setdash
.86175 .2052 m
.89252 .80683 L
s
.25 Mabswid
.86377 .24465 m
.85773 .24303 L
s
gsave
.87584 .24788 -61 -9.12251 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.87003 .36705 m
.86396 .36558 L
s
gsave
.88218 .37 -61 -9.30043 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.87651 .49375 m
.8704 .49243 L
s
gsave
.88873 .49639 -61 -9.48507 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.88322 .62496 m
.87708 .6238 L
s
gsave
.8955 .62728 -61 -9.67683 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.89017 .76093 m
.884 .75994 L
s
gsave
.90251 .76291 -61 -9.87613 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.865 .2688 m
.86138 .26784 L
s
.86625 .29311 m
.86262 .29217 L
s
.8675 .31759 m
.86386 .31667 L
s
.86876 .34224 m
.86512 .34133 L
s
.87131 .39204 m
.86766 .39118 L
s
.87259 .4172 m
.86894 .41636 L
s
.87389 .44254 m
.87023 .44171 L
s
.87519 .46805 m
.87153 .46724 L
s
.87783 .51962 m
.87416 .51885 L
s
.87916 .54568 m
.87549 .54492 L
s
.88051 .57192 m
.87683 .57118 L
s
.88186 .59834 m
.87818 .59763 L
s
.88459 .65176 m
.8809 .65109 L
s
.88597 .67876 m
.88228 .6781 L
s
.88736 .70595 m
.88366 .70532 L
s
.88876 .73334 m
.88506 .73273 L
s
.86254 .22066 m
.85893 .21967 L
s
.89159 .78872 m
.88789 .78814 L
s
gsave
.94981 .50961 -61 -9.48507 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00I@3oool3000000030?ooo`2HV9P000000080000000<0V9RH0?ooo`3oool0/03oool006H0
oooo00P000000?ooo`3oool0000009RHV03oool0V9RH00000;80oooo001V0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0>03oool3000007D0oooo001L0?ooo`L000000`3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo03P0oooo00<0k^k^0000003^k^h0M@3o
ool006H0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo07@0oooo001V0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0>03o
ool00`3^k^h000000>k^kP1e0?ooo`00IP3oool020000000oooo0?ooo`000000V9RH0?ooo`2HV9P0
0000>P3oool304A4A7D0oooo001U0?ooo`05024Q8@000000oooo0?ooo`2HV9P00`0000000`2HV9P0
oooo0?ooo`0g0?ooo`0508N7Q`14A4@0oooo038b<P2YZJT0M03oool00:H0oooo00L0c<c<0000003^
k^h0oooo0<c<c0000000c<c<07<0oooo002V0?ooo`80000000<0<S8b0?ooo`0000000P00001c0?oo
o`00F@3oool300000<@0oooo001H0?ooo`8000000P3oool5000002T0oooo00D0410@000000000000
000009RHV02A0?ooo`00E`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<00000
:P3oool00`2HV9P000000?ooo`2@0?ooo`00H`3oool4000002L0oooo00<000000?ooo`3oool0S`3o
ool005D0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0000000@000005`3o
ool7000000@0oooo00<000000?ooo`3oool0S`3oool005@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0`00000O0?ooo`0309RHV0000000
oooo0900oooo001C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo00000003000001P0oooo100000000`2HV9P0oooo0?ooo`2?0?ooo`00F@3oool00`000000
oooo0?ooo`0F0?ooo`D000004`3oool00`1gMgL0EEEE0?ooo`2C0?ooo`00D@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool00000008000004P3oool0100@410000000000000b<S:A0?ooo`00
D03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo1000002S0?ooo`00C`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`0000000`00
000X0?ooo`0509RHV000000000000000002HV9P0LP3oool005T0oooo00<000000?ooo`3oool0903o
ool4000002D0oooo00D0000009RHV03oool0V9RH0000001b0?ooo`00C@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02H0oooo00<000000?ooo`0000000`00000Q0?ooo`050000003o
ool0oooo0?ooo`000000LP3oool004`0oooo00<000000?ooo`3oool0>@3oool4000001d0oooo00D0
00000?ooo`3oool0oooo0000001b0?ooo`00B`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0000000<000006P3oool01@000000oooo0?ooo`3oool000000780oooo001I0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool00`3oool4000001H0oooo00D000000?ooo`3oool0oooo
0000001b0?ooo`00B@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool01000000B0?ooo`050000002HV9P0oooo09RHV0000000LP3oool004P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0k0?ooo`@000003`3oool01@2HV9P000000000
00000000V9RH0780oooo00170?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0400000880oooo002N0?ooo`@00000:03oool01@0@4100000000000000
0000V9RH0540oooo00140?ooo`800000F03oool00`000000oooo0?ooo`04000002P0oooo00<0V9RH
0000003oool0D03oool004<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1:0?oo
o`@000009@3oool00`000000oooo0?ooo`1?0?ooo`00@P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04X0oooo00@000000?ooo`3oool0oooo1000000Q0?ooo`030000003oool0oooo
04l0oooo001H0?ooo`030000003oool0oooo0540oooo1000000M0?ooo`0309RHV0000000oooo0500
oooo00100?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`05000001H0oooo100000000`2HV9P0oooo0?ooo`1?0?ooo`00?`3oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo00@0oooo1@00000B0?ooo`0307MgM`1EEED0oooo05<0oooo000n
0?ooo`030000003oool0oooo0780oooo00@000000?ooo`3oool0oooo1000000@0?ooo`04010@4000
00000000038b<U40oooo001H0?ooo`030000003oool0oooo05l0oooo1@00001Q0?ooo`00?03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool00P3oool4
000002H0oooo0`0000000`3oool0V9RH000000020000000309RHV03oool0oooo02`0oooo000k0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0I@3oool00`000000oooo000000030000
02@0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000002h0oooo000j0?ooo`030000003o
ool0oooo0500oooo1@00000c0?ooo`D00000803oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo02`0oooo002:0?ooo`<0000000<0l@000?l0003o00000P3o0002000003<0oooo00<0
00000?ooo`3oool01000000L0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
;03oool003P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0/0?ooo`<000001@3a
00040?l003X0oooo1000000I0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
;03oool003L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0Z0?ooo`800000203a
00050?l003T0oooo00<000000?ooo`3oool01@00000E0?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0;03oool003H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0W0?ooo`<0000000<0gP000000003a0000203a00040?l003X0oooo00<000000?ooo`3oool00`3o
ool500000140oooo00P000000?ooo`3oool0000009RHV03oool0V9RH000002h0oooo001H0?ooo`03
0000003oool0oooo02@0oooo0`0000050=h000030000003a0000l@0000H0l@001@3o000o0?ooo`04
0000003oool0oooo0?ooo`@000003@3oool01@0Q8B4000000?ooo`3oool0V9RH00<0000000<0V9RH
0?ooo`3oool0;03oool003@0oooo00<000000?ooo`3oool0A@3oool3000000P0gP0000<000000?40
003a00001`3a00040?l004D0oooo1P0000100?ooo`00<`3oool00`000000oooo0?ooo`140?ooo`80
0000303N00000`000000l@000?4000060?4000D0o`00A03oool010000000oooo0?ooo`3oool60000
03`0oooo000b0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0703oool300000003
0<h0003N0000gP0000/0gP0000<000000?40003a00001`3a00040?l004/0oooo00<000000?ooo`00
00000`00000i0?ooo`00F03oool00`000000oooo0?ooo`0J0?ooo`8000001@3>000=0=h000030000
003a0000l@0000H0l@001@3o001?0?ooo`D00000=@3oool00300oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0H0?ooo`8000001`3>000=0=h000030000003a0000l@0000L0l@00103o
000F0?ooo`P00000<P3oool00`000000oooo0000000500000340oooo000_0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool05@3oool3000000X0cP003@3N00000`000000l@000?400006
0?4000@0o`0000<06@000?ooo`3oool04@3oool20000000306h0002^0000[P0000D0[P001P00000b
0?ooo`D00000;P3oool002h0oooo00<000000?ooo`3oool0?@3oool2000000d0cP003@3N00000`00
0000l@000?4000070?4000@0o`004@3oool2000000<0KP002`2^00020</000<00000;`3oool01000
0000oooo0?ooo`3oool5000002X0oooo001/0?ooo`80000000<0_@000<h0003>00003@3>000=0=h0
00030000003a0000l@0000H0l@00103o00000`0I0000oooo0?ooo`0<0?ooo`800000101^000<0:h0
00D0b`000`00000/0?ooo`030000003oool0oooo00<0oooo1@00000X0?ooo`00;03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0100oooo00<000000;d0002m00000P2m000>0<h000d0
gP0000<000000?40003a00001`3a00040?l000`0oooo0P00000606h000/0[P002@3;0003000002l0
oooo00<000000?ooo`3oool00P00000X0?ooo`00:`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00h0oooo0P0000050;d000l0cP003@3N00000`000000l@000?4000060?4000@0o`00
00<06@000?ooo`3oool0203oool00`0000008P000000000506h000/0[P003@3;0002000002h0oooo
0P0000000`3oool000000?ooo`0W0?ooo`00:P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00`0oooo0P0000080;d000h0cP003@3N00000`000000l@000?4000070?4000@0o`002@3o
ool00`0000008P000000000506h000`0[P003@3;00020=h000800000;`3oool00`000000oooo0?oo
o`0V0?ooo`00F03oool00`000000oooo0?ooo`0;0?ooo`030000002m0000_@0000P0_@003`3>000=
0=h000030000003a0000l@0000H0l@00103o00000`0I0000oooo0?ooo`040?ooo`80000000<08P00
0000000000001@1^000;0:h000h0b`00103N00000`000000oooo0?ooo`0V0?ooo`800000103oool0
0`000000oooo0?ooo`0V0?ooo`00:03oool2000003X0oooo0P00000<0;d000h0cP003@3N00000`00
0000l@000?4000070?4000@0o`001@3oool01@0000008P000280000R0000000000D0KP00302^000=
0</000H0gP000P00000T0?ooo`8000001@3oool2000002P0oooo000X0?ooo`040000003oool0oooo
0?ooo`@00000<`3oool00`000000X`000;d0000<0;d000l0cP003@3N00000`000000l@000?400006
0?4000@0o`00103oool01@0000008P000280000R0000000000H0KP002`2^000>0</000P0gP000P00
000Z0?ooo`030000003oool0oooo02H0oooo000X0?ooo`030000003oool0oooo00L0oooo0P00000T
0?ooo`030000003oool0oooo00L0oooo00@000000:<0002S0000X`003@2m000>0<h000d0gP0000<0
00000?40003a00001P3a00050?l000030?ooo`000000000000@08P0000<0000006h0001^00000`1^
000;0:h000h0b`002`3N00000`000000oooo0?ooo`0L0?ooo`8000002@3oool00`000000oooo0?oo
o`0V0?ooo`00:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<000007P3oool0
0`000000oooo0?ooo`050?ooo`800000102S000=0;d000l0cP003@3N00000`000000l@000?400006
0?4000@0o`0000<000000280000R00000`0R00000`000000KP0006h0000306h000`0[P003@3;000=
0=h000030000003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0V
0?ooo`00>P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000:<0
002S00001@2S000=0;d000h0cP003@3N00000`000000l@000?4000060?4000D0o`00100R00020000
00D0KP002`2^000>0</000d0gP0000<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`00?@3oool4000001d0oooo00<000000:<0002S00001P2S000=0;d000l0cP003@3N00000`000000
l@000?4000060?4000@0o`00100R00000`000000KP0006h0000306h000/0[P003P3;000=0=h00003
0000003`0000000001L0oooo0P00000>0?ooo`030000003oool0oooo02H0oooo000X0?ooo`030000
003oool0oooo01L0oooo0`00000G0?ooo`8000002P2S000<0;d000l0cP003@3N00000`000000l@00
0?4000060?4000D0o`000P0R00000`000000KP0006h0000406h000/0[P003P3;000=0=h000040000
003`0000l000000001D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000W0?ooo`00
:03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<00000303oool01`000000oooo
0?ooo`3oool0000008`0000000002P2S000=0;d000l0cP003@3N00000`000000l@000?4000060?40
00@0o`000P0R00000`000000KP0006h0000306h000/0[P003P3;000=0=h000030000003`0000l000
0080l00000<000000?ooo`3oool08`3oool2000002L0oooo000X0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000308`000030000002S0000X`00
00P0X`00302m000?0<h000d0gP0000<000000?40003a00001P3a00050?l000030000001^0000KP00
00<0KP002`2^000>0</000d0gP0000<000000?00003`0000103`00000`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0140oooo0P00000>0?ooo`<0000000<0oooo09RHV00000000P0000000`2H
V9P0oooo0?ooo`0>0?ooo`00CP3oool3000000H0oooo00<000000?ooo`000000102<00000`000000
X`000:<000080:<000d0_@003P3>000>0=h000030000003a0000l@0000H0l@00103o000606h000/0
[P003P3;000=0=h000030000003`0000l00000D0l00000<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00P000000?ooo`3oool0000009RHV03oool0
V9RH00000100oooo001C0?ooo`<0000000<0oooo0000000000001P2<00000`000000X`000:<00008
0:<000`0_@003`3>000=0=h000030000003a0000l@0000H0l@001@3o000406h000/0[P003P3;000=
0=h000030000003`0000l00000L0l00000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0>0?ooo`00:03oool00`000000oooo0?ooo`0[0?ooo`8000001`2<00000`000000X`000:<00008
0:<000d0_@003P3>000>0=h000030000003a0000l@0000H0l@00103o000406h000/0[P003P3;000=
0=h000030000003`0000l00000P0l00000<000000?ooo`3oool01P3oool2000001P0oooo00<00000
0?ooo`3oool00`3oool7000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0>0?ooo`00:03oool00`000000oooo0?ooo`0Z0?ooo`8000002@2<00000`000000X`000:<00008
0:<000`0_@003`3>000=0=h000030000003a0000l@0000H0l@00103o00000`0I0000KP0006h0000;
0:h000h0b`003@3N00000`000000l0000?00000:0?0000030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool03P3oool002P0oooo00<000000?ooo`3oool0:@3oool010000000S00008`00000
000808`000030000002S0000X`0000P0X`003@2m000>0<h000h0gP0000<000000?40003a00001P3a
00040?l0000306h0002^0000[P0000T0[P003P3;000>0=h000030000003`0000l00000X0l00000<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`8000003`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00h0oooo000X0?ooo`030000003oool0oooo02P0oooo00D0
000008`0002<0000S0000000000908`000030000002S0000X`0000P0X`00302m000?0<h000d0gP00
00<000000?40003a00001P3a00040?l0000301T0002^0000[P0000T0[P003P3;000=0=h000030000
003`0000l00000/0l00000<0o`000000003oool00P00000M0?ooo`030000003oool0oooo00d0oooo
00P000000?ooo`3oool0000009RHV03oool0V9RH00000100oooo001B0?ooo`030000002<0000S000
0080S00000<0000008`0002<00001`2<00000`000000X`000:<000080:<000d0_@003P3>000>0=h0
00030000003a0000l@0000H0l@00103o000:0:h000h0b`003@3N00000`000000l0000?00000;0?00
0080o`000P00000O0?ooo`030000003oool0oooo00`0oooo00D08B4Q0000003oool0oooo09RHV003
0000000309RHV03oool0oooo00h0oooo001A0?ooo`030000002<0000S00000<0S00000<0000008`0
002<0000202<00000`000000X`000:<000080:<000`0_@003`3>000=0=h000030000003a0000l@00
00H0l@00103o00000`0I0000[P000:h000060:h000l0b`003@3N00000`000000l0000?00000;0?00
0080o`0000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0U0?ooo`00:03oool00`000000
oooo0?ooo`0U0?ooo`030000002<0000S00000l0S00000<000000:<0002S0000202S000=0;d000h0
cP003P3N00000`000000l@000?4000060?4000@0o`00202^000>0</000d0gP0000<000000?00003`
00002`3`00040?l000030000003oool0oooo01d0oooo00<000000?ooo`3oool09@3oool002P0oooo
00<000000?ooo`3oool08`3oool2000001<0S00000<000000:<0002S00001`2S000=0;d000l0cP00
3@3N00000`000000l@000?4000060?4000@0o`001`2^000>0</000h0gP0000<000000?00003`0000
2P3`00050?l000030000003oool0oooo01d0oooo00<000000?ooo`3oool09@3oool002L0oooo00<0
00000?ooo`3oool08`3oool00`000000S00008`0000708`000030000002<0000S00000T0S00000<0
00000:<0002S0000202S000=0;d000h0cP003P3N00000`000000l@000?4000040?4000T000000`2^
000>0</000d0gP0000<000000?00003`00002`3`00050?l000030000003oool0oooo01d0oooo00<0
00000?ooo`3oool09@3oool002L0oooo00<000000?ooo`3oool08P3oool00`000000S00008`00008
08`000030000002<0000S00000X0S00000<000000:<0002S00001`2S000=0;d000l0cP003@3N0000
0`000000l@000?400004000000H0]0000`2W0004000000`0b`003P3N00000`000000l0000?00000:
0?0000L0o`0000<000000?ooo`3oool06`3oool2000002L0oooo001;0?ooo`030000002<0000S000
00T0S00000<0000008`0002<00002P2<00000`000000X`000:<000080:<000d0_@003P3>000=0=h0
00<000002@2d00080:L000<000002@3;000=0=h000030000003`0000l00000/0l0001`3o00000`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo02D0oooo001:0?ooo`030000002<0000S00000X0
S00000<0000008`0002<00002`2<00000`000000X`000:<000070:<000d0_@003`3>000:0=h00080
00002P2d000=0:L000<000001@3;000=0=h000030000003`0000l00000/0l000203o00000`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo02D0oooo000W0?ooo`030000003oool0oooo01l0oooo
00<0000008`0002<00006@2<00000`000000X`000:<000080:<000d0_@003P3>00070=h000@00000
2P2d000A0:L000<0000000<0b`000=h0003N0000303N00000`000000l0000?00000:0?0000T0o`00
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0U0?ooo`009`3oool00`000000oooo0?oo
o`0N0?ooo`030000002<0000S00000T0S0001000000>08`000030000002S0000X`0000L0X`003@2m
000?0<h000@0gP000P0000000`2d00000000000000090;@001H0Y`000P00000<0=h000030000003`
0000l00000/0l0002@3o00000`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02D0oooo000W
0?ooo`030000003oool0oooo01d0oooo0P00000808`000<000000`1N0002000000d0S00000<00000
0:<0002S0000202S000<0;d000l0cP000P3N000200000080]00000<000000;@0002d0000202d000I
0:L000030000003N0000gP0000T0gP0000<000000?00003`00002P3`000:0?l000030000003oool0
oooo01`0oooo0P00000V0?ooo`009`3oool00`000000oooo0?ooo`0L0?ooo`040000001R0000HP00
000000@0S0000`00000605h000030000001N0000000000<0T`002P2<00000`000000X`000:<00007
0:<000d0_@003P3>0002000000<0]0001P0000030;@000<000006P2W0002000000P0gP0000<00000
0?00003`00002`3`00090?l000030000003oool0oooo01d0oooo0P00000V0?ooo`00A@3oool01000
0000HP000680001R000200000080S00000<0000005h0000000001`1N00000`000000GP0000000002
0>4000D0T`001P2<00000`000000X`000:<000080:<000`0_@00303>0002000000<0]0000`000000
102C0000000007<0001c0004000000<0Y`0000<000000:L0002W00006@2W00000`000000gP000=h0
00050=h000030000003`0000l00000X0l0002P3o00000`000000oooo0?ooo`0L0?ooo`<000009P3o
ool002L0oooo00<000000?ooo`3oool06`3oool5068000030000002<000000000080GP0000<00000
05h0001N0000201N00000`000000h@000>4000030>4000H0T`000P2<00000`000000X`000:<00007
0:<000d0_@002@3>0002000000<0]0000P0000001P00FK/0000009<0002C0000000007<000<00000
00<0]0000:L0002W00000`2W00000`000000Y`000:L0000I0:L000030000003N0000gP0000<0gP00
00<000000?00003`00002P3`000;0?l000030000003oool0oooo01d0oooo0P00000V0?ooo`009`3o
ool00`000000oooo0?ooo`0L0?ooo`@0HP000P00000305h000030000001N0000GP0000P0GP0000<0
00000>40003Q0000203Q000509<0000308`0002S0000X`0000H0X`00302m00070<h0008000000`2d
0002000000@005Vk00@0000009<00000000000000P2d00080:L000030000002W0000Y`0001T0Y`00
0P0000020=h000030000003`0000l00000/0l0002`3o00000`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02@0oooo000W0?ooo`030000003oool0oooo01`0oooo101R00000`000000GP0005h0
000205h000030000001N0000GP0000D0GP0000D0000005h0001N0000GP000000000=0>4000D0T`00
0P2<00030:<000d0_@00103>0002000000<0]0000`000005001I^`8000000`2d000:0:L000030000
002W0000Y`000080Y`001@00000C0:L000030000003N0000000000`0l000303o000Q0?ooo`030000
003oool0oooo02@0oooo000W0?ooo`030000003oool0oooo01d0oooo0P1R00000`000000GP0005h0
000305h000030000001N0000GP0000D0GP0000D0000005h0001N0000GP000000000A0>4000H0T`00
00<0S0000;d0002m00002P2m00020<h0008000000P2d0003000000<005Vk00<00000001I^`00FK/0
0`00FK/00`000000]0000;@0000<0:L000040000002W000000000000008000a200<00000001I^`00
FK/01000000?0:L0008000003@3`000<0?l00240oooo00<000000?ooo`3oool0903oool004L0oooo
0P00000605h000030000001N0000GP0000D0GP0000<0000005h0001N00000P1N00000`000000h@00
0>40000B0>4000H0T`002@2m000200000080]0000P0000000`00FK/00000001I^`03001I^`030000
0000FK/005Vk00<005Vk00<000000:L0002W00003@2W00020000008000a200<00000001I^`00FK/0
1000FK/4000000X0Y`000P0000020:L000030000003`0000l00000T0l000303o000R0?ooo`030000
003oool0oooo02@0oooo00160?ooo`030000001N0000GP0000H0GP0000<0000005h0001N00001@1N
00000`000000GP0005h0000205h000030000003Q0000h@0001H0h@0000<0_@0009<0002C00000P2C
00040;d0008000000P2d0002000000@005Vk00<00000001I^`00FK/00P00FK/00`00000005Vk001I
^`02001I^`800000302W00000`00000000a200000003000<@P0300000000FK/005Vk00@005Vk00@0
0000001I^`00FK/005Vk0P0000070:L000030000002W0000Y`0000<0Y`0000<000000?00003`0000
1`3`000=0?l00280oooo00<000000?ooo`3oool0903oool002L0oooo00<000000?ooo`3oool06`3o
ool00`000000GP0005h0000705h000030000001N0000GP0000/0GP0000<000000>40003Q00006P3Q
00000`2C0000000000000002000000050;@00000000000000;@0000000001000FK/00`00000005Vk
001I^`02001I^`0300000000FK/005Vk00800000302W00020000008000a200@00000000<@P003480
00001P00FK/00`00000005Vk001I^`03001I^`<000000`2W0002000000L0Y`0000<000000?00003`
00001P3`000<0?l00280oooo0P00000V0?ooo`009`3oool00`000000oooo0?ooo`0J0?ooo`030000
001N0000GP0000P0GP0000<0000005h0001N00002`1N00000`000000i`000>L0000N0>40000309<0
00000000]000008005Vk00<00000001I^`00FK/00`00FK/01000000005Vk001I^`00FK/4000000`0
Y`000P000002000<@P0400000000348000a2000000H005Vk00<00000001I^`00FK/01000FK/01P00
000005Vk001I^`000000Y`00000000X0Y`0000<000000?00003`0000103`000=0?l002<0oooo00<0
00000?ooo`3oool0903oool002H0oooo00<000000?ooo`3oool06P3oool00`000000GP0005h00009
05h000030000001N0000GP0000D0GP0000<0000005h0001N00000`1N00000`000000i`000>L00004
0>L001/0h@0000D00000001I^`00FK/005Vk00000005001I^`0400000000FK/000000000008008Km
302W0003000000<000a200@00000000<@P00348000001P00FK/00`00000005Vk001I^`03001I^`03
00000000FK/005Vk008005Vk00<000000:L0002W00002P2W00000`000000l0000?0000030?0000`0
o`00903oool00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000oooo0?ooo`0H0?ooo`800000
301N00000`000000GP0005h0000505h000030000001N0000GP0000<0GP0000<000000>L0003W0000
2@3W000G0>40000500000000FK/005Vk001I^`0000000`00FK/6000000`0Y`0000<00000000<@P00
00000`0034800`00000000a200000002000000D005Vk00<00000001I^`00FK/01000FK/00`000000
05Vk001I^`02001I^`030000002W0000Y`0000/0Y`0000@000000?00003`0000l0002P3o00000`00
0000o`000?ooo`0T0?ooo`030000003oool0oooo02@0oooo00100?ooo`030000001N0000GP0000`0
GP0000<0000005h0001N00001@1N00000`000000GP0005h0000305h000030000003W0000i`0000d0
i`004`3Q00001000000005Vk001I^`00FK/8000000`0Y`000P000002000<@P0600000000348000a2
00000000348000000`00F_H01@00000005Vk001I^`00FK/0000000H005Vk00<00000001I^`00FK/0
0`00FK/2000000d0Y`0000<000000?00003o0000303o000U0?ooo`030000003oool0oooo02@0oooo
000o0?ooo`030000001N0000GP0000d0GP0000<0000005h0001N00001@1N00000`000000GP0005h0
000305h000030000003W0000i`000140i`00403Q0004000000030026o@000000000000<00000302W
00001@00000000a2000<@P003480000000<000a20P000005001JmP0400000000FK/005Vk000000D0
05Vk00<00000001I^`00FK/00`00FK/01000000005Vk001I^`00000=0:L000030000003o0000o`00
00X0o`009P3oool00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000oooo0?ooo`0E0?ooo`03
0000001N0000GP0000h0GP0000@0000005h00000000000002P1N00000`000000i`000>L0000E0>L0
00`0h@000P0000001P00Q_d0000000000000000008Km000000`0Y`000`000002000<@P8000000P00
34800`00000005[f001JmP06001JmP8000001P00FK/00`00000005Vk001I^`03001I^`0500000000
FK/005Vk001I^`000000302W00000`000000o`000?l0000:0?l002H0oooo00<000000?ooo`3oool0
903oool002H0oooo00<000000?ooo`3oool0503oool00`000000GP0005h0000?05h000D000002@1N
00000`000000i`000>L0000I0>L000T0h@001P00000<0:L00003000000003480000000<000a200<0
0000000<@P0000000P000007001JmP80000000<005[f00000000FK/00`00FK/00`00000005Vk001I
^`03001I^`0300000000FK/005Vk00<005Vk00<000000:L0002W00002P2W00000`000000o`000?l0
00080?l002D0oooo0`00000V0?ooo`009P3oool00`000000oooo0?ooo`0C0?ooo`030000001N0000
GP0000h0GP0000<000000;D0002e00000P2e00001@26000000000000001N0000000000H0GP0000<0
00000>L0003W00007P3W00040>4000@00000302W00020000008000a200H00000000<@P0034800000
000<@P000003001JmP0300000000F_H005[f00<005[f00<00000001JmP00F_H00P00F_H01@000000
05Vk001I^`00FK/0000000D005Vk00<00000001I^`00FK/00`00FK/00`000000Y`000:L0000:0:L0
00030000003o0000o`0000P0o`009`3oool00`000000oooo0?ooo`0;0?ooo`05010@400000000000
0000002HV9P0503oool002H0oooo00<000000?ooo`3oool04P3oool00`000000GP0005h0000>05h0
00030000002e0000]@0000D0]@0000<0000005h0000000001P1N00000`000000i`000>L0000R0>L0
00040>40000000000000000000/0Y`000P000002000<@P0400000000348000a2000<@P8000001@00
F_H00`00000005[f001JmP02000000H005[f00<00000001I^`0000001@00FK/00`00000005Vk001I
^`04001I^`030000002W0000Y`0000/0Y`0000<000000?l0003o00001P3o000X0?ooo`030000003o
ool0oooo00h0oooo00<0V9RH0000003oool04`3oool003/0oooo00<0000005h0001N0000301N0004
000000H0]@0000<0000005h0000000001P1N00000`000000i`000>L0000S0>L000040000002W0000
Y`00000000P0Y`000P000000103m00000000000<@P000003000<@P0300000000F_H005[f00H005[f
0P000008001JmP8000001@00FK/00`00000005Vk001I^`04001I^`03000000110000000000`0Y`00
00<000000?l0003o00001P3o000X0?ooo`800000403oool00`000000oooo0?ooo`0B0?ooo`00>P3o
ool2000000d0GP0000<00000000QY00000000P00FK/500000080]@000P00000505h000@000008`3W
00001@000000Y`000:L0002W0000000000H0Y`0000@000000?d0003m000000000P0034800`000000
00a200000002000000L005[f0P0000000`00F_H00000001JmP05001JmP0400000000F_H005[f0000
00@005Vk00<00000001I^`00FK/00`00FK/010000000@@0004400000000<0:L000030000003o0000
o`0000D0o`00:P3oool00`000000oooo0?ooo`030?ooo`L00000103oool00`000000oooo0?ooo`0B
0?ooo`009P3oool00`000000oooo0?ooo`0@0?ooo`030000001N0000000000`0GP0000@00000000Q
Y0008J@000001`00FK/3000000D0GP0000<0000005h0000000000P3V0005000001h0i`0000<00000
0:L0002W00000P2W000010000000Y`000:L0002W0002000000<0o@0000D00000000<@P00000000a2
00000003001JmP0300000000F_H005[f00<005[f00<00000001JmP00F_H00P00F_H01000000005[f
001JmP00F_H2000000@005[f00@00000001I^`00FK/000001P00FK/010000000@@0004400000000=
0:L000030000003o0000o`000080o`000P0I000Z0?ooo`030000003oool0oooo00d0oooo00<0V9RH
0000003oool04`3oool002H0oooo00<000000?ooo`3oool03`3oool010000000GP0005h00000000;
05h00005000000008J@0026T000QY00000002@00FK/2000000<0GP0000@0000005h0001N00000000
1`3V0004000001X0i`0000<000000:L0002W00000`2W00000`000000Y`00000000020?l00080o@00
00<00000000<@P0034800P000005001JmP0300000000F_H005[f008000001P00F_H00`00000005[f
00000007001JmP0300000000FK/0000000D005Vk00D00000044000110000@@000000000=0:L00003
0000003o0000o`0000<0o`00:P3oool2000000`0oooo100000000`2HV9P0oooo0?ooo`0B0?ooo`00
9P3oool00`000000oooo0?ooo`0>0?ooo`050000001N0000GP0005h0000000002@1N0002000000@0
026T00<00000001I^`00FK/01`00FK/200000080GP0000D0000005h0001N0000GP000000000;0>H0
00@000005P3W00000`000000Y`000:L000040:L000030000003o0000o`000080o@0000<00000000<
@P0034800P000007001JmP8000002000F_H2000000P005[f0P000006001I^`05000000110000@@00
0440000000003P2W000010000000o`000?l0003o000[0?ooo`800000303oool00`1gMgL0EEEE0?oo
o`0F0?ooo`009P3oool00`000000oooo0?ooo`0=0?ooo`030000001N0000GP000080GP0000<00000
05h0001N00001P1N00000`000000026T00000004000QY00300000000FK/005Vk00P005Vk00<00000
05h000000000101N00000`000000iP000>H0000=0>H000D000004P3W00000`000000Y`000:L00003
0:L000030000003o0000o`000080o@0000@00000000<@P00000000001`00F_H200000003001JmP00
000005[f00D005[f00<00000001JmP0000001`00F_H01000000005[f001JmP000004001I^`040000
00110000@@000440008000003P2W000010000000o`000?l0003o000[0?ooo`8000003@3oool0100@
410000000000000b<S8D0?ooo`00=P3oool00`000000GP0005h0000205h000030000001N0000GP00
00D0GP0000@00000000QY0008J@000000`008J@4000000P005Vk0P00000505h000030000003V0000
iP000180iP001000000>0>L000030000002W0000Y`000080Y`0000<000000?l0003o00000P3m0003
0000008005[f00<00000001JmP00F_H00`00F_H00`00000005[f001JmP02001JmP0400000000F_H0
05[f001JmP8000000`00F_H00`00000005[f001JmP02001JmP8000001000F_H01000000005Vk001I
^`0000040440008000003P2W00000`000000o`000?l0000]0?ooo`030000003oool0oooo02<0oooo
000V0?ooo`030000003oool0oooo00`0oooo00<0000005h0001N00000P1N00000`000000GP0005h0
000505h00005000000008J@0026T000QY00000000P008J@00`000000026T00000002001I^`@00000
1000FK/00`000000GP0005h0000405h000030000003V0000iP0001H0iP001000000:0>L000030000
002W0000Y`000080Y`0000<000000?l0003o00000P3m00000`00000005[f001JmP03001JmP030000
0000F_H005[f008000001P00F_H00`00000005[f00000006001JmP0400000000F_H005[f000000L0
05[f00<00000001I^`000000101100000`000000Y`000:L0000=0:L00080000000<0o`000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`0<0?ooo`030000
001N0000GP000080GP0000<0000005h0001N0000101N00000`000000026T000QY002000QY0030000
00008J@000000080026T00<00000001I^`00FK/01000FK/300000003001I^`000000GP0000D0GP00
00<000000>H0003V00006P3V0005000000D0i`0000<000000:L0002W00000P2W00001@000000o`00
0?d0003m0000000000L005[f0P000009001JmP0300000000F_H005[f00H005[f0P000009001JmP04
000000110000@@00044000<000003P2W0003080000030000002C0000T`000080S000:@3oool00`00
0000oooo0?ooo`0S0?ooo`009P3oool00`000000oooo0?ooo`0;0?ooo`030000001N0000GP0000<0
GP0000<0000005h0001N00000P1N0002000000D0026T0P000003000QY00300000000FK/005Vk00L0
05Vk0P00000505h000030000003V0000iP000200iP00100000000`3W000000000:L000030:L00004
0000003m0000o@00000000L005[f00@00000001JmP00F_H000001P00F_H01@00000005[f001JmP00
F_H0000000D005[f00@00000001JmP00F_H000001@00F_H2000000<0@@000P0000030:L000030000
002W0000Y`0000T0Y`001@2000000`000000h@000>40000509<0000308`0003oool0oooo02<0oooo
00<000000?ooo`3oool08`3oool002H0oooo00<000000?ooo`3oool02`3oool00`000000GP0005h0
000305h000070000001N0000GP0005h000000000026T00000004000QY080000010008J@00`000000
05Vk001I^`08001I^`030000001N0000GP0000<0GP0000<000000>H0003V0000903V0002000000@0
Y`0000<000000?d0003m00000P3m00001000000005[f001JmP00F_H2000000@005[f00@00000001J
mP00F_H005[f0P000005001JmP0300000000F_H005[f008000001000F_H01@00000005[f001JmP00
F_H0000000@0@@0000<000000:L0002W0000102W0002000000P0Y`001@2000000`000000P0000000
00050>4000D0T`0000<0S0000?ooo`3oool07`3oool00`000000oooo0?ooo`0S0?ooo`00<`3oool0
0`000000GP0005h0000405h000040000001N0000GP0000000080026T00<00000000QY0008J@00`00
0005000QY00300000000FK/005Vk00L005Vk0P00000505h000030000003V0000iP0002D0iP0000<0
00000:L0002W00000P2W00000`000000o@000?d000020?d000040>`00000000005[f000000L005[f
00<00000001JmP0000002000F_H2000000L005[f0`000003044000800000202W0002000000H0Y`00
202000000`000000h@000>4000070>4000D0T`0000<0S0000?ooo`3oool06`3oool00`000000oooo
0?ooo`0S0?ooo`00<`3oool00`000000GP0005h0000405h000030000001N0000000000<0026T00<0
0000000QY00000000P008J@00`000000026T000QY002000QY0@000001`00FK/2000000D0GP0000<0
00000>H0003V00003`3V0003000001<0iP0000<000000:L0002W00000`2W00000`000000o@000?d0
00030>`0000300000000F_H005[f00H005[f0`000007001JmP<000001P00F_H300000080@@000P00
000;0:L0008000000`2W000;080000030000003Q0000h@0000X0h@001P2C000H0?ooo`8000009@3o
ool002D0oooo00<000000?ooo`3oool02P3oool00`000000GP0005h0000505h00080000010008J@2
000000<0026T00L00000000QY0008J@0026T000000008J@00000008005Vk1@000002001I^`030000
001N0000GP0000@0GP0000<000000>H0003V00009@3V00000`000000Y`000:L000030:L000030000
003m0000k00000@0k00000<00000001JmP00F_H01000F_H01@00000005[f001JmP00F_H0000000@0
05[f0P000003001JmP0300000000F_H005[f008005[f00<000000440001100000P1100000`000000
Y`000:L0000<0:L00003080000000000P00000`0P00000<000000>40003Q00003P3Q000609<00003
0?ooo`00000000000180oooo00<000000?ooo`3oool08`3oool002D0oooo00<000000?ooo`3oool0
2P3oool00`000000GP0005h0000405h00003000000008J@0000000<0026T0`000003000QY0040000
00008J@0026T00000080026T00<00000001I^`00FK/01@00FK/3000000H0GP0000<000000>H0003V
00009@3V00000`000000Y`000:L000040:L000030000003/0000k00000<0k0000P000003001JmP80
00001@00F_H01000000005[f001JmP000006001JmP0400000000F_H00000000000<0@@000P00000?
0:L00003080000000000P00000d0P00000<000000>40003Q00004@3Q00000`000000T`0009<00002
09<000800000403oool00`000000oooo0?ooo`0S0?ooo`009@3oool00`000000oooo0?ooo`090?oo
o`050000001N0000GP0005h0003I00000P1N000010000000026T000QY0000002000QY00300000000
8J@000000080026T00<00000000QY00000000P000003000QY00300000000FK/005Vk00L005Vk0P00
000505h000030000003V0000iP0002D0iP0000<000000:L0002W0000102W00000`000000k0000>`0
00020>`000060000003L0000g00000000000F_H000002000F_H2000000L005[f0P00000304400080
00003`2W0003080000030000003V0000P00000`0P00000<000000>40003Q00005@3Q000309<00080
00003P3oool00`000000oooo0?ooo`0S0?ooo`009@3oool00`000000oooo0?ooo`090?ooo`070000
001N0000GP0005h0003I0000GP0000000003000QY003000000008J@000000080026T00<00000000Q
Y0008J@00P008J@2000000@0026T00<00000001I^`00FK/01P00FK/00`000000GP000000000505h0
00030000003R0000hP0002D0iP0000<000000:L0002W00001@2W000010000000k0000>`000000004
0=`0008000001P00F_H200000003001JmP00000005[f00D005[f00@00000044000110000@@000P00
000@0:L000@0P00000<000000>H0002000003@2000000`000000h@000>40000H0>40000309<00000
0000oooo00`0oooo00<000000?ooo`3oool08`3oool00340oooo00H0000005h0001N0000GP000=l0
00000004000QY08000000`008J@00`000000026T000QY003000000D0026T00<00000001I^`00FK/0
1P00FK/00`000000GP000000000505h000030000003R0000hP0000D0hP007`3V00000`000000Y`00
0:L000070:L000030000003/0000000000H0g00000<00000001JmP00F_H00P00F_H00`00000005[f
001JmP02001JmP0400000000F_H005[f001JmP8000000`1100000`000000Y`000:L0000>0:L000H0
P00000<000000800002000003@2000000`000000i`000>L0000I0>4000030000003oool0oooo00/0
oooo00<000000?ooo`3oool08`3oool00300oooo00<0000005h0001N00000P1N00000`3O00000000
000QY002000QY080000010008J@00`000000026T00000002000QY004000000008J@0026T000QY0@0
00001`00FK/00`000000GP000000000405h000030000003R0000hP0000/0hP006P3V00000`000000
Y`000:L000070:L000<000001P3L00000`3<00000000001JmP02000000H005[f00@00000001JmP00
000000000P110002000000l0Y`00202000000`000000P0000800000=080000030000003W0000i`00
00D0i`005@3Q00000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo000U0?ooo`03
0000003oool0oooo00P0oooo00<0000005h0001N00000P1N00001`3O00000000000QY0008J@00000
000QY000000010008J@2000000<0026T00H00000000QY0008J@00000000QY0000002001I^`D00000
00<005Vk0000001N00001P1N00000`000000hP000>80000@0>8001D0iP000P0000060:L000800000
0`2W0002000000<0g0000`3<0002000000L005[f0`0000000`11000000000000000@0:L000T0P000
00<000000800002000003@2000000`000000i`000>L0000:0>L00140h@0000<000000?ooo`3oool0
203oool00`000000oooo0000000T0?ooo`009@3oool00`000000oooo0?ooo`080?ooo`030000001N
0000GP000080GP0000@0g`00000000008J@000000P008J@010000000026T000QY0008J@2000000@0
026T00<00000000QY00000000P008J@00`00000005Vk001I^`05001I^`8000001`1N00000`000000
hP000>80000E0>800100iP0000<000000?ooo`000000102W00000`000000Y`000:L000050:L00003
0000003L0000g00000@0c00000<00000001JmP00F_H01000F_H00`000000O`0007l00002000000l0
Y`00302000000`000000P0000800000>080000030000003W0000i`0000h0i`003@3Q00000`000000
oooo0?ooo`080?ooo`800000903oool002D0oooo00<000000?ooo`3oool01`3oool00`000000GP00
05h0000305h000030=l000000000000000<0026T00H00000000QY0008J@00000000QY0000004000Q
Y08000000`008J@00`00000005Vk001I^`06001I^`040000001N0000GP00000000<0GP0000<00000
0>80003R00006`3R000;0>H000050000003oool0oooo0000002W00000P0000090:L0008000001@3<
00001000000005[f001JmP00F_H200000080O`000P00000?0:L000d0P00000<00000080000000000
0`00000;080000030000003W0000i`000180i`002@3Q00000`000000oooo0?ooo`080?ooo`800000
903oool002D0oooo00<000000?ooo`3oool01`3oool00`000000GP0005h0000305h000<000000`00
8J@00`000000026T00000002000QY004000000008J@0026T000QY080000010008J@00`00000005Vk
001I^`05001I^`050000001N0000GP0005h0000000000`1N00000`000000hP000>80000P0>8000H0
iP0000@000000?ooo`3oool0oooo0P00000<0:L000<000000P3<00001@2c00000000001JmP000000
O`0000@000003P2W000>080000H0000000<0QP000000002000002@2000000`000000i`000>L0000G
0>L000D0h@0000<000000?ooo`3oool01`3oool2000002@0oooo000_0?ooo`030000001N0000GP00
00<0GP000P000004000QY08000000`008J@01P000000026T000QY0000000026T000000@0026T00<0
0000001I^`00FK/01@00FK/01@000000GP0005h0001N0000000000<0GP0000<000000>80003R0000
9@3R00000`3V000000000?ooo`040?ooo`030000002W0000Y`0000`0Y`001`0000030:L000800000
302W000=080000800000102e000208H0008000002P2000000`000000i`000>L0000L0>L000030>40
00000000oooo00L0oooo0P00000T0?ooo`00;`3oool00`000000GP0005h0000305h0008000000`00
8J@2000000@0026T00<00000000QY00000000P008J@010000000026T000QY0008J@2000000L005Vk
00D0000005h0001N0000GP000000000205h000030000003R0000hP0002L0hP0000<000000?ooo`3o
ool0103oool2000000d0Y`0000<0c0000:L0002W00001`2W0002000000T0Y`003P2000000`000000
]@000;D000080;D00003000000200000P00000L0P00000<000000>L0003W00007@3W00000`000000
oooo0?ooo`070?ooo`030000003oool0oooo0280oooo000U0?ooo`030000003oool0oooo00H0oooo
00<0000005h0001N0000101N000200000080026T00<00000000QY000000010008J@2000000<0026T
00@00000000QY0008J@000001@00Lol4000000L0GP0000<000000>80003R00009P3R00000`000000
oooo0?ooo`070?ooo`030000002W0000Y`0000/0Y`0000<0c0000:L0002W00001`2W0002000000H0
Y`003P200006000000L0]@0000<00000080000200000202000000`000000i`000>L0000L0>L00003
0000003oool0oooo00L0oooo00<000000?ooo`3oool08P3oool002D0oooo00<000000?ooo`3oool0
1P3oool00`000000GP0005h0000305h000050000003O00000000000QY00000000P008J@010000000
026T000QY0008J@2000000@0026T00<00000000QY00000002@00Lol00`000000GP0005h0000205h0
00040000001N0000GP00000002P0hP0000<000000?ooo`3oool0203oool00`000000Y`000:L0000;
0:L000030<`0002W0000Y`0000L0Y`000P0000040:L000d0P000100000001000<K@00000001I^`00
FK/5000000<0]@0000<000000800002000001`2000000`000000i`000>L0000L0>L000030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08P3oool002D0oooo00<000000?ooo`3oool01P3oool0
0`000000GP0005h0000305h000040000003O00000000000000<0026T00H00000000QY0008J@00000
000QY0000004000QY08000002@00Lol00`000000GP0005h0000305h000030000001N0000000002T0
hP0000<000000?ooo`3oool02@3oool2000001H0Y`000P0000000`2W0000P0000800000;080000@0
00000`00<K@00`00000005Vk001I^`05001I^`@0000020200004000001d0i`0000<000000?ooo`3o
ool01@3oool2000002@0oooo000^0?ooo`030000001N0000GP0000<0GP0000<000000=l000000000
10008J@00`000000026T00000002000QY004000000008J@0026T000QY0@000001`00Lol00`000000
GP0005h0000405h000030000001N0000000002P0hP0000<000000?ooo`3oool0303oool00`000000
Y`000:L0000;0:L000030<`0002W0000Y`0000H0Y`0000<000000800002000002P200004000000D0
036d00<00000001I^`00FK/02000FK/00`000000P0000800000408000080000000@0P0000000003V
0000iP001@00000H0>L000030000003oool0oooo00H0oooo00<000000?ooo`3oool08P3oool002h0
oooo00<0000005h0001N00000`1N00000`000000h`0000000004000QY08000000`008J@010000000
026T000QY0000004001co`@0000000<007?o0000000000001`1N00000`000000GP00000000030=X0
02D0hP0000<000000?ooo`3oool03@3oool200000180Y`000P2000000`000000P000080000090800
00040000002e00000000000000H0036d00<00000001I^`00FK/02000FK/00`000000P00008000002
0800008000000`2000000`000000iP000>H000050>H000D000004`3W00000`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0280oooo000U0?ooo`030000003oool0oooo00H0oooo00<0000005h0
001N00000`1N00000`000000h`0000000003000QY080000010008J@00`000000026T00000009001c
o`<00000201N00000`000000fP000=X000070=X00200hP0000<000000?ooo`3oool03`3oool30000
00h0Y`000`2000000`000000P00008000007080000@0000000<0036d00000000<K@01000<K@40000
00T005Vk00@0000008000020000000001@2000000`000000iP000>H0000:0>H000D000003P3W0000
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo000U0?ooo`030000003oool0oooo
00H0oooo00<0000005h0001N00000`1N00000`000000h`0000000002000QY08000001@008J@20000
00P007?o0P00000205h000030000001N0000GP0000H0GP0000<000000=X0003J00003@3J000I0>80
00030000003oool0oooo01<0oooo0P00000;0:L000@0P00000<000000800002000001@2000040000
00<0036d00@00000000a]000<K@0036d0P0000001000<K@00000001I^`00FK/3000000H005Vk0`00
0006080000030000003V0000iP0000l0iP001000000:0>L000030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08P3oool002@0oooo00<000000?ooo`3oool01`3oool00`000000GP0005h00002
05h000080000003S0000h`00000000008J@00000000QY0000004000QY0D000001@00Lol00`000000
GP0005h0000205h000030000001N0000GP0000D0GP0000<000000=X0003J0000503J000C0>800003
0000003oool0oooo01D0oooo0`0000060:L000H0P00000<000000800002000000`200004000000D0
036d00@00000000a]000000000000`00<K@00`00000005Vk001I^`03001I^`D0000000<005Vk0000
002000000P200002000000<0P00000<000000>H0003V00004`3V0005000000H0i`0000<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`00903oool00`000000oooo0?ooo`060?ooo`03
0000001N0000GP0000<0GP0000<000000><0003S00000P000002000QY005000000008J@0026T000Q
Y00000001@00Lol4000000H0GP0000<0000005h0001N00001@1N00000`000000fP000=X0000I0=X0
00h0hP0000<000000?ooo`3oool0603oool5000000@0P00000@0Y`0008000020000000000`200004
00000003000a]0000000036d00@0036d0P000005000a]00300000000FK/005Vk00P005Vk0P000008
080000030000003V0000iP0001P0iP001@0000000`3W000000000?ooo`060?ooo`030000003oool0
oooo0280oooo000]0?ooo`030000001N0000GP000080GP001@000003000QY004000000008J@00000
000000P007?o00<0000005h0001N00001@1N00000`000000GP0005h0000405h000030000003J0000
fP000200fP001`3R00000`000000oooo0?ooo`0M0?ooo`03000000200000P00000D0P00000H00000
08000020000000000;D000000003000a]00300000000<K@0036d0080036d0P000006000a]0030000
0000FK/005Vk00T005Vk00<000000800002000001@2000000`000000iP000>H0000N0>H000800000
1@3oool3000000D0oooo00D0V9RH000000000000000009RHV00J0?ooo`00;@3oool02@000000GP00
05h0001N0000000005h000000000i00000000004000QY08000002@00Lol905h000030000001N0000
GP0000@0GP0000<000000=X0003J00009@3J00020>8000030000003oool0oooo01`0oooo00<00000
0800002000001P2000000`000000P00000000002000000@0036d00<00000000a]000<K@00P000000
0`00<K@00000000a]005000a]00300000000FK/005Vk00T005Vk00<000000800002000001@200000
0`000000iP000>H0000O0>H000030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
1@000000V9RH0?ooo`2HV9P0000001X0oooo000T0?ooo`030000003oool0oooo00H0oooo00@00000
05h00000000000000P1N00000`000000i00000000003000QY0P0000000<007?o0000000000002P1N
00000`000000GP0005h0000305h000030000003J0000fP0002P0fP0000<000000?ooo`3oool06`3o
ool00`000000P00008000007080000@000001@00<K@3000000<0036d00<00000000a]000<K@00`00
<K@4000000P005Vk00<000000800002000001P2000000`000000iP000>H0000O0>H000030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000001X0oooo
000T0?ooo`030000003oool0oooo00H0oooo0P00000405h000040000003T00000000000QY0800000
2000Lol2000000/0GP0000<0000005h0001N00000`1N00000`000000fP000=X0000W0=X000030000
003oool0oooo01`0oooo00<000000800002000001`20000010000000036d000a]0000004000a]0<0
00001@00<K@00`000000036d000a]00200000004000a]000000005Vk001I^`D000000`00FK/00`00
0000P00008000006080000030000003V0000iP0001l0iP0000<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000006P3oool002@0oooo00<000000?oo
o`3oool01P3oool00`000000GP0005h0000305h000040000003T00000000000000T007?o00<00000
05h0001N00002P1N00000`000000GP0005h0000305h000030000003J0000000002P0fP0000<00000
0?ooo`3oool0703oool00`000000P000080000050800008000000`00<K@00`000000036d000a]002
00000003000a]0000000036d0080036d00<00000000a]000<K@00`000003000a]00300000000FK/0
05Vk00D005Vk10000008080000030000003V0000iP0001l0iP0000<000000?ooo`3oool01@3oool2
000000@0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`H00000203oool002@0oooo00<00000
0?ooo`3oool01P3oool00`000000GP0005h0000305h000<000002@00Lol00`000000GP0005h0000;
05h000030000001N0000GP0000<0GP0000@000000<L000000000a`009P3J0002000001d0oooo00<0
00000800002000001@2000000`000000036d000a]003000a]00300000000<K@0000000<0036d00<0
0000000a]000<K@00`00<K@2000000D0036d00<00000001I^`00FK/02000FK/00`000000P0000800
0006080000030000003V0000iP0001l0iP0000<000000?ooo`3oool01@3oool2000000@0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`060:VYZ@0b<S80oooo0?ooo`3^k^h0<S8b203oool002d0
oooo00<0000005h0001N00000`1N00000`000000h@000>400009000000h0GP0000<0000005h0001N
00000P1N000010000000a`000<L0000000060<L00240fP001P00000I0?ooo`03000000200000P000
00D0P00000<00000000a]000<K@00`00<K@2000000@0036d00<00000000a]000<K@00P00<K@00`00
0000036d00000005000a]00300000000FK/005Vk00P005Vk00<000000800002000001P2000000`00
0000hP000>80000O0>H000030000003oool0oooo00D0oooo0P0000040?ooo`050000002HV9P0oooo
09RHV00000003@3oool00`1VIVH0MgMg0?ooo`0:0?ooo`00;@3oool00`000000GP0005h0000405h0
00030000003Q0000h@0000<0h@0000<000000>4000000000401N00001@000000GP0005h0001N0000
000000<0a`0000<000000<L0003700002@37000K0=X000D0[P000P3;0003000001H0oooo00<00000
08000020000010200002000000<0036d0`000005000a]00300000000<K@0036d008000000P00<K@0
0`000000036d000a]002000a]0@000001`00FK/00`000000P00008000006080000030000003R0000
hP0000H0hP006@3V00000`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00D0V9RH
000000000000000009RHV00=0?ooo`030>k^kP0Q8B40c<c<00X0oooo000T0?ooo`030000003oool0
oooo00H0oooo00<0000005h0001N0000101N00000`000000h@000>4000040>4000030000001N0000
GP0000l0GP0000@0000005h0001N000000005P37000B0=X000P0[P001@3;0002000001<0oooo00<0
00000800002000001@20000200000080036d00@00000000a]000<K@000001@00<K@3000000@0036d
00<00000000a]000<K@00P0000001000<K@00000001I^`00FK/50000008005Vk00<0000008000020
00001P2000000`000000hP000>80000;0>8001@0iP0000<000000?ooo`3oool01P3oool2000001L0
oooo00<0c<c<024Q8@3^k^h02@3oool002@0oooo00<000000?ooo`3oool01P3oool00`000000GP00
05h0000505h0008000000`3Q00000`000000GP0005h0000@05h000030000001N0000000001`0a`00
2`3J00090:h000P0b`000P00000A0?ooo`03000000200000P00000@0P00000<000000=T000000000
0P000003000a]00300000000<K@0036d0080036d0P000006000a]0<000000`00<K@00`00000005Vk
001I^`05001I^`<00000202000000`000000hP000>80000@0>8000l0iP0000<000000?ooo`3oool0
1P3oool2000001P0oooo00<0MgMg06IVIP3oool0203oool002@0oooo00<000000?ooo`3oool01P3o
ool00`000000GP0005h0000705h000H00000401N0002000000H0a`0000<000000<L0003700006@37
00030=X000`0[P002P3;0003000000h0oooo00<000000800002000001020000010000000g`000000
00000004000a]00300000000<K@0036d0080000000<0036d00000000<K@01000<K@2000000D0036d
00<00000001I^`00FK/01`00FK/00`000000P00008000005080000030000003R0000hP0001D0hP00
2`3V00000`000000oooo0?ooo`060?ooo`8000005@3oool01P0b<S80k^k^0?ooo`3oool0<S8b0:VY
Z@P0oooo000T0?ooo`030000003oool0oooo00H0oooo00<0000005h0001N00002@1N00000`000000
GP0005h0000805h000D0/0000`1N0005000000@0a`0000<000000<L0003700006P3700000`1^0000
[P000:h0000:0:h000h0b`000P00000<0?ooo`03000000200000P00000<0P00000@000000=l0003O
000000001@00<K@3000000<0036d00<00000000a]000<K@00P00<K@00`000000036d00000005000a
]00300000000FK/005Vk00H005Vk00<000000800002000001P2000000`000000hP000>80000J0>80
00H0iP0000<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0C0?ooo`H00000203oool002d0
oooo00<0000005h0001N00002@1N00000`000000GP0005h0000?05h000030000002]0000[@0000<0
[@001@00000K0<L00080KP002`2^000?0</00080gP0000<000000?ooo`3oool0203oool00`000000
P00008000004080000040000003O0000g`00000000@0036d0`000004000a]00300000000<K@0036d
008000000P00<K@00`000000036d000a]003000a]00300000000FK/005Vk00D005Vk00<000000800
002000001`2000000`000000hP000>80000O0>8000030>H000000000oooo00P0oooo00<000000?oo
o`3oool08@3oool002d0oooo00<0000005h0001N00002@1N00000`000000GP0005h0000=05h00080
00002`2]0005000001D0a`000P1^000<0:h000l0b`000`3N0002000000P0oooo00<0000008000020
00001020000010000000g`000=l000000002000a]080000000<0036d00000000<K@01000<K@30000
00@0036d00<00000000a]000<K@00`00<K@4000000@005Vk00<000000800002000001P2000000`00
0000hP000>80000Q0>8000030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool002@0
oooo00<000000?ooo`3oool01P3oool00`000000GP0005h0000905h000030000001N0000GP0000`0
GP0000<000000:d0002]0000402]0005000000d0a`001@1^000;0:h000l0b`001P3N0002000000H0
oooo00<000000800002000000`20000010000000g`000=l0003O0003000000<0036d00<00000000a
]000<K@00P00<K@3000000D0036d00<00000000a]000<K@00P000005001co`@000002@2000000`00
0000hP000>80000P0>8000030000003oool0oooo00P0oooo00<000000?ooo`3oool08@3oool002@0
oooo00<000000?ooo`3oool01P3oool00`000000GP0005h0000905h000030000001N0000GP0000X0
GP000P00000=0:d000030000002]0000[@0000P0[@001`0000040<L000H0KP00302^000?0</000P0
gP0000<000000?ooo`3oool00`3oool00`000000P00008000003080000050000003O0000g`000=l0
000000001@00<K@00`000000036d000a]00200000003000a]0000000036d00D0036d0`000008001c
o`05000000200000P0000800000000001`2000000`000000hP000>80000P0>8000030000003oool0
oooo00L0oooo0P00000S0?ooo`00903oool00`000000oooo0?ooo`060?ooo`030000001N0000GP00
00T0GP0000<0000005h0001N00002@1N00000`000000[@000:d0000=0:d000030000002]0000[@00
00h0[@0000@0iP0000000000000000001P1^000<0:h000l0b`002P3N0002000000<0oooo00<00000
0800002000000`2000001@000000h`000><0003S0000000000D0036d00<00000000a]00000000`00
<K@00`000000036d000a]003000a]0@000001`00Lol00`000000P00008000009080000030000003R
0000hP000240hP0000<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool0
0`000000GP0005h0000805h000030000001N0000GP0000L0GP000P00000@0:d000030000002]0000
[@000100[@000P00000606h000P0[P0000<0iP000:h0000000003`3;000=0=h000030000003oool0
000000H0P00000D000000><0003S0000h`0000000005000a]08000001000<K@00`000000036d000a
]002000a]00300000000Lol007?o008007?o100000000`00Lol000000000000<080000030000003R
0000hP000200hP0000<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`00;P3oool0
0`000000GP0005h0000705h000030000001N0000GP0000L0GP0000<000000:d0002]0000402]0000
0`000000[@000:d0000?0:d00003028000000000KP0000D0KP00302^000?0</000h0gP000P000006
080000050000003S0000h`000><0000000000`00<K@3000000D0036d00<00000000a]000<K@00P00
0008001co`@000003020000010000000fP000=X00038000O0>8000030000003oool0oooo00T0oooo
00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool0203oool00`000000GP0005h0
000705h000030000001N0000GP0000D0GP000P00000S0:d000808P0000<0000006h0001^00001@1^
000;0:h000l0b`003`3N0002000000H0P00000D000000><0003S0000h`0000000002000a]0040000
0000<K@0036d000000D0036d0`000008001co`8000000`2000000`000000P0000800000908000003
0000003J0000fP0000H0fP0000<0b0000>80003R0000603R00000`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0240oooo000S0?ooo`030000003oool0oooo00T0oooo00<0000005h0001N0000
1P1N00000`000000GP0005h0000405h000030000002]0000[@000240[@00100R00000`000000KP00
06h0000406h000`0[P003`3;000>0=h000040000003`0000l000000000@0P00010000000103S0000
0000000000000003000a]00300000000<K@0036d0080036d0P000009001co`800000102000000`00
0000P00008000007080000<000003P3J00000`380000hP000>80000A0>8000030000003oool0oooo
00X0oooo00<000000?ooo`3oool08@3oool002<0oooo00<000000?ooo`3oool02@3oool00`000000
GP0005h0000605h000030000001N0000GP000080GP000P00000F0:d000030000002]0000[@0000X0
[@00100R00000`000000KP0006h0000406h000`0[P003`3;000?0=h000060000003`0000l0000?00
00000000P0000P0000001020000000000>@0003T0002000000D0036d00<00000000a]000<K@00P00
0005001co`H000001P2000000`000000P00008000006080000030000003o0000000001D0fP003P3R
00000`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo000S0?ooo`030000003oool0
oooo00T0oooo00<0000005h0001N00001P1N00001@000000GP0005h0001N0000000001P0[@0000<0
00000:d0002]0000202]00050280008000001P1^000;0:h000l0b`003`3N00000`000000l0000?00
00030?000005000000200000P0000800000000000`3T00000`000000036d000a]003000a]0<00000
2@00Lol2000000P0P00000<0iP0000000020000010200002000000<0o`006P3J00000`270000hP00
0>8000060>8000030000003oool0oooo00T0oooo0P00000S0?ooo`00<03oool00`000000GP0005h0
000505h000040000001N00000000000001T0[@0000<000000:d0002]00001`2]0006028000030000
001^0000KP0000@0KP00302^000?0</000h0gP0000<000000?00003`00001@3`00001@000000P000
08000020000000000080i00000<00000000a]000<K@00P00<K@90000008007?o0`00000908000003
0>H000000000P0000080P0000P0000000`3a0000o`000?l000020?l0000301T0003J0000fP0001d0
fP000P3R00000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo000a0?ooo`030000
001N0000GP0000@0GP000P00000K0:d000030000002]0000[@0000D0[@001`0R00000`000000KP00
06h0000506h000/0[P003`3;000?0=h000030000003`0000l00000H0l00000@00000080000200000
00000P3T00000`000000036d000a]002000000T007?o0`00000;080000030>H000000000P0000080
0000103a00040?l001/0fP0000<0Q`000=X0003J00000`3J00000`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0200oooo000S0?ooo`030000003oool0oooo00`0oooo00@0000005h0001N0000
GP001P00000O0:d000T08P0000<0000006h0001^0000101^000;0:h000030000003;0000b`0000d0
b`003P3N00000`000000l0000?0000080?00000300000020000000000080i0000`000009001co`<0
00001`2000000`2`0000P000080000040800008000001P3a00040?l0000301T0003J0000fP0000/0
fP000`3V000?0=X000030000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool002<0oooo
00<000000?ooo`3oool03@3oool3000000H0I`001@00000I0:d000T08P0000<0000006h0001^0000
101^000<0:h000l0b`003`3N00000`000000l0000?0000090?00008000000P3Q0004000000H007?o
0`000008080000030;0000200000P00000<0P0000P0000090?4000@0o`001@3V000I0=X000030000
003oool0oooo00d0oooo0P00000R0?ooo`008`3oool00`000000oooo0?ooo`0A0?ooo`X0I`001P00
000>0:d000030000002]0000[@0000X08P000P00000606h000/0[P003`3;000?0=h000030000003`
0000l00000/0l00000<000000>40003Q0000103Q0007000000D0P0000P000002080000030;000020
0000P0000080P0000P0000000`3N000000000?4000080?4000@0o`007P3J00000`000000oooo0?oo
o`0=0?ooo`8000008P3oool002<0oooo00<000000?ooo`3oool05`3oool906L000H000002@2]0000
0`000000[@000280000:028000030000001^0000KP0000@0KP00302^000?0</000l0gP0000<00000
0?00003`00002`3`0002000000P0h@000P00000508000080000000@005Vk000000200000/0000P20
0003000000@0gP0000<000000?40003a00001`3a00040?l001`0fP0000<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0P0?ooo`00@`3oool806L000H00000102]00000`0000008P0002800009
028000030000001^0000KP0000D0KP002`2^000?0</000l0gP0000<000000?00003`0000303`0000
0`3o00000000000000050>40008000001@200002000000@005Vk00@0000008000000000000001`3N
00000`000000l@000?4000070?4000@0o`000`37000I0=X000030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0803oool004T0oooo201W0003000000030280000000008P0000X08P0000<00000
06h0001^0000101^000;0:h000030000003;0000b`0000d0b`003P3N00000`000000l0000?00000<
0?000080o`0000D00000080000000000]P000>400002000000D0P0000P0000000`00FK/00000001I
^`03001I^`8000002P3N00000`000000l@000?4000070?4000@0o`001`37000C0=X000030000003o
ool0oooo00l0oooo0P00000R0?ooo`008`3oool00`000000oooo0?ooo`0Y0?ooo`<0I`000P00000<
028000030000001^0000KP0000@0KP00302^000?0</000l0gP0000<000000?00003`0000303`0003
0?l00006000000200000000000000020000000000`200002000000@005Vk00@00000001I^`000000
0000303N00000`000000l@000?4000070?4000@0o`003037000=0=X000030000003oool0oooo0140
oooo00<000000?ooo`3oool0803oool002<0oooo00<000000?ooo`3oool0:`3oool00`0I00000000
0280000;0280008000001P1^000:0:h000030>H0003;0000b`0000d0b`003`3N00000`000000l000
0?00000<0?0000@0o`0000<000000800002000000P2000001P000000P00000000000000005Vk0000
00@005Vk0P0000000`3>0000gP000=h0000<0=h000030000003a0000l@0000L0l@00103o000@0<L0
00P0fP0000<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`008`3oool00`000000
oooo0?ooo`0[0?ooo`050000000R00008P000280000000002@0R00000`000000KP0006h0000406h0
00`0[P003`3;000?0=h000030000003`0000l00000/0l0001@3o000010000000P000080000200003
000000@005Vk100000040<h000d0gP0000<000000?40003a00001`3a00040?l000X0a`000P3V0009
0<L000030=X000000000000001@0oooo00<000000?ooo`3oool0803oool002<0oooo00<000000?oo
o`3oool0:P3oool2000000<08P0000<000000280000R00001P0R00000`000000KP0006h0000506h0
00/0[P003`3;000?0=h000030000003`0000l00000`0l0001P3o000300000003001I^`00000005Vk
00<005Vk0P0000070<h000h0gP0000<000000?40003a00001`3a00040?l001@0a`0000<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0P0?ooo`00C`3oool00`0I000000000280000302800003
0000000R00008P0000H08P0000<0000006h0001^0000101^000<0:h000l0b`003P3N00000`000000
l0000?00000<0?0000L0o`0000<00000001I^`00FK/00P00FK/01000000005Vk00000000000:0<h0
00d0gP0000<000000?40003a00001`3a00040?l000@000003P370002000001L0oooo00<000000?oo
o`3oool0803oool002<0oooo00<000000?ooo`3oool0:@3oool2000000`08P0000<0000006h0001^
0000101^000<0:h000l0b`003`3N00000`000000l0000?00000<0?0000P0o`0000@00000001I^`00
FK/005Vk0P00000<0<h000h0gP0000<000000?40003a00001`3a00040?l000030:d000370000a`00
00D00000203700000`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo000S0?ooo`03
0000003oool0oooo02P0oooo0P00000<0280008000000`1^0009000000D0[P003`3;000?0=h00003
0000003`0000l00000`0l0002@3o00001@00000005Vk000000000000_@0000h0cP003@3N00000`00
0000l@000?4000070?4000@0o`001P2]00020<L000D000000P3700000`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0200oooo000R0?ooo`030000003oool0oooo02T0oooo00<000000280000R
00000`0R00000`0000008P0002800005028000D000002@2G0006000000h0b`003`3N00000`000000
l0000?00000;0?0000X0o`000P0000040;d000d0cP003P3N00000`000000l@000?4000070?4000@0
o`002`2]00000`37000000000000000I0?ooo`<000001@3oool01@0@41000000000000000000V9RH
01P0oooo000R0?ooo`030000003oool0oooo02P0oooo0P000005028000030000000R00008P0000<0
8P000`00000C09L000<000002P3;000?0=h000030000003`0000l00000`0l0002@3o0002000000D0
_@003P3>000=0=h000030000003a0000l@0000L0l@00103o00080:d0000408L0002]000000000000
01d0oooo00<000000?ooo`3oool01P3oool00`2HV9P000000?ooo`0G0?ooo`00C03oool00`0I0000
000002800005028000040000000R00008P000280008000000`2G00000`000000U`0009L0000C09L0
00800000203;000?0=h000030000003`0000l00000/0l0002`3o00070;d000d0cP003P3N00000`00
0000l@000?4000070?4000<0o`0000<0Q`000:d0002]00001@2]0002000001l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`00C03oool00`0000008P000280000502800004
0000000R00008P00000000H0U`0000<0000009L0002G0000502G0002000000D0b`003`3N00000`00
0000l0000?00000<0?0000T0o`0000<0_@000?l0002m00001P2m000>0<h000d0gP0000<000000?40
003a00001`3a00040?l000D0[@000P00000Q0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool05P3oool00280oooo00<000000?ooo`3oool09P3oool2000000P08P000P00000809L00080
00005P2G0003000000030</0003N0000gP0000d0gP0000<000000?00003`0000303`000<0?l000P0
_@003@3>000>0=h000030000003a0000l@0000H0l@00103o00030:d0008000008`3oool00`000000
oooo0?ooo`060?ooo`0309RHV0000000oooo01L0oooo000R0?ooo`030000003oool0oooo02H0oooo
00<000000280000R00001@0R0002000000`0U`0000<0000009L0002G00005P2G0002000000h0gP00
00<000000?00003`00002`3`000:0?l000030;d0003o0000_@0000P0_@003P3>000=0=h000030000
003a0000l@0000L0l@00103o0002000002H0oooo00<000000?ooo`3oool00P3oool40000000309RH
V03oool0oooo01H0oooo000R0?ooo`030000003oool0oooo02D0oooo00<000000280000R00001@0R
00000`000000U`000000000=09L000030000002G0000U`0001L0U`0000<000000=h0003N00002P3N
00000`000000l0000?00000<0?0000`0o`002P2m000=0<h000h0gP0000<000000?40003a00001P3a
00040?l002L0oooo0P0000040?ooo`0307MgM`1EEED0oooo01X0oooo000R0?ooo`030000003oool0
oooo02@0oooo00<06@000000000R0000100R000200000080U`0000<0000009L0002G0000302G0000
0`000000U`0009L0000G09L000030000003N0000gP0000T0gP0000<000000?00003`00002`3`000=
0?l000X0_@003P3>000=0=h000030000003a0000l@0000L0l@00103o000U0?ooo`<000001@3oool0
100@410000000000000b<S8H0?ooo`00B@3oool00`0000008P0002800002028000800000102G0000
0`000000U`0009L0000=09L000800000602G0002000000P0gP0000<000000?00003`0000303`000<
0?l000`0_@003@3>000=0=h000030000003a0000l@0000L0l@00103o000V0?ooo`8000008@3oool0
04P0oooo0P000003028000030000002G0000U`0000@0U`0000<0000009L0002G00003`2G00000`00
0000U`0009L0000G09L000030000003N0000gP0000D0gP0000<000000?00003`00002`3`000=0?l0
00`0_@003P3>000=0=h000030000003a0000l@0000L0l@00103o000V0?ooo`030000003oool0oooo
01l0oooo000R0?ooo`030000003oool0oooo02<0oooo00<000000280000R00000P00000J09L00003
0000002G0000U`0000H000004@2G0002000000@0gP0000<000000?00003`00002`3`000>0?l000`0
_@003P3>000=0=h000030000003a0000l@0000L0l@00103o000V0?ooo`030000003oool0oooo01l0
oooo000R0?ooo`030000003oool0oooo0280oooo00@0000002800000000000007@2G0002000000<0
00a200<00000001I^`00FK/01000000?09L000040000003N0000gP00000000h0l0003@3o000>0;d0
00h0cP003@3N00000`000000l@000?4000070?4000@0o`009@3oool00`000000oooo0?ooo`0O0?oo
o`008P3oool00`000000oooo0?ooo`0Q0?ooo`0301T000000000000000/0U`0000<0000009L0002G
00003P2G00020000008000a200@00000000<@P00348000001P00FK/4000000d0U`0000<000000=h0
000000003@3`000;0?l000040:<0003o0000o`000>H000d0_@003P3>000=0=h000030000003a0000
l@0000L0l@00103o000U0?ooo`030000003oool0oooo01l0oooo000R0?ooo`030000003oool0oooo
0240oooo0P00000<09L000030000002G0000U`0000`0U`000P000003000<@P0500000000348000a2
000<@P0000001P00FK/01000000005Vk001I^`00FK/2000000/0U`000`00000=0?0000h0o`0000<0
X`000;d0002m0000302m000>0<h000d0gP0000<000000?40003a00001`3a00040?l002@0oooo00<0
00000?ooo`3oool07`3oool004D0oooo0P00000=09L000030000002G0000U`0000X0U`000P000000
1@0034800000000<@P003480000000<000a200<00000001I^`00FK/01000FK/00`00000005Vk001I
^`04001I^`030000002G0000U`0000D0U`000`00000309L000030000003`0000l00000T0l0002`3o
00000`2S0000o`000?l000020:<000030>H0002m0000_@0000/0_@003P3>000=0=h000030000003a
0000l@0000L0l@00103o000T0?ooo`030000003oool0oooo01l0oooo00150?ooo`030000002G0000
000000`0U`0000<0000009L0002G0000202G00020000008000a200D00000000<@P00348000a20000
0003000<@P0300000000FK/005Vk00@005Vk00<00000001I^`00FK/01000FK/3000000<0U`000P00
000709L000030000003`0000l00000L0l0003`3o00030:<000h0_@003P3>000=0=h000030000003a
0000l@0000L0l@00103o000R0?ooo`8000008@3oool00280oooo00<000000?ooo`3oool07`3oool0
1@000000U`0009L0002G0000000001@0U`000P000003000<@P0500000000348000a2000<@P000000
0`0034800`00000005Vk001I^`04001I^`0300000000FK/005Vk00@005Vk00L00000001I^`00FK/0
05Vk0000002G0000000000X0U`0000<000000?00003`00001P3`000;0?l000030:<0003o0000o`00
00@0X`003P2m000>0<h000d0gP0000<000000?40003a00001`3a00040?l002<0oooo00<000000?oo
o`3oool07`3oool00280oooo00<000000?ooo`3oool07P3oool00`000000U`0009L0000309L00080
0000402G000200000003000<@P00000000a2008000a200@00000000<@P00348000000P0034830000
00D005Vk00<00000001I^`00FK/01@00FK/00`00000005Vk001I^`02001I^`030000002G0000U`00
00X0U`0000<000000?00003`0000103`000>0?l000H0X`003P2m000>0<h000d0gP0000<000000?40
003a00001`3a00040?l00280oooo00<000000?ooo`3oool07`3oool00280oooo00<000000?ooo`3o
ool07@3oool00`000000U`0009L0000609L000030000002G0000U`0000H0U`0000<0000009L0002G
00000P2G00020000008000a200D00000000<@P00348000a200000003000<@P<000000`00F_h00`00
000005Vk001I^`02001I^`0300000000FK/005Vk00@005Vk00<00000001I^`00FK/01000FK/00`00
0000U`0009L0000:09L000030000003`0000l00000<0l0002`3o00000`2S0000o`000?l000060:<0
00h0_@003P3>000=0=h000030000003a0000l@0000L0l@00103o000R0?ooo`030000003oool0oooo
01l0oooo000R0?ooo`030000003oool0oooo01d0oooo00<0000009L0002G00001`2G00000`000000
U`0009L0000509L000030000002G0000U`0000<000000`0034801@00000000a2000<@P0034800000
008000a20P000006001JoP0400000000FK/005Vk000000L005Vk00<00000001I^`00FK/01000FK/2
000000`0U`0000@000000?00003`0000l0003P3o00080:<000h0_@003P3>000=0=h000030000003a
0000l@0000L0l@000`3o000200000200oooo00<000000?ooo`3oool07`3oool00480oooo00<00000
09L0002G0000202G0002000000D0U`0000<0000009L0000000000P3m00001000000000a2000<@P00
0003000<@P0300000000348000a2008000002000F_h3000000H005Vk00<00000001I^`00FK/01000
FK/01000000005Vk001I^`00000<09L000030000003`0000o`0000h0o`00202S000>0;d000h0cP00
3@3N00000`000000l@000?4000070?400080o`0000<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0O0?ooo`008@3oool00`000000oooo0?ooo`0N0?ooo`030000002G0000U`0000X0U`0000<0
000009L0002G00000P2G000200000080o@0000@00000000<@P00348000000`0034801000000000a2
000000000002001JoP0300000000F_h005[n00D005[n0`000006001I^`0300000000FK/005Vk00@0
05Vk00D00000001I^`00FK/005Vk0000000<09L000030000003o0000o`0000/0o`0000<000000:<0
002S0000202S000>0;d000h0cP003@3N00000`000000l@000?4000060?40008000008`3oool00`00
0000oooo0?ooo`0O0?ooo`008@3oool00`000000oooo0?ooo`0O0?ooo`030000002G0000U`0000X0
U`0000D0000009L00000000000000?l000020?d0000500000000348000a2000<@P0000000`003482
000000D005[n00<00000001JoP00F_h00P00F_h2000000<005[n00<00000001I^`00FK/00P00FK/0
0`00000005Vk001I^`04001I^`0300000000FK/005Vk008005Vk00<0000009L0002G00002P2G0000

0`000000o`000?l0000;0?l000030000002S0000X`0000P0X`003P2m000>0<h000d0gP0000<00000
0?40003a0000103a0002000002D0oooo00<000000?ooo`3oool07`3oool00240oooo00<000000?oo
o`3oool07`3oool00`000000U`0009L0000;09L000040000000I0000o`0000000080o@0000@00000
000<@P00348000000P003483000000L005[n00@00000001JoP00000000001P00F_h01000000005Vk
001I^`000006001I^`0300000000FK/005Vk00@005Vk00<0000009L0002G00002P2G00000`000000
o`000?l0000:0?l0000308`000000000X`0000T0X`003P2m000>0<h000d0gP0000@000000?40003a
0000l@000P00000V0?ooo`8000008@3oool00240oooo00<000000?ooo`3oool07`3oool00`000000
U`0009L0000;09L000060000003o0000o`000000003m000000000`003483000000<005[n00<00000
001JoP00F_h01000F_h3000000P005[n00<00000001I^`0000001P00FK/00`00000005Vk001I^`04
001I^`8000002`2G00000`000000o`000?l000090?l00080S00000<000000:<0002S0000202S000>
0;d000h0cP003@3N000010000000l@0000000000000Y0?ooo`800000803oool004<0oooo00<00000
09L0002G00002P2G00001`0000006@000?l0003m000000000?d0000000000P003482000000H005[n
00@00000001JoP00F_h005[n0P000003001JoP0300000000F_h005[n00D005[n0`000005001I^`03
00000000FK/005Vk00@005Vk00<00000044000000000302G00000`000000o`000?l000080?l000<0
S00000<000000:<0002S0000202S000>0;d000h0cP00303N0002000002/0oooo0P00000P0?ooo`00
@`3oool00`000000U`0009L0000:09L000030000003o0000o`0000<000000P003482000000P005[n
0`000006001JoP0300000000F_h005[n008005[n0P000003001JoP0300000000FK/005Vk008005Vk
00<00000001I^`00FK/01000FK/010000000@@0004400000000<09L000030000003o0000o`0000H0
o`00102<00000`000000X`000:<000080:<000h0_@003P3>000:0=h000800000;@3oool200000200
oooo000Q0?ooo`030000003oool0oooo0200oooo00<0000009L0002G00002@2G00001P000000o`00
0000003m00000000000<@PH000001@00F_h3000000P005[n10000006001JoP80000000<005Vk0000
0000FK/01@00FK/01@000000@@00044000110000000000`0U`0000<000000?l0003o00001P3o0005
08`000030000002S0000X`0000P0X`003P2m000>0<h000P0gP0000<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0N0?ooo`008@3oool00`000000oooo0?ooo`0Q0?ooo`030000002G0000U`00
00L0U`000P0000000`3o0000o@000?d00002000000D005[n0P0000000`00F_h00000000000020000
008005[n00<00000001JoP00F_h01@00F_h3000000P005[n0P000007001I^`05000000110000@@00
0440000000003@2G00000`000000o`000?l000040?l000H0S00000<000000:<0002S0000202S000>
0;d000h0cP001P3N000200000300oooo0P00000P0?ooo`008@3oool00`000000oooo0?ooo`0Q0?oo
o`030000002G0000U`0000H0U`0000<0000009L0000000000P3m00000`00000005[n001JoP07001J
oP8000001@00F_h30000008005[n0`000003001JoP0300000000F_h005[n00<005[n0P000002001J
oP0300000000FK/005Vk00<005Vk00@00000044000110000@@000P00000=09L000030000003o0000
o`0000<0o`00202<00000`000000X`000:<000070:<000030>H0002m0000_@0000/0_@003`3>0003
0=h000800000<P3oool200000200oooo000Q0?ooo`030000003oool0oooo0280oooo00<0000009L0
002G0000102G000010000000U`0009L0000000040?d0000300000000F_h005[n00@005[n00<00000
001JoP0000001`00F_h01000000005[n000000000002001JoP0300000000F_h005[n00<0000000<0
05[n0000000000001@00F_h20000008005Vk00<000000440001100000P1100000`000000U`0009L0
000=09L000030000003o0000o`000080o`00202<00000`000000X`000:<000080:<000h0_@003P3>
00020=h000030000003oool0oooo03<0oooo00<000000?ooo`3oool07P3oool004H0oooo00@00000
09L0002G0000U`000P00000509L000060000003m0000o@000?d0003/000000000`00F_h2000000<0
05[n0P000006001JoP0300000000F_h005[n00L005[n0P000002001JoP8000001@00F_h00`000000
05Vk00000002044000<000003`2G000010000000o`000?l0000I000:08`000030000002S0000X`00
00L0X`0000<0iP000;d0002m00002`2m000>0<h000<00000=03oool200000200oooo00170?ooo`03
0000002G0000000000P0U`0000<000000?d0003/00000P3/0003000000L005[n00<00000001JoP00
F_h00P000003001JoP0300000000F_h005[n00<005[n0P000002001JoP0500000000F_h005[n001J
oP0000000P00F_h400000003044000000000000000<0U`0000<0000009L0002G0000302G00001000
0000o`000?l0003o000:08`000030000002S0000X`0000P0X`003P2m000:0<h000<000000P00FK/2
000003@0oooo00<000000?ooo`3oool07P3oool00240oooo00<000000?ooo`3oool0903oool20000
00T0U`0000L000000>`0003/0000k0000000003/0000000000L005[n0`000006001JoP80000000<0
05[n0000000000001@00F_h2000000@005[n0P0000001011000000000000002G00040000000309L0
00000000U`0000`0U`0000<000000?l0003o0000302<00000`000000X`000:<000070:<000030>H0
002m0000_@0000/0_@00203>000200000005001I^`00000005Vk001I^`000000=P3oool00`000000
oooo0?ooo`0N0?ooo`008@3oool00`000000oooo0?ooo`0P0?ooo`800000103oool00`000000U`00
09L0000709L000030000003/0000k0000080k0000P000004001JoP8000000`00F_h00`00000005[n
001JoP04001JoP8000002@00F_h01@00000005[n000000000000@@00008000002@2G0003000000X0
U`0000<000000?l0003o0000302<00000`000000X`000:<000080:<000h0_@001@3>0002000000<0
05Vk0`00000g0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01@3oool00`000000U`0009L0000709L000080000003/0000k0000>`00000
0000g00000000000F_h2000000H005[n00@00000001JoP00F_h005[n0P000002001JoP0300000000
F_h005[n00H005[n0P0000000`11000000000000000<09L000040000002G0000U`0009L000@00000
0P2G0003000000030?l0002<0000S00000`0S00000<000000:<0002S00001`2S000>0;d00080cP00
0`0000001000FK/00000001I^`00FK/3000003P0oooo00<000000?ooo`3oool07P3oool00240oooo
00<000000?ooo`3oool0:03oool00`000000U`0009L0000709L000030000003/0000000000<0g000
0P000008001JoP<000001@00F_h2000000@005[n0P0000000`11000000000000000?09L000030000
002G0000U`0000P0U`000P00000208`0008000002P2<00000`000000X`000:<000080:<000d0_@00
0P000004001I^`0300000000FK/0000003/0oooo00<000000?ooo`3oool07P3oool003l0oooo0P00
000<0?ooo`030000002G0000U`0000H0U`000`0000050=`0000300000000F_h005[n00D005[n0P00
0008001JoP0500000000F_h000000000001100000P00000B09L000030000002G0000U`0000L0U`00
00<0000008`0002<00000`2<00000`000000S00008`00004000000@0S00000<000000:<0002S0000
1`2S000;0;d00080000000<005Vk00000000FK/00`00FK/2000003`0oooo00<000000?ooo`3oool0
7P3oool003h0oooo00<000000?ooo`3oool03@3oool00`000000U`0009L0000209L000<000000`2G
0002000000<0g00000<0c00000000000F_h00`00F_h20000008005[n00<00000001JoP00F_h01@00
F_h200000003044000000000000001D0U`0000<0000009L0002G00001@2G00000`000000S00008`0
000=08`000@000002@2S00080;d0008000001000FK/01000000005Vk00000000000n0?ooo`030000
003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04@3o
ool010000000U`0000000000000809L000030000003L0000c0000080c00000@00000001JoP000000
00001@00F_h00`00000005[n001JoP02001JoP80000000<0@@00000000000000602G00000`000000
U`0009L0000309L000030000002<0000S0000140S00000<000000:<0002S00000`0000040:<000L0
_@0000<000000016f`00FK/00`00FK/3000003h0oooo0`0000070?ooo`<0000000<0oooo09RHV000
00000P0000000`2HV9P0oooo0?ooo`0>0?ooo`008@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo01<0oooo0P00000:09L000<000000P3<00000`00000005[n001JoP06001JoP@00000
00<0@@000000000000006`2G00001@000000U`0009L0002G0000000001@0S00000<000000:<0002S
00001@2S000400000080_@000`0000020016f`0600000000FK/000000000003oool00000@@3oool0
0`000000oooo0?ooo`060?ooo`080000003oool0oooo0000002HV9P0oooo09RHV000000@0?ooo`00
803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo00<0000009L0002G0000
2P2G0004000000L005[n1@00000N09L000030000002G0000000001H0S00000<000000:<0002S0000
1`2S0000102m000000000000000000020016f`0300000000A]/0000000<00000@`3oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool03P3oool003H0
oooo00<000000?ooo`3oool06P3oool2000000d0U`000P000004001JoP80000000<0O`0000000000
00008@2G00000`000000S00008`0000E08`000030000002S0000X`0000L0X`000P0000040016f`80
0000103oool00`000000oooo00000002000003h0oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00h0oooo000e0?ooo`030000003oool0oooo01d0
oooo00<0000009L0002G00002`2G000200000003001JoP000000000000@000007`2G0002000001X0
S00000<000000:<0002S00000`2S00030000008004KK00@000000016f`00000000001`3oool01@00
0000oooo0?ooo`3oool000000080oooo1000000g0?ooo`8000001`3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07`3oool00`000000U`0009L0000<09L000030000002G0000U`0000@0U`0000<00000
09L0002G00006@2G0003000001`0S00000<000000:<0002S00000`0000040016f`<000002@3oool0
0`000000oooo0?ooo`0:0?ooo`@00000<P3oool00`000000oooo0?ooo`050?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool03@3oool2
000002D0oooo0P00000D09L0008000005`2G000200000080HP0000<0000008`0002<00006`2<0002
000000030016f`00000004KK008004KK0P00000<0?ooo`030000003oool0oooo00l0oooo1000000]
0?ooo`030000003oool0oooo00D0oooo00P000000?ooo`3oool0000009RHV03oool0V9RH00000100
oooo000P0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09`3oool00`000000U`00
09L0000C09L000030000002G0000U`000180U`000P000002068000040?l0001R00000000000001T0
S0000P0000040016f`0400000000A]/00000000000h0oooo00<000000?ooo`3oool05@3oool40000
0080oooo0`00000Q0?ooo`8000001P3oool01@0Q8B4000000?ooo`3oool0V9RH00<0000000<0V9RH
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0=`3oool2000001@0U`000P00000?09L0
00<000000P3oool3068000030?l0001R0000000001H0S000100000050016f`800000<@3oool00`00
0000oooo00000002000001/0oooo0`00000O0?ooo`00:`3oool2000002l0oooo0P00000D09L00003
0000002G0000U`0000X0U`000P0000060?ooo`@0HP0000<0000008`0002<00004P2<000200000004
01T00000A]/004KK0000008004KK0`00000h0?ooo`030000003oool0oooo00<000005P3oool20000
01l0oooo000Z0?ooo`030000003oool0oooo0340oooo0`00000B09L000030000002G0000U`0000L0
U`000P0000080?ooo`@0HP000P00000A08`00080000000<06@000016f`00A]/00`00A]/2000001D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`04000000l0oooo0P00000O0?ooo`00
803oool00`000000oooo0?ooo`0n0?ooo`8000004@2G0002000000@0U`000`00000:0?ooo`030=40
001R0000HP000080HP0000<0000008`0002<0000302<0005000000@004KK0P00000G0?ooo`030000
003oool0oooo0340oooo1000000;0?ooo`030000003oool0oooo01d0oooo000P0?ooo`030000003o
ool0oooo00<0oooo0P00000k0?ooo`8000004@2G000010000000U`0000000000000>0?ooo`<0HP00
00<0o`000000000000002`2<00020000000601T000000000oooo0?ooo`00000004KK0`00000I0?oo
o`030000003oool0oooo03L0oooo100000050?ooo`030000003oool0oooo01d0oooo000P0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0?@3oool6000000P0U`001@00000@0?ooo`D0
HP0000<0000008`0002<00001`2<00020000000301T000000000oooo00@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0m0?ooo`@000007`3oool00200oooo00<000000?ooo`000000
B03oool8000001H0oooo101R0002000000H0S0000`00001Q0?ooo`030000003oool0oooo00<00000
8@3oool00240oooo00<000000?ooo`3oool0I@3oool5068000040000002<0000S00008`000<00000
G`3oool00`000000oooo0?ooo`020?ooo`<00000903oool00200oooo10000000103oool000000000
0000001R0?ooo`@0HP0000D0000008`000000000000001T0000Z0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`0000000P00000W0?ooo`00:03oool00`000000oooo0?ooo`03000005`0oooo
0`1R0003000002d0oooo00<000000?ooo`3oool0<`3oool3000002X0oooo000^0?ooo`030000003o
ool0oooo00@00000EP3oool200000300oooo00<000000?ooo`3oool0;`3oool5000002`0oooo000g
0?ooo`<000000P3oool3000007h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`03
00000300oooo000o0?ooo`030000003oool0oooo00@00000Y03oool400000380oooo00180?ooo`<0
0000V`3oool00`000000oooo00000002000003D0oooo001=0?ooo`@000000P3oool3000006L0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`05000003L0oooo001F0?ooo`030000003o
ool0oooo00@00000H03oool00`000000oooo0?ooo`0M0?ooo`040000003oool0oooo0?ooo`@00000
>`3oool005h0oooo100000020?ooo`<00000EP3oool00`000000oooo0?ooo`0M0?ooo`D00000?P3o
ool006L0oooo00<000000?ooo`3oool00`00001_0?ooo`<00000@@3oool006d0oooo00<000000?oo
o`0000000`00001U0?ooo`@000005@3oool01@0@41000000000000000000V9RH02X0oooo001e0?oo
o`@000000P3oool300000400oooo00<000000?ooo`3oool04`3oool00`000000oooo000000020000
01/0oooo00<0V9RH0000003oool0:@3oool007h0oooo00<000000?ooo`3oool00`00000j0?ooo`03
0000003oool0oooo0180oooo0`00000O0?ooo`030000003oool0oooo02P0oooo00260?ooo`@00000
=03oool00`000000oooo0?ooo`0?0?ooo`@000008@3oool00`000000oooo0?ooo`0X0?ooo`00S03o
ool400000080oooo0P00000Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`00
000S0?ooo`0309RHV0000000oooo02T0oooo002D0?ooo`030000003oool0oooo00@00000;03oool0
10000000oooo0?ooo`3oool3000002<0oooo100000000`2HV9P0oooo0?ooo`0X0?ooo`00W@3oool4
00000080oooo0`00000Q0?ooo`@000009P3oool00`1gMgL0EEEE0?ooo`0/0?ooo`00YP3oool00`00
0000oooo00000002000001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020000
02X0oooo00@0410@000000000000<S8b:P3oool00:/0oooo00<000000?ooo`3oool01000000<0?oo
o`8000000P3oool3000001D0oooo00D0V9RH000000000000000009RHV0110?ooo`00]03oool40000
00040?ooo`000000000000000080oooo1@00000G0?ooo`050000002HV9P0oooo09RHV0000000@@3o
ool00;`0oooo00@000000?ooo`00000000006P3oool01@000000oooo0?ooo`3oool000000440oooo
003J0?ooo`050000003oool0oooo0?ooo`000000@@3oool00=X0oooo00D000000?ooo`3oool0oooo
000000110?ooo`00fP3oool01@000000oooo0?ooo`3oool000000440oooo003J0?ooo`050000002H
V9P0oooo09RHV0000000@@3oool00<T0oooo00D0410@000000000000000009RHV00<0?ooo`0509RH
V000000000000000002HV9P0@@3oool00<`0oooo00<0V9RH0000003oool0D@3oool00<d0oooo00<0
00000?ooo`3oool0D03oool00<40oooo1`0000050?ooo`030000003oool0oooo0500oooo003<0?oo
o`0309RHV0000000oooo0540oooo00390?ooo`@0000000<0V9RH0?ooo`3oool0D03oool00<T0oooo
00<0MgMg05EEE@3oool0E03oool00<X0oooo00@0410@000000000000<S8bDP3oool00?l0oooo8@3o
ool00?l0oooo8@3oool00?l0oooo8@3oool00=P0oooo0`0000000`3oool0MgMg0000000200000400
oooo003I0?ooo`0609RHV01gMgL0oooo0?ooo`0Q8B40ZJVY@@3oool00=X0oooo00@0EEEE09RHV01g
MgL0IVIV@P3oool00=X0oooo00<0k^k^024Q8@0b<S80@`3oool00=X0oooo00<0k^k^010@400b<S80
@`3oool00=X0oooo00@0IVIV07MgM`2YZJT0IVIV@P3oool00=T0oooo00@0ZJVY024Q8@3oool0oooo
0P2HV9P00`3^k^h0oooo0?ooo`0n0?ooo`00f03oool30000000307MgM`3oool0<S8b0080000000<0
^[Zj0?ooo`3oool0?@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo
8@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}}]
}, Open  ]],

Cell[BoxData[
    \(\(radObjDrwQD3D[m];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute the magnetic field", "Section"],

Cell["\<\
The computed field and field integral are the expected quadratic \
dependence vs transverse coordinate.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = Object /. f[seg[3, 3, 3], \(-4.5\)];\)\), "\[IndentingNewLine]", 
    \(\(Plot[radFld[m, "\<by\>", {0, 0, z}], {z, \(-2\), 2}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0147151 249.68 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .13956 -36 -4.5 ]
[.4875 .13956 0 4.5 ]
[.4875 .26439 -30 -4.5 ]
[.4875 .26439 0 4.5 ]
[.4875 .38923 -36 -4.5 ]
[.4875 .38923 0 4.5 ]
[.4875 .51407 -30 -4.5 ]
[.4875 .51407 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-1)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13956 m
.50625 .13956 L
s
[(0.0005)] .4875 .13956 1 0 Mshowa
.5 .26439 m
.50625 .26439 L
s
[(0.001)] .4875 .26439 1 0 Mshowa
.5 .38923 m
.50625 .38923 L
s
[(0.0015)] .4875 .38923 1 0 Mshowa
.5 .51407 m
.50625 .51407 L
s
[(0.002)] .4875 .51407 1 0 Mshowa
.125 Mabswid
.5 .03968 m
.50375 .03968 L
s
.5 .06465 m
.50375 .06465 L
s
.5 .08962 m
.50375 .08962 L
s
.5 .11459 m
.50375 .11459 L
s
.5 .16452 m
.50375 .16452 L
s
.5 .18949 m
.50375 .18949 L
s
.5 .21446 m
.50375 .21446 L
s
.5 .23943 m
.50375 .23943 L
s
.5 .28936 m
.50375 .28936 L
s
.5 .31433 m
.50375 .31433 L
s
.5 .3393 m
.50375 .3393 L
s
.5 .36427 m
.50375 .36427 L
s
.5 .4142 m
.50375 .4142 L
s
.5 .43917 m
.50375 .43917 L
s
.5 .46414 m
.50375 .46414 L
s
.5 .48911 m
.50375 .48911 L
s
.5 .53904 m
.50375 .53904 L
s
.5 .56401 m
.50375 .56401 L
s
.5 .58898 m
.50375 .58898 L
s
.5 .61395 m
.50375 .61395 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .51072 L
.10458 .41906 L
.14415 .3417 L
.18221 .27519 L
.22272 .21279 L
.26171 .16087 L
.30316 .11437 L
.34309 .078 L
.3815 .05079 L
.40095 .03992 L
.42237 .03019 L
.44268 .02315 L
.45178 .02068 L
.46172 .01848 L
.4671 .01749 L
.4721 .01671 L
.47727 .01604 L
.48196 .01555 L
.48658 .01518 L
.4887 .01504 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .01578 L
.5293 .01692 L
.53882 .01858 L
.54906 .0209 L
.56016 .02401 L
.58032 .03128 L
.60019 .0405 L
.62123 .05247 L
.65912 .07979 L
.69946 .11704 L
.73829 .16086 L
.77956 .21608 L
Mistroke
.81932 .27772 L
.85757 .34489 L
.89827 .42495 L
.93745 .51047 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`003@3oool5000003d0oooo0`00001l0?ooo`<00000?@3oool5000000d0oooo000>0?ooo`04
0000003oool0oooo000003h0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0m0?oo
o`040000003oool0oooo000000d0oooo00070?ooo`D000000`3oool00`000000oooo0?ooo`0f0?oo
o`D000000`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03@3oool00100oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0303oool000d0oooo00D000000?ooo`3oool0
oooo0000000n0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0?03oool01@000000
oooo0?ooo`3oool0000000d0oooo000=0?ooo`050000003oool0oooo0?ooo`000000?@3oool20000
07d0oooo0P00000n0?ooo`050000003oool0oooo0?ooo`0000003@3oool000h0oooo0`00000o0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0?@3oool3000000h0oooo002?0?ooo`03
0000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo00070?ooool000004P0000080?oo
o`003@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo00000003000000L0oooo00<000000?ooo`3oool01@3oool6000000`0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0
oooo000=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0;@3oool6000000/0oooo
00<000000?ooo`3oool02P3oool300000340oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0<0?ooo`00N`3oool300000140oooo00<000000?ooo`3oool03@3oool4000007d0oooo001i
0?ooo`800000503oool00`000000oooo0?ooo`0A0?ooo`@00000N@3oool007L0oooo0P00000F0?oo
o`030000003oool0oooo01D0oooo0P00001g0?ooo`00M@3oool2000001P0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1d0?ooo`00L`3oool2000001X0oooo0P00000I0?ooo`800000
M03oool00740oooo0P00000L0?ooo`030000003oool0oooo01X0oooo0P00001b0?ooo`00L03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo0P00001`0?ooo`00KP3oool20000
01l0oooo00<000000?ooo`3oool07P3oool2000006h0oooo001]0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1[0?ooo`00J`3oool200000280oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1Z0?ooo`00J@3oool2000002@0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1Y0?ooo`00J03oool00`000000oooo0?ooo`0T
0?ooo`800000903oool2000006T0oooo001V0?ooo`8000009`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo06H0oooo001U0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`1U0?ooo`00H`3oool2000002X0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`1T0?ooo`00HP3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo02P0oooo0P00001T0?ooo`00H@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0H@3oool00600oooo00<000000?ooo`3oool0;03oool20000
02`0oooo00<000000?ooo`3oool0H03oool005l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo05l0oooo001N0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`1N0?ooo`00G@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0G@3oool005`0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05`0oooo001K0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1K0?oo
o`00FP3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0FP3oool005T0oooo00<000000?ooo`3oool0<`3oool2000003<0oooo00<000000?ooo`3oool0
F@3oool005T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo05P0oooo001H0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1H0?ooo`00E`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0E`3oool005H0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo05H0oooo001E0?ooo`030000003oool0oooo0180oooo
0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`800000103oool2000000<0oooo
0`0000050?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0E@3oool005@0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05@0oooo001C
0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`020?ooo`<00000>03oool00`000000oooo0?ooo`1C0?ooo`00D`3oool00`000000
oooo0?ooo`0C0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003o
ool0oooo01@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool000000?ooo`04000000D0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo0?ooo`0E0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo0500oooo001@0?ooo`030000003oool0oooo01L0oooo0P00000:0?ooo`80
0000103oool2000000@0oooo0P0000020?ooo`D00000103oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo04l0oooo001?0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`1>0?ooo`00CP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool0C@3oool004h0oooo00<000000?ooo`3oool0?P3oool2
000003l0oooo00<000000?ooo`3oool0C@3oool004d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo04`0oooo001<0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1;0?ooo`00B`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0BP3oool004X0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04X0oooo001:
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`19
0?ooo`00B@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0B03oool004P0oooo00<000000?ooo`3oool0A03oool2000004D0oooo00<000000?ooo`3o
ool0A`3oool004L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo04L0oooo00170?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`160?ooo`00AP3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0A@3oool004D0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00140?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`140?ooo`00@`3oool00`000000oooo
0?ooo`190?ooo`800000B@3oool00`000000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0@P3oool00480oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0480oooo00110?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`110?oo
o`00@@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0@03oool00400oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0400oooo000o0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo0?ooo`1=0?ooo`800000CP3oool0
0`000000oooo0?ooo`0n0?ooo`00?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0?P3oool003d0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo03d0oooo000m0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0l0?ooo`00?03oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0?03oool003`0oooo00<00000
0?ooo`3oool0<@3oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000@0oooo0P000003
0?ooo`<000001@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03/0oooo000k0?oo
o`030000003oool0oooo0340oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo03/0oooo000j0?ooo`030000003oool0oooo0380oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool0103oool300000540oooo00<000000?ooo`3oool0>P3oool003X0
oooo00<000000?ooo`3oool0<P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0>@3oool003T0oooo00<000000?ooo`3oool0<`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0>@3oool003P0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool2000000H0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0h0?ooo`00>03oool00`000000oooo0?ooo`0e0?oo
o`8000002P3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0=`3oool003L0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03H0oooo000f0?ooo`030000003o
ool0oooo05H0oooo0P00001G0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0e0?ooo`00=@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0=03oool003@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo03@0
oooo000d0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0c0?ooo`00<`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0
00000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo05X0oooo0P00001K0?oo
o`030000003oool0oooo0340oooo000b0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0a0?ooo`00<@3oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0<03oool00300oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0_0?ooo`00;`3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;P3oool002l0
oooo00<000000?ooo`3oool0G@3oool2000005h0oooo00<000000?ooo`3oool0;P3oool002h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02d0oooo
000^0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0/0?ooo`00;@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<00000
0?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo02/0oooo000/0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0H@3o
ool200000680oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02T0oooo000Z0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02P0oooo
000X0?ooo`030000003oool0oooo03l0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P00
00040?ooo`8000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0?P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1T0?oo
o`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0oooo03l0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`<00000I@3oool00`000000oooo0?oo
o`0V0?ooo`009`3oool00`000000oooo0?ooo`0o0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02H0
oooo000V0?ooo`030000003oool0oooo0400oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0oooo1000
00050?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool09@3oool002H0oooo00<00000
0?ooo`3oool0@03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo0480oooo
0P00000:0?ooo`800000103oool2000000@0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02@0oooo000T0?ooo`030000003o
ool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0S0?ooo`00903oool0
0`000000oooo0?ooo`1X0?ooo`800000J@3oool00`000000oooo0?ooo`0S0?ooo`008`3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08P3oool002<0
oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0280
oooo000R0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`0Q0?ooo`008P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool08@3oool00240oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`1[0?ooo`80
0000K@3oool00`000000oooo0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool07`3oool00200oooo00<000000?ooo`3oool0K03o
ool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo01l0oooo000O0?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`00
0000oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool07P3oool001h0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01d0
oooo000N0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`0M0?ooo`007@3oool00`000000oooo0?ooo`1_0?ooo`800000L03oool00`000000oooo0?oo
o`0L0?ooo`007@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo01`0oooo000L0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool06`3oool001/0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0
oooo0740oooo0P00001b0?ooo`030000003oool0oooo01X0oooo000J0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06@3oool001X0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01T0oooo
000I0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0H0?ooo`006@3oool00`000000oooo0?ooo`1D0?ooo`800000103oool00`000000oooo0?ooo`03
0?ooo`800000103oool200000080oooo1@0000040?ooo`030000003oool0oooo07<0oooo00<00000
0?ooo`3oool0603oool001P0oooo00<000000?ooo`3oool0E03oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool05`3oool001P0oooo
00<000000?ooo`3oool0E03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`<00000M03oool0
0`000000oooo0?ooo`0G0?ooo`005`3oool00`000000oooo0?ooo`1E0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0F0?ooo`005`3o
ool00`000000oooo0?ooo`1E0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01H0oooo000F0?ooo`030000003oool0oooo
05H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0E`3oool2000000X0oooo
0P0000040?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool05@3oool001D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo07L0oooo0P00001h0?oo
o`030000003oool0oooo01@0oooo000D0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool04`3oool001<0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003oool0
oooo07T0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0B0?ooo`004P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool04@3oool00180
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0140
oooo000B0?ooo`030000003oool0oooo07X0oooo0P00001k0?ooo`030000003oool0oooo0140oooo
000A0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`0@0?ooo`004@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo07/0oooo00<00000
0?ooo`3oool0403oool00100oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo00l0oooo000@0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0?0?ooo`003`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00h0oooo000?0?ooo`030000003oool0
oooo07d0oooo0P00001n0?ooo`030000003oool0oooo00h0oooo000>0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool03@3oool000d0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00`0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`800000S`3oool008l0oooo00<000000?ooo`3oool0SP3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.21006, -0.000182236, \
0.0154011, 1.46865*^-5}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(y = 0;\)\), "\[IndentingNewLine]", 
    \(\(Plot[
        radFldInt[
          m, "\<inf\>", "\<iby\>", {1, y, z}, {\(-1\), y, z}], {z, \(-2\), 
          2}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0147151 27.8533 [
[.02381 .00222 -9.125 -14 ]
[.02381 .00222 9.125 0 ]
[.2619 .00222 -9.125 -14 ]
[.2619 .00222 9.125 0 ]
[.7381 .00222 -5 -14 ]
[.7381 .00222 5 0 ]
[.97619 .00222 -5 -14 ]
[.97619 .00222 5 0 ]
[.4875 .15398 -31 -7 ]
[.4875 .15398 0 7 ]
[.4875 .29325 -25 -7 ]
[.4875 .29325 0 7 ]
[.4875 .43252 -31 -7 ]
[.4875 .43252 0 7 ]
[.4875 .57178 -25 -7 ]
[.4875 .57178 0 7 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
gsave
.02381 .00222 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .15398 m
.50625 .15398 L
s
gsave
.4875 .15398 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.005) show
1.000 setlinewidth
grestore
.5 .29325 m
.50625 .29325 L
s
gsave
.4875 .29325 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
1.000 setlinewidth
grestore
.5 .43252 m
.50625 .43252 L
s
gsave
.4875 .43252 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.015) show
1.000 setlinewidth
grestore
.5 .57178 m
.50625 .57178 L
s
gsave
.4875 .57178 -86 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .04257 m
.50375 .04257 L
s
.5 .07042 m
.50375 .07042 L
s
.5 .09828 m
.50375 .09828 L
s
.5 .12613 m
.50375 .12613 L
s
.5 .18184 m
.50375 .18184 L
s
.5 .20969 m
.50375 .20969 L
s
.5 .23754 m
.50375 .23754 L
s
.5 .2654 m
.50375 .2654 L
s
.5 .3211 m
.50375 .3211 L
s
.5 .34896 m
.50375 .34896 L
s
.5 .37681 m
.50375 .37681 L
s
.5 .40466 m
.50375 .40466 L
s
.5 .46037 m
.50375 .46037 L
s
.5 .48822 m
.50375 .48822 L
s
.5 .51608 m
.50375 .51608 L
s
.5 .54393 m
.50375 .54393 L
s
.5 .59964 m
.50375 .59964 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .51148 L
.10458 .4203 L
.14415 .34314 L
.18221 .27662 L
.22272 .2141 L
.26171 .16196 L
.30316 .11519 L
.34309 .07856 L
.3815 .05113 L
.40095 .04016 L
.42237 .03034 L
.44268 .02323 L
.45178 .02074 L
.46172 .01852 L
.4671 .01752 L
.4721 .01673 L
.47727 .01605 L
.48196 .01556 L
.48658 .01518 L
.4887 .01505 L
.49093 .01493 L
.49332 .01483 L
.49438 .0148 L
.49552 .01477 L
.49675 .01474 L
.49789 .01473 L
.49859 .01472 L
.49925 .01472 L
.50049 .01472 L
.50163 .01472 L
.50286 .01474 L
.50401 .01476 L
.50508 .01478 L
.50754 .01486 L
.51014 .01498 L
.51268 .01513 L
.51504 .0153 L
.5204 .01579 L
.5293 .01694 L
.53882 .01862 L
.54906 .02096 L
.56016 .0241 L
.58032 .03144 L
.60019 .04075 L
.62123 .05283 L
.65912 .08037 L
.69946 .11788 L
.73829 .16196 L
.77956 .21739 L
Mistroke
.81932 .27915 L
.85757 .34632 L
.89827 .42617 L
.93745 .51124 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00503oool4
000000030;Zj^P3oool0oooo03X0oooo0`00001f0?ooo`<00000>P3oool4000000030;Zj^P3oool0
oooo00h0oooo000D0?ooo`050<c<c03^k^h0oooo0<c<c01EEED0?@3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo03T0oooo00D0c<c<0>k^kP3oool0c<c<05EEE@0@0?ooo`005@3oool0
0`3<c<`0k^k^0?ooo`0n0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0>P3oool0
0`3<c<`0k^k^0?ooo`0A0?ooo`00303oool7000000<0oooo00<0ZJVY0>k^kP3oool0<P3oool70000
00@0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0k0?ooo`030:VYZ@3^k^h0oooo
0100oooo000F0?ooo`030=gMg@1VIVH0oooo03d0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0k0?ooo`030=gMg@1VIVH0oooo0100oooo000D0?ooo`0407MgM`3oool0oooo000003h0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`0407MgM`3oool0oooo0000
0140oooo000D0?ooo`040000002HV9P0V9RH000003h0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0i0?ooo`040000002HV9P0V9RH00000140oooo000D0?ooo`0409RHV00000000000
09RHV3d0oooo00<08B4Q0000003oool0MP3oool00`0Q8B4000000?ooo`0j0?ooo`0409RHV0000000
000009RHV140oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo
08d0oooo002@0?ooo`030000003oool0oooo08d0oooo002@0?ooo`030000003oool0oooo08d0oooo
000<0?ooool000002`00000:0?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool6000000L0oooo00<000000?ooo`3oool0203oool3
000000`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00l0oooo000B0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0;03oool30000
00d0oooo00<000000?ooo`3oool02P3oool6000002`0oooo00<000000?ooo`3oool0?03oool00`00
0000oooo0?ooo`0?0?ooo`00O@3oool300000100oooo00<000000?ooo`3oool0403oool3000007X0
oooo001k0?ooo`8000004`3oool00`000000oooo0?ooo`0C0?ooo`800000N03oool007T0oooo0P00
000E0?ooo`030000003oool0oooo01D0oooo0P00001f0?ooo`00M`3oool2000001L0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1c0?ooo`00M@3oool2000001T0oooo0P00000I0?oo
o`800000L`3oool007<0oooo0P00000K0?ooo`030000003oool0oooo01X0oooo0P00001a0?ooo`00
LP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
KP3oool00700oooo0P00000N0?ooo`030000003oool0oooo01d0oooo0P00001^0?ooo`00K`3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0J`3oool0
06d0oooo0P00000Q0?ooo`030000003oool0oooo0200oooo0P00001[0?ooo`00K03oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo0280oooo0P00001Y0?ooo`00J`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0IP3oool006T0oooo0P00
000U0?ooo`8000009P3oool2000006H0oooo001X0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`1S0?ooo`00IP3oool2000002P0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`1R0?ooo`00I@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool0H@3oool006@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0600oooo001S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1O0?ooo`00H@3oool2
000002d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1N0?ooo`00H03oool00`00
0000oooo0?ooo`0]0?ooo`800000;P3oool00`000000oooo0?ooo`1M0?ooo`00G`3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0G03oool005h0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05/0oooo
001M0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`1J0?ooo`00G03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0F@3oool005`0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo05P0oooo001K0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`1H0?ooo`00FP3oool00`000000oooo0?ooo`0c0?ooo`800000
=03oool00`000000oooo0?ooo`1G0?ooo`00F@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0EP3oool005P0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo05D0oooo001G0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1D0?ooo`00EP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0D`3oool005H0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo05<0oooo
001E0?ooo`030000003oool0oooo01P0oooo00D0V9RH000000000000000009RHV0020?ooo`03038b
<P3oool0V9RH00<0000000<0V9RH0?ooo`2HV9P00`0000000`2HV9P0oooo010@40030000000309RH
V03oool0oooo00@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1B0?ooo`00E03o
ool00`000000oooo0?ooo`0I0?ooo`050000002HV9P0oooo09RHV0000000103oool02`000000V9RH
0?ooo`2HV9P000000?ooo`000000V9RH0?ooo`2HV9P0000000@0oooo00<0V9RH0000003oool01@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0540oooo001C0?ooo`030000003oool0
oooo01X0oooo00D000000?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool3000003X0
oooo00<000000?ooo`3oool0D03oool00580oooo00<000000?ooo`3oool06`3oool01@000000oooo
0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0C`3oool00540oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0
000000@0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0
0P3oool00`2HV9P000000?ooo`050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
CP3oool00540oooo00<000000?ooo`3oool0703oool01@000000oooo0?ooo`3oool0000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`0000000`0000000`2H
V9P0oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0CP3oool00500
oooo00<000000?ooo`3oool07@3oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00h0000009RH
V03oool0V9RH0000003oool0000009RHV03oool0V9RH0000003oool0MgMg05EEE@T0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`1=0?ooo`00C`3oool00`000000oooo0?ooo`0N0?oo
o`0509RHV000000000000000002HV9P0103oool01`2HV9P00000000000000000V9RH0?ooo`2HV9P0
0`000000102HV9P0oooo0?ooo`0@410200000003038b<P3oool0oooo00@0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`1<0?ooo`00CP3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0B`3oool004h0oooo00<000000?ooo`3oool0?`3o
ool200000440oooo00<000000?ooo`3oool0BP3oool004d0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo04X0oooo001<0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`190?ooo`00C03oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0B03oool004/0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04L0oooo
001:0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`170?ooo`00B@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool0AP3oool004T0oooo00<000000?ooo`3oool0A03oool2000004H0oooo00<000000?oo
o`3oool0A@3oool004P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo04@0oooo00170?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`130?ooo`00A`3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0@`3oool004H0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo0480oooo00150?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`110?ooo`00A@3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0@@3oool004@0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0400oooo
00130?ooo`030000003oool0oooo04X0oooo0P00001<0?ooo`030000003oool0oooo03l0oooo0013
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0o
0?ooo`00@P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0?P3oool00440oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo03d0oooo00100?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0m0?ooo`00@03oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0?03oool003l0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03`0oooo000n0?ooo`030000003oool0oooo
04l0oooo0P00001@0?ooo`030000003oool0oooo03/0oooo000n0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0j0?ooo`00?@3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0>P3oool003`0oooo00<0
00000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo03T0oooo000l
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0h
0?ooo`00>`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0>03oool003/0oooo00<000000?ooo`3oool0>03oool01@2HV9P00000000000000000V9RH
0080oooo00<0<S8b0?ooo`2HV9P00`000000102HV9P0oooo0?ooo`3oool3000000H0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0g0?ooo`00>P3oool00`000000oooo0?ooo`0i0?oo
o`050000002HV9P0oooo09RHV0000000103oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03L0oooo000i
0?ooo`030000003oool0oooo03X0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`050?ooo`<00000E03oool00`000000oooo
0?ooo`0f0?ooo`00>@3oool00`000000oooo0?ooo`0j0?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo03D0oooo000h0?ooo`030000003oool0oooo03/0oooo
00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0=@3oool003P0
oooo00<000000?ooo`3oool0>`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0d0?ooo`00=`3oool00`000000oooo0?ooo`0l0?ooo`050000002HV9P0oooo
09RHV0000000103oool01@000000V9RH0?ooo`2HV9P0000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03@0oooo000g0?ooo`030000003oool0
oooo03`0oooo00D0V9RH000000000000000009RHV0040?ooo`0509RHV000000000000000002HV9P0
0`3oool00`0Q8B4000000?ooo`060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
<`3oool003H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo03<0oooo000f0?ooo`030000003oool0oooo05L0oooo0P00001I0?ooo`030000003oool0
oooo0380oooo000e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0b0?ooo`00=03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0<@3oool003@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo0300oooo000c0?ooo`030000003oool0oooo05X0oooo00<0

00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0`0?ooo`00<`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0;`3oool00380oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02l0oooo000b0?ooo`03
0000003oool0oooo05/0oooo0P00001M0?ooo`030000003oool0oooo02h0oooo000a0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0^0?ooo`00<@3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0;@3o
ool00300oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo02d0oooo000`0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0/0?ooo`00;`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0;03oool002l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo02/0oooo000^0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`0[0?ooo`00;P3oool00`000000oooo0?ooo`1O
0?ooo`800000H@3oool00`000000oooo0?ooo`0Z0?ooo`00;@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0:P3oool002d0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02T0oooo000/0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0X0?ooo`00;03o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0:03o
ool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo02L0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0W0?ooo`00:P3oool00`000000oooo0?ooo`1S0?ooo`800000I@3oool00`000000
oooo0?ooo`0V0?ooo`00:P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool09P3oool002T0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo02D0oooo000Y0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`0U0?ooo`00:03oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0903oool002P0oooo00<000000?ooo`3o
ool0A@3oool01@2HV9P00000000000000000V9RH0080oooo00<0<S8b0?ooo`2HV9P00`000000102H
V9P0oooo0?ooo`3oool3000000030?ooo`0@410000000080000000<0V9RH0?ooo`3oool0103oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02@0oooo000W0?ooo`030000003oool0oooo
04H0oooo00D0000009RHV03oool0V9RH000000040?ooo`050000002HV9P0oooo09RHV0000000103o
ool00`000000oooo0?ooo`030?ooo`0309RHV0000000oooo00D0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0S0?ooo`009`3oool00`000000oooo0?ooo`160?ooo`050000003oool0
oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`<00000I`3oool00`000000oooo0?ooo`0S0?ooo`009P3o
ool00`000000oooo0?ooo`170?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool08P3oool002H0oooo00<000000?ooo`3oool0
A`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?oo
o`030000003oool0oooo00<0oooo00<0V9RH0000003oool01@3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo0280oooo000U0?ooo`030000003oool0oooo04P0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`04
0000000309RHV03oool0oooo00@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0Q
0?ooo`009@3oool00`000000oooo0?ooo`180?ooo`050000002HV9P0oooo09RHV0000000103oool0
1@000000V9RH0?ooo`2HV9P0000000@0oooo00D000000?ooo`3oool0MgMg05EEE@090?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool08@3oool002D0oooo00<000000?ooo`3oool0B03o
ool01@2HV9P00000000000000000V9RH00@0oooo00D0V9RH000000000000000009RHV0030?ooo`03
024Q8@000000oooo0080oooo00@0410@000000000000<S8b1P3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0200oooo000T0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`0P0?ooo`00903oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo06X0oooo00<000000?ooo`3oool0803oool002<0oooo00<000000?ooo`3oool0JP3o
ool2000006`0oooo00<000000?ooo`3oool07`3oool002<0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01l0oooo000R0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0N0?ooo`008P3oool00`000000
oooo0?ooo`1[0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool07P3oool00240oooo
00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01d0oooo
000Q0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0M0?ooo`00803oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0703oool00200oooo00<000000?ooo`3oool0K@3oool2000006l0oooo00<000000?oo
o`3oool0703oool00200oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo01/0oooo000O0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0K0?ooo`007`3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool06`3oool001h0oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01X0oooo000N0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0J0?ooo`007@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool06@3oool001d0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01T0oooo
000L0?ooo`030000003oool0oooo0740oooo0P00001c0?ooo`030000003oool0oooo01P0oooo000L
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0H
0?ooo`006`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool0603oool001/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo01L0oooo000K0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
L`3oool00`000000oooo0?ooo`0G0?ooo`006P3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo07@0oooo00<000000?ooo`3oool05P3oool001X0oooo00<000000?ooo`3oool0L`3oool0
0`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo
07@0oooo0P00001e0?ooo`030000003oool0oooo01H0oooo000I0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0E0?ooo`00603oool00`000000oooo
0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool05@3oool001P0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01@0oooo000G
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0D
0?ooo`005`3oool00`000000oooo0?ooo`1L0?ooo`0509RHV000000000000000002HV9P00P3oool0
0`0b<S80oooo09RHV0030000000309RHV03oool0000000<0000000<0^[Zj0?ooo`3oool0103oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01@0oooo000G0?ooo`030000003oool0oooo
05`0oooo00D0000009RHV03oool0V9RH000000040?ooo`0;0000002HV9P0oooo09RHV0000000oooo
0<c<c03^k^h0oooo0<c<c01EEED01P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
01<0oooo000F0?ooo`030000003oool0oooo05d0oooo00D000000?ooo`3oool0oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`3<c<`0k^k^0?ooo`070?ooo`<00000M`3oool0
0`000000oooo0?ooo`0C0?ooo`005P3oool00`000000oooo0?ooo`1M0?ooo`050000003oool0oooo
0?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<0ZJVY0>k^kP3oool01P3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0180oooo000E0?ooo`030000003oool0
oooo05h0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`3MgMd0IVIV0?ooo`060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
4P3oool001D0oooo00<000000?ooo`3oool0GP3oool01@000000oooo0?ooo`3oool0000000@0oooo
00L000000?ooo`3oool0oooo0000003oool0MgMg0080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo0180oooo000D0?ooo`030000003oool0oooo05l0
oooo00D0000009RHV03oool0V9RH000000040?ooo`070000002HV9P0oooo09RHV0000000oooo0000
000209RHV0030000003oool0oooo00D0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0A0?ooo`00503oool00`000000oooo0?ooo`1O0?ooo`0509RHV000000000000000002HV9P0103o
ool01`2HV9P00000000000000000V9RH0?ooo`2HV9P00P0000000`2HV9P0oooo0?ooo`050?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool04@3oool001@0oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0100oooo000C0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0@0?ooo`004`3oool0
0`000000oooo0?ooo`1j0?ooo`800000N`3oool00`000000oooo0?ooo`0@0?ooo`004P3oool00`00
0000oooo0?ooo`1k0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool03`3oool00900
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool0S@3oool00900oooo00<0
00000?ooo`3oool0S@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.30031, -0.0023484, \
0.0158738, 0.000135692}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sextupole Strength  vs Current density", "Section"],

Cell["\<\
We shall now make use of the \"Listable\" attribute of the function f[],  to \
compute the strength of the sextupole for several values of the current \
density.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(w = {6, 3, 
          6};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ Magnet\ dimensions\ *) \), "\n", 
    \(\(g = 
        12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Free\ radius\ of\ the\ sextupole\ *) \), "\n", 
    \(\(n = 
        seg[2, 2, 
          2];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \  (*\ Segmentation\ Parameter\ *) \), "\n", 
    \(\(curdens = {1, 1.5, 2, 3, 4, 7, 
          10};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Current\ density\ in\ the\ coil\ *) \[IndentingNewLine]\
\[IndentingNewLine]\), "\n", 
    \(\(radUtiDelAll[];\)\), "\n", 
    \(pb = f[n, curdens]\), "\n", 
    \(ib = \((Sext /. pb)\)/curdens\), "\n", 
    \(ListPlot[Transpose[{curdens, ib/ib[\([1]\)]}], PlotJoined \[Rule] True, 
      Frame \[Rule] True]\)}], "Input"],

Cell[BoxData[
    \({{Segm \[Rule] seg[2, 2, 2], Cur \[Rule] 1, Obj \[Rule] 29, 
        Solv \[Rule] {0.00008148471332331812`, 0.02510535629591826`, 
            0.00002506729683946464`, 14}, 
        Sext \[Rule] 0.0012171792778950235`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 1.5`, Obj \[Rule] 62, 
        Solv \[Rule] {0.00009311994884386202`, 0.03781859458781439`, 
            0.00003776565192030793`, 15}, 
        Sext \[Rule] 0.0018247566275439741`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 2, Obj \[Rule] 95, 
        Solv \[Rule] {0.00009496589247212226`, 0.0505894661799095`, 
            0.00005052693756316422`, 16}, 
        Sext \[Rule] 0.0024320178022067757`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 3, Obj \[Rule] 128, 
        Solv \[Rule] {0.00008448021739424114`, 0.07622073968424586`, 
            0.00007616253708419971`, 18}, 
        Sext \[Rule] 0.00364613747551418`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 4, Obj \[Rule] 161, 
        Solv \[Rule] {0.00008736073211207264`, 0.10177619244521005`, 
            0.00010176589595125233`, 19}, 
        Sext \[Rule] 0.004860733413309545`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 7, Obj \[Rule] 194, 
        Solv \[Rule] {0.00009322915428933086`, 0.1784443061497583`, 
            0.000178988306517592`, 21}, 
        Sext \[Rule] 0.008504519221035572`}, {Segm \[Rule] seg[2, 2, 2], 
        Cur \[Rule] 10, Obj \[Rule] 227, 
        Solv \[Rule] {0.00008271653913696496`, 0.255167198424783`, 
            0.00025720744401756313`, 23}, 
        Sext \[Rule] 0.012147903416781309`}}\)], "Output"],

Cell[BoxData[
    \({0.0012171792778950235`, 0.0012165044183626494`, 
      0.0012160089011033878`, 0.0012153791585047266`, 0.0012151833533273863`, 
      0.001214931317290796`, 0.001214790341678131`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0820106 0.10582 -299.294 299.898 [
[.12963 -0.0125 -3 -9 ]
[.12963 -0.0125 3 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.55291 -0.0125 -3 -9 ]
[.55291 -0.0125 3 0 ]
[.76455 -0.0125 -3 -9 ]
[.76455 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00352 -30 -4.5 ]
[-0.0125 .00352 0 4.5 ]
[-0.0125 .15347 -36 -4.5 ]
[-0.0125 .15347 0 4.5 ]
[-0.0125 .30342 -30 -4.5 ]
[-0.0125 .30342 0 4.5 ]
[-0.0125 .45337 -36 -4.5 ]
[-0.0125 .45337 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12963 0 m
.12963 .00625 L
s
[(2)] .12963 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(4)] .34127 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(6)] .55291 -0.0125 0 1 Mshowa
.76455 0 m
.76455 .00625 L
s
[(8)] .76455 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.18254 0 m
.18254 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.5 0 m
.5 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00352 m
.00625 .00352 L
s
[(0.998)] -0.0125 .00352 1 0 Mshowa
0 .15347 m
.00625 .15347 L
s
[(0.9985)] -0.0125 .15347 1 0 Mshowa
0 .30342 m
.00625 .30342 L
s
[(0.999)] -0.0125 .30342 1 0 Mshowa
0 .45337 m
.00625 .45337 L
s
[(0.9995)] -0.0125 .45337 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03351 m
.00375 .03351 L
s
0 .0635 m
.00375 .0635 L
s
0 .09349 m
.00375 .09349 L
s
0 .12348 m
.00375 .12348 L
s
0 .18346 m
.00375 .18346 L
s
0 .21345 m
.00375 .21345 L
s
0 .24344 m
.00375 .24344 L
s
0 .27343 m
.00375 .27343 L
s
0 .33341 m
.00375 .33341 L
s
0 .3634 m
.00375 .3634 L
s
0 .39339 m
.00375 .39339 L
s
0 .42338 m
.00375 .42338 L
s
0 .48336 m
.00375 .48336 L
s
0 .51335 m
.00375 .51335 L
s
0 .54334 m
.00375 .54334 L
s
0 .57333 m
.00375 .57333 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12963 .61178 m
.12963 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.76455 .61178 m
.76455 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.18254 .61428 m
.18254 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.28836 .61428 m
.28836 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.81746 .61428 m
.81746 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.02381 .61428 m
.02381 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00352 m
1 .00352 L
s
.99375 .15347 m
1 .15347 L
s
.99375 .30342 m
1 .30342 L
s
.99375 .45337 m
1 .45337 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03351 m
1 .03351 L
s
.99625 .0635 m
1 .0635 L
s
.99625 .09349 m
1 .09349 L
s
.99625 .12348 m
1 .12348 L
s
.99625 .18346 m
1 .18346 L
s
.99625 .21345 m
1 .21345 L
s
.99625 .24344 m
1 .24344 L
s
.99625 .27343 m
1 .27343 L
s
.99625 .33341 m
1 .33341 L
s
.99625 .3634 m
1 .3634 L
s
.99625 .39339 m
1 .39339 L
s
.99625 .42338 m
1 .42338 L
s
.99625 .48336 m
1 .48336 L
s
.99625 .51335 m
1 .51335 L
s
.99625 .54334 m
1 .54334 L
s
.99625 .57333 m
1 .57333 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.12963 0 m
.12963 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.07672 .43704 L
.12963 .31495 L
.23545 .15979 L
.34127 .11155 L
.65873 .04945 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00A03oool500000340oooo0`00000a0?ooo`<00000<@3oool3000002h0oooo0`0000040?oo
o`800000103oool004D0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0?ooo`0_0?oo
o`050000003oool0oooo0?ooo`000000;`3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00AP3oool00`000000oooo0?oo
o`0_0?ooo`D00000<03oool01@000000oooo0?ooo`3oool0000002l0oooo00D000000?ooo`3oool0
oooo0000000^0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool004L0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000a0?ooo`@00000<@3oool30000
02l0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`00A03oool01@00
0000oooo0?ooo`3oool000000300oooo00<000000?ooo`000000<@3oool00`000000oooo0?ooo`0a
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo00140?ooo`050000003oool0oooo0?ooo`000000<@3oool200000380oooo
00<000000?ooo`3oool0<03oool01@000000oooo0?ooo`3oool0000002d0oooo0P0000040?ooo`04
0000003oool0oooo000000<0oooo00150?ooo`<00000<`3oool00`000000oooo0?ooo`0a0?ooo`80
0000<@3oool3000002l0oooo00<000000?ooo`3oool00`3oool2000000@0oooo003o0?ooob40oooo
003o0?ooob40oooo00080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`800000103oool2
000000@0oooo0`00003n0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`3k0?ooo`001`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`020?ooooP000000@3oool000L0oooo00@000000?ooo`3oool00000203o
ool400000080oooo100000020?ooo`<000001@3oool2000000<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool200000040oooo00070?ooo`040000003oool0oooo000000L0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`40
00000@3oool000L0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool000P0oooo0P0000090?oo
o`<000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0b@3oool6000000D0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0;l0oooo2P00000;0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`2f0?ooo`T000005@3oool100000040oooo000W0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0[03oool:000001h0oooo0@0000010?ooo`009`3oool2
000001h0oooo00<000000?ooo`3oool0XP3oool:000002L0oooo0P0000010?ooo`009`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo09P0oooo2P00000b0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`2?0?ooo`T00000?03oool100000040
oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0Q@3oool:000004D0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo07h0oooo1`00
001?0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1i
0?ooo`D00000EP3oool100000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0M03oool5000005/0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06l0oooo1@00001P0?ooo`4000000@3oool002L0oooo0P00000N0?ooo`030000
003oool0oooo06X0oooo1@00001T0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1U0?ooo`D00000JP3oool100000040oooo000W0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0H03oool5000006l0oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo1@00001d0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1F0?ooo`D00000N@3oool100000040
oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0D@3oool5000007h0oooo
0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04`0oooo1@00
00230?ooo`4000000@3oool002L0oooo0P00000N0?ooo`030000003oool0oooo04L0oooo1@000027
0?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`120?oo
o`D00000S@3oool100000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0?@3oool500000980oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03P0oooo1@00002G0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0c0?ooo`D00000W03oool100000040oooo000W0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0<03oool300000:40oooo0@0000010?ooo`009`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02h0oooo0P00002T0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0/0?ooo`800000YP3oool100000040
oooo000W0?ooo`8000007P3oool00`000000oooo0?ooo`0Y0?ooo`<00000Y`3oool200000040oooo
000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09`3oool200000:/0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02D0oooo0P00002]
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0S0?oo
o`800000[`3oool100000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool08@3oool200000;40oooo0@0000010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool2000000@0oooo0P0000040?ooo`<000000`3oool3000000D0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0O0?ooo`800000/`3oool100000040oooo00001@3oool000000?oo
o`3oool0000000X0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01`0oooo0`00002e0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`00
00002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`8000007P3oool00`000000oooo0?ooo`0J0?ooo`80
0000]`3oool200000040oooo00001@3oool000000?ooo`3oool0000000P0oooo100000020?ooo`@0
00000P3oool3000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01P0oooo0P00002j0?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`00
00001`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`030000003oool0000000<000001@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0^P3oool100000040oooo00001@3oool000000?ooo`3oool0
000000L0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`000000
0`3oool00`000000oooo000000080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`2j0?ooo`4000000@3oool00080oooo0P0000090?ooo`<000000`3o
ool3000000<0oooo0`0000020?ooo`D00000103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0^`3oool100000040oooo000W0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2l0?ooo`4000000@3oool0
02L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0;`0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0_@3oool100000040oooo000W0?ooo`8000007P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0;d0oooo0P0000010?ooo`009`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0_P3oool100000040oooo000W
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2o
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0<00oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0`@3oool100000040oooo000W0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`310?ooo`400000
0@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0<80oooo0@0000010?ooo`009`3oool2000001h0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`320?ooo`8000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0<<0oooo0@0000010?ooo`009`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0a03oool100000040
oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`350?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0<D0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0aP3oool100000040oooo000W0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`370?oo
o`4000000@3oool002L0oooo0P00000N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0aP3oool200000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`380?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0<T0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0b@3oool1
00000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3:0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0</0oooo0@0000010?ooo`009`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0b`3oool100000040oooo
000W0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3<0?ooo`4000000@3oool002L0oooo0P00000N0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0c03oool200000040oooo000W0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`3>0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<h0oooo0@0000010?ooo`00
9`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
c`3oool100000040oooo000W0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo
0000003B0?ooo`4000000@3oool000P0oooo0P0000040?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`800000103oool2000000H0oooo00<000000?ooo`3oool07@3oool01@000000oooo0?oo
o`3oool000000=80oooo0@0000010?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01d0oooo00@000000?ooo`3oool00000d`3oool100000040oooo00070?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo0P00000N0?ooo`030000003oool000000=<0oooo0P0000010?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`@000000P3oool400000080oooo100000040?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`000000e03oool100000040oooo00070?ooo`040000
003oool0oooo000000L0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo0P00003E
0?ooo`4000000@3oool000L0oooo00@000000?ooo`3oool000001`3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000`3oool00`000000oooo000000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool000P0oooo0P00
00090?ooo`<000000`3oool3000000<0oooo0`0000050?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo01`0oooo0P00003F
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0703oool200000=H0oooo0@0000010?oo
o`009`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool000000=H0oooo0@0000010?ooo`00
9`3oool2000001`0oooo00<000000?ooo`000000e@3oool200000040oooo000W0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`000000eP3oool100000040oooo000W0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000eP3oool100000040oooo000W0?ooo`030000003oool0
oooo01X0oooo00@000000?ooo`3oool00000eP3oool100000040oooo000W0?ooo`030000003oool0
oooo01T0oooo00D000000?ooo`3oool0oooo0000003F0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool06@3oool01@000000oooo0?ooo`3oool000000=H0oooo0@0000010?ooo`009`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0e03oool1
00000040oooo000W0?ooo`8000006@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0=<0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=@0oooo0@00
00010?ooo`009`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`00
9`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
e03oool100000040oooo000W0?ooo`8000005P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0=<0oooo0P0000010?ooo`009`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0=@0
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0=@0oooo0@000001
0?ooo`009`3oool2000001<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3C0?oo
o`8000000@3oool002L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3D0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0=@0oooo0@0000010?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool20000
00@0oooo0P0000040?ooo`800000103oool3000000D0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`0000D0oooo0000003o
ool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo0000000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0d`3oool200000040oooo00001@3oool000000?ooo`3oool0
000000P0oooo100000020?ooo`@000000P3oool4000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e03oool1
00000040oooo00001@3oool000000?ooo`3oool0000000L0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo00000003000000D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=@0oooo
0@0000010?ooo`0000D0oooo0000003oool0oooo000000070?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e03oool10000
0040oooo00020?ooo`8000002@3oool3000000<0oooo0`0000030?ooo`<000000P3oool5000000@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0=@0
oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=@0oooo0@000001
0?ooo`009`3oool2000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3C0?oo
o`8000000@3oool002L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3D0?ooo`4000000@3o
ool002L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo
0P00000;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0d`3oool200000040oooo
000W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`3D0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`3D0?ooo`40
00000@3oool002L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool0
02L0oooo0P0000080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0d`3oool20000
0040oooo000W0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0e03oool100000040oooo000W
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3D
0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0e03oool100000040oooo000W0?ooo`800000
1P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0=<0oooo0P0000010?ooo`009`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0e03o
ool100000040oooo000W0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`3D0?ooo`4000000@3oool002L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0=@0oooo0@0000010?ooo`009`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0e03oool100000040
oooo000O0?ooo`<000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0e03oool100000040oooo000P0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0=@0oooo0@00
00010?ooo`00803oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`3D0?ooo`4000000@3oool00200oooo00<000000?oo
o`3oool0103oool2000000<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3C0?oo
o`8000000@3oool00200oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0=@0oooo0@0000010?ooo`007`3oool2000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`4000000@3oool00200oooo00<000000?ooo`3oool0103o
oooh00000040oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.716192, 0.99775, \
0.0381394, 1.34576*^-5}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sextupole Strength  vs Segmentation", "Section"],

Cell["\<\
We shall now make use of the \"Listable\" attribute of the function f[],  to \
compute the strength of the sextupole for several case of segmentation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(w = {6, 3, 
          6};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \  (*\ Magnet\ dimensions\ *) \), "\n", 
    \(\(g = 
        12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Free\ radius\ of\ the\ sextupole\ *) \), "\[IndentingNewLine]", 
    \(\(nt = {2, 3, 4, 5};\)\), "\n", 
    \(\(n = 
        seg[nt, 3, 
          nt];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Segmentation\ Parameter\ *) \), "\n", 
    \(\(curdens = 
        5;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \  (*\ 
      Current\ density\ in\ the\ coil\ *) \[IndentingNewLine]\
\[IndentingNewLine]\), "\n", 
    \(\(radUtiDelAll[];\)\), "\n", 
    \(pb = f[n, curdens]\), "\n", 
    \(ib = \((Sext /. pb)\)\), "\n", 
    \(\(ListPlot[Transpose[{nt, ib/Last[ib]}], PlotJoined \[Rule] True, 
        Frame \[Rule] True];\)\)}], "Input"],

Cell[BoxData[
    \({{Segm \[Rule] seg[2, 3, 2], Cur \[Rule] 5, Obj \[Rule] 37, 
        Solv \[Rule] {0.00009484038367951042`, 0.22480611011980703`, 
            0.00022611406182738663`, 79}, 
        Sext \[Rule] 0.006010322641773311`}, {Segm \[Rule] seg[3, 3, 3], 
        Cur \[Rule] 5, Obj \[Rule] 108, 
        Solv \[Rule] {0.00009948698090565652`, 0.17720874221941507`, 
            0.00017773749714265316`, 45}, 
        Sext \[Rule] 0.0058671450531755705`}, {Segm \[Rule] seg[4, 3, 4], 
        Cur \[Rule] 5, Obj \[Rule] 221, 
        Solv \[Rule] {0.00009952024408156688`, 0.15057143801654346`, 
            0.00015082738079769795`, 33}, 
        Sext \[Rule] 0.005796500880661718`}, {Segm \[Rule] seg[5, 3, 5], 
        Cur \[Rule] 5, Obj \[Rule] 388, 
        Solv \[Rule] {0.00009229226415624534`, 0.13920317900590265`, 
            0.00013937257106407243`, 30}, 
        Sext \[Rule] 0.0057594939169607435`}}\)], "Output"],

Cell[BoxData[
    \({0.006010322641773311`, 0.0058671450531755705`, 0.005796500880661718`, 
      0.0057594939169607435`}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.611111 0.31746 -13.5007 13.5154 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .14987 -24 -4.5 ]
[-0.0125 .14987 0 4.5 ]
[-0.0125 .28502 -24 -4.5 ]
[-0.0125 .28502 0 4.5 ]
[-0.0125 .42018 -24 -4.5 ]
[-0.0125 .42018 0 4.5 ]
[-0.0125 .55533 -24 -4.5 ]
[-0.0125 .55533 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(2)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(2.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(3)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(3.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(4)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(4.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(5)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(1)] -0.0125 .01472 1 0 Mshowa
0 .14987 m
.00625 .14987 L
s
[(1.01)] -0.0125 .14987 1 0 Mshowa
0 .28502 m
.00625 .28502 L
s
[(1.02)] -0.0125 .28502 1 0 Mshowa
0 .42018 m
.00625 .42018 L
s
[(1.03)] -0.0125 .42018 1 0 Mshowa
0 .55533 m
.00625 .55533 L
s
[(1.04)] -0.0125 .55533 1 0 Mshowa
.125 Mabswid
0 .04175 m
.00375 .04175 L
s
0 .06878 m
.00375 .06878 L
s
0 .09581 m
.00375 .09581 L
s
0 .12284 m
.00375 .12284 L
s
0 .1769 m
.00375 .1769 L
s
0 .20393 m
.00375 .20393 L
s
0 .23096 m
.00375 .23096 L
s
0 .25799 m
.00375 .25799 L
s
0 .31205 m
.00375 .31205 L
s
0 .33909 m
.00375 .33909 L
s
0 .36612 m
.00375 .36612 L
s
0 .39315 m
.00375 .39315 L
s
0 .44721 m
.00375 .44721 L
s
0 .47424 m
.00375 .47424 L
s
0 .50127 m
.00375 .50127 L
s
0 .5283 m
.00375 .5283 L
s
0 .58236 m
.00375 .58236 L
s
0 .60939 m
.00375 .60939 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .14987 m
1 .14987 L
s
.99375 .28502 m
1 .28502 L
s
.99375 .42018 m
1 .42018 L
s
.99375 .55533 m
1 .55533 L
s
.125 Mabswid
.99625 .04175 m
1 .04175 L
s
.99625 .06878 m
1 .06878 L
s
.99625 .09581 m
1 .09581 L
s
.99625 .12284 m
1 .12284 L
s
.99625 .1769 m
1 .1769 L
s
.99625 .20393 m
1 .20393 L
s
.99625 .23096 m
1 .23096 L
s
.99625 .25799 m
1 .25799 L
s
.99625 .31205 m
1 .31205 L
s
.99625 .33909 m
1 .33909 L
s
.99625 .36612 m
1 .36612 L
s
.99625 .39315 m
1 .39315 L
s
.99625 .44721 m
1 .44721 L
s
.99625 .47424 m
1 .47424 L
s
.99625 .50127 m
1 .50127 L
s
.99625 .5283 m
1 .5283 L
s
.99625 .58236 m
1 .58236 L
s
.99625 .60939 m
1 .60939 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.34127 .26733 L
.65873 .10156 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3oool5000001h0oooo1@0000030?ooo`030000
003oool0oooo0080oooo0`00000P0?ooo`<000008@3oool3000000@0oooo00<000000?ooo`3oool0
0P3oool300000240oooo0`00000P0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000
803oool3000000L0oooo000O0?ooo`040000003oool0oooo000001l0oooo00@000000?ooo`3oool0
00001`3oool01@000000oooo0?ooo`3oool0000001h0oooo00D000000?ooo`3oool0oooo0000000O
0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000240oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
00007P3oool01@000000oooo0?ooo`3oool0000000H0oooo000P0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`D000007P3oool5000000/0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`008@3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool200000280oooo
0P00000<0?ooo`030000003oool0oooo01`0oooo00@000000?ooo`3oool000007`3oool010000000
oooo0?ooo`00000<0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0103oool001h0
oooo00D000000?ooo`3oool0oooo0000000N0?ooo`050000003oool0oooo0?ooo`0000001`3oool4
000002<0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`@00000803oool0
0`000000oooo0000000P0?ooo`030000003oool0000000P0oooo1000000O0?ooo`@000001`3oool0
01h0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`050000003oool0oooo0?ooo`0000001`3o
ool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000007`3oool01@000000oooo
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool08P3oool200000240oooo0P0000080?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0203oool001l0oooo0`00000P0?ooo`<00000
203oool5000001l0oooo0`00000Q0?ooo`<00000203oool500000240oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`060?ooo`D000007P3oool5000000H0oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo000K0?ooool000001@0000010?ooo`004`3o
ool3000000D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`4000000@3o
ool001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00<0oooo0@0000010?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0?l0oooo0@3oool100000040oooo000D0?ooo`030000003oool0oooo00@0oooo0P00003i0?ooo`<0
0000103oool200000040oooo000D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
m03oool4000000P0oooo0@0000010?ooo`004`3oool2000000H0oooo00<000000?ooo`3oool0l@3o
ool3000000`0oooo0@0000010?ooo`00503oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0>d0oooo1000000?0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0j@3oool40000
01<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`3U0?ooo`@000005`3oool100000040
oooo000K0?ooo`030000003oool0oooo0>80oooo0`00000K0?ooo`4000000@3oool001/0oooo0P00
003O0?ooo`@000007@3oool200000040oooo000K0?ooo`030000003oool0oooo0=X0oooo1000000R
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0e`3oool3000002H0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`3C0?ooo`@00000:@3oool100000040oooo000K0?ooo`030000
003oool0oooo0<l0oooo1000000]0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0b`3o
ool400000340oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`380?ooo`<00000=@3oool1
00000040oooo000K0?ooo`800000a@3oool4000003L0oooo0P0000010?ooo`006`3oool00`000000
oooo0?ooo`300?ooo`@00000?03oool100000040oooo000K0?ooo`030000003oool0oooo0;`0oooo
100000100?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0^@3oool3000004@0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`2e0?ooo`@00000A`3oool100000040oooo000K0?oo
o`030000003oool0oooo0;40oooo1000001;0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool0[P3oool3000004l0oooo0@0000010?ooo`006`3oool200000:/0oooo1000001A0?ooo`800000
0@3oool001/0oooo00<000000?ooo`3oool0Y`3oool3000005H0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`2U0?ooo`800000F@3oool100000040oooo000K0?ooo`030000003oool0oooo
0:<0oooo0P00001K0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0X@3oool2000005d0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`2O0?ooo`800000G`3oool100000040oooo
000K0?ooo`030000003oool0oooo09d0oooo0P00001Q0?ooo`4000000@3oool001/0oooo0P00002L
0?ooo`800000HP3oool200000040oooo000K0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0H`3oool100000040oooo000K0?ooo`030000003oool0oooo09P0oooo0P00001V0?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool0UP3oool2000006P0oooo0@0000010?ooo`0000@0
oooo0000000000000000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo
00<000000?ooo`3oool0U03oool2000006X0oooo0@0000010?ooo`000P3oool00`000000oooo0?oo
o`080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2B0?ooo`800000K03oool100000040oooo00020?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0900oooo
0P00001^0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00@0oooo0P00002?0?ooo`800000K`3oool200000040oooo
00020?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08`0oooo0P00001b0?ooo`4000000@3oool000030?ooo`00
0000000000X0oooo00@000000?ooo`3oool000000P3oool2000000H0oooo00<000000?ooo`3oool0
RP3oool2000007@0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`090?ooo`800000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08P0oooo0P00001f0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0QP3oool2000007P0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`240?ooo`800000NP3oool100000040oooo000K0?ooo`030000003oool0oooo0880
oooo0P00001l0?ooo`4000000@3oool001/0oooo0P0000210?ooo`800000O@3oool200000040oooo
000K0?ooo`030000003oool0oooo07h0oooo0P0000200?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0O@3oool00`000000oooo0?ooo`200?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool0N`3oool2000008<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1i0?ooo`80
0000Q@3oool100000040oooo000K0?ooo`030000003oool0oooo07L0oooo0P0000270?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool0M@3oool2000008T0oooo0@0000010?ooo`006`3oool2
000007@0oooo0P00002:0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0L@3oool20000
08d0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1_0?ooo`800000S`3oool100000040
oooo000K0?ooo`030000003oool0oooo06d0oooo0P00002A0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0J`3oool2000009<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1Y
0?ooo`800000U@3oool100000040oooo000K0?ooo`030000003oool0oooo06L0oooo0P00002G0?oo
o`4000000@3oool001/0oooo0P00001V0?ooo`800000V03oool200000040oooo000K0?ooo`030000
003oool0oooo06<0oooo0P00002K0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`2K0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0H03oool2
000009h0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1N0?ooo`800000X03oool10000
0040oooo000K0?ooo`030000003oool0oooo05`0oooo0P00002R0?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool0FP3oool200000:@0oooo0@0000010?ooo`006`3oool2000005T0oooo0P00
002U0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0EP3oool200000:P0oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0:P0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0:P0oooo0@0000010?ooo`00
00@0oooo0000000000000000103oool00`000000oooo0?ooo`030?ooo`8000000P3oool5000000@0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2Y0?ooo`4000000@3oool00080oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`2Z0?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`2[0?ooo`4000000@3oool00080
oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo0P00001B0?ooo`030000003oool0oooo0:/0oooo0P0000010?ooo`000P3oool00`000000
oooo0?ooo`080?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0[@3oool100000040oooo00000`3o
ool000000000000:0?ooo`060000003oool0oooo0000003oool000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0[P3oool100000040oooo0002
0?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0:l0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0;00oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0;40oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0;80oooo0@0000010?ooo`006`3oool2000004/0oooo00<000000?ooo`3oool0/P3o
ool200000040oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0]03oool1
00000040oooo000K0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0]@3oool10000
0040oooo000K0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0]P3oool100000040
oooo000K0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0]P3oool100000040oooo
000K0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0]`3oool100000040oooo000K
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0^03oool100000040oooo000K0?oo
o`800000A@3oool00`000000oooo0?ooo`2h0?ooo`8000000@3oool001/0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`2j0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`2k0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`2l0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`2m0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2n0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`2o0?ooo`4000000@3oool001/0oooo0P00000n0?ooo`030000003oool0oooo0;l0oooo
0P0000010?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0<40oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0<80oooo0@000001
0?ooo`006`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0<<0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0<<0oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0<@0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0<D0oooo0@0000010?ooo`006`3oool2
000003P0oooo00<000000?ooo`3oool0a@3oool200000040oooo000K0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0a`3oool100000040oooo000K0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0b03oool100000040oooo000K0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0b@3oool100000040oooo000K0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0bP3oool100000040oooo0000103oool000000000000000040?ooo`030000003o
ool0oooo00<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0</0oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`080?ooo`060000003oool0
oooo0000003oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0c03oool100000040oooo00020?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooo`800000<@3oool00`000000oooo
0?ooo`3<0?ooo`8000000@3oool00080oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`0000030?ooo`8000001@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0<h0oooo
0@0000010?ooo`000P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0<l0oooo
0@0000010?ooo`0000<0oooo0000000000002P3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0=00
oooo0@0000010?ooo`000P3oool00`000000oooo0?ooo`090?ooo`8000000`3oool3000000D0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`3A0?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`3A0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`3B0?ooo`4000000@3oool001/0oooo0P00000[0?oo
o`030000003oool0oooo0=80oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0=@0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo0=D0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo0=H0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0=L0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0=P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0=T0
oooo0@0000010?ooo`006`3oool2000002@0oooo00<000000?ooo`3oool0f@3oool200000040oooo
000K0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0f`3oool100000040oooo000K
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0g03oool100000040oooo000K0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0g@3oool100000040oooo000K0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0gP3oool100000040oooo000K0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0g`3oool100000040oooo000K0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0g`3oool100000040oooo000K0?ooo`8000007P3oool0
0`000000oooo0?ooo`3O0?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`3Q0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`3R0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`3S0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`3T0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`3U
0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3V0?oo
o`4000000@3oool001/0oooo0P00000G0?ooo`030000003oool0oooo0>H0oooo0P0000010?ooo`00
6`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0>P0oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0>T0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0>X0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0>/0oooo0@0000010?ooo`0000@0oooo00000000
00000000103oool00`000000oooo0?ooo`030?ooo`800000103oool3000000@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3/0?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`3/0?ooo`4000000@3oool00080oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`000000oooo00D00000103oool200000140oooo00<000000?oo
o`3oool0k03oool200000040oooo00020?ooo`030000003oool0oooo00P0oooo00H000000?ooo`3o
ool000000?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3^0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool0203oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3_0?ooo`4000000@3oool000030?ooo`000000000000X0oooo00@000000?oo
o`3oool000000`3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3`
0?ooo`4000000@3oool00080oooo00<000000?ooo`3oool02@3oool2000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?40oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?80oooo0@0000010?ooo`00
6`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?<0oooo0@0000010?ooo`006`3o
ool2000000X0oooo00<000000?ooo`3oool0l`3oool200000040oooo000K0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0m@3oool100000040oooo000K0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0mP3oool100000040oooo000K0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0m`3oool100000040oooo000K0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0n03oool100000040oooo000K0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0n@3oool100000040oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0nP3oool100000040oooo000K0?ooo`800000o`3oool10?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo
o`00000500000040oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {1.59442, 0.994819, \
0.0121328, 0.000284984}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sextupole Strength vs  Current density  and Segmentation", "Section"],

Cell["\<\
This computation performs two nested loop of computation. One loop is made on \
the current densities, the other one is made on the sementation parameter. \
Indeed, it has no physical interest beside tutorial. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(w = {6, 3, 
          6};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \), "\n", 
    \(\(g = 12;\)\ \ \), "\[IndentingNewLine]", 
    \(\(nn = {2, 
          2};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(nt = {nn, nn, nn};\)\), "\n", 
    \(\(n = 
        seg[nt, 2, 
          2];\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \), "\n\
", 
    \(\(curdens = {2, 3, 5, 
          10};\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Note\ that\ curdens\ and\ nt\ must\ have\ the\ same\ dimension\ *) \
\[IndentingNewLine]\[IndentingNewLine]\), "\n", 
    \(\(radUtiDelAll[];\)\), "\n", 
    \(\(pb = f[n, curdens]\ ;\)\), "\[IndentingNewLine]", 
    \(TableForm[pb]\[IndentingNewLine]\), "\n", 
    \(\(ib = \((Sext /. pb)\)\ ;\)\), "\[IndentingNewLine]", 
    \(\ MatrixForm[ib]\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ListContourPlot[
        ib, \[IndentingNewLine]PlotLabel \[Rule] \ "\<Sextupole vs segm and \
Current\>", \[IndentingNewLine]MeshRange \[Rule] {{First[nn], 
              Last[nn]}, \[IndentingNewLine]{First[curdens], 
              Last[curdens]}}];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(ListPlot3D[
        ib, \[IndentingNewLine]PlotLabel \[Rule] \ "\<Sextupole vs segm and \
Current\>", \[IndentingNewLine]MeshRange \[Rule] {{First[nn], 
              Last[nn]}, \[IndentingNewLine]{First[curdens], 
              Last[curdens]}}];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 2\)},
                {\(Obj \[Rule] 29\)},
                {\(Solv \[Rule] {0.00009496526593811259`, 
                      0.05058946475028957`, 0.00005052693613424867`, 16}\)},
                {\(Sext \[Rule] 0.002432017704221535`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 2\)},
                {\(Obj \[Rule] 62\)},
                {\(Solv \[Rule] {0.00009496588728281476`, 
                      0.05058946561268823`, 0.000050526936996222416`, 16}\)},
                {\(Sext \[Rule] 0.002432017748006596`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[3, 2, 2]\)},
                {\(Cur \[Rule] 2\)},
                {\(Obj \[Rule] 103\)},
                {\(Solv \[Rule] {0.0000914007213094669`, 
                      0.06764618471569493`, 0.00006758239522188596`, 28}\)},
                {\(Sext \[Rule] 0.0024893912707644903`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 3\)},
                {\(Obj \[Rule] 136\)},
                {\(Solv \[Rule] {0.00008448083941576195`, 
                      0.07622074199195054`, 0.00007616253939404251`, 18}\)},
                {\(Sext \[Rule] 0.003646137489939337`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 3\)},
                {\(Obj \[Rule] 169\)},
                {\(Solv \[Rule] {0.00008448138626685882`, 
                      0.0762207482123554`, 0.00007616254562021071`, 18}\)},
                {\(Sext \[Rule] 0.0036461375456435245`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[3, 2, 2]\)},
                {\(Cur \[Rule] 3\)},
                {\(Obj \[Rule] 210\)},
                {\(Solv \[Rule] {0.00009400574664716962`, 
                      0.10174904654492596`, 0.00010173867083611586`, 31}\)},
                {\(Sext \[Rule] 0.003733414686379785`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 5\)},
                {\(Obj \[Rule] 243\)},
                {\(Solv \[Rule] {0.00008510757146425866`, 
                      0.12736172332527143`, 0.00012745786698782957`, 20}\)},
                {\(Sext \[Rule] 0.006075198265902234`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 5\)},
                {\(Obj \[Rule] 276\)},
                {\(Solv \[Rule] {0.00008510755774416948`, 
                      0.1273617233203062`, 0.00012745786698283704`, 20}\)},
                {\(Sext \[Rule] 0.006075198112659103`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[3, 2, 2]\)},
                {\(Cur \[Rule] 5\)},
                {\(Obj \[Rule] 317\)},
                {\(Solv \[Rule] {0.0000921690652764883`, 0.1699363401537235`, 
                      0.00017038020410707223`, 35}\)},
                {\(Sext \[Rule] 0.006221309176993883`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]},
          {GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 10\)},
                {\(Obj \[Rule] 350\)},
                {\(Solv \[Rule] {0.00008271341289240747`, 
                      0.2551671950046705`, 0.00025720744050329803`, 23}\)},
                {\(Sext \[Rule] 0.012147902850246374`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[2, 2, 2]\)},
                {\(Cur \[Rule] 10\)},
                {\(Obj \[Rule] 383\)},
                {\(Solv \[Rule] {0.00008271442291600702`, 0.255167174903895`, 
                      0.00025720741984916663`, 23}\)},
                {\(Sext \[Rule] 0.012147903832491093`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}], GridBox[{
                {\(Segm \[Rule] seg[3, 2, 2]\)},
                {\(Cur \[Rule] 10\)},
                {\(Obj \[Rule] 424\)},
                {\(Solv \[Rule] {0.00009138462656905545`, 
                      0.3399773458625458`, 0.000345304386403008`, 40}\)},
                {\(Sext \[Rule] 0.012440747783356186`\)}
                },
              RowSpacings->0.25,
              ColumnSpacings->1,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{Segm -> seg[ 2, 2, 2], Cur -> 2, Obj -> 29, Solv -> {
        9.4965265938112592*^-05, 0.050589464750289567, 
        5.0526936134248668*^-05, 16}, Sext -> 0.0024320177042215351}, {Segm -> 
        seg[ 2, 2, 2], Cur -> 2, Obj -> 62, Solv -> {9.4965887282814763*^-05, 
        0.050589465612688227, 5.0526936996222416*^-05, 16}, Sext -> 
        0.0024320177480065962}, {Segm -> seg[ 3, 2, 2], Cur -> 2, Obj -> 103, 
        Solv -> {9.1400721309466894*^-05, 0.067646184715694932, 
        6.7582395221885957*^-05, 28}, Sext -> 0.0024893912707644903}}, {{Segm -> 
        seg[ 2, 2, 2], Cur -> 3, Obj -> 136, Solv -> {8.4480839415761947*^-05,
         0.076220741991950544, 7.6162539394042513*^-05, 18}, Sext -> 
        0.0036461374899393372}, {Segm -> seg[ 2, 2, 2], Cur -> 3, Obj -> 169, 
        Solv -> {8.4481386266858823*^-05, 0.076220748212355402, 
        7.6162545620210708*^-05, 18}, Sext -> 0.0036461375456435245}, {Segm -> 
        seg[ 3, 2, 2], Cur -> 3, Obj -> 210, Solv -> {9.4005746647169621*^-05,
         0.10174904654492596, 0.00010173867083611586, 31}, Sext -> 
        0.003733414686379785}}, {{Segm -> seg[ 2, 2, 2], Cur -> 5, Obj -> 243,
         Solv -> {8.5107571464258656*^-05, 0.12736172332527143, 
        0.00012745786698782957, 20}, Sext -> 0.0060751982659022338}, {Segm -> 
        seg[ 2, 2, 2], Cur -> 5, Obj -> 276, Solv -> {8.5107557744169477*^-05,
         0.12736172332030621, 0.00012745786698283704, 20}, Sext -> 
        0.0060751981126591029}, {Segm -> seg[ 3, 2, 2], Cur -> 5, Obj -> 317, 
        Solv -> {9.2169065276488294*^-05, 0.1699363401537235, 
        0.00017038020410707223, 35}, Sext -> 0.0062213091769938826}}, {{Segm -> 
        seg[ 2, 2, 2], Cur -> 10, Obj -> 350, Solv -> {
        8.2713412892407472*^-05, 0.2551671950046705, 0.00025720744050329803, 
        23}, Sext -> 0.012147902850246374}, {Segm -> seg[ 2, 2, 2], Cur -> 10,
         Obj -> 383, Solv -> {8.2714422916007019*^-05, 0.25516717490389501, 
        0.00025720741984916663, 23}, Sext -> 0.012147903832491093}, {Segm -> 
        seg[ 3, 2, 2], Cur -> 10, Obj -> 424, Solv -> {
        9.1384626569055447*^-05, 0.3399773458625458, 0.00034530438640300801, 
        40}, Sext -> 0.012440747783356186}}}]]], "Output"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0.002432017704221535`", "0.002432017748006596`", 
              "0.0024893912707644903`"},
            {"0.003646137489939337`", "0.0036461375456435245`", 
              "0.003733414686379785`"},
            {"0.006075198265902234`", "0.006075198112659103`", 
              "0.006221309176993883`"},
            {"0.012147902850246374`", "0.012147903832491093`", 
              "0.012440747783356186`"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.90385 0.961538 -0.221154 0.120192 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -6 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .25962 -6 -4.5 ]
[-0.0125 .25962 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .74038 -6 -4.5 ]
[-0.0125 .74038 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[.5 1.0125 -89.0625 0 ]
[.5 1.0125 89.0625 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(2)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(2.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(2.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(2.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(2.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(3)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(2)] -0.0125 .01923 1 0 Mshowa
0 .25962 m
.00625 .25962 L
s
[(4)] -0.0125 .25962 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(6)] -0.0125 .5 1 0 Mshowa
0 .74038 m
.00625 .74038 L
s
[(8)] -0.0125 .74038 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .07933 m
.00375 .07933 L
s
0 .13942 m
.00375 .13942 L
s
0 .19952 m
.00375 .19952 L
s
0 .31971 m
.00375 .31971 L
s
0 .37981 m
.00375 .37981 L
s
0 .4399 m
.00375 .4399 L
s
0 .5601 m
.00375 .5601 L
s
0 .62019 m
.00375 .62019 L
s
0 .68029 m
.00375 .68029 L
s
0 .80048 m
.00375 .80048 L
s
0 .86058 m
.00375 .86058 L
s
0 .92067 m
.00375 .92067 L
s
.25 Mabswid
0 0 m
0 1 L
s
.01923 .99375 m
.01923 1 L
s
.21154 .99375 m
.21154 1 L
s
.40385 .99375 m
.40385 1 L
s
.59615 .99375 m
.59615 1 L
s
.78846 .99375 m
.78846 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.06731 .99625 m
.06731 1 L
s
.11538 .99625 m
.11538 1 L
s
.16346 .99625 m
.16346 1 L
s
.25962 .99625 m
.25962 1 L
s
.30769 .99625 m
.30769 1 L
s
.35577 .99625 m
.35577 1 L
s
.45192 .99625 m
.45192 1 L
s
.5 .99625 m
.5 1 L
s
.54808 .99625 m
.54808 1 L
s
.64423 .99625 m
.64423 1 L
s
.69231 .99625 m
.69231 1 L
s
.74038 .99625 m
.74038 1 L
s
.83654 .99625 m
.83654 1 L
s
.88462 .99625 m
.88462 1 L
s
.93269 .99625 m
.93269 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .25962 m
1 .25962 L
s
.99375 .5 m
1 .5 L
s
.99375 .74038 m
1 .74038 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .07933 m
1 .07933 L
s
.99625 .13942 m
1 .13942 L
s
.99625 .19952 m
1 .19952 L
s
.99625 .31971 m
1 .31971 L
s
.99625 .37981 m
1 .37981 L
s
.99625 .4399 m
1 .4399 L
s
.99625 .5601 m
1 .5601 L
s
.99625 .62019 m
1 .62019 L
s
.99625 .68029 m
1 .68029 L
s
.99625 .80048 m
1 .80048 L
s
.99625 .86058 m
1 .86058 L
s
.99625 .92067 m
1 .92067 L
s
.25 Mabswid
1 0 m
1 1 L
s
gsave
.5 1.0125 -150.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sextupole) show
123.000 13.000 moveto
(vs) show
141.000 13.000 moveto
(segm) show
171.125 13.000 moveto
(and) show
195.125 13.000 moveto
(Current) show
237.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.01923 .20538 m
.5 .20538 L
.98077 .18613 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .20538 m
.5 .20538 L
.98077 .18613 L
s
.2 g
.01923 .39865 m
.5 .39865 L
.98077 .38601 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .39865 m
.5 .39865 L
.98077 .38601 L
s
.3 g
.01923 .52471 m
.5 .52471 L
.98077 .50909 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .52471 m
.5 .52471 L
.98077 .50909 L
s
.4 g
.01923 .65077 m
.5 .65077 L
.98077 .63217 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .65077 m
.5 .65077 L
.98077 .63217 L
s
.5 g
.01923 .70689 m
.5 .70689 L
.98077 .69826 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .70689 m
.5 .70689 L
.98077 .69826 L
s
.6 g
.01923 .75731 m
.5 .75731 L
.98077 .74749 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .75731 m
.5 .75731 L
.98077 .74749 L
s
.7 g
.01923 .80773 m
.5 .80773 L
.98077 .79673 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .80773 m
.5 .80773 L
.98077 .79673 L
s
.8 g
.01923 .85816 m
.5 .85816 L
.98077 .84596 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .85816 m
.5 .85816 L
.98077 .84596 L
s
.9 g
.01923 .90858 m
.5 .90858 L
.98077 .89519 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .90858 m
.5 .90858 L
.98077 .89519 L
s
1 g
.01923 .95901 m
.5 .95901 L
.98077 .94443 L
.98077 .98077 L
.01923 .98077 L
F
0 g
.01923 .95901 m
.5 .95901 L
.98077 .94443 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`005`3oool5000002L0oooo1@0000030?ooo`040000003oool0oooo0?ooo`D000008@3oool5
000000<0oooo00<000000?ooo`3oool00`3oool300000240oooo1@0000030?ooo`030000003oool0
oooo0080oooo0`00000Q0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`<00000:@3oool3
000000`0oooo000H0?ooo`040000003oool0oooo000002P0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000R0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool08@3oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000008@3oool0
10000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`0000009`3oool01@000000oooo
0?ooo`3oool0000000/0oooo000I0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo1@00000S0?ooo`030000
003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000R0?ooo`030000003oool0oooo00L0
oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`060?oo
o`@00000903oool00`000000oooo0?ooo`070?ooo`<00000:P3oool2000000`0oooo000G0?ooo`05
0000003oool0oooo0?ooo`0000009`3oool01@000000oooo0?ooo`3oool0000000L0oooo00D00000
0?ooo`3oool0oooo0000000Q0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo
0000000R0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0R0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool0000002/0oooo00<00000
0?ooo`3oool02@3oool001L0oooo00D000000?ooo`3oool0oooo0000000W0?ooo`050000003oool0
oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000240oooo00D000000?ooo`3oool0
oooo000000090?ooo`8000008P3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`3oool08@3oool01@000000oooo0?ooo`3oool0000000L0oooo00D000000?ooo`3oool0oooo0000
000W0?ooo`050000003oool0oooo0?ooo`0000002`3oool001P0oooo0`00000Y0?ooo`<000002@3o
ool3000002<0oooo0`00000;0?ooo`030000003oool0oooo0240oooo0`00000:0?ooo`8000008P3o
ool3000000T0oooo0`00000Y0?ooo`<00000303oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool001D0ooooo`000005000000L0oooo000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool000`0oooo1@0000040?ooo`03
0000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`003@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`00
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo
0?ooo`050?ooo`003`3oool00`000000oooo0?ooo`030?ooo`800000o`3oool10?ooo`8000001`3o
ool000`0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooon@00
00050?ooo`030000003oool0oooo00D0oooo000<0?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`003@3oool3
000000D0oooo00<000000?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0
00000?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3o
ool00P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
0P3ooooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3o
oooi000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi
000000D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi0000
00D0oooo00<000000?ooo`3oool01@3oool001D0oooo0P0000030?ooooT00000103oool2000000L0
oooo000E0?ooo`030000003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
0080oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080
oooon@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooo
n@0000050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@00
00050?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@000005
0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0000050?oo
o`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0000050?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`8000000`3ooooi000000@0oooo0P0000070?ooo`005@3o
ool00`000000oooo0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo
0?ooo`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`020?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`02
0?ooooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oo
ooT000001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0
00001@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT00000
1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT000001@3o
ool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooX00000103oool0
0`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooond00000300I6AT50?oo
o`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080ooooe000000U01TI6@D0
oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooonk000003h06ATI
1@3oool00`000000oooo0?ooo`050?ooo`005@3oool2000000<0ooooXP00001G01TI6@@0oooo0P00
00070?ooo`005@3oool00`000000oooo0?ooo`020?ooohT00000L00I6AT50?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000>0?ooo`<00000103oool00`000000
oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`003`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo
000<0?ooo`D00000103oool2000000<0oooon@0I6AT40?ooo`8000001`3oool000`0oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?oo
o`050?ooo`003@3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooon@0I6AT5
0?ooo`030000003oool0oooo00D0oooo000>0?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
ooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
0080oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080
oooon@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooo
n@0I6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I
6AT50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT5
0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?oo
o`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0I6AT50?ooo`030000
003oool0oooo00D0oooo000E0?ooo`8000000`3ooooi01TI6@@0oooo0P0000070?ooo`005@3oool0
0`000000oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo
0?ooo`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`020?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`02
0?ooooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oo
ooT06ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0
6ATI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI
1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3o
ool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3oool0
0`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT06ATI1@3oool00`000000oooo
0?ooo`050?ooo`005@3oool2000000<0oooon@0I6AT40?ooo`8000001`3oool001D0oooo00<00000
0?ooo`3oool00P3ooooi01TI6@D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool00P3ooooT01TI6AH00000103oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`020?oook/06ATI:@00000E03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool00P3ooonB01TI6BT00000?P0c<c<50?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080ooooTP00001W03<c<`D0oooo00<000000?ooo`3oool01@3o
ool001D0oooo00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0
oooo00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo
00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<0
00000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3o
ool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
0P3ooooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3o
oooi03<c<`D0oooo00<000000?ooo`3oool01@3oool001D0oooo0P0000030?ooooT0<c<c103oool2
000000L0oooo000E0?ooo`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
0080oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080
oooon@0c<c<50?ooo`030000003oool0oooo00D0oooo000=0?ooo`<000001@3oool00`000000oooo
0?ooo`020?ooooT0<c<c1@3oool00`000000oooo0?ooo`050?ooo`00303oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<000000?ooo`3oool0
1@3oool000`0oooo00D000000?ooo`3oool0oooo000000040?ooo`8000000`3ooooi03<c<`@0oooo
0P0000070?ooo`00303oool4000000D0oooo00<000000?ooo`3oool00P3ooooi03<c<`D0oooo00<0
00000?ooo`3oool01@3oool000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooooT0<c<c1@3oool00`000000oooo0?ooo`050?ooo`003@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooojP0c<c<@000000@0oooo00<000000?ooo`3oool01@3oool000h0
oooo0P0000050?ooo`030000003oool0oooo0080oooob`0c<c<O000000l0C4a<1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oooj`0<c<c7`00000^04a<C0D0oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooon=03<c<al00000C@1<
C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080ooooS@00001/
04a<C0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<
C0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0
oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo00<0
00000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo00<00000
0?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo00<000000?ooo`3o
ool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi04a<C0D0oooo00<000000?ooo`3oool0
1@3oool001D0oooo0P0000030?ooooT0C4a<103oool2000000L0oooo000E0?ooo`030000003oool0
oooo0080oooon@1<C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo
0080oooon@1<C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080
oooon@1<C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooo
n@1<C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<
C4`50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`5
0?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?oo
o`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000
003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003oool0oooo00D0
oooo000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080oooon@1<C4`50?ooo`030000003oool0oooo00D0oooo000E
0?ooo`8000000`3ooooi04a<C0@0oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`020?oo
ooT0C4a<1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0
C4a<1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooond0C4a<
3@0000040?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080ooooe01<
C4`I000000`0IVIV1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`02
0?oook/0C4a<6@00000U06IVIPD0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool00P3ooonR04a<C1T00000?P1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080ooooR@1<C4`I000005L0IVIV1@3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`020?ooohT00000L01VIVH50?ooo`030000003oool0oooo00D0oooo
000E0?ooo`030000003oool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?oo
o`030000003oool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003o
ool0oooo0080oooon@1VIVH50?ooo`030000003oool0oooo00D0oooo000E0?ooo`8000000`3ooooi
06IVIP@0oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0IVIV1@3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0IVIV1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0IVIV1@3oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0IVIV1@3oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`020?ooomX0IVIV800000040?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo0080ooooW01VIVHn000001l0Ogmo1@3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oooi`00000G@1oOgl50?ooo`03
0000003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000
003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003oool0oooo
00D0oooo000E0?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003oool0oooo00D0
oooo000=0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooooT0Ogmo1@3oool00`000000oooo
0?ooo`050?ooo`00303oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0
0P3ooooi07moO`D0oooo00<000000?ooo`3oool01@3oool000`0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003oool0oooo00D0oooo
000=0?ooo`<000001@3oool2000000<0oooon@1oOgl40?ooo`8000001`3oool000`0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080oooon@1oOgl50?ooo`030000003o
ool0oooo00D0oooo000<0?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`020?ooomX0Ogmo800000040?ooo`030000003oool0oooo00D0oooo000=0?ooo`<000001@3oool0
0`000000oooo0?ooo`020?oooi`0Ogmo?P00000O09VIV@D0oooo00<000000?ooo`3oool01@3oool0
01D0oooo00<000000?ooo`3oool00P3ooonL000005d0VIVI1@3oool00`000000oooo0?ooo`050?oo
o`005@3oool00`000000oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool0
0`000000oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000
oooo0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo
0?ooo`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?oo
o`020?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`02
0?ooooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oo
ooT0VIVI1@3oool00`000000oooo0?ooo`050?ooo`005@3oool2000000<0oooofP2IVITP000000<0
oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`020?oooi`0VIVI?P00000O0;>c/`D0oooo
00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooonL000005d0/k>c1@3o
ool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool0
0`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo0?ooo`050?oo
o`005@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo0?ooo`050?ooo`00
5@3oool00`000000oooo0?ooo`020?ooooT0/k>c1@3oool00`000000oooo0?ooo`050?ooo`005@3o
ool00`000000oooo0?ooo`020?ooon@0/k>c5P0000040?ooo`030000003oool0oooo00D0oooo000E
0?ooo`030000003oool0oooo0080oooo^`2c/k<Y000001D0c<c<1@3oool00`000000oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`020?oooi80/k>c:@00000n0<c<c0D0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooonB000006L0c<c<1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool2000000<0oooon@3<c<`40?ooo`8000001`3oool001D0oooo00<0
00000?ooo`3oool00P3ooooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<00000
0?ooo`3oool00P3ooooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?oo
o`3oool00P3ooooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3o
ool00P3ooooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool0
0P3ooooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3o
oooi0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi
0<c<c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooi0<c<
c0D0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooooZ0<c<c100
0000103oool00`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?oool/0c<c<
7`00000?0>KViPD0oooo00<000000?ooo`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3o
oon/0<c<c1l00000;P3Vi^H50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000003oool0
oooo0080ooooS@3<c<`O000004d0i^KV1@3oool00`000000oooo0?ooo`050?ooo`005@3oool00`00
0000oooo0?ooo`020?ooohd00000K03Vi^H50?ooo`030000003oool0oooo00D0oooo000E0?ooo`03
0000003oool0oooo0080oooon@3Vi^H50?ooo`030000003oool0oooo00D0oooo000E0?ooo`030000
003oool0oooo0080oooon@3Vi^H50?ooo`030000003oool0oooo00D0oooo000E0?ooo`8000000`3o
oooi0>KViP@0oooo0P0000070?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0i^KV1@3oool0
0`000000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0i^KV1@3oool00`00
0000oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0i^KV1@3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0i^KV1@3oool00`000000oooo
0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooooT0i^KV1@3oool00`000000oooo0?oo
o`050?ooo`005@3oool00`000000oooo0?ooo`020?ooonX0i^KV400000040?ooo`030000003oool0
oooo00D0oooo000E0?ooo`030000003oool0oooo0080oooob`3Vi^HO000001@0oooo00<000000?oo
o`3oool01@3oool001D0oooo00<000000?ooo`3oool00P3ooon/0>KViQl00000<`3oool00`000000
oooo0?ooo`050?ooo`005@3oool00`000000oooo0?ooo`020?ooohd0i^KV7`00001B0?ooo`030000
003oool0oooo00D0oooo000E0?ooo`030000003oool0oooo0080ooooS@00001a0?ooo`030000003o
ool0oooo00D0oooo000E0?ooo`030000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`05
0?ooo`005@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3oool01@3oool000L0
oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3o
ool01@3oool000P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0?l0oooo0@3oool00`000000oooo0?ooo`050?ooo`00203oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo0P00003o0?ooo`40oooo0P0000070?ooo`00
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3oool10?ooo`030000003oool0oooo00D0oooo00080?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`3o0?ooo`40oooo00<000000?ooo`3o
ool01@3oool000L0oooo0P0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0o`3oool10?ooo`030000003oool0oooo00D0oooo00080?ooo`030000003oool0oooo00<0oooo
0P0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool001D0ooooo`00
0005000000L0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
001M0?ooo`<00000>P3oool3000008<0oooo001N0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0P03oool00400oooo0`0000030?ooo`<000000P3oool2000000030?ooo`0000000000
00<0oooo0P0000040?ooo`80000000<0oooo0000003oool00`0000030?ooo`<000000P3oool50000
0080oooo0`00000:0?ooo`040000003oool0oooo0?ooo`@00000203oool4000000<0oooo0`000003
0?ooo`@0000000H0oooo0000003oool000000?ooo`0000090?ooo`@0000000D0oooo000000000000
00000?ooo`02000000030?ooo`0000000000008000002@3oool2000000@0oooo0P0000000`3oool0
000000000002000000<0oooo0`0000040?ooo`<000000P3oool3000000030?ooo`00000000000080
oooo0P00000d0?ooo`00@03oool01P000000oooo0?ooo`000000oooo000000H0oooo00<000000?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H0
00000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo000000050?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000203oool010000000oooo0?ooo`0000030?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`070?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000003<0oooo00130?oo
o`030000003oool0000000@000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00D000000?ooo`3oool0oooo000000030?ooo`D00000203oool00`000000oooo000000030?ooo`<0
00002@3oool300000080oooo1@0000000`3oool000000?ooo`020?ooo`070000003oool000000?oo
o`000000oooo000000090?ooo`<000000`3oool01P000000oooo0?ooo`000000oooo00000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`D000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo03@0oooo00110?ooo`8000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00L000000?ooo`000000oooo0000003oool0000000P0
oooo00@000000?ooo`3oool000000`3oool01P000000oooo0?ooo`000000oooo00000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000080oooo
0P0000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0d0?ooo`00@03oool00`000000oooo0?ooo`030?ooo`<0
00000P3oool2000000040?ooo`00000000000?ooo`@000000P3oool2000000040?ooo`0000000000
0?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool3000000P0oooo0P000000
0`3oool00000000000020?ooo`@00000203oool400000080oooo0`0000030?ooo`L0000000<0oooo
0000003oool02@3oool2000000<0oooo100000030?ooo`<00000203oool00`000000oooo0?ooo`03
0?ooo`80000000@0oooo000000000000oooo0P000000103oool000000000003oool2000000030?oo
o`00000000000080oooo0`0000020?ooo`@000000P3oool4000003@0oooo00100?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?ooo`0d0?ooo`00
@@3oool3000000h0oooo00<000000?ooo`3oool0503oool3000004h0oooo0P00000:0?ooo`<00000
803oool00`000000oooo0?ooo`0d0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {1.89463, 1.44742, 0.00400756, \
0.0320606}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.57959e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -89.0625 0 ]
[.5 .82364 89.0625 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 6 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 6 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02389 .26652 -36 -2.74351 ]
[.02389 .26652 0 6.25649 ]
[.01546 .31936 -30 -2.78819 ]
[.01546 .31936 0 6.21181 ]
[.00673 .37405 -36 -2.83459 ]
[.00673 .37405 0 6.16541 ]
[-0.0023 .43068 -24 -2.88282 ]
[-0.0023 .43068 0 6.11718 ]
[-0.01167 .48936 -36 -2.93297 ]
[-0.01167 .48936 0 6.06703 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -150.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Sextupole) show
123.000 13.000 moveto
(vs) show
141.000 13.000 moveto
(segm) show
171.125 13.000 moveto
(and) show
195.125 13.000 moveto
(Current) show
237.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(2)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(2.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(2.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(2.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(2.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(3)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(4)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(6)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(8)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(10)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.71016 .03277 m
.70649 .03419 L
s
.73096 .06459 m
.72728 .06598 L
s
.75117 .0955 m
.74748 .09687 L
s
.78989 .15473 m
.78618 .15605 L
s
.80845 .18312 m
.80473 .18442 L
s
.8265 .21073 m
.82278 .21202 L
s
.86118 .26378 m
.85745 .26503 L
s
.87784 .28927 m
.87411 .2905 L
s
.89408 .3141 m
.89033 .31531 L
s
.92532 .36189 m
.92156 .36307 L
s
.94036 .3849 m
.9366 .38606 L
s
.95503 .40734 m
.95127 .40849 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03611 .26175 m
.04222 .25936 L
s
[(0.0025)] .02389 .26652 1 -0.39033 Mshowa
.02772 .3147 m
.03385 .31237 L
s
[(0.005)] .01546 .31936 1 -0.3804 Mshowa
.01904 .3695 m
.02519 .36722 L
s
[(0.0075)] .00673 .37405 1 -0.37009 Mshowa
.01004 .42625 m
.01622 .42403 L
s
[(0.01)] -0.0023 .43068 1 -0.35937 Mshowa
.00073 .48505 m
.00692 .48289 L
s
[(0.0125)] -0.01167 .48936 1 -0.34823 Mshowa
.125 Mabswid
.03446 .2722 m
.03813 .27077 L
s
.03279 .28271 m
.03646 .28129 L
s
.03111 .2933 m
.03479 .29189 L
s
.02942 .30396 m
.0331 .30256 L
s
.02601 .32551 m
.02969 .32411 L
s
.02428 .33639 m
.02797 .335 L
s
.02255 .34735 m
.02623 .34597 L
s
.0208 .35839 m
.02449 .35701 L
s
.01726 .38069 m
.02096 .37933 L
s
.01548 .39196 m
.01917 .39061 L
s
.01368 .40331 m
.01738 .40196 L
s
.01187 .41474 m
.01557 .4134 L
s
.00821 .43784 m
.01191 .43652 L
s
.00636 .44952 m
.01007 .4482 L
s
.00449 .46127 m
.00821 .45997 L
s
.00262 .47312 m
.00633 .47182 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.639 .589 .781 r
.29246 .57666 .39828 .79953 .68243 .72453 .57888 .48742 Metetra
.637 .588 .782 r
.57888 .48742 .68243 .72453 .99922 .6478 .89862 .39108 Metetra
.654 .668 .852 r
.17285 .41472 .29246 .57666 .57888 .48742 .46796 .31136 Metetra
.652 .668 .852 r
.46796 .31136 .57888 .48742 .89862 .39108 .79913 .1973 Metetra
.659 .704 .88 r
.03634 .26033 .17285 .41472 .46796 .31136 .34274 .14065 Metetra
.658 .703 .88 r
.34274 .14065 .46796 .31136 .79913 .1973 .68912 .00662 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(2)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(2.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(2.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(2.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(2.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(3)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000jB000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00aP3oool3000005L0oooo00350?ooo`050000003oool0oooo0?ooo`000000EP3oool00<T0
oooo00<000000?ooo`3oool0E03oool00<L0oooo0P00001G0?ooo`00b@3oool00`000000oooo0?oo
o`1D0?ooo`00a@3oool01@000000oooo0?ooo`3oool0000000D0oooo1@00001<0?ooo`00aP3oool3
000000L0oooo00@000000?ooo`3oool00000C03oool00=40oooo00<000000?ooo`3oool0C03oool0
0=80oooo00<000000?ooo`3oool0B`3oool00<l0oooo00D000000?ooo`3oool0oooo0000001<0?oo
o`00c`3oool01@000000oooo0?ooo`3oool0000004`0oooo003;0?ooo`8000000`3oool3000004d0
oooo00380?ooo`H00000DP3oool00<H0oooo0P0000030?ooo`<00000DP3oool009P0oooo1@000003
0?ooo`030000003oool0oooo0080oooo0`00000K0?ooo`<000000P3oool3000000040:Rch@000000
oooo00000540oooo002I0?ooo`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo
0000000G0?ooo`<0000000<0oooo0000003oool00P0000040:Rch@<00000D@3oool009X0oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000001D0oooo0P0000030?ooo`<00000
1P2X/n4010000000Z;?Q00000000001@0?ooo`00V`3oool00`000000oooo0?ooo`070?ooo`<00000
4`3oool300000080oooo0`0000090:Rch@050000002X/n4000000?ooo`000000C`3oool009P0oooo
00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`000000403oool20000
00<0oooo0P00000<0:Rch@030000002X/n40Z;?Q00800000C`3oool009P0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000003@3oool300000080oooo0`00000>
0:Rch@030000002X/n40Z;?Q00<00000CP3oool009T0oooo0`0000090?ooo`<00000303oool20000
00<0oooo0P00000A0:Rch@070000002X/n40Z;?Q0:Rch@000000oooo0000001=0?ooo`00/@3oool3
00000080oooo0`00000C0:Rch@030000002X/n40Z;?Q0080Z;?Q0P00001=0?ooo`00[P3oool30000
00030?ooo`0000000000008000005`2X/n401`000000Z;?Q0:Rch@2X/n4000000?ooo`000000C03o
ool00:`0oooo0P0000030?ooo`8000006P2X/n400`000000Z;?Q0:Rch@020:Rch@800000C03oool0
0:T0oooo0`0000020?ooo`<00000702X/n400`000000Z;?Q0:Rch@020:Rch@030000003oool00000
04/0oooo002W0?ooo`<000000P3oool2000001l0Z;?Q00<000000:Rch@2X/n400`2X/n400`000000
oooo0000001:0?ooo`00Y03oool300000080oooo0`00000Q0:Rch@030000002X/n40Z;?Q00@0Z;?Q
0P00001:0?ooo`00MP3oool5000000<0oooo00<000000?ooo`3oool00P3oool3000001`0oooo0P00
00020?ooo`<00000902X/n400`000000Z;?Q0:Rch@040:Rch@<00000B@3oool007L0oooo00@00000
0?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000001P0oooo0`0000020?ooo`800000
9`2X/n400`000000Z;?Q0:Rch@050:Rch@030000003oool0000004P0oooo001h0?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000E0?ooo`<000000P3oool3000002T0Z;?Q
00<000000:Rch@2X/n401@2X/n400`000000oooo000000180?ooo`00N@3oool00`000000oooo0?oo
o`060?ooo`@00000503oool2000000<0oooo0P00000/0:Rch@030000002X/n40Z;?Q00H0Z;?Q00<0
00000?ooo`000000A`3oool007H0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo0180oooo0`0000020?ooo`<00000;P2X/n400`000000Z;?Q0:Rch@070:Rch@030000003o
ool0000004H0oooo001f0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?oo
o`0?0?ooo`8000000P3oool300000340Z;?Q00<000000:Rch@2X/n401`2X/n400`000000oooo0000
00160?ooo`00M`3oool3000000X0oooo0P00000<0?ooo`<000000P3oool2000003@0Z;?Q00<00000
0:Rch@2X/n40202X/n400`000000oooo000000150?ooo`00T03oool200000080oooo0`00000f0:Rc
h@030000002X/n40Z;?Q00P0Z;?Q00@000000?ooo`0000000000A03oool008d0oooo0`000000103o
ool0000000000000000i0:Rch@030000002X/n40Z;?Q00T0Z;?Q00<000000?ooo`000000A03oool0
08X0oooo0`0000020?ooo`<00000>`2X/n400`000000Z;?Q0:Rch@0:0:Rch@030000003oool00000
00P0oooo0`00000h0?ooo`00R03oool200000080oooo0`00000n0:Rch@030000002X/n40Z;?Q00X0
Z;?Q00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0g0?ooo`00Q@3oool300000004
0?ooo`000000000000000440Z;?Q00<000000:Rch@2X/n402`2X/n400`000000oooo000000050?oo
o`D00000>03oool005H0oooo1@0000030?ooo`030000003oool0oooo00<0oooo0`00000L0?ooo`80
00000P3oool400000480Z;?Q00<000000:Rch@2X/n402`2X/n4010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000003T0oooo001G0?ooo`040000003oool0oooo000000X0oooo00<00000
0?ooo`3oool0603oool300000080oooo0P0000160:Rch@030000002X/n40Z;?Q00`0Z;?Q00@00000
0?ooo`3oool00000103oool00`000000oooo0000000i0?ooo`00F03oool00`000000oooo0?ooo`07
0?ooo`D000005P3oool3000000030?ooo`000000000000800000B@2X/n400`000000Z;?Q0:Rch@0<
0:Rch@040000003oool00000000000@0oooo0P00000i0?ooo`00F@3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000001D0oooo0P0000020?ooo`<00000C02X/n400`000000Z;?Q0:Rc
h@0<0:Rch@80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0g0?ooo`00EP3oool0
1@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000004P3oool300000080oooo0P00
001?0:Rch@030000002X/n40Z;?Q00d0Z;?Q00<000000?ooo`000000?`3oool005H0oooo00D00000
0?ooo`3oool0oooo000000090?ooo`800000403oool2000000030?ooo`000000000000800000D@2X
/n400`000000Z;?Q0:Rch@0=0:Rch@040000003oool0oooo000003h0oooo001G0?ooo`<000002`3o
ool00`000000oooo0?ooo`0;0?ooo`<000000P3oool2000005@0Z;?Q00<000000:Rch@2X/n403P2X
/n4010000000oooo0?ooo`00000m0?ooo`00L@3oool200000080oooo0`0000000`2X]>4000000:Rc
h@1C0:Rch@030000002X/n40Z;?Q00l0Z;?Q00<000000?ooo`000000?@3oool006h0oooo1`000005
0:Rdh@030000002X/n40Z;?Q0540Z;?Q00<000000:Rch@2X/n403`2X/n4010000000oooo0?ooo`00
000l0?ooo`00J`3oool300000080oooo0`0000080:Rdh@030000002X/n40Z;?Q0500Z;?Q00<00000
0:Rch@2X/n40402X/n4010000000oooo0?ooo`00000k0?ooo`00J@3oool2000000<0oooo0P00000<
0:Rdh@030000002X/n40Z;?Q04l0Z;?Q00<000000:Rch@2X/n40402X/n4010000000oooo00000000
000k0?ooo`00IP3oool4000000040?ooo`0000000000000000h0Z;CQ00<000000:Rch@2X/n40C`2X
/n400`000000Z;?Q0:Rch@0A0:Rch@040000003oool0oooo000003X0oooo000g0?ooo`D000000`3o
ool010000000oooo0?ooo`3oool5000001`0oooo0P0000020?ooo`<000004P2X]>400`000000Z;?Q
0:Rch@1>0:Rch@030000002X/n40Z;?Q0180Z;?Q00@000000?ooo`3oool00000>@3oool003P0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000I0?ooo`<000000P3oool20000
01H0Z;CQ00<000000:Rch@2X/n40C@2X/n400`000000Z;?Q0:Rch@0B0:Rch@040000003oool0oooo
000003T0oooo000i0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool20000
00030?ooo`000000000000800000602X]>400`000000Z;?Q0:Rch@1=0:Rch@030000002X/n40Z;?Q
01<0Z;?Q00@000000?ooo`3oool00000>03oool003X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0C0?ooo`<000000P3oool2000001`0Z;CQ00<000000:Rch@2X/n40C02X/n400`00
0000Z;?Q0:Rch@0C0:Rch@050000003oool0oooo0?ooo`000000=`3oool003L0oooo00D000000?oo
o`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000004@3oool300000080oooo0`00
000O0:Rdh@030000002X/n40Z;?Q04/0Z;?Q00<000000:Rch@2X/n40502X/n400`000000oooo0?oo
o`02000003H0oooo000g0?ooo`050000003oool0oooo0?ooo`0000001`3oool01@000000oooo0?oo
o`3oool0000000l0oooo0P0000020?ooo`<000008`2X]>400`000000Z;?Q0:Rch@1:0:Rch@030000
002X/n40Z;?Q01D0Z;?Q00@000000?ooo`3oool00000=P3oool003P0oooo0`0000090?ooo`<00000
3@3oool300000080oooo0`00000U0:Rdh@030000002X/n40Z;?Q04X0Z;?Q00<000000:Rch@2X/n40
5@2X/n401@000000oooo0?ooo`3oool0000003D0oooo001B0?ooo`8000000`3oool2000002T0Z;CQ
00<000000:Rch@2X/n40B@2X/n400`000000Z;?Q0:Rch@0E0:Rch@8000000P3oool00`000000oooo
0?ooo`0c0?ooo`00C`3oool300000080oooo0`00000/0:Rdh@030000002X/n40Z;?Q04P0Z;?Q00<0
00000:Rch@2X/n404P2X/n43000000030:J[fP000000oooo0080oooo00<000000?ooo`3oool0<P3o
ool004d0oooo0P0000020?ooo`<00000<02X]>400`000000Z;?Q0:Rch@170:Rch@030000002X/n40
Z;?Q00l0Z;?Q0`0000050:J[fP050000003oool0oooo0?ooo`000000<`3oool004X0oooo0`000002
0?ooo`800000<`2X]>400`000000Z;?Q0:Rch@180:Rch@030000002X/n40Z;?Q00/0Z;?Q0`000008
0:J[fP050000003oool0oooo0?ooo`000000<`3oool004L0oooo0`0000020?ooo`<00000=P2X]>40
0`000000Z;?Q0:Rch@170:Rch@030000002X/n40Z;?Q00P0Z;?Q0`00000<0:J[fP030000003oool0
oooo00800000<P3oool002L0oooo1@00000I0?ooo`8000000`3oool2000003X0Z;CQ00<000000:Rc
h@2X/n40AP2X/n400`000000Z;?Q0:Rch@050:Rch@<000003`2VZmX00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo0`00000X0?ooo`00:03oool010000000oooo0?ooo`00000F0?oo
o`<000000P3oool3000003d0Z;CQ00<000000:Rch@2X/n40A@2X/n400`000000Z;?Q0:Rch@020:Rc
h@<000004`2VZmX01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo0000
000W0?ooo`00:@3oool00`000000oooo0?ooo`0D0?ooo`8000000`3oool200000400Z;CQ00<00000
0:Rch@2X/n40A@2X/n400`000000Z;?Q0:Rch@02000001H0YZ_J00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000009`3oool002X0oooo00<00000
0?ooo`3oool0403oool300000080oooo0`0000130:Rdh@030000002X/n40Z;?Q04@0Z;?Q0`00000I
0:J[fP050000003oool0oooo0?ooo`000000103oool4000002P0oooo000W0?ooo`050000003oool0
oooo0?ooo`0000003`3oool300000080oooo0P0000170:Rdh@030000002X/n40Z;?Q0400Z;?Q1000
000K0:J[fP030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000[0?ooo`009`3o
ool01@000000oooo0?ooo`3oool0000000`0oooo0`0000020?ooo`<00000B@2X]>400`000000Z;?Q
0:Rch@0m0:Rch@<000000`2VZmX00`000000YZ_J0:J[fP0J0:J[fP030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo0000000Z0?ooo`00:03oool3000000X0oooo0`0000020?ooo`<00000
C@2X]>400`000000Z;?Q0:Rch@0i0:Rch@<000001P2VZmX00`000000YZ_J0:J[fP0J0:J[fP040000
003oool0oooo0?ooo`800000103oool2000002P0oooo000c0?ooo`80000000<0oooo000000000000
0P00001A0:Rdh@030000002X/n40Z;?Q03D0Z;?Q0`0000080:J[fP8000007@2VZmX00`000000oooo
0?ooo`020?ooo`030000003oool0oooo02/0oooo000`0?ooo`<000000P3oool3000005@0Z;CQ00<0
00000:Rch@2X/n40<@2X/n43000000P0YZ_J0`0000000`2VZmX000000:J[fP0L0:J[fP030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0:P3oool002l0oooo0P0000020?ooo`800000E`2X]>40
0`000000Z;?Q0:Rch@0_0:Rch@800000202VZmX3000000D0YZ_J00<000000:J[fP2VZmX06`2VZmX0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02X0oooo000_0?ooo`@00000FP2X]>400`00
0000Z;?Q0:Rch@0[0:Rch@<000001`2VZmX3000000T0YZ_J00<000000:J[fP2VZmX06P2VZmX00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo000_0?ooo`030000002X]>40Z;CQ05`0
Z;CQ00<000000:Rch@2X/n409`2X/n43000000L0YZ_J0`00000=0:J[fP030000002VZmX0YZ_J01X0
YZ_J00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`002P3oool2000000@0oooo
00<000000?ooo`3oool00`3oool2000000@0oooo0P0000020?ooo`D000000P3oool3000000D0oooo
00<000000:Rdh@2X]>40G@2X]>400`000000Z;?Q0:Rch@0S0:Rch@<000001`2VZmX300000100YZ_J
00<000000:J[fP2VZmX06P2VZmX00`000000oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo
00090?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?oo
o`3oool3000005h0Z;CQ00<000000:Rch@2X/n40802X/n43000000L0YZ_J0`00000D0:J[fP030000
002VZmX0YZ_J01X0YZ_J00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`002@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000Z;CQ0:Rdh@1L0:Rdh@030000002X/n40Z;?Q01`0Z;?Q0`0000080:J[fP800000602VZmX0
0`000000YZ_J0:J[fP0I0:J[fP030000003oool0oooo00@0oooo00<000000?ooo`3oool09P3oool0
00T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000:Rdh@2X]>40G02X]>400`000000Z;?Q0:Rch@0H0:Rch@<00000202VZmX3000001/0
YZ_J00<000000:J[fP2VZmX06@2VZmX00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0
oooo00090?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`0000040?ooo`8000000`3o
ool00`000000Z;CQ0:Rdh@1L0:Rdh@030000002X/n40Z;?Q01D0Z;?Q0P0000080:J[fP<000007P2V
ZmX00`000000YZ_J0:J[fP0I0:J[fP030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3o
ool000T0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo000000070?ooo`030000003oool0oooo
00<0oooo00<000000:Rdh@2X]>40F`2X]>400`000000Z;?Q0:Rch@0B0:Rch@<000001`2VZmX30000
0280YZ_J00<000000:J[fP2VZmX06@2VZmX00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02@0oooo000:0?ooo`8000002P3oool2000000@0oooo0P0000030?ooo`<000000P3oool5000000<0
oooo0P0000050?ooo`030000002X]>40Z;CQ05/0Z;CQ00<000000:Rch@2X/n403P2X/n43000000L0
YZ_J0`00000V0:J[fP030000002VZmX0YZ_J01P0YZ_J00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0T0?ooo`00;@3oool2000000L0oooo00<000000:Rdh@2X]>40F`2X]>400`000000Z;?Q
0:Rch@0:0:Rch@<000001`2VZmX3000002T0YZ_J00<000000:J[fP2VZmX06@2VZmX00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02<0oooo000]0?ooo`030000003oool0oooo00L0oooo00<0
00000:Rdh@2X]>40FP2X]>400`000000Z;?Q0:Rch@070:Rch@<000001`2VZmX3000002d0YZ_J00<0
00000:J[fP2VZmX0602VZmX00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo000]
0?ooo`800000203oool00`000000Z;CQ0:Rdh@1K0:Rdh@030000002X/n40Z;?Q00<0Z;?Q0`000007
0:J[fP<00000<@2VZmX00`000000YZ_J0:J[fP0G0:J[fP030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08P3oool002d0oooo00<000000?ooo`3oool0203oool00`000000Z;CQ0:Rdh@1K0:Rd
h@030000002X/n40000000800000202VZmX2000003D0YZ_J00<000000:J[fP2VZmX05`2VZmX00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo000]0?ooo`8000002P3oool00`000000
Z;CQ0:Rdh@1J0:Rdh@800000202VZmX3000003L0YZ_J00<000000:J[fP2VZmX05`2VZmX00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0240oooo000>0?ooo`800000103oool00`000000oooo
0?ooo`030?ooo`800000103oool2000000<0oooo0`0000050?ooo`030000003oool0oooo00X0oooo
00<000000:Rdh@2X]>40EP2X]>43000000030:N[fP000000YZ_J00@0YZ_J0`00000k0:J[fP030000
002VZmX0YZ_J01L0YZ_J00<000000?ooo`3oool0103oool2000000L0oooo0`00000H0?ooo`003@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3o
ool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool0
0`000000Z;CQ0:Rdh@1B0:Rdh@<000001@2WZmX00`000000YZ_J00000002000003l0YZ_J00<00000
0:J[fP2VZmX05P2VZmX00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000G0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool20000
00h0oooo00<000000:Rdh@2X]>40CP2X]>43000000L0Yj_J0`0000130:J[fP030000002VZmX0YZ_J
01H0YZ_J00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000005`3oool000d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000002X]>40Z;CQ04X0Z;CQ0`0000070:N[fP<000000P2WZmX00`000000YZ_J0:J[fP110:J[fP03
0000002VZmX0YZ_J01H0YZ_J00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`<0
0000603oool000d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0000003oool0100000040?ooo`030000003oool0oooo00l0oooo00<00000
0:Rdh@2X]>40AP2X]>43000000L0Yj_J0`0000060:N[fP030000002VZmX0YZ_J0440YZ_J00<00000
0:J[fP2VZmX05P2VZmX00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000`3o
ool00`000000oooo0?ooo`0E0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`8000004@3oool00`00
0000Z;CQ0:Rdh@130:Rdh@800000202WZmX2000000X0Yj_J00<000000:J[fP2VZmX0@@2VZmX00`00
0000YZ_J0:J[fP0E0:J[fP030000003oool0oooo00H0oooo0P0000020?ooo`050000003oool0oooo
0?ooo`0000005`3oool000h0oooo0P00000:0?ooo`800000103oool200000080oooo1@0000030?oo
o`030000003oool0oooo0140oooo00<000000:Rdh@2X]>40?`2X]>43000000L0Yj_J0`00000<0:N[
fP030000002VZmX0YZ_J0480YZ_J00<000000:J[fP2VZmX05@2VZmX00`000000oooo0?ooo`050?oo
o`8000000`3oool3000001P0oooo000/0?ooo`8000004P3oool00`000000Z;CQ0:Rdh@0l0:Rdh@<0
00001`2WZmX300000100Yj_J00<000000:J[fP2VZmX0@@2VZmX00`000000YZ_J0:J[fP0E0:J[fP03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool002/0oooo0P00000D0?ooo`030000
002X]>40Z;CQ03P0Z;CQ0`0000070:N[fP<000004`2WZmX00`000000YZ_J0:J[fP120:J[fP030000
002VZmX0YZ_J01D0YZ_J00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`00:`3o
ool00`000000oooo0?ooo`0D0?ooo`030000002X]>40Z;CQ03@0Z;CQ0`0000070:N[fP<000005`2W
ZmX00`000000YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J01@0YZ_J00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`00:`3oool2000001H0oooo00<000000:Rdh@2X]>40<02X]>43
000000L0Yj_J0`00000K0:N[fP030000002VZmX0YZ_J0440YZ_J00<000000:J[fP2VZmX05@2VZmX0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo000[0?ooo`030000003oool0oooo
01H0oooo00<000000:Rdh@2X]>40;02X]>43000000L0Yj_J0`00000N0:N[fP030000002VZmX0YZ_J
0480YZ_J00<000000:J[fP2VZmX0502VZmX00`000000oooo0?ooo`070?ooo`8000006P3oool002/0
oooo0P00000H0?ooo`030000002X]>40Z;CQ02T0Z;CQ0P0000070:N[fP<000008P2WZmX00`000000
YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J01@0YZ_J00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`0H0?ooo`030000002X]>40Z;CQ02D0Z;CQ
0`0000070:N[fP8000009P2WZmX00`000000YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J01<0YZ_J
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`001P3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`00
00040?ooo`030000003oool0oooo01X0oooo00<000000:Rdh@2X]>408@2X]>43000000L0Yj_J0`00
000X0:N[fP030000002VZmX0YZ_J0480YZ_J00<000000:J[fP2VZmX0502VZmX00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01L0oooo00050?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`3oool2000001`0oooo00<000000:Rdh@2X]>407@2X]>43
000000L0Yj_J0`00000/0:N[fP030000002VZmX0YZ_J0480YZ_J00<000000:J[fP2VZmX04`2VZmX0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00050?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000002X]>40Z;CQ01X0
Z;CQ0`0000070:N[fP<00000<02WZmX00`000000YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J01<0
YZ_J00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`001@3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000007P3oool00`000000Z;CQ0:Rd
h@0F0:Rdh@<000001`2WZmX3000003<0Yj_J00<000000:J[fP2VZmX0@`2VZmX00`000000YZ_J0:J[
fP0B0:J[fP030000003oool0oooo00P0oooo0P00000F0?ooo`001@3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool00`000000
oooo00000003000000@0oooo0P00000N0?ooo`030000002X]>40Z;CQ01<0Z;CQ0P0000070:N[fP<0
0000=`2WZmX00`000000YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J0140YZ_J0`00000:0?ooo`03
0000003oool0oooo01@0oooo00050?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`0000001`3o
ool00`000000oooo0?ooo`0N0?ooo`030000002X]>40Z;CQ00l0Z;CQ0`0000060:N[fP<00000>`2W
ZmX00`000000YZ_J0:J[fP120:J[fP030000002VZmX0YZ_J00d0YZ_J0`0000020:>Fb0030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0503oool000H0oooo0P00000:0?ooo`800000103oool2
00000080oooo1@0000000`3oool0000000000003000000<0oooo00<000000?ooo`3oool07`3oool0
0`000000Z;CQ0:Rdh@0;0:Rdh@<000001`2WZmX2000003h0Yj_J00<000000:J[fP2VZmX0@`2VZmX0
0`000000YZ_J0:J[fP090:J[fP<000001P2SU/P00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01<0oooo000Y0?ooo`8000008P3oool00`000000Z;CQ0:Rdh@070:Rdh@<000001`2WZmX30000
0440Yj_J00<000000:J[fP2VZmX0@`2VZmX00`000000YZ_J0:J[fP040:J[fP@000002@2SU/P00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000Y0?ooo`030000003oool0oooo0280
oooo00<000000:Rdh@2X]>400`2X]>43000000L0Yj_J0`0000140:N[fP030000002VZmX0YZ_J04<0
YZ_J00@000000:J[fP2VZmX0YZ_J0`00000=0:>Fb0030000003oool0oooo00T0oooo0P0000070?oo
o`<00000103oool2000000<0oooo000Y0?ooo`800000903oool00`000000Z;CQ00000002000000L0
Yj_J0`0000180:N[fP030000002VZmX0YZ_J04<0YZ_J0`00000A0:>Fb0030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
0080oooo000Y0?ooo`030000003oool0oooo02@0oooo00<000000:N[fP2WZmX01@2WZmX3000004`0
Yj_J00<000000:J[fP2VZmX0?`2VZmX3000000030:>Fb0000000XiK80140XiK800<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000P3oool002T0oooo00<000000?ooo`3oool0903oool00`000000Yj_J0:N[fP020:N[fP<0
0000C`2WZmX00`000000YZ_J0:J[fP0k0:J[fP@00000102SU/P00`000000XiK80:>Fb00A0:>Fb003
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo000Y0?ooo`8000009P3oool4000005<0Yj_J00<000000:J[fP2V
ZmX0=`2VZmX3000000T0XiK800<000000:>Fb02SU/P0402SU/P00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?oo
o`00403oool2000000@0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`0000040?ooo`80
00009P3oool3000005H0Yj_J00<000000:J[fP2VZmX0<`2VZmX3000000d0XiK800<000000:>Fb02S
U/P03`2SU/P00`000000oooo0?ooo`090?ooo`<00000103oool2000000@0oooo00@000000?ooo`3o
ool000000P3oool000l0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool3000000<0oooo00<00000
0:N[fP2WZmX0D`2WZmX00`000000YZ_J0:J[fP0_0:J[fP@000004@2SU/P00`000000XiK80:>Fb00?
0:>Fb0030000003oool0oooo00D0oooo0`0000000`3oool00000000000050?ooo`030000003oool0
oooo00<0oooo0P0000030?ooo`003`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool200000200oooo0`0000060?ooo`030000002W
ZmX0Yj_J05@0Yj_J00<000000:J[fP2VZmX0:`2VZmX3000001D0XiK800<000000:>Fb02SU/P03`2S
U/P00`000000oooo0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0>0?ooo`003`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0L0?ooo`<000002P3oool00`000000Yj_J0:N[fP1D0:N[fP030000
002VZmX0YZ_J02L0YZ_J0`00000I0:>Fb0030000002SU/P0XiK800l0XiK8100000080?ooo`030000
003oool0oooo00h0oooo000?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo0`00000>0?ooo`03
0000002WZmX0Yj_J05<0Yj_J00<000000:J[fP2VZmX08`2VZmX4000001d0XiK800<000000:>Fb02S
U/P03P2SU/P00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo000?0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool2000000D0oooo0P00000G0?oo
o`<000004P3oool00`000000Yj_J0:N[fP1C0:N[fP030000002VZmX0YZ_J01l0YZ_J0`00000R0:>F
b0030000002SU/P0XiK800d0XiK800<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?oo
o`00403oool2000000X0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0503oool3000001D0oooo00<000000:N[fP2WZmX0E02WZmX00`000000YZ_J0:J[fP0K0:J[fP<0
00009@2SU/P00`000000XiK80:>Fb00>0:>Fb0030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03@3oool002L0oooo00<000000?ooo`3oool04@3oool3000001T0oooo00<000000:N[fP2WZmX0
D`2WZmX00`000000YZ_J0:J[fP0G0:J[fP@00000:@2SU/P00`000000XiK80:>Fb00=0:>Fb0030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool002L0oooo0P00000@0?ooo`8000007@3o
ool00`000000Yj_J0:N[fP1C0:N[fP030000002VZmX0YZ_J01<0YZ_J0`00000^0:>Fb0030000002S
U/P0XiK800d0XiK800<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`009`3oool0
0`000000oooo0?ooo`0<0?ooo`<00000803oool00`000000Yj_J0:N[fP1B0:N[fP030000002VZmX0
YZ_J0100YZ_J0`00000b0:>Fb0030000002SU/P0XiK800`0XiK800<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0=0?ooo`009`3oool2000000X0oooo0`00000S0?ooo`030000002WZmX0Yj_J
05<0Yj_J00<000000:J[fP2VZmX0302VZmX3000003D0XiK800<000000:>Fb02SU/P0302SU/P00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo000W0?ooo`030000003oool0oooo00H0
oooo0`00000W0?ooo`030000002WZmX0Yj_J05<0Yj_J00<000000:J[fP2VZmX01`2VZmX4000003T0
XiK800<000000:>Fb02SU/P0302SU/P00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0
oooo000W0?ooo`030000003oool0oooo00<0oooo0`00000[0?ooo`030000002WZmX0Yj_J0580Yj_J
00<000000:J[fP2VZmX0102VZmX3000003h0XiK800<000000:>Fb02SU/P02`2SU/P00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00`0oooo000V0?ooo`<0000000@0oooo0000000000000000
;`3oool00`000000Yj_J0:N[fP1B0:N[fP030000002VZmX0YZ_J00<00000@P2SU/P00`000000XiK8
0:>Fb00;0:>Fb0030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00080oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`<000000P3oool500000080oooo0`00
00040?ooo`@00000<P3oool00`000000Yj_J0:N[fP1A0:N[fP@00000A@2SU/P00`000000XiK80:>F
b00;0:>Fb0030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool000050?ooo`000000
oooo0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo
00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo0?ooo`800000=@3oool0
0`000000Yj_J0:N[fP1=0:N[fP<000000P2SU/L00`000000XiK80:>Fb0150:>Fb0030000002SU/P0
XiK800X0XiK800<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`0000D0oooo0000
003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<`3o
ool00`000000Yj_J0:N[fP190:N[fP<000001P2SU/L00`000000XiK80:>Fb0150:>Fb0030000002S
U/P0XiK800X0XiK800<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
<`3oool00`000000Yj_J0:N[fP150:N[fP<000002@2SU/L00`000000XiK80:>Fb0150:>Fb0030000
002SU/P0XiK800X0XiK800<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`0000D0
oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0000000<00000203oool00`000000oooo0?ooo`0b0?oo
o`030000002WZmX0Yj_J0480Yj_J0`00000<0:>Fa`030000002SU/P0XiK804H0XiK800<000000:>F
b02SU/P02P2SU/P00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00001@3oool0
00000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool2000000<0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000`0oooo0P00000c0?ooo`030000002WZmX0Yj_J03h0Yj_J
0`00000@0:>Fa`030000002SU/P0XiK804H0XiK800<000000:>Fb02SU/P02@2SU/P00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00/0oooo00020?ooo`8000002P3oool2000000@0oooo00<0
00000?ooo`3oool00P3oool300000080oooo1@00000:0?ooo`030000003oool0oooo0340oooo00<0
00000:N[fP2WZmX0>P2WZmX3000001<0XiK700<000000:>Fb02SU/P0A`2SU/P00`000000XiK80:>F
b0080:>Fb0030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool002h0oooo00<00000
0?ooo`3oool0<03oool00`000000Yj_J0:N[fP0f0:N[fP@000005`2SU/L00`000000XiK80:>Fb016
0:>Fb0030000002SU/P0XiK800T0XiK800<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;
0?ooo`00;`3oool00`000000oooo0?ooo`0`0?ooo`030000002WZmX0Yj_J0380Yj_J0`00000K0:>F
a`030000002SU/P0XiK804L0XiK800<000000:>Fb02SU/P0202SU/P00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00/0oooo000`0?ooo`800000<@3oool00`000000Yj_J0:N[fP0^0:N[fP<0
00007`2SU/L00`000000XiK80:>Fb0170:>Fb0030000002SU/P0XiK800P0XiK800<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0;0?ooo`00<P3oool00`000000oooo0?ooo`0_0?ooo`030000
002WZmX0Yj_J02X0Yj_J0`00000R0:>Fa`030000002SU/P0XiK804P0XiK800<000000:>Fb02SU/P0
1`2SU/P00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000c0?ooo`030000003o
ool0oooo02h0oooo00<000000:N[fP2WZmX09`2WZmX3000002D0XiK700<000000:>Fb02SU/P0B02S
U/P00`000000XiK80:>Fb0080:>Fb0030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3o
ool003@0oooo00<000000?ooo`3oool0;P3oool00`000000Yj_J0:N[fP0S0:N[fP<00000:@2SU/L0
0`000000XiK80:>Fb0180:>Fb0030000002SU/P0XiK800L0XiK800<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0:0?ooo`00=@3oool2000002l0oooo00<000000:N[fP2WZmX07`2WZmX30000
02`0XiK700<000000:>Fb02SU/P0B@2SU/P00`000000XiK80:>Fb0060:>Fb0030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool003L0oooo00<000000?ooo`3oool0;@3oool00`000000
Yj_J0:N[fP0K0:N[fP<00000<02SU/L00`000000XiK80:>Fb0190:>Fb0030000002SU/P0XiK800H0
XiK800<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00>03oool00`000000oooo
0?ooo`0/0?ooo`030000002WZmX0Yj_J01L0Yj_J1000000c0:>Fa`030000002SU/P0XiK804T0XiK8
00<000000:>Fb02SU/P01P2SU/P00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
000i0?ooo`030000003oool0oooo02`0oooo00<000000:N[fP2WZmX04`2WZmX3000003P0XiK700<0
00000:>Fb02SU/P0B@2SU/P00`000000XiK80:>Fb0060:>Fb0030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool003X0oooo0P00000]0?ooo`030000002WZmX0Yj_J00l0Yj_J0`00000k
0:>Fa`030000002SU/P0XiK804X0XiK800<000000:>Fb02SU/P01@2SU/P00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00T0oooo000l0?ooo`030000003oool0oooo02/0oooo00<000000:N[
fP2WZmX02`2WZmX3000003h0XiK700<000000:>Fb02SU/P0BP2SU/P00`000000XiK80:>Fb0050:>F
b0030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool003d0oooo00<000000?ooo`3o
ool0:P3oool00`000000Yj_J0:N[fP080:N[fP<00000@P2SU/L00`000000XiK80:>Fb01:0:>Fb003
0000002SU/P0XiK800D0XiK800<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00
?P3oool00`000000oooo0?ooo`0Z0?ooo`030000002WZmX0Yj_J00@0Yj_J0`0000150:>Fa`030000
002SU/P0XiK804/0XiK800<000000:>Fb02SU/P0102SU/P00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo000o0?ooo`800000:`3oool00`000000Yj_J0:N[fP03000004T0XiK700<0
00000:>Fb02SU/P0B`2SU/P00`000000XiK80:>Fb0040:>Fb0050000003oool0oooo0?ooo`000000
2`3oool00440oooo00<000000?ooo`3oool0:@3oool2000004`0XiK700<000000:>Fb02SU/P0B`2S
U/P00`000000XiK80:>Fb0040:>Fb0050000003oool0oooo0?ooo`0000002`3oool00480oooo00<0
00000?ooo`3oool0:03oool00`000000XiK70:>Fa`1;0:>Fa`030000002SU/P0XiK804`0XiK800<0
00000:>Fb02SU/P00`2SU/P01@000000oooo0?ooo`3oool0000000/0oooo00130?ooo`030000003o
ool0oooo02P0oooo00<000000:>Fa`2SU/L0B`2SU/L00`000000XiK80:>Fb01<0:>Fb0030000002S
U/P0XiK800<0XiK800D000000?ooo`3oool0oooo0000000:0?ooo`00A03oool2000002P0oooo00<0
00000:>Fa`2SU/L0B`2SU/L00`000000XiK80:>Fb01=0:>Fb0030000002SU/P0XiK80080XiK800D0
00000?ooo`3oool0oooo0000000:0?ooo`00AP3oool00`000000oooo0?ooo`0V0?ooo`030000002S
U/L0XiK704/0XiK700<000000:>Fb02SU/P0C02SU/P00`000000XiK80:>Fb0030:>Fb0040000003o
ool0oooo000000X0oooo00170?ooo`030000003oool0oooo02D0oooo00<000000:>Fa`2SU/L0B`2S
U/L00`000000XiK80:>Fb01=0:>Fb0030000002SU/P0XiK80080XiK800@000000?ooo`3oool00000
2P3oool004P0oooo00<000000?ooo`3oool09@3oool00`000000XiK70:>Fa`1;0:>Fa`030000002S
U/P0XiK804d0XiK800D000000:>Fb02SU/P0XiK8000000020?ooo`030000003oool0oooo00P0oooo
00190?ooo`8000009@3oool00`000000XiK70:>Fa`1;0:>Fa`030000002SU/P0XiK804h0XiK800L0
00000:>Fb02SU/P0XiK80000003oool0000000X0oooo001;0?ooo`030000003oool0oooo02<0oooo
00<000000:>Fa`2SU/L0BP2SU/L00`000000XiK80:>Fb01>0:>Fb0070000002SU/P0XiK80:>Fb000
0000oooo0000000:0?ooo`00C03oool00`000000oooo0?ooo`0R0?ooo`030000002SU/L0XiK704/0
XiK700<000000:>Fb02SU/P0CP2SU/P01`000000XiK80:>Fb02SU/P000000?ooo`0000002@3oool0
04d0oooo00<000000?ooo`3oool08@3oool00`000000XiK70:>Fa`1;0:>Fa`030000002SU/P0XiK8
04l0XiK800H000000:>Fb02SU/P000000?ooo`0000090?ooo`00CP3oool200000280oooo00<00000
0:>Fa`2SU/L0B`2SU/L00`000000XiK80:>Fb01>0:>Fb0060000002SU/P0XiK80000003oool00000
2@3oool00500oooo00<000000?ooo`3oool07`3oool00`000000XiK70:>Fa`1;0:>Fa`030000002S
U/P0XiK804l0XiK800<000000:>Fb02SU/P00P0000090?ooo`00D@3oool00`000000oooo0?ooo`0O
0?ooo`030000002SU/L0XiK704/0XiK700<000000:>Fb02SU/P0C`2SU/P010000000XiK800000000
00090?ooo`00DP3oool00`000000oooo0?ooo`0N0?ooo`030000002SU/L0XiK704/0XiK700<00000
0:>Fb02SU/P0D02SU/P00`000000XiK8000000090?ooo`00D`3oool2000001l0oooo00<000000:>F
a`2SU/L0BP2SU/L00`000000XiK80:>Fb01@0:>Fb0030000002SU/P0000000T0oooo001E0?ooo`03
0000003oool0oooo01`0oooo00<000000:>Fa`2SU/L0B`2SU/L00`000000XiK80:>Fb01@0:>Fb0<0
0000203oool005H0oooo00<000000?ooo`3oool0703oool00`000000XiK70:>Fa`1:0:>Fa`030000
002SU/P0XiK80500XiK80`0000080?ooo`00E`3oool00`000000oooo0?ooo`0K0?ooo`030000002S
U/L0XiK704/0XiK700<000000:>Fb02SU/P0B`2SU/P7000000P0oooo001H0?ooo`030000003oool0
oooo01/0oooo00<000000:>Fa`2SU/L0BP2SU/L00`000000XiK80:>Fb0160:>Fb0T000002`3oool0
05T0oooo0P00000K0?ooo`030000002SU/L0XiK704X0XiK700<000000:>Fb02SU/P0@P2SU/P40000
00030?ooo`0000000000008000003`3oool005/0oooo00<000000?ooo`3oool06@3oool00`000000
XiK70:>Fa`1:0:>Fa`030000002SU/P0XiK803d0XiK8100000020?ooo`<000004`3oool005`0oooo
00<000000?ooo`3oool0603oool00`000000XiK70:>Fa`1:0:>Fa`030000002SU/P0XiK803P0XiK8
1@0000020?ooo`@000005P3oool005d0oooo00<000000?ooo`3oool0603oool00`000000XiK70:>F
a`1:0:>Fa`030000002SU/P0XiK803<0XiK8100000030?ooo`@000006P3oool005h0oooo0P00000H
0?ooo`030000002SU/L0XiK704X0XiK700<000000:>Fb02SU/P0;`2SU/P4000000<0oooo1000000N
0?ooo`00H03oool00`000000oooo0?ooo`0F0?ooo`030000002SU/L0XiK704X0XiK700<000000:>F
b02SU/P0:P2SU/P4000000<0oooo1000000R0?ooo`00H@3oool00`000000oooo0?ooo`0E0?ooo`03
0000002SU/L0XiK704X0XiK700<000000:>Fb02SU/P09@2SU/P5000000@0oooo0`00000V0?ooo`00
HP3oool00`000000oooo0?ooo`0E0?ooo`030000002SU/L0XiK704T0XiK700<000000:>Fb02SU/P0
8@2SU/P4000000D0oooo1000000Y0?ooo`00H`3oool2000001D0oooo00<000000:>Fa`2SU/L0BP2S
U/L00`000000XiK80:>Fb00L0:>Fb0@000001@3oool4000002d0oooo001U0?ooo`030000003oool0
oooo0180oooo00<000000:>Fa`2SU/L0BP2SU/L00`000000XiK80:>Fb00H0:>Fb0@000001@3oool4
00000340oooo001V0?ooo`030000003oool0oooo0180oooo00<000000:>Fa`2SU/L0BP2SU/L00`00
0000XiK80:>Fb00B0:>Fb0D000001@3oool4000003D0oooo001W0?ooo`030000003oool0oooo0140
oooo00<000000:>Fa`2SU/L0BP2SU/L00`000000XiK80:>Fb00>0:>Fb0@000001P3oool4000003T0
oooo001X0?ooo`8000004P3oool00`000000XiK70:>Fa`1:0:>Fa`030000002SU/P0XiK800T0XiK8
100000070?ooo`<00000?@3oool006X0oooo00<000000?ooo`3oool03`3oool00`000000XiK70:>F
a`1:0:>Fa`030000002SU/P0XiK800@0XiK81@0000070?ooo`@00000@03oool006/0oooo00<00000
0?ooo`3oool03`3oool00`000000XiK70:>Fa`190:>Fa`030000002SU/P0XiK800@00000203oool4
000004@0oooo001/0?ooo`030000003oool0oooo00h0oooo00<000000:>Fa`2SU/L0B02SU/L40000
00P0oooo100000180?ooo`00K@3oool2000000l0oooo00<000000:>Fa`2SU/L0@`2SU/L4000000P0
oooo1000001<0?ooo`00K`3oool00`000000oooo0?ooo`0<0?ooo`030000002SU/L0XiK70400XiK7
0`0000090?ooo`<00000D03oool00700oooo00<000000?ooo`3oool0303oool00`000000XiK70:>F
a`0k0:>Fa`@00000203oool4000005<0oooo001a0?ooo`030000003oool0oooo00/0oooo00<00000
0:>Fa`2SU/L0=`2SU/L4000000P0oooo1000001G0?ooo`00LP3oool2000000`0oooo00<000000:>F
a`2SU/L0<P2SU/L4000000P0oooo1000001K0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`03
0000002SU/L0XiK702h0XiK7100000080?ooo`@00000G`3oool007D0oooo00<000000?ooo`3oool0
2@3oool00`000000XiK70:>Fa`0Z0:>Fa`<000002@3oool3000006<0oooo001f0?ooo`030000003o
ool0oooo00P0oooo00<000000:>Fa`2SU/L09P2SU/L4000000P0oooo1000001V0?ooo`00M`3oool2
000000T0oooo00<000000:>Fa`2SU/L08@2SU/L4000000P0oooo1000001Z0?ooo`00N@3oool00`00
0000oooo0?ooo`060?ooo`030000002SU/L0XiK701d0XiK7100000080?ooo`@00000KP3oool007X0
oooo00<000000?ooo`3oool01@3oool00`000000XiK70:>Fa`0J0:>Fa`<00000203oool400000780
oooo001k0?ooo`030000003oool0oooo00D0oooo00<000000:>Fa`2SU/L05@2SU/L4000000L0oooo
1000001f0?ooo`00O03oool2000000D0oooo00<000000:>Fa`2SU/L04@2SU/L4000000P0oooo0`00
001j0?ooo`00OP3oool00`000000oooo0?ooo`030?ooo`030000002SU/L0XiK700`0XiK710000008
0?ooo`@00000O@3oool007l0oooo00<000000?ooo`3oool00P3oool00`000000XiK70:>Fa`080:>F
a`@00000203oool400000840oooo00200?ooo`030000003oool0oooo0080oooo00<000000:>Fa`2S
U/L0102SU/L3000000P0oooo100000250?ooo`00P@3oool200000080oooo00<000000:>Fa`2SU/L0
100000070?ooo`@00000R@3oool008<0oooo00<000000?ooo`3oool00P0000080?ooo`<00000S@3o
ool008@0oooo00<000000?ooo`0000001@3oool400000900oooo00250?ooo`80000000<0oooo0000
000000000P00002D0?ooo`00QP3oool2000009P0oooo003o0?ooob40oooo003o0?ooob40oooo003o
0?ooob40oooo003o0?ooob40oooo001V0?ooo`<00000>P3oool3000007X0oooo001W0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0M`3oool004T0oooo0`0000030?ooo`<000000P3o
ool2000000030?ooo`000000000000<0oooo0P0000040?ooo`80000000<0oooo0000003oool00`00
00030?ooo`<000000P3oool500000080oooo0`00000:0?ooo`040000003oool0oooo0?ooo`@00000
203oool4000000<0oooo0`0000030?ooo`@0000000H0oooo0000003oool000000?ooo`0000080?oo
o`@0000000D0oooo00000000000000000?ooo`02000000030?ooo`0000000000008000002@3oool2
000000@0oooo0P0000000`3oool0000000000002000000<0oooo0`0000040?ooo`<000000P3oool3
000000030?ooo`00000000000080oooo0P00000/0?ooo`00B@3oool01P000000oooo0?ooo`000000
oooo000000H0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo000000050?ooo`0;0000003oool0oooo0?ooo`000000
oooo0000003oool000000?ooo`0000001`3oool010000000oooo0?ooo`0000030?ooo`060000003o
ool0oooo0000003oool000000P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000002/0oooo001<0?ooo`030000003oool0000000@000000`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`D00000203oool0
0`000000oooo000000030?ooo`<000002@3oool300000080oooo1@0000000`3oool000000?ooo`02
0?ooo`070000003oool000000?ooo`000000oooo000000080?ooo`<000000`3oool01P000000oooo
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`D000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02`0oooo001:
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000P0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00L000000?ooo`00
0000oooo0000003oool0000000L0oooo00@000000?ooo`3oool000000`3oool01P000000oooo0?oo
o`000000oooo00000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo0P0000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0/0?ooo`00B@3oool0
0`000000oooo0?ooo`030?ooo`<000000P3oool2000000040?ooo`00000000000?ooo`@000000P3o
ool2000000040?ooo`00000000000?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3oool0
0P3oool3000000P0oooo0P0000000`3oool00000000000020?ooo`@00000203oool400000080oooo
0`0000030?ooo`L0000000<0oooo0000003oool0203oool2000000<0oooo100000030?ooo`<00000
203oool00`000000oooo0?ooo`030?ooo`80000000@0oooo000000000000oooo0P000000103oool0
00000000003oool2000000030?ooo`00000000000080oooo0`0000020?ooo`@000000P3oool40000
02`0oooo00190?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000803oool0
0`000000oooo0?ooo`0/0?ooo`00BP3oool3000000h0oooo00<000000?ooo`3oool0503oool30000
04d0oooo0P00000:0?ooo`<00000803oool00`000000oooo0?ooo`0/0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {232.562, 0}} -> {-0.153688, -0.00275213, \
0.00396018, 0.00396018}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowSize->{740, 647},
WindowMargins->{{96, Automatic}, {Automatic, 16}},
ShowCellLabel->False,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
0@00D01804P000000]X2:?oQon82n@96D005:0?l0040D01804P000000]X2:000
0000I0000000000000000BL?00400@00000000000000000B0002I0000aP00000
8W800@0100<00P0000000000oS`10000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 111, 4, 84, "Title"],
Cell[1831, 55, 63, 3, 54, "Text"],
Cell[1897, 60, 354, 8, 126, "Text"],

Cell[CellGroupData[{
Cell[2276, 72, 33, 0, 53, "Section"],
Cell[2312, 74, 1604, 23, 238, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3953, 102, 33, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[4011, 106, 42, 1, 47, "Input"],
Cell[4056, 109, 220, 4, 22, "Print"],
Cell[4279, 115, 121, 2, 37, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[4449, 123, 42, 0, 33, "Section"],
Cell[4494, 125, 131, 4, 54, "Text"],
Cell[4628, 131, 2506, 42, 719, "Input"],

Cell[CellGroupData[{
Cell[7159, 177, 1219, 23, 159, "Input"],
Cell[8381, 202, 245, 4, 61, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8675, 212, 39, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[8739, 216, 110, 2, 63, "Input"],
Cell[8852, 220, 256112, 10100, 296, 183443, 9198, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[264979, 10323, 54, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[265070, 10329, 45, 0, 33, "Section"],
Cell[265118, 10331, 127, 3, 26, "Text"],

Cell[CellGroupData[{
Cell[265270, 10338, 170, 2, 63, "Input"],
Cell[265443, 10342, 22801, 504, 186, 3625, 263, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[288281, 10851, 198, 5, 63, "Input"],
Cell[288482, 10858, 27988, 739, 186, 8356, 492, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[316519, 11603, 57, 0, 33, "Section"],
Cell[316579, 11605, 185, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[316789, 11613, 1198, 23, 191, "Input"],
Cell[317990, 11638, 1618, 28, 166, "Output"],
Cell[319611, 11668, 214, 3, 46, "Output"],
Cell[319828, 11673, 24687, 602, 186, 4239, 345, "GraphicsData", "PostScript", \
"Graphics"],
Cell[344518, 12277, 130, 3, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[344697, 12286, 54, 0, 33, "Section"],
Cell[344754, 12288, 174, 3, 26, "Text"],

Cell[CellGroupData[{
Cell[344953, 12295, 1311, 26, 207, "Input"],
Cell[346267, 12323, 938, 16, 121, "Output"],
Cell[347208, 12341, 135, 2, 46, "Output"],
Cell[347346, 12345, 22719, 650, 186, 5168, 429, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[370114, 13001, 75, 0, 33, "Section"],
Cell[370192, 13003, 234, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[370451, 13011, 1935, 37, 447, "Input"],
Cell[372389, 13050, 8391, 173, 281, "Output"],
Cell[380783, 13225, 559, 12, 89, "Output"],

Cell[CellGroupData[{
Cell[381367, 13241, 34296, 851, 296, 6456, 503, "GraphicsData", "PostScript", \
"Graphics"],
Cell[415666, 14094, 45345, 962, 242, 7660, 492, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

